#!/usr/bin/env python
#Time-stamp: <2007-01-28 19:53:24 poser>
#Identify contents of file byte by byte
#
# Copyright (C) 2004-2007 William J. Poser
#         
# Author: Bill Poser (billposer@alum.mit.edu)
#
#Permission is hereby granted, free of charge, to any person obtaining
#a copy of this software and associated documentation files (the
#"Software"), to deal in the Software without restriction, including
#without limitation the rights to use, copy, modify, merge, publish,
#distribute, sublicense, and/or sell copies of the Software, and to
#permit persons to whom the Software is furnished to do so, subject to
#the following conditions:

#The above copyright notice and this permission notice shall be
#included in all copies or substantial portions of the Software.

#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
#EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
#MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
#NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
#LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
#OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
#WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import sys
import os
import getopt

#Buckwalter transliteration of Arabic
buckwalterxtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"Unused",
0x21	:"Unused",
0x22	:"Unused",
0x23	:"Unused",
0x24	:"shiin			 U+0634",
0x25	:"Unused",
0x26	:"hamza-on-waaw		 U+0624",
0x27	:"hamza-on-the-line	 U+0621",
0x28	:"Unused",
0x29	:"Unused",
0x2A	:"Unused",
0x2B	:"Unused",
0x2C	:"Unused",
0x2D	:"Unused",
0x2E	:"Unused",
0x2F	:"Unused",
0x30	:"Unused",
0x31	:"Unused",
0x32	:"Unused",
0x33	:"Unused",
0x34	:"Unused",
0x35	:"Unused",
0x36	:"Unused",
0x37	:"Unused",
0x38	:"Unused",
0x39	:"Unused",
0x3A	:"Unused",
0x3B	:"Unused",
0x3C	:"hamza-under-'alif	 U+0625",
0x3D	:"Unused",
0x3E	:"hamza-on-'alif		 U+0623",
0x3F	:"Unused",
0x40	:"Unused",
0x41	:"bare 'alif		 U+0627",
0x42	:"Unused",
0x43	:"Unused",
0x44	:"Daad			 U+0636",
0x45	:"cayn			 U+0639",
0x46	:"fatHatayn		 U+064B",
0x47	:"gaf			 U+06AF",
0x48	:"Haa'			 U+062D",
0x49	:"Unused",
0x4A	:"tcheh			 U+0686",
0x4B	:"kasratayn		 U+064D",
0x4C	:"Unused",
0x4D	:"Unused",
0x4E	:"Dammatayn		 U+064C",
0x4F	:"Unused",
0x50	:"peh			 U+067E",
0x51	:"Unused",
0x52	:"Unused",
0x53	:"Saad			 U+0635",
0x54	:"Taa'			 U+0637",
0x55	:"Unused",
0x56	:"veh			 U+06A4",
0x57	:"Unused",
0x58	:"Unused",
0x59	:"'alif maqSuura		 U+0649",
0x5A	:"Zaa' (DHaa')		 U+0638",
0x5B	:"Unused",
0x5C	:"Unused",
0x5D	:"Unused",
0x5E	:"Unused",
0x5F	:"taTwiil			 U+0640",
0x60	:"dagger 'alif		 U+0670",
0x61	:"fatHa			 U+064E",
0x62	:"baa'			 U+0628",
0x63	:"Unused",
0x64	:"daal			 U+062F",
0x65	:"Unused",
0x66	:"faa'			 U+0641",
0x67	:"ghayn			 U+063A",
0x68	:"haa'			 U+0647",
0x69	:"kasra			 U+0650",
0x6A	:"jiim			 U+062C",
0x6B	:"kaaf			 U+0643",
0x6C	:"laam			 U+0644",
0x6D	:"miim			 U+0645",
0x6E	:"nuun			 U+0646",
0x6F	:"sukuun			 U+0652",
0x70	:"taa' marbuuTa		 U+0629",
0x71	:"qaaf			 U+0642",
0x72	:"raa'			 U+0631",
0x73	:"siin			 U+0633",
0x74	:"taa'			 U+062A",
0x75	:"Damma			 U+064F",
0x76	:"thaa'			 U+062B",
0x77	:"waaw			 U+0648",
0x78	:"khaa'			 U+062E",
0x79	:"yaa'			 U+064A",
0x7A	:"zaay			 U+0632",
0x7B	:"waSla			 U+0671",
0x7C	:"madda			 U+0622",
0x7D	:"hamza-on-yaa'		 U+0626",
0x7E	:"shaddah			 U+0651",
0x7F	:"Unused",
0x80	:"Unused",
0x81	:"Unused",
0x82	:"Unused",
0x83	:"Unused",
0x84	:"Unused",
0x85	:"Unused",
0x86	:"Unused",
0x87	:"Unused",
0x88	:"Unused",
0x89	:"Unused",
0x8A	:"Unused",
0x8B	:"Unused",
0x8C	:"Unused",
0x8D	:"Unused",
0x8E	:"Unused",
0x8F	:"Unused",
0x90	:"Unused",
0x91	:"Unused",
0x92	:"Unused",
0x93	:"Unused",
0x94	:"Unused",
0x95	:"Unused",
0x96	:"Unused",
0x97	:"Unused",
0x98	:"Unused",
0x99	:"Unused",
0x9A	:"Unused",
0x9B	:"Unused",
0x9C	:"Unused",
0x9D	:"Unused",
0x9E	:"Unused",
0x9F	:"Unused",
0xA0	:"Unused",
0xA1	:"Unused",
0xA2	:"Unused",
0xA3	:"Unused",
0xA4	:"Unused",
0xA5	:"Unused",
0xA6	:"Unused",
0xA7	:"Unused",
0xA8	:"Unused",
0xA9	:"Unused",
0xAA	:"Unused",
0xAB	:"Unused",
0xAC	:"Unused",
0xAD	:"Unused",
0xAE	:"Unused",
0xAF	:"Unused",
0xB0	:"Unused",
0xB1	:"Unused",
0xB2	:"Unused",
0xB3	:"Unused",
0xB4	:"Unused",
0xB5	:"Unused",
0xB6	:"Unused",
0xB7	:"Unused",
0xB8	:"Unused",
0xB9	:"Unused",
0xBA	:"Unused",
0xBB	:"Unused",
0xBC	:"Unused",
0xBD	:"Unused",
0xBE	:"Unused",
0xBF	:"Unused",
0xC0	:"Unused",
0xC1	:"Unused",
0xC2	:"Unused",
0xC3	:"Unused",
0xC4	:"Unused",
0xC5	:"Unused",
0xC6	:"Unused",
0xC7	:"Unused",
0xC8	:"Unused",
0xC9	:"Unused",
0xCA	:"Unused",
0xCB	:"Unused",
0xCC	:"Unused",
0xCD	:"Unused",
0xCE	:"Unused",
0xCF	:"Unused",
0xD0	:"Unused",
0xD1	:"Unused",
0xD2	:"Unused",
0xD3	:"Unused",
0xD4	:"Unused",
0xD5	:"Unused",
0xD6	:"Unused",
0xD7	:"Unused",
0xD8	:"Unused",
0xD9	:"Unused",
0xDA	:"Unused",
0xDB	:"Unused",
0xDC	:"Unused",
0xDD	:"Unused",
0xDE	:"Unused",
0xDF	:"Unused",
0xE0	:"Unused",
0xE1	:"Unused",
0xE2	:"Unused",
0xE3	:"Unused",
0xE4	:"Unused",
0xE5	:"Unused",
0xE6	:"Unused",
0xE7	:"Unused",
0xE8	:"Unused",
0xE9	:"Unused",
0xEA	:"Unused",
0xEB	:"Unused",
0xEC	:"Unused",
0xED	:"Unused",
0xEE	:"Unused",
0xEF	:"Unused",
0xF0	:"Unused",
0xF1	:"Unused",
0xF2	:"Unused",
0xF3	:"Unused",
0xF4	:"Unused",
0xF5	:"Unused",
0xF6	:"Unused",
0xF7	:"Unused",
0xF8	:"Unused",
0xF9	:"Unused",
0xFA	:"Unused",
0xFB	:"Unused",
0xFC	:"Unused",
0xFD	:"Unused",
0xFE	:"Unused",
0xFF	:"Unused"
}

#MS DOS CP437 - the original IBM PC encoding
msd437xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"latin capital letter a (U+0041)",
0x42	:"latin capital letter b (U+0042)",
0x43	:"latin capital letter c (U+0043)",
0x44	:"latin capital letter d (U+0044)",
0x45	:"latin capital letter e (U+0045)",
0x46	:"latin capital letter f (U+0046)",
0x47	:"latin capital letter g (U+0047)",
0x48	:"latin capital letter h (U+0048)",
0x49	:"latin capital letter i (U+0049)",
0x4A	:"latin capital letter j (U+004A)",
0x4B	:"latin capital letter k (U+004B)",
0x4C	:"latin capital letter l (U+004C)",
0x4D	:"latin capital letter m (U+004D)",
0x4E	:"latin capital letter n (U+004E)",
0x4F	:"latin capital letter o (U+004F)",
0x50	:"latin capital letter p (U+0050)",
0x51	:"latin capital letter q (U+0051)",
0x52	:"latin capital letter r (U+0052)",
0x53	:"latin capital letter s (U+0053)",
0x54	:"latin capital letter t (U+0054)",
0x55	:"latin capital letter u (U+0055)",
0x56	:"latin capital letter v (U+0056)",
0x57	:"latin capital letter w (U+0057)",
0x58	:"latin capital letter x (U+0058)",
0x59	:"latin capital letter y (U+0059)",
0x5A	:"latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"latin small letter a (U+0061)",
0x62	:"latin small letter b (U+0062)",
0x63	:"latin small letter c (U+0063)",
0x64	:"latin small letter d (U+0064)",
0x65	:"latin small letter e (U+0065)",
0x66	:"latin small letter f (U+0066)",
0x67	:"latin small letter g (U+0067)",
0x68	:"latin small letter h (U+0068)",
0x69	:"latin small letter i (U+0069)",
0x6A	:"latin small letter j (U+006A)",
0x6B	:"latin small letter k (U+006B)",
0x6C	:"latin small letter l (U+006C)",
0x6D	:"latin small letter m (U+006D)",
0x6E	:"latin small letter n (U+006E)",
0x6F	:"latin small letter o (U+006F)",
0x70	:"latin small letter p (U+0070)",
0x71	:"latin small letter q (U+0071)",
0x72	:"latin small letter r (U+0072)",
0x73	:"latin small letter s (U+0073)",
0x74	:"latin small letter t (U+0074)",
0x75	:"latin small letter u (U+0075)",
0x76	:"latin small letter v (U+0076)",
0x77	:"latin small letter w (U+0077)",
0x78	:"latin small letter x (U+0078)",
0x79	:"latin small letter y (U+0079)",
0x7A	:"latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"latin capital letter c with cedilla (U+00C7)",
0x81	:"latin small letter u with diaeresis (U+00FC)",
0x82	:"latin small letter e with acute (U+00E9)",
0x83	:"latin small letter a with circumflex (U+00E2)",
0x84	:"latin small letter a with diaeresis (U+00E4)",
0x85	:"latin small letter a with grave (U+00E0)",
0x86	:"latin small letter a with ring above (U+00E5)",
0x87	:"latin small letter c with cedilla (U+00E7)",
0x88	:"latin small letter e with circumflex (U+00EA)",
0x89	:"latin small letter e with diaeresis (U+00EB)",
0x8A	:"latin small letter e with grave (U+00E8)",
0x8B	:"latin small letter i with diaeresis (U+00EF)",
0x8C	:"latin small letter i with circumflex (U+00EE)",
0x8D	:"latin small letter i with grave (U+00EC)",
0x8E	:"latin capital letter a with diaeresis (U+00C4)",
0x8F	:"latin capital letter a with ring above (U+00C5)",
0x90	:"latin capital letter e with acute (U+00C9)",
0x91	:"latin small ligature ae (U+00E6)",
0x92	:"latin capital ligature ae (U+00C6)",
0x93	:"latin small letter o with circumflex (U+00F4)",
0x94	:"latin small letter o with diaeresis (U+00F6)",
0x95	:"latin small letter o with grave (U+00F2)",
0x96	:"latin small letter u with circumflex (U+00FB)",
0x97	:"latin small letter u with grave (U+00F9)",
0x98	:"latin small letter y with diaeresis (U+00FF)",
0x99	:"latin capital letter o with diaeresis (U+00D6)",
0x9A	:"latin capital letter u with diaeresis (U+00DC)",
0x9B	:"cent sign (U+00A2)",
0x9C	:"pound sign (U+00A3)",
0x9D	:"yen sign (U+00A5)",
0x9E	:"peseta sign (U+20A7)",
0x9F	:"latin small letter f with hook (U+0192)",
0xA0	:"latin small letter a with acute (U+00E1)",
0xA1	:"latin small letter i with acute (U+00ED)",
0xA2	:"latin small letter o with acute (U+00F3)",
0xA3	:"latin small letter u with acute (U+00FA)",
0xA4	:"latin small letter n with tilde (U+00F1)",
0xA5	:"latin capital letter n with tilde (U+00D1)",
0xA6	:"feminine ordinal indicator (U+00AA)",
0xA7	:"masculine ordinal indicator (U+00BA)",
0xA8	:"inverted question mark (U+00BF)",
0xA9	:"reversed not sign (U+2310)",
0xAA	:"not sign (U+00AC)",
0xAB	:"vulgar fraction one half (U+00BD)",
0xAC	:"vulgar fraction one quarter (U+00BC)",
0xAD	:"inverted exclamation mark (U+00A1)",
0xAE	:"left-pointing double angle quotation mark (U+00AB)",
0xAF	:"right-pointing double angle quotation mark (U+00BB)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"box drawings vertical single and left double (U+2561)",
0xB6	:"box drawings vertical double and left single (U+2562)",
0xB7	:"box drawings down double and left single (U+2556)",
0xB8	:"box drawings down single and left double (U+2555)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255D)",
0xBD	:"box drawings up double and left single (U+255C)",
0xBE	:"box drawings up single and left double (U+255B)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252C)",
0xC3	:"box drawings light vertical and right (U+251C)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253C)",
0xC6	:"box drawings vertical single and right double (U+255E)",
0xC7	:"box drawings vertical double and right single (U+255F)",
0xC8	:"box drawings double up and right (U+255A)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256C)",
0xCF	:"box drawings up single and horizontal double (U+2567)",
0xD0	:"box drawings up double and horizontal single (U+2568)",
0xD1	:"box drawings down single and horizontal double (U+2564)",
0xD2	:"box drawings down double and horizontal single (U+2565)",
0xD3	:"box drawings up double and right single (U+2559)",
0xD4	:"box drawings up single and right double (U+2558)",
0xD5	:"box drawings down single and right double (U+2552)",
0xD6	:"box drawings down double and right single (U+2553)",
0xD7	:"box drawings vertical double and horizontal single (U+256B)",
0xD8	:"box drawings vertical single and horizontal double (U+256A)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250C)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"left half block (U+258C)",
0xDE	:"right half block (U+2590)",
0xDF	:"upper half block (U+2580)",
0xE0	:"greek small letter alpha (U+03B1)",
0xE1	:"latin small letter sharp s (U+00DF)",
0xE2	:"greek capital letter gamma (U+0393)",
0xE3	:"greek small letter pi (U+03C0)",
0xE4	:"greek capital letter sigma (U+03A3)",
0xE5	:"greek small letter sigma (U+03C3)",
0xE6	:"micro sign (U+00B5)",
0xE7	:"greek small letter tau (U+03C4)",
0xE8	:"greek capital letter phi (U+03A6)",
0xE9	:"greek capital letter theta (U+0398)",
0xEA	:"greek capital letter omega (U+03A9)",
0xEB	:"greek small letter delta (U+03B4)",
0xEC	:"infinity (U+221E)",
0xED	:"greek small letter phi (U+03C6)",
0xEE	:"greek small letter epsilon (U+03B5)",
0xEF	:"intersection (U+2229)",
0xF0	:"identical to (U+2261)",
0xF1	:"plus-minus sign (U+00B1)",
0xF2	:"greater-than or equal to (U+2265)",
0xF3	:"less-than or equal to (U+2264)",
0xF4	:"top half integral (U+2320)",
0xF5	:"bottom half integral (U+2321)",
0xF6	:"division sign (U+00F7)",
0xF7	:"almost equal to (U+2248)",
0xF8	:"degree sign (U+00B0)",
0xF9	:"bullet operator (U+2219)",
0xFA	:"middle dot (U+00B7)",
0xFB	:"square root (U+221A)",
0xFC	:"superscript latin small letter n (U+207F)",
0xFD	:"superscript two (U+00B2)",
0xFE	:"black square (U+25A0)",
0xFF	:"no-break space (U+00A0)"
}

#Classical Sanskrit Extended (used for scholarly transliteration of Sanskrit)
csxxtbl={\
0x00	:"<control> (U+0000)",
0x01	:"<control> (U+0001)",
0x02	:"<control> (U+0002)",
0x03	:"<control> (U+0003)",
0x04	:"<control> (U+0004)",
0x05	:"<control> (U+0005)",
0x06	:"<control> (U+0006)",
0x07	:"<control> (U+0007)",
0x08	:"<control> (U+0008)",
0x09	:"<control> (U+0009)",
0x0A	:"<control> (U+000A)",
0x0B	:"<control> (U+000B)",
0x0C	:"<control> (U+000C)",
0x0D	:"<control> (U+000D)",
0x0E	:"<control> (U+000E)",
0x0F	:"<control> (U+000F)",
0x10	:"<control> (U+0010)",
0x11	:"<control> (U+0011)",
0x12	:"<control> (U+0012)",
0x13	:"<control> (U+0013)",
0x14	:"<control> (U+0014)",
0x15	:"<control> (U+0015)",
0x16	:"<control> (U+0016)",
0x17	:"<control> (U+0017)",
0x18	:"<control> (U+0018)",
0x19	:"<control> (U+0019)",
0x1A	:"<control> (U+001A)",
0x1B	:"<control> (U+001B)",
0x1C	:"<control> (U+001C)",
0x1D	:"<control> (U+001D)",
0x1E	:"<control> (U+001E)",
0x1F	:"<control> (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"latin capital letter a (U+0041)",
0x42	:"latin capital letter b (U+0042)",
0x43	:"latin capital letter c (U+0043)",
0x44	:"latin capital letter d (U+0044)",
0x45	:"latin capital letter e (U+0045)",
0x46	:"latin capital letter f (U+0046)",
0x47	:"latin capital letter g (U+0047)",
0x48	:"latin capital letter h (U+0048)",
0x49	:"latin capital letter i (U+0049)",
0x4A	:"latin capital letter j (U+004A)",
0x4B	:"latin capital letter k (U+004B)",
0x4C	:"latin capital letter l (U+004C)",
0x4D	:"latin capital letter m (U+004D)",
0x4E	:"latin capital letter n (U+004E)",
0x4F	:"latin capital letter o (U+004F)",
0x50	:"latin capital letter p (U+0050)",
0x51	:"latin capital letter q (U+0051)",
0x52	:"latin capital letter r (U+0052)",
0x53	:"latin capital letter s (U+0053)",
0x54	:"latin capital letter t (U+0054)",
0x55	:"latin capital letter u (U+0055)",
0x56	:"latin capital letter v (U+0056)",
0x57	:"latin capital letter w (U+0057)",
0x58	:"latin capital letter x (U+0058)",
0x59	:"latin capital letter y (U+0059)",
0x5A	:"latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"latin small letter a (U+0061)",
0x62	:"latin small letter b (U+0062)",
0x63	:"latin small letter c (U+0063)",
0x64	:"latin small letter d (U+0064)",
0x65	:"latin small letter e (U+0065)",
0x66	:"latin small letter f (U+0066)",
0x67	:"latin small letter g (U+0067)",
0x68	:"latin small letter h (U+0068)",
0x69	:"latin small letter i (U+0069)",
0x6A	:"latin small letter j (U+006A)",
0x6B	:"latin small letter k (U+006B)",
0x6C	:"latin small letter l (U+006C)",
0x6D	:"latin small letter m (U+006D)",
0x6E	:"latin small letter n (U+006E)",
0x6F	:"latin small letter o (U+006F)",
0x70	:"latin small letter p (U+0070)",
0x71	:"latin small letter q (U+0071)",
0x72	:"latin small letter r (U+0072)",
0x73	:"latin small letter s (U+0073)",
0x74	:"latin small letter t (U+0074)",
0x75	:"latin small letter u (U+0075)",
0x76	:"latin small letter v (U+0076)",
0x77	:"latin small letter w (U+0077)",
0x78	:"latin small letter x (U+0078)",
0x79	:"latin small letter y (U+0079)",
0x7A	:"latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"<control> (U+007F)",
0x80	:"latin capital letter c with cedilla (U+00C7)",
0x81	:"latin small letter u with diaeresis (U+00FC)",
0x82	:"latin small letter e with acute (U+00E9)",
0x83	:"latin small letter a with circumflex (U+00E2)",
0x84	:"latin small letter a with diaeresis (U+00E4)",
0x85	:"latin small letter a with grave (U+00E0)",
0x86	:"latin small letter a with ring above (U+00E5)",
0x87	:"latin small letter c with cedilla (U+00E7)",
0x88	:"latin small letter e with circumflex (U+00EA)",
0x89	:"latin small letter e with diaeresis (U+00EB)",
0x8A	:"latin small letter e with grave (U+00E8)",
0x8B	:"latin small letter i with diaeresis (U+00EF)",
0x8C	:"latin small letter i with circumflex (U+00EE)",
0x8D	:"latin small letter i with grave (U+00EC)",
0x8E	:"latin capital letter a with diaeresis (U+00C4)",
0x8F	:"latin capital letter a with ring above (U+00C5)",
0x90	:"latin capital letter e with acute (U+00C9)",
0x91	:"latin small letter ae (U+00E6)",
0x92	:"latin capital letter ae (U+00C6)",
0x93	:"latin small letter o with circumflex (U+00F4)",
0x94	:"latin small letter o with diaeresis (U+00F6)",
0x95	:"latin small letter o with grave (U+00F2)",
0x96	:"latin small letter u with circumflex (U+00FB)",
0x97	:"latin small letter u with grave (U+00F9)",
0x98	:"latin small letter ae with macron (U+01E3)",
0x99	:"latin capital letter o with diaeresis (U+00D6)",
0x9A	:"latin capital letter u with diaeresis (U+00DC)",
0x9B	:"latin small letter u with breve (U+016D)",
0x9C	:"latin small letter e with macron + combining tilde (U+0113 0x0303)",
0x9D	:"latin small letter r + combining ring below (U+0072 0x0325)",
0x9E	:"latin small letter a with acute (U+00E1)",
0x9F	:"latin small letter r with line below (U+1E5F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"latin small letter i with acute (U+00ED)",
0xA2	:"latin small letter o with acute (U+00F3)",
0xA3	:"latin small letter u with acute (U+00FA)",
0xA4	:"latin small letter n with tilde (U+00F1)",
0xA5	:"latin capital letter n with tilde (U+00D1)",
0xA6	:"latin small letter l + combining tilde (U+006C 0x0303)",
0xA7	:"latin small letter m with dot above (U+1E41)",
0xA8	:"latin small letter a with macron + combining breve (U+0101 0x0306)",
0xA9	:"latin small letter i with macron + combining breve (U+012B 0x0306)",
0xAA	:"latin small letter u with macron + combining breve (U+016B 0x0306)",
0xAB	:"latin small letter a with macron + combining tilde (U+0101 0x0303)",
0xAC	:"latin small letter i with macron + combining tilde (U+012B 0x0303)",
0xAD	:"latin small letter n with line below (U+1E49)",
0xAE	:"latin small letter r + combining macron + combining ring below (U+0072 0x0304 0x0325)",
0xAF	:"latin small letter l + combining ring below (U+006C 0x0325)",
0xB0	:"latin small letter l + combining macron + combining ring below (U+006C 0x0304 0x0325)",
0xB1	:"latin small letter r with acute + combining ring below (U+0155 0x0325)",
0xB2	:"latin small letter r + combining grave accent + combining ring below (U+0072 0x0300 0x0325)",
0xB3	:"latin small letter r + combining macron + combining acute accent + combining ring below (U+0072 0x0304 0x0301 0x0325)",
0xB4	:"latin small letter m + combining breve (U+006D 0x0306)",
0xB5	:"latin small letter a with macron + combining acute accent (U+0101 0x0301)",
0xB6	:"latin small letter a with macron + combining grave accent (U+0101 0x0300)",
0xB7	:"latin small letter i with macron + combining acute accent (U+012B 0x0301)",
0xB8	:"latin small letter i with macron + combining grave accent (U+012B 0x0300)",
0xB9	:"latin small letter e with macron (U+0113)",
0xBA	:"latin small letter o with macron (U+014D)",
0xBB	:"latin capital letter r + combining ring below (U+0052 0x0325)",
0xBC	:"latin small letter y with dot above (U+1E8F)",
0xBD	:"latin small letter u with macron + combining acute accent (U+016B 0x0301)",
0xBE	:"latin small letter u with macron + combining grave accent (U+016B 0x0300)",
0xBF	:"latin small letter r + combining breve (U+0072 0x0306)",
0xC0	:"latin small letter o with macron + combining tilde (U+014D 0x0303)",
0xC1	:"latin small letter m + combining breve + combining dot above (U+006D 0x0306 0x0307)",
0xC2	:"latin small letter t with line below (U+1E6F)",
0xC3	:"latin capital letter e with macron (U+0112)",
0xC4	:"latin capital letter o with macron (U+014C)",
0xC5	:"latin small letter n + combining breve (U+006E 0x0306)",
0xC6	:"latin small letter r with dot below + combining acute accent (U+1E5B 0x0301)",
0xC7	:"latin small letter r with dot below + combining grave accent (U+1E5B 0x0300)",
0xC8	:"latin capital letter k + latin small letter h + combining double macron below (U+004B 0x0068 0x035F)",
0xC9	:"latin small letter k with line below (U+1E35)",
0xCA	:"space (U+0020)",
0xCB	:"latin capital letter ae with macron (U+01E2)",
0xCC	:"latin small letter k + latin small letter h + combining double macron below (U+006B 0x0068 0x035F)",
0xCD	:"latin small letter g with dot above (U+0121)",
0xCE	:"latin small letter c with circumflex (U+0109)",
0xCF	:"latin small letter r with dot below and macron + combining acute accent (U+1E5D 0x0301)",
0xD0	:"latin small letter a with tilde (U+00E3)",
0xD1	:"latin small letter i with tilde (U+0129)",
0xD2	:"latin small letter u with tilde (U+0169)",
0xD3	:"latin small letter e with tilde (U+1EBD)",
0xD4	:"latin small letter o with tilde (U+00F5)",
0xD5	:"latin small letter e with breve (U+0115)",
0xD6	:"latin small letter o with breve (U+014F)",
0xD7	:"latin small letter l with line below (U+1E3B)",
0xD8	:"latin small letter u with macron + combining tilde (U+016B 0x0303)",
0xD9	:"latin capital letter g with dot above (U+0120)",
0xDA	:"latin capital letter c with circumflex (U+0108)",
0xDB	:"latin small letter h + combining minus sign below (U+0068 0x0320)",
0xDC	:"latin small letter h with breve below (U+1E2B)",
0xDD	:"en dash (U+2013)",
0xDE	:"em dash (U+2014)",
0xDF	:"left double quotation mark (U+201C)",
0xE0	:"latin small letter a with macron (U+0101)",
0xE1	:"latin small letter sharp s (U+00DF)",
0xE2	:"latin capital letter a with macron (U+0100)",
0xE3	:"latin small letter i with macron (U+012B)",
0xE4	:"latin capital letter i with macron (U+012A)",
0xE5	:"latin small letter u with macron (U+016B)",
0xE6	:"latin capital letter u with macron (U+016A)",
0xE7	:"latin small letter r with dot below (U+1E5B)",
0xE8	:"latin capital letter r with dot below (U+1E5A)",
0xE9	:"latin small letter r with dot below + combining macron (U+1E5B 0x0304)",
0xEA	:"latin capital letter r with dot below + combining macron (U+1E5A 0x0304)",
0xEB	:"latin small letter l with dot below (U+1E37)",
0xEC	:"latin capital letter l with dot below (U+1E36)",
0xED	:"latin small letter l with dot below + combining macron (U+1E37 0x0304)",
0xEE	:"latin capital letter l with dot below + combining macron (U+1E36 0x0304)",
0xEF	:"latin small letter n with dot above (U+1E45)",
0xF0	:"latin capital letter n with dot above (U+1E44)",
0xF1	:"latin small letter t with dot below (U+1E6D)",
0xF2	:"latin capital letter t with dot below (U+1E6C)",
0xF3	:"latin small letter d with dot below (U+1E0D)",
0xF4	:"latin capital letter d with dot below (U+1E0C)",
0xF5	:"latin small letter n with dot below (U+1E47)",
0xF6	:"latin capital letter n with dot below (U+1E46)",
0xF7	:"latin small letter s with acute (U+015B)",
0xF8	:"latin capital letter s with acute (U+015A)",
0xF9	:"latin small letter s with dot below (U+1E63)",
0xFA	:"latin capital letter s with dot below (U+1E62)",
0xFB	:"right double quotation mark (U+201D)",
0xFC	:"latin small letter m with dot below (U+1E43)",
0xFD	:"latin capital letter m with dot below (U+1E42)",
0xFE	:"latin small letter h with dot below (U+1E25)",
0xFF	:"latin capital letter h with dot below (U+1E24)"
}

#EGA Farsi encoding
egafxtbl={\
0x00	:"<control> (U+0000)",
0x01	:"<control> (U+0001)",
0x02	:"<control> (U+0002)",
0x03	:"<control> (U+0003)",
0x04	:"<control> (U+0004)",
0x05	:"<control> (U+0005)",
0x06	:"<control> (U+0006)",
0x07	:"<control> (U+0007)",
0x08	:"<control> (U+0008)",
0x09	:"<control> (U+0009)",
0x0A	:"<control> (U+000A)",
0x0B	:"<control> (U+000B)",
0x0C	:"<control> (U+000C)",
0x0D	:"<control> (U+000D)",
0x0E	:"<control> (U+000E)",
0x0F	:"<control> (U+000F)",
0x10	:"<control> (U+0010)",
0x11	:"<control> (U+0011)",
0x12	:"<control> (U+0012)",
0x13	:"<control> (U+0013)",
0x14	:"<control> (U+0014)",
0x15	:"<control> (U+0015)",
0x16	:"<control> (U+0016)",
0x17	:"<control> (U+0017)",
0x18	:"<control> (U+0018)",
0x19	:"<control> (U+0019)",
0x1A	:"<control> (U+001A)",
0x1B	:"<control> (U+001B)",
0x1C	:"<control> (U+001C)",
0x1D	:"<control> (U+001D)",
0x1E	:"<control> (U+001E)",
0x1F	:"<control> (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"latin capital letter a (U+0041)",
0x42	:"latin capital letter b (U+0042)",
0x43	:"latin capital letter c (U+0043)",
0x44	:"latin capital letter d (U+0044)",
0x45	:"latin capital letter e (U+0045)",
0x46	:"latin capital letter f (U+0046)",
0x47	:"latin capital letter g (U+0047)",
0x48	:"latin capital letter h (U+0048)",
0x49	:"latin capital letter i (U+0049)",
0x4A	:"latin capital letter j (U+004A)",
0x4B	:"latin capital letter k (U+004B)",
0x4C	:"latin capital letter l (U+004C)",
0x4D	:"latin capital letter m (U+004D)",
0x4E	:"latin capital letter n (U+004E)",
0x4F	:"latin capital letter o (U+004F)",
0x50	:"latin capital letter p (U+0050)",
0x51	:"latin capital letter q (U+0051)",
0x52	:"latin capital letter r (U+0052)",
0x53	:"latin capital letter s (U+0053)",
0x54	:"latin capital letter t (U+0054)",
0x55	:"latin capital letter u (U+0055)",
0x56	:"latin capital letter v (U+0056)",
0x57	:"latin capital letter w (U+0057)",
0x58	:"latin capital letter x (U+0058)",
0x59	:"latin capital letter y (U+0059)",
0x5A	:"latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"latin small letter a (U+0061)",
0x62	:"latin small letter b (U+0062)",
0x63	:"latin small letter c (U+0063)",
0x64	:"latin small letter d (U+0064)",
0x65	:"latin small letter e (U+0065)",
0x66	:"latin small letter f (U+0066)",
0x67	:"latin small letter g (U+0067)",
0x68	:"latin small letter h (U+0068)",
0x69	:"latin small letter i (U+0069)",
0x6A	:"latin small letter j (U+006A)",
0x6B	:"latin small letter k (U+006B)",
0x6C	:"latin small letter l (U+006C)",
0x6D	:"latin small letter m (U+006D)",
0x6E	:"latin small letter n (U+006E)",
0x6F	:"latin small letter o (U+006F)",
0x70	:"latin small letter p (U+0070)",
0x71	:"latin small letter q (U+0071)",
0x72	:"latin small letter r (U+0072)",
0x73	:"latin small letter s (U+0073)",
0x74	:"latin small letter t (U+0074)",
0x75	:"latin small letter u (U+0075)",
0x76	:"latin small letter v (U+0076)",
0x77	:"latin small letter w (U+0077)",
0x78	:"latin small letter x (U+0078)",
0x79	:"latin small letter y (U+0079)",
0x7A	:"latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"<control> (U+007F)",
0x80	:"extended arabic-indic digit zero (U+06F0)",
0x81	:"extended arabic-indic digit one (U+06F1)",
0x82	:"extended arabic-indic digit two (U+06F2)",
0x83	:"extended arabic-indic digit three (U+06F3)",
0x84	:"extended arabic-indic digit four (U+06F4)",
0x85	:"extended arabic-indic digit five (U+06F5)",
0x86	:"extended arabic-indic digit six (U+06F6)",
0x87	:"extended arabic-indic digit seven (U+06F7)",
0x88	:"extended arabic-indic digit eight (U+06F8)",
0x89	:"extended arabic-indic digit nine (U+06F9)",
0x8A	:"arabic comma (U+060C)",
0x8B	:"hyphen-minus (U+002D)",
0x8C	:"arabic question mark (U+061F)",
0x8D	:"arabic letter alef with madda above (U+0622)",
0x8E	:"arabic letter yeh with hamza above (U+0626)",
0x8F	:"arabic letter hamza (U+0621)",
0x90	:"arabic letter alef (U+0627)",
0x91	:"arabic letter alef (U+0627)",
0x92	:"arabic letter beh + zwnj (U+0628 0x200C)",
0x93	:"arabic letter beh (U+0628)",
0x94	:"arabic letter peh + zwnj (U+067E 0x200C)",
0x95	:"arabic letter peh (U+067E)",
0x96	:"arabic letter teh + zwnj (U+062A 0x200C)",
0x97	:"arabic letter teh (U+062A)",
0x98	:"arabic letter theh + zwnj (U+062B 0x200C)",
0x99	:"arabic letter theh (U+062B)",
0x9A	:"arabic letter jeem + zwnj (U+062C 0x200C)",
0x9B	:"arabic letter jeem (U+062C)",
0x9C	:"arabic letter tcheh + zwnj (U+0686 0x200C)",
0x9D	:"arabic letter tcheh (U+0686)",
0x9E	:"arabic letter hah + zwnj (U+062D 0x200C)",
0x9F	:"arabic letter hah (U+062D)",
0xA0	:"arabic letter khah + zwnj (U+062E 0x200C)",
0xA1	:"arabic letter khah (U+062E)",
0xA2	:"arabic letter dal (U+062F)",
0xA3	:"arabic letter thal (U+0630)",
0xA4	:"arabic letter reh (U+0631)",
0xA5	:"arabic letter zain (U+0632)",
0xA6	:"arabic letter jeh (U+0698)",
0xA7	:"arabic letter seen + zwnj (U+0633 0x200C)",
0xA8	:"arabic letter seen (U+0633)",
0xA9	:"arabic letter sheen + zwnj (U+0634 0x200C)",
0xAA	:"arabic letter sheen (U+0634)",
0xAB	:"arabic letter sad + zwnj (U+0635 0x200C)",
0xAC	:"arabic letter sad (U+0635)",
0xAD	:"arabic letter dad + zwnj (U+0636 0x200C)",
0xAE	:"arabic letter dad (U+0636)",
0xAF	:"arabic letter tah (U+0637)",
0xB0	:"replacement character (U+FFFD)",
0xB1	:"replacement character (U+FFFD)",
0xB2	:"replacement character (U+FFFD)",
0xB3	:"replacement character (U+FFFD)",
0xB4	:"replacement character (U+FFFD)",
0xB5	:"replacement character (U+FFFD)",
0xB6	:"replacement character (U+FFFD)",
0xB7	:"replacement character (U+FFFD)",
0xB8	:"replacement character (U+FFFD)",
0xB9	:"replacement character (U+FFFD)",
0xBA	:"replacement character (U+FFFD)",
0xBB	:"replacement character (U+FFFD)",
0xBC	:"replacement character (U+FFFD)",
0xBD	:"replacement character (U+FFFD)",
0xBE	:"replacement character (U+FFFD)",
0xBF	:"replacement character (U+FFFD)",
0xC0	:"replacement character (U+FFFD)",
0xC1	:"replacement character (U+FFFD)",
0xC2	:"replacement character (U+FFFD)",
0xC3	:"replacement character (U+FFFD)",
0xC4	:"replacement character (U+FFFD)",
0xC5	:"replacement character (U+FFFD)",
0xC6	:"replacement character (U+FFFD)",
0xC7	:"replacement character (U+FFFD)",
0xC8	:"replacement character (U+FFFD)",
0xC9	:"replacement character (U+FFFD)",
0xCA	:"replacement character (U+FFFD)",
0xCB	:"replacement character (U+FFFD)",
0xCC	:"replacement character (U+FFFD)",
0xCD	:"replacement character (U+FFFD)",
0xCE	:"replacement character (U+FFFD)",
0xCF	:"replacement character (U+FFFD)",
0xD0	:"replacement character (U+FFFD)",
0xD1	:"replacement character (U+FFFD)",
0xD2	:"replacement character (U+FFFD)",
0xD3	:"replacement character (U+FFFD)",
0xD4	:"replacement character (U+FFFD)",
0xD5	:"replacement character (U+FFFD)",
0xD6	:"replacement character (U+FFFD)",
0xD7	:"replacement character (U+FFFD)",
0xD8	:"replacement character (U+FFFD)",
0xD9	:"replacement character (U+FFFD)",
0xDA	:"replacement character (U+FFFD)",
0xDB	:"replacement character (U+FFFD)",
0xDC	:"replacement character (U+FFFD)",
0xDD	:"replacement character (U+FFFD)",
0xDE	:"replacement character (U+FFFD)",
0xDF	:"replacement character (U+FFFD)",
0xE0	:"arabic letter zah (U+0638)",
0xE1	:"arabic letter ain (U+0639)",
0xE2	:"arabic letter ain + zwnj (U+0639 0x200C)",
0xE3	:"arabic letter ain (U+0639)",
0xE4	:"arabic letter ain (U+0639)",
0xE5	:"arabic letter ghain (U+063A)",
0xE6	:"arabic letter ghain + zwnj (U+063A 0x200C)",
0xE7	:"arabic letter ghain (U+063A)",
0xE8	:"arabic letter ghain (U+063A)",
0xE9	:"arabic letter feh + zwnj (U+0641 0x200C)",
0xEA	:"arabic letter feh (U+0641)",
0xEB	:"arabic letter qaf + zwnj (U+0642 0x200C)",
0xEC	:"arabic letter qaf (U+0642)",
0xED	:"arabic letter keheh + zwnj (U+06A9 0x200C)",
0xEE	:"arabic letter keheh (U+06A9)",
0xEF	:"arabic letter gaf + zwnj (U+06AF 0x200C)",
0xF0	:"arabic letter gaf (U+06AF)",
0xF1	:"arabic letter lam + zwnj (U+0644 0x200C)",
0xF2	:"arabic letter lam + arabic letter alef (U+0644 0x0627)",
0xF3	:"arabic letter lam (U+0644)",
0xF4	:"arabic letter meem + zwnj (U+0645 0x200C)",
0xF5	:"arabic letter meem (U+0645)",
0xF6	:"arabic letter noon + zwnj (U+0646 0x200C)",
0xF7	:"arabic letter noon (U+0646)",
0xF8	:"arabic letter waw (U+0648)",
0xF9	:"arabic letter heh + zwnj (U+0647 0x200C)",
0xFA	:"arabic letter heh (U+0647)",
0xFB	:"arabic letter heh (U+0647)",
0xFC	:"arabic letter farsi yeh + zwnj (U+06CC 0x200C)",
0xFD	:"arabic letter farsi yeh (U+06CC)",
0xFE	:"arabic letter farsi yeh (U+06CC)",
0xFF	:"replacement character (U+FFFD)"
}


#Buddhist Relief Mission Pali encoding
brmpxtbl={\
0x00	:"<control> (U+0000)",
0x01	:"<control> (U+0001)",
0x02	:"<control> (U+0002)",
0x03	:"<control> (U+0003)",
0x04	:"<control> (U+0004)",
0x05	:"<control> (U+0005)",
0x06	:"<control> (U+0006)",
0x07	:"<control> (U+0007)",
0x08	:"<control> (U+0008)",
0x09	:"<control> (U+0009)",
0x0A	:"<control> (U+000A)",
0x0B	:"<control> (U+000B)",
0x0C	:"<control> (U+000C)",
0x0D	:"<control> (U+000D)",
0x0E	:"<control> (U+000E)",
0x0F	:"<control> (U+000F)",
0x10	:"<control> (U+0010)",
0x11	:"<control> (U+0011)",
0x12	:"<control> (U+0012)",
0x13	:"<control> (U+0013)",
0x14	:"<control> (U+0014)",
0x15	:"<control> (U+0015)",
0x16	:"<control> (U+0016)",
0x17	:"<control> (U+0017)",
0x18	:"<control> (U+0018)",
0x19	:"<control> (U+0019)",
0x1A	:"<control> (U+001A)",
0x1B	:"<control> (U+001B)",
0x1C	:"<control> (U+001C)",
0x1D	:"<control> (U+001D)",
0x1E	:"<control> (U+001E)",
0x1F	:"<control> (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"latin capital letter a (U+0041)",
0x42	:"latin capital letter b (U+0042)",
0x43	:"latin capital letter c (U+0043)",
0x44	:"latin capital letter d (U+0044)",
0x45	:"latin capital letter e (U+0045)",
0x46	:"latin capital letter f (U+0046)",
0x47	:"latin capital letter g (U+0047)",
0x48	:"latin capital letter h (U+0048)",
0x49	:"latin capital letter i (U+0049)",
0x4A	:"latin capital letter j (U+004A)",
0x4B	:"latin capital letter k (U+004B)",
0x4C	:"latin capital letter l (U+004C)",
0x4D	:"latin capital letter m (U+004D)",
0x4E	:"latin capital letter n (U+004E)",
0x4F	:"latin capital letter o (U+004F)",
0x50	:"latin capital letter p (U+0050)",
0x51	:"latin capital letter q (U+0051)",
0x52	:"latin capital letter r (U+0052)",
0x53	:"latin capital letter s (U+0053)",
0x54	:"latin capital letter t (U+0054)",
0x55	:"latin capital letter u (U+0055)",
0x56	:"latin capital letter v (U+0056)",
0x57	:"latin capital letter w (U+0057)",
0x58	:"latin capital letter x (U+0058)",
0x59	:"latin capital letter y (U+0059)",
0x5A	:"latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"latin small letter a (U+0061)",
0x62	:"latin small letter b (U+0062)",
0x63	:"latin small letter c (U+0063)",
0x64	:"latin small letter d (U+0064)",
0x65	:"latin small letter e (U+0065)",
0x66	:"latin small letter f (U+0066)",
0x67	:"latin small letter g (U+0067)",
0x68	:"latin small letter h (U+0068)",
0x69	:"latin small letter i (U+0069)",
0x6A	:"latin small letter j (U+006A)",
0x6B	:"latin small letter k (U+006B)",
0x6C	:"latin small letter l (U+006C)",
0x6D	:"latin small letter m (U+006D)",
0x6E	:"latin small letter n (U+006E)",
0x6F	:"latin small letter o (U+006F)",
0x70	:"latin small letter p (U+0070)",
0x71	:"latin small letter q (U+0071)",
0x72	:"latin small letter r (U+0072)",
0x73	:"latin small letter s (U+0073)",
0x74	:"latin small letter t (U+0074)",
0x75	:"latin small letter u (U+0075)",
0x76	:"latin small letter v (U+0076)",
0x77	:"latin small letter w (U+0077)",
0x78	:"latin small letter x (U+0078)",
0x79	:"latin small letter y (U+0079)",
0x7A	:"latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"<control> (U+007F)",
0x80	:"replacement character (U+FFFD)",
0x81	:"replacement character (U+FFFD)",
0x82	:"replacement character (U+FFFD)",
0x83	:"replacement character (U+FFFD)",
0x84	:"replacement character (U+FFFD)",
0x85	:"latin small letter n with dot below (U+1E47)",
0x86	:"replacement character (U+FFFD)",
0x87	:"replacement character (U+FFFD)",
0x88	:"replacement character (U+FFFD)",
0x89	:"latin small letter n with dot above (U+1E45)",
0x8A	:"replacement character (U+FFFD)",
0x8B	:"replacement character (U+FFFD)",
0x8C	:"latin small letter d with dot below (U+1E0D)",
0x8D	:"replacement character (U+FFFD)",
0x8E	:"replacement character (U+FFFD)",
0x8F	:"replacement character (U+FFFD)",
0x90	:"replacement character (U+FFFD)",
0x91	:"replacement character (U+FFFD)",
0x92	:"replacement character (U+FFFD)",
0x93	:"replacement character (U+FFFD)",
0x94	:"replacement character (U+FFFD)",
0x95	:"replacement character (U+FFFD)",
0x96	:"latin capital letter m with dot below (U+1E42)",
0x97	:"latin capital letter d with dot below (U+1E0C)",
0x98	:"replacement character (U+FFFD)",
0x99	:"latin capital letter l with dot below (U+1E36)",
0x9A	:"replacement character (U+FFFD)",
0x9B	:"replacement character (U+FFFD)",
0x9C	:"latin small letter m with dot below (U+1E43)",
0x9D	:"replacement character (U+FFFD)",
0x9E	:"replacement character (U+FFFD)",
0x9F	:"replacement character (U+FFFD)",
0xA0	:"replacement character (U+FFFD)",
0xA1	:"replacement character (U+FFFD)",
0xA2	:"latin capital letter n with dot above (U+1E44)",
0xA3	:"replacement character (U+FFFD)",
0xA4	:"latin capital letter n with dot below (U+1E46)",
0xA5	:"replacement character (U+FFFD)",
0xA6	:"replacement character (U+FFFD)",
0xA7	:"replacement character (U+FFFD)",
0xA8	:"latin capital letter t with dot below (U+1E6C)",
0xA9	:"replacement character (U+FFFD)",
0xAA	:"replacement character (U+FFFD)",
0xAB	:"replacement character (U+FFFD)",
0xAC	:"latin small letter l with dot below (U+1E37)",
0xAD	:"replacement character (U+FFFD)",
0xAE	:"replacement character (U+FFFD)",
0xAF	:"replacement character (U+FFFD)",
0xB0	:"latin capital letter a with macron (U+0100)",
0xB1	:"latin capital letter i with macron (U+012A)",
0xB2	:"latin capital letter u with macron (U+016A)",
0xB3	:"replacement character (U+FFFD)",
0xB4	:"replacement character (U+FFFD)",
0xB5	:"replacement character (U+FFFD)",
0xB6	:"replacement character (U+FFFD)",
0xB7	:"replacement character (U+FFFD)",
0xB8	:"replacement character (U+FFFD)",
0xB9	:"latin small letter a with macron (U+0101)",
0xBA	:"latin small letter i with macron (U+012B)",
0xBB	:"replacement character (U+FFFD)",
0xBC	:"latin small letter u with macron (U+016B)",
0xBD	:"replacement character (U+FFFD)",
0xBE	:"replacement character (U+FFFD)",
0xBF	:"replacement character (U+FFFD)",
0xC0	:"replacement character (U+FFFD)",
0xC1	:"replacement character (U+FFFD)",
0xC2	:"replacement character (U+FFFD)",
0xC3	:"replacement character (U+FFFD)",
0xC4	:"replacement character (U+FFFD)",
0xC5	:"replacement character (U+FFFD)",
0xC6	:"replacement character (U+FFFD)",
0xC7	:"replacement character (U+FFFD)",
0xC8	:"replacement character (U+FFFD)",
0xC9	:"replacement character (U+FFFD)",
0xCA	:"replacement character (U+FFFD)",
0xCB	:"replacement character (U+FFFD)",
0xCC	:"replacement character (U+FFFD)",
0xCD	:"replacement character (U+FFFD)",
0xCE	:"replacement character (U+FFFD)",
0xCF	:"replacement character (U+FFFD)",
0xD0	:"replacement character (U+FFFD)",
0xD1	:"replacement character (U+FFFD)",
0xD2	:"replacement character (U+FFFD)",
0xD3	:"replacement character (U+FFFD)",
0xD4	:"replacement character (U+FFFD)",
0xD5	:"replacement character (U+FFFD)",
0xD6	:"replacement character (U+FFFD)",
0xD7	:"replacement character (U+FFFD)",
0xD8	:"replacement character (U+FFFD)",
0xD9	:"replacement character (U+FFFD)",
0xDA	:"replacement character (U+FFFD)",
0xDB	:"replacement character (U+FFFD)",
0xDC	:"replacement character (U+FFFD)",
0xDD	:"replacement character (U+FFFD)",
0xDE	:"replacement character (U+FFFD)",
0xDF	:"replacement character (U+FFFD)",
0xE0	:"replacement character (U+FFFD)",
0xE1	:"replacement character (U+FFFD)",
0xE2	:"replacement character (U+FFFD)",
0xE3	:"replacement character (U+FFFD)",
0xE4	:"replacement character (U+FFFD)",
0xE5	:"replacement character (U+FFFD)",
0xE6	:"replacement character (U+FFFD)",
0xE7	:"replacement character (U+FFFD)",
0xE8	:"replacement character (U+FFFD)",
0xE9	:"replacement character (U+FFFD)",
0xEA	:"replacement character (U+FFFD)",
0xEB	:"replacement character (U+FFFD)",
0xEC	:"replacement character (U+FFFD)",
0xED	:"replacement character (U+FFFD)",
0xEE	:"replacement character (U+FFFD)",
0xEF	:"replacement character (U+FFFD)",
0xF0	:"replacement character (U+FFFD)",
0xF1	:"replacement character (U+FFFD)",
0xF2	:"replacement character (U+FFFD)",
0xF3	:"replacement character (U+FFFD)",
0xF4	:"replacement character (U+FFFD)",
0xF5	:"replacement character (U+FFFD)",
0xF6	:"replacement character (U+FFFD)",
0xF7	:"replacement character (U+FFFD)",
0xF8	:"replacement character (U+FFFD)",
0xF9	:"replacement character (U+FFFD)",
0xFA	:"replacement character (U+FFFD)",
0xFB	:"replacement character (U+FFFD)",
0xFC	:"replacement character (U+FFFD)",
0xFD	:"replacement character (U+FFFD)",
0xFE	:"replacement character (U+FFFD)",
0xFF	:"replacement character (U+FFFD)",
}


#Adobe Postscript encoding
adobepsxtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"space [no-break space](U+00A0)",
0x21	:"exclam [exclamation mark](U+0021)",
0x22	:"quotedbl [quotation mark](U+0022)",
0x23	:"numbersign [number sign](U+0023)",
0x24	:"dollar [dollar sign](U+0024)",
0x25	:"percent [percent sign](U+0025)",
0x26	:"ampersand [ampersand](U+0026)",
0x27	:"quoteright [right single quotation mark](U+2019)",
0x28	:"parenleft [left parenthesis](U+0028)",
0x29	:"parenright [right parenthesis](U+0029)",
0x2A	:"asterisk [asterisk](U+002A)",
0x2B	:"plus [plus sign](U+002B)",
0x2C	:"comma [comma](U+002C)",
0x2D	:"hyphen [hyphen-minus](U+002D)",
0x2D	:"hyphen [soft hyphen](U+00AD)",
0x2E	:"period [full stop](U+002E)",
0x2F	:"slash [solidus](U+002F)",
0x30	:"zero [digit zero](U+0030)",
0x31	:"one [digit one](U+0031)",
0x32	:"two [digit two](U+0032)",
0x33	:"three [digit three](U+0033)",
0x34	:"four [digit four](U+0034)",
0x35	:"five [digit five](U+0035)",
0x36	:"six [digit six](U+0036)",
0x37	:"seven [digit seven](U+0037)",
0x38	:"eight [digit eight](U+0038)",
0x39	:"nine [digit nine](U+0039)",
0x3A	:"colon [colon](U+003A)",
0x3B	:"semicolon [semicolon](U+003B)",
0x3C	:"less [less-than sign](U+003C)",
0x3D	:"equal [equals sign](U+003D)",
0x3E	:"greater [greater-than sign](U+003E)",
0x3F	:"question [question mark](U+003F)",
0x40	:"at [commercial at](U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"bracketleft [left square bracket](U+005B)",
0x5C	:"backslash [reverse solidus](U+005C)",
0x5D	:"bracketright [right square bracket](U+005D)",
0x5E	:"asciicircum [circumflex accent](U+005E)",
0x5F	:"underscore [low line](U+005F)",
0x60	:"quoteleft [left single quotation mark](U+2018)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"braceleft [left curly bracket](U+007B)",
0x7C	:"bar [vertical line](U+007C)",
0x7D	:"braceright [right curly bracket](U+007D)",
0x7E	:"asciitilde [tilde](U+007E)",
0x81	:"Unused",
0x82	:"Unused",
0x83	:"Unused",
0x84	:"Unused",
0x85	:"Unused",
0x86	:"Unused",
0x87	:"Unused",
0x88	:"Unused",
0x89	:"Unused",
0x8A	:"Unused",
0x8B	:"Unused",
0x8C	:"Unused",
0x8D	:"Unused",
0x8E	:"Unused",
0x8F	:"Unused",
0x90	:"Unused",
0x91	:"Unused",
0x92	:"Unused",
0x93	:"Unused",
0x94	:"Unused",
0x95	:"Unused",
0x96	:"Unused",
0x97	:"Unused",
0x98	:"Unused",
0x99	:"Unused",
0x9A	:"Unused",
0x9B	:"Unused",
0x9C	:"Unused",
0x9D	:"Unused",
0x9E	:"Unused",
0x9F	:"Unused",
0xA0	:"Unused",
0xA1	:"exclamdown [inverted exclamation mark](U+00A1)",
0xA2	:"cent [cent sign](U+00A2)",
0xA3	:"sterling [pound sign](U+00A3)",
0xA4	:"fraction [fraction slash](U+2044)",
0xA4	:"fraction [division slash](U+2215)",
0xA5	:"yen [yen sign](U+00A5)",
0xA6	:"florin [Latin small letter f with hook](U+0192)",
0xA7	:"section [section sign](U+00A7)",
0xA8	:"currency [currency sign](U+00A4)",
0xA9	:"quotesingle [apostrophe](U+0027)",
0xAA	:"quotedblleft [left double quotation mark](U+201C)",
0xAB	:"guillemotleft [left-pointing double angle quotation mark](U+00AB)",
0xAC	:"guilsinglleft [single left-pointing angle quotation mark](U+2039)",
0xAD	:"guilsinglright [single right-pointing angle quotation mark](U+203A)",
0xAE	:"fi [Latin small ligature fi](U+FB01)",
0xAF	:"fl [Latin small ligature fl](U+FB02)",
0xB1	:"endash [en dash](U+2013)",
0xB2	:"dagger [dagger](U+2020)",
0xB3	:"daggerdbl [double dagger](U+2021)",
0xB4	:"periodcentered [middle dot](U+00B7)",
0xB4	:"periodcentered [bullet operator](U+2219)",
0xB6	:"paragraph [pilcrow sign](U+00B6)",
0xB7	:"bullet [bullet](U+2022)",
0xB8	:"quotesinglbase [single low-9 quotation mark](U+201A)",
0xB9	:"quotedblbase [double low-9 quotation mark](U+201E)",
0xBA	:"quotedblright [right double quotation mark](U+201D)",
0xBB	:"guillemotright [right-pointing double angle quotation mark](U+00BB)",
0xBC	:"ellipsis [horizontal ellipsis](U+2026)",
0xBD	:"perthousand [per mille sign](U+2030)",
0xBE	:"Unused",
0xBF	:"questiondown [inverted question mark](U+00BF)",
0xC0	:"Unused",
0xC1	:"grave [grave accent](U+0060)",
0xC2	:"acute [acute accent](U+00B4)",
0xC3	:"circumflex [modifier letter circumflex accent](U+02C6)",
0xC4	:"tilde [small tilde](U+02DC)",
0xC5	:"macron [macron](U+00AF)",
0xC5	:"macron [modifier letter macron](U+02C9)",
0xC6	:"breve [breve](U+02D8)",
0xC7	:"dotaccent [dot above](U+02D9)",
0xC8	:"dieresis [diaeresis](U+00A8)",
0xCA	:"ring [ring above](U+02DA)",
0xCB	:"cedilla [cedilla](U+00B8)",
0xCC	:"Unused",
0xCD	:"hungarumlaut [double acute accent](U+02DD)",
0xCE	:"ogonek [ogonek](U+02DB)",
0xCF	:"caron [caron](U+02C7)",
0xD0	:"emdash [em dash](U+2014)",
0xD1	:"Unused",
0xD2	:"Unused",
0xD3	:"Unused",
0xD4	:"Unused",
0xD5	:"Unused",
0xD6	:"Unused",
0xD7	:"Unused",
0xD8	:"Unused",
0xD9	:"Unused",
0xDA	:"Unused",
0xDB	:"Unused",
0xDC	:"Unused",
0xDD	:"Unused",
0xDE	:"Unused",
0xDF	:"Unused",
0xE0	:"Unused",
0xE1	:"AE [Latin capital letter ae](U+00C6)",
0xE2	:"Unused",
0xE3	:"ordfeminine [feminine ordinal indicator](U+00AA)",
0xE4	:"Unused",
0xE5	:"Unused",
0xE6	:"Unused",
0xE7	:"Unused",
0xE8	:"Lslash [Latin capital letter l with stroke](U+0141)",
0xE9	:"Oslash [Latin capital letter o with stroke](U+00D8)",
0xEA	:"OE [Latin capital ligature oe](U+0152)",
0xEB	:"ordmasculine [masculine ordinal indicator](U+00BA)",
0xEC	:"Unused",
0xED	:"Unused",
0xEE	:"Unused",
0xEF	:"Unused",
0xF0	:"Unused",
0xF1	:"ae [Latin small letter ae](U+00E6)",
0xF2	:"Unused",
0xF3	:"Unused",
0xF4	:"Unused",
0xF5	:"dotlessi [Latin small letter dotless i](U+0131)",
0xF6	:"Unused",
0xF7	:"Unused",
0xF8	:"lslash [Latin small letter l with stroke](U+0142)",
0xF9	:"oslash [Latin small letter o with stroke](U+00F8)",
0xFA	:"oe [Latin small ligature oe](U+0153)",
0xFB	:"germandbls [Latin small letter sharp s](U+00DF)",
0xFC	:"Unused",
0xFD	:"Unused",
0xFE	:"Unused",
0xFF	:"Unused"
}

#ARMSCII7 (Armenian)
armscii7xtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"Unused",
0x21	:"Armenian eternity symbol (not in Unicode)",
0x22	:"Armenian letter ew (U+0587)",
0x23	:"Armenian full stop (U+0589)",
0x24	:"right parenthesis (U+0029)",
0x25	:"left parenthesis (U+0028)",
0x26	:"Armenian right quote (U+00BB)",
0x27	:"Armenian left quote (U+00AB)",
0x28	:"Armenian em dash (U+2014)",
0x29	:"Armenian dot (U+002E)",
0x2A	:"Armenian comma (U+055D)",
0x2B	:"comma (U+002C)",
0x2C	:"Armenian en dash (U+002D)",
0x2D	:"Armenian yentamna (U+058A)",
0x2E	:"Armenian ellipsis (U+2026)",
0x2F	:"Armenian exclamation diacritic (U+055C)",
0x30	:"Armenian accent diacritic (U+055B)",
0x31	:"Armenian question diacritic (U+055E)",
0x32	:"Armenian capital letter ayb (U+0531)",
0x33	:"Armenian small letter ayb (U+0561)",
0x34	:"Armenian capital letter ben (U+0532)",
0x35	:"Armenian small letter ben (U+0562)",
0x36	:"Armenian capital letter gim (U+0533)",
0x37	:"Armenian small letter gim (U+0563)",
0x38	:"Armenian capital letter da (U+0534)",
0x39	:"Armenian small letter da (U+0564)",
0x3A	:"Armenian capital letter yech (U+0535)",
0x3B	:"Armenian small letter yech (U+0565)",
0x3C	:"Armenian capital letter za (U+0536)",
0x3D	:"Armenian small letter za (U+0566)",
0x3E	:"Armenian capital letter e (U+0537)",
0x3F	:"Armenian small letter e (U+0567)",
0x40	:"Armenian capital letter at (U+0538)",
0x41	:"Armenian small letter at (U+0568)",
0x42	:"Armenian capital letter to (U+0539)",
0x43	:"Armenian small letter to (U+0569)",
0x44	:"Armenian capital letter zhe (U+053A)",
0x45	:"Armenian small letter zhe (U+056A)",
0x46	:"Armenian capital letter ini (U+053B)",
0x47	:"Armenian small letter ini (U+056B)",
0x48	:"Armenian capital letter lyun (U+053C)",
0x49	:"Armenian small letter lyun (U+056C)",
0x4A	:"Armenian capital letter khe (U+053D)",
0x4B	:"Armenian small letter khe (U+056D)",
0x4C	:"Armenian capital letter tsa (U+053E)",
0x4D	:"Armenian small letter tsa (U+056E)",
0x4E	:"Armenian capital letter ken (U+053F)",
0x4F	:"Armenian small letter ken (U+056F)",
0x50	:"Armenian capital letter ho (U+0540)",
0x51	:"Armenian small letter ho (U+0570)",
0x52	:"Armenian capital letter dza (U+0541)",
0x53	:"Armenian small letter dza (U+0571)",
0x54	:"Armenian capital letter ghat (U+0542)",
0x55	:"Armenian small letter ghat (U+0572)",
0x56	:"Armenian capital letter tche (U+0543)",
0x57	:"Armenian small letter tche (U+0573)",
0x58	:"Armenian capital letter men (U+0544)",
0x59	:"Armenian small letter men (U+0574)",
0x5A	:"Armenian capital letter hi (U+0545)",
0x5B	:"Armenian small letter hi (U+0575)",
0x5C	:"Armenian capital letter nu (U+0546)",
0x5D	:"Armenian small letter nu (U+0576)",
0x5E	:"Armenian capital letter sha (U+0547)",
0x5F	:"Armenian small letter sha (U+0577)",
0x60	:"Armenian capital letter vo (U+0548)",
0x61	:"Armenian small letter vo (U+0578)",
0x62	:"Armenian capital letter cha (U+0549)",
0x63	:"Armenian small letter cha (U+0579)",
0x64	:"Armenian capital letter pe (U+054A)",
0x65	:"Armenian small letter pe (U+057A)",
0x66	:"Armenian capital letter je (U+054B)",
0x67	:"Armenian small letter je (U+057B)",
0x68	:"Armenian capital letter ra (U+054C)",
0x69	:"Armenian small letter ra (U+057C)",
0x6A	:"Armenian capital letter se (U+054D)",
0x6B	:"Armenian small letter se (U+057D)",
0x6C	:"Armenian capital letter vev (U+054E)",
0x6D	:"Armenian small letter vev (U+057E)",
0x6E	:"Armenian capital letter tyun (U+054F)",
0x6F	:"Armenian small letter tyun (U+057F)",
0x70	:"Armenian capital letter re (U+0550)",
0x71	:"Armenian small letter re (U+0580)",
0x72	:"Armenian capital letter tso (U+0551)",
0x73	:"Armenian small letter tso (U+0581)",
0x74	:"Armenian capital letter vyun (U+0552)",
0x75	:"Armenian small letter vyun (U+0582)",
0x76	:"Armenian capital letter pyur (U+0553)",
0x77	:"Armenian small letter pyur (U+0583)",
0x78	:"Armenian capital letter ke (U+0554)",
0x79	:"Armenian small letter ke (U+0584)",
0x7A	:"Armenian capital letter o (U+0555)",
0x7B	:"Armenian small letter o (U+0585)",
0x7C	:"Armenian capital letter fe (U+0556)",
0x7D	:"Armenian small letter fe (U+0586)",
0x7E	:"Armenian apostrophe (U+055A)",
0x7F	:"Unused",
0x80	:"Unused (7-bit encoding)",
0x81	:"Unused (7-bit encoding)",
0x82	:"Unused (7-bit encoding)",
0x83	:"Unused (7-bit encoding)",
0x84	:"Unused (7-bit encoding)",
0x85	:"Unused (7-bit encoding)",
0x86	:"Unused (7-bit encoding)",
0x87	:"Unused (7-bit encoding)",
0x88	:"Unused (7-bit encoding)",
0x89	:"Unused (7-bit encoding)",
0x8A	:"Unused (7-bit encoding)",
0x8B	:"Unused (7-bit encoding)",
0x8C	:"Unused (7-bit encoding)",
0x8D	:"Unused (7-bit encoding)",
0x8E	:"Unused (7-bit encoding)",
0x8F	:"Unused (7-bit encoding)",
0x90	:"Unused (7-bit encoding)",
0x91	:"Unused (7-bit encoding)",
0x92	:"Unused (7-bit encoding)",
0x93	:"Unused (7-bit encoding)",
0x94	:"Unused (7-bit encoding)",
0x95	:"Unused (7-bit encoding)",
0x96	:"Unused (7-bit encoding)",
0x97	:"Unused (7-bit encoding)",
0x98	:"Unused (7-bit encoding)",
0x99	:"Unused (7-bit encoding)",
0x9A	:"Unused (7-bit encoding)",
0x9B	:"Unused (7-bit encoding)",
0x9C	:"Unused (7-bit encoding)",
0x9D	:"Unused (7-bit encoding)",
0x9E	:"Unused (7-bit encoding)",
0x9F	:"Unused (7-bit encoding)",
0xA0	:"Unused (7-bit encoding)",
0xA1	:"Unused (7-bit encoding)",
0xA2	:"Unused (7-bit encoding)",
0xA3	:"Unused (7-bit encoding)",
0xA4	:"Unused (7-bit encoding)",
0xA5	:"Unused (7-bit encoding)",
0xA6	:"Unused (7-bit encoding)",
0xA7	:"Unused (7-bit encoding)",
0xA8	:"Unused (7-bit encoding)",
0xA9	:"Unused (7-bit encoding)",
0xAA	:"Unused (7-bit encoding)",
0xAB	:"Unused (7-bit encoding)",
0xAC	:"Unused (7-bit encoding)",
0xAD	:"Unused (7-bit encoding)",
0xAE	:"Unused (7-bit encoding)",
0xAF	:"Unused (7-bit encoding)",
0xB0	:"Unused (7-bit encoding)",
0xB1	:"Unused (7-bit encoding)",
0xB2	:"Unused (7-bit encoding)",
0xB3	:"Unused (7-bit encoding)",
0xB4	:"Unused (7-bit encoding)",
0xB5	:"Unused (7-bit encoding)",
0xB6	:"Unused (7-bit encoding)",
0xB7	:"Unused (7-bit encoding)",
0xB8	:"Unused (7-bit encoding)",
0xB9	:"Unused (7-bit encoding)",
0xBA	:"Unused (7-bit encoding)",
0xBB	:"Unused (7-bit encoding)",
0xBC	:"Unused (7-bit encoding)",
0xBD	:"Unused (7-bit encoding)",
0xBE	:"Unused (7-bit encoding)",
0xBF	:"Unused (7-bit encoding)",
0xC0	:"Unused (7-bit encoding)",
0xC1	:"Unused (7-bit encoding)",
0xC2	:"Unused (7-bit encoding)",
0xC3	:"Unused (7-bit encoding)",
0xC4	:"Unused (7-bit encoding)",
0xC5	:"Unused (7-bit encoding)",
0xC6	:"Unused (7-bit encoding)",
0xC7	:"Unused (7-bit encoding)",
0xC8	:"Unused (7-bit encoding)",
0xC9	:"Unused (7-bit encoding)",
0xCA	:"Unused (7-bit encoding)",
0xCB	:"Unused (7-bit encoding)",
0xCC	:"Unused (7-bit encoding)",
0xCD	:"Unused (7-bit encoding)",
0xCE	:"Unused (7-bit encoding)",
0xCF	:"Unused (7-bit encoding)",
0xD0	:"Unused (7-bit encoding)",
0xD1	:"Unused (7-bit encoding)",
0xD2	:"Unused (7-bit encoding)",
0xD3	:"Unused (7-bit encoding)",
0xD4	:"Unused (7-bit encoding)",
0xD5	:"Unused (7-bit encoding)",
0xD6	:"Unused (7-bit encoding)",
0xD7	:"Unused (7-bit encoding)",
0xD8	:"Unused (7-bit encoding)",
0xD9	:"Unused (7-bit encoding)",
0xDA	:"Unused (7-bit encoding)",
0xDB	:"Unused (7-bit encoding)",
0xDC	:"Unused (7-bit encoding)",
0xDD	:"Unused (7-bit encoding)",
0xDE	:"Unused (7-bit encoding)",
0xDF	:"Unused (7-bit encoding)",
0xE0	:"Unused (7-bit encoding)",
0xE1	:"Unused (7-bit encoding)",
0xE2	:"Unused (7-bit encoding)",
0xE3	:"Unused (7-bit encoding)",
0xE4	:"Unused (7-bit encoding)",
0xE5	:"Unused (7-bit encoding)",
0xE6	:"Unused (7-bit encoding)",
0xE7	:"Unused (7-bit encoding)",
0xE8	:"Unused (7-bit encoding)",
0xE9	:"Unused (7-bit encoding)",
0xEA	:"Unused (7-bit encoding)",
0xEB	:"Unused (7-bit encoding)",
0xEC	:"Unused (7-bit encoding)",
0xED	:"Unused (7-bit encoding)",
0xEE	:"Unused (7-bit encoding)",
0xEF	:"Unused (7-bit encoding)",
0xF0	:"Unused (7-bit encoding)",
0xF1	:"Unused (7-bit encoding)",
0xF2	:"Unused (7-bit encoding)",
0xF3	:"Unused (7-bit encoding)",
0xF4	:"Unused (7-bit encoding)",
0xF5	:"Unused (7-bit encoding)",
0xF6	:"Unused (7-bit encoding)",
0xF7	:"Unused (7-bit encoding)",
0xF8	:"Unused (7-bit encoding)",
0xF9	:"Unused (7-bit encoding)",
0xFA	:"Unused (7-bit encoding)",
0xFB	:"Unused (7-bit encoding)",
0xFC	:"Unused (7-bit encoding)",
0xFD	:"Unused (7-bit encoding)",
0xFE	:"Unused (7-bit encoding)",
0xFF	:"Unused (7-bit encoding)"
}


#ARMSCII8 (Armenian) Defined in AST 34.002
armscii8xtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0a	:"Unused",
0x0b	:"Unused",
0x0c	:"Unused",
0x0d	:"Unused",
0x0e	:"Unused",
0x0f	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1a	:"Unused",
0x1b	:"Unused",
0x1c	:"Unused",
0x1d	:"Unused",
0x1e	:"Unused",
0x1f	:"Unused",
0x20	:"Space",
0x21	:"Exclamation point",
0x22	:"Double quote",
0x23	:"Pound sign",
0x24	:"Dollar sign",
0x25	:"Percent sign",
0x26	:"Ampersand",
0x27	:"Right single quote / apostrophe",
0x28	:"Left parenthesis",
0x29	:"Right parenthesis",
0x2a	:"Asterisk",
0x2b	:"Plus",
0x2c	:"Comma",
0x2d	:"Hyphen",
0x2e	:"Period",
0x2f	:"Slash",
0x30	:"Latin digit 0",
0x31	:"Latin digit 1",
0x32	:"Latin digit 2",
0x33	:"Latin digit 3",
0x34	:"Latin digit 4",
0x35	:"Latin digit 5",
0x36	:"Latin digit 6",
0x37	:"Latin digit 7",
0x38	:"Latin digit 8",
0x39	:"Latin digit 9",
0x3a	:"Colon",
0x3b	:"Semi-colon",
0x3c	:"Less-than",
0x3d	:"Equal-sign",
0x3e	:"Greater-than",
0x3f	:"Question mark",
0x40	:"At-sign",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5b	:"Left square bracket",
0x5c	:"Backslash",
0x5d	:"Right square bracket",
0x5e	:"Caret",
0x5f	:"Underscore",
0x60	:"Left single quote",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7b	:"Left curly bracket",
0x7c	:"Pipe",
0x7d	:"Right curly bracket",
0x7e	:"Tilde",
0x7f	:"DEL",
0x80	:"Unused",
0x81	:"Unused",
0x82	:"Unused",
0x83	:"Unused",
0x84	:"Unused",
0x85	:"Unused",
0x86	:"Unused",
0x87	:"Unused",
0x88	:"Unused",
0x89	:"Unused",
0x8A	:"Unused",
0x8B	:"Unused",
0x8C	:"Unused",
0x8D	:"Unused",
0x8E	:"Unused",
0x8F	:"Unused",
0x90	:"Unused",
0x91	:"Unused",
0x92	:"Unused",
0x93	:"Unused",
0x94	:"Unused",
0x95	:"Unused",
0x96	:"Unused",
0x97	:"Unused",
0x98	:"Unused",
0x99	:"Unused",
0x9A	:"Unused",
0x9B	:"Unused",
0x9C	:"Unused",
0x9D	:"Unused",
0x9E	:"Unused",
0x9F	:"Unused",
0xA0	:"Unused",
0xA1	:"Armenian eternity symbol (no Unicode codepoint)",
0xA2	:"Armenian letter ew (U+0587)",
0xA3	:"Armenian fullstop (U+0589)",
0xA4	:"Armenian parenright (U+0029)",
0xA5	:"Armenian parenleft (U+0028)",
0xA6	:"Armenian quotright (U+00BB)",
0xA7	:"Armenian quotleft (U+00AB)",
0xA8	:"Armenian emdash (U+2014)",
0xA9	:"Armenian dot (U+002E)",
0xAA	:"Armenian sep (U+055D)",
0xAB	:"Armenian comma (U+002C)",
0xAC	:"Armenian endash (U+002D)",
0xAD	:"Armenian yentamna (U+058A)",
0xAE	:"Armenian ellipsis (U+2026)",
0xAF	:"Armenian exclamation diacritic (U+055C)",
0xB0	:"Armenian accent diacritic (U+055B)",
0xB1	:"Armenian question diacritic (U+055E)",
0xB2	:"Armenian capital letter ayb (U+0531)",
0xB3	:"Armenian small ayb (U+0561)",
0xB4	:"Armenian capital letter ben (U+0532)",
0xB5	:"Armenian small ben (U+0562)",
0xB6	:"Armenian capital letter gim (U+0533)",
0xB7	:"Armenian small gim (U+0563)",
0xB8	:"Armenian capital letter da (U+0534)",
0xB9	:"Armenian small da (U+0564)",
0xBA	:"Armenian capital letter yech (U+0535)",
0xBB	:"Armenian small yech (U+0565)",
0xBC	:"Armenian capital letter za (U+0536)",
0xBD	:"Armenian small za (U+0566)",
0xBE	:"Armenian capital letter e (U+0537)",
0xBF	:"Armenian small e (U+0567)",
0xC0	:"Armenian capital letter at (U+0538)",
0xC1	:"Armenian small at (U+0568)",
0xC2	:"Armenian capital letter to (U+0539)",
0xC3	:"Armenian small to (U+0569)",
0xC4	:"Armenian capital letter zhe (U+053A)",
0xC5	:"Armenian small zhe (U+056A)",
0xC6	:"Armenian capital letter ini (U+053B)",
0xC7	:"Armenian small ini (U+056B)",
0xC8	:"Armenian capital letter lyun (U+053C)",
0xC9	:"Armenian small lyun (U+056C)",
0xCA	:"Armenian capital letter khe (U+053D)",
0xCB	:"Armenian small khe (U+056D)",
0xCC	:"Armenian capital letter tsa (U+053E)",
0xCD	:"Armenian small tsa (U+056E)",
0xCE	:"Armenian capital letter ken (U+053F)",
0xCF	:"Armenian small ken (U+056F)",
0xD0	:"Armenian capital letter ho (U+0540)",
0xD1	:"Armenian small ho (U+0570)",
0xD2	:"Armenian capital letter dza (U+0541)",
0xD3	:"Armenian small dza (U+0571)",
0xD4	:"Armenian capital letter ghat (U+0542)",
0xD5	:"Armenian small ghat (U+0572)",
0xD6	:"Armenian capital letter tche (U+0543)",
0xD7	:"Armenian small tche (U+0573)",
0xD8	:"Armenian capital letter men (U+0544)",
0xD9	:"Armenian small men (U+0574)",
0xDA	:"Armenian capital letter hi (U+0545)",
0xDB	:"Armenian small hi (U+0575)",
0xDC	:"Armenian capital letter nu (U+0546)",
0xDD	:"Armenian small nu (U+0576)",
0xDE	:"Armenian capital letter sha (U+0547)",
0xDF	:"Armenian small sha (U+0577)",
0xE0	:"Armenian capital letter vo (U+0548)",
0xE1	:"Armenian small vo (U+0578)",
0xE2	:"Armenian capital letter cha (U+0549)",
0xE3	:"Armenian small cha (U+0579)",
0xE4	:"Armenian capital letter pe (U+054A)",
0xE5	:"Armenian small pe (U+057A)",
0xE6	:"Armenian capital letter je (U+054B)",
0xE7	:"Armenian small je (U+057B)",
0xE8	:"Armenian capital letter ra (U+054C)",
0xE9	:"Armenian small ra (U+057C)",
0xEA	:"Armenian capital letter se (U+054D)",
0xEB	:"Armenian small se (U+057D)",
0xEC	:"Armenian capital letter vev (U+054E)",
0xED	:"Armenian small vev (U+057E)",
0xEE	:"Armenian capital letter tyun (U+054F)",
0xEF	:"Armenian small tyun (U+057F)",
0xF0	:"Armenian capital letter re (U+0550)",
0xF1	:"Armenian small re (U+0580)",
0xF2	:"Armenian capital letter tso (U+0551)",
0xF3	:"Armenian small tso (U+0581)",
0xF4	:"Armenian capital letter vyun (U+0552)",
0xF5	:"Armenian small vyun (U+0582)",
0xF6	:"Armenian capital letter pyur (U+0553)",
0xF7	:"Armenian small pyur (U+0583)",
0xF8	:"Armenian capital letter ke (U+0554)",
0xF9	:"Armenian small ke (U+0584)",
0xFA	:"Armenian capital letter o (U+0555)",
0xFB	:"Armenian small o (U+0585)",
0xFC	:"Armenian capital letter fe (U+0556)",
0xFD	:"Armenian small fe (U+0586)",
0xFE	:"Armenian apostrophe (U+055A)",
0xFF	:"Unused"
}

#ARMSCII8A (Armenian) Defined in AST 34.002
armscii8axtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Armenian small letter ew (U+0587)",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"Unused",
0x21	:"Unused",
0x22	:"Unused",
0x23	:"Unused",
0x24	:"Unused",
0x25	:"Unused",
0x26	:"Unused",
0x27	:"Armenian accent diacritic (U+055B)",
0x28	:"Armenian left parenthesis (U+0028)",
0x29	:"Armenian right parenthesis (U+0029)",
0x2A	:"Unused",
0x2B	:"Unused",
0x2C	:"Armenian comma (U+002C)",
0x2D	:"Armenian emdash (U+2014)",
0x2E	:"Armenian dot (U+002E)",
0x2F	:"Unused",
0x30	:"Unused",
0x31	:"Unused",
0x32	:"Unused",
0x33	:"Unused",
0x34	:"Unused",
0x35	:"Unused",
0x36	:"Unused",
0x37	:"Unused",
0x38	:"Unused",
0x39	:"Unused",
0x3A	:"Armenian fullstop (U+0589)",
0x3B	:"Unused",
0x3C	:"Unused",
0x3D	:"Unused",
0x3E	:"Unused",
0x3F	:"Unused",
0x40	:"Unused",
0x41	:"Unused",
0x42	:"Unused",
0x43	:"Unused",
0x44	:"Unused",
0x45	:"Unused",
0x46	:"Unused",
0x47	:"Unused",
0x48	:"Unused",
0x49	:"Unused",
0x4A	:"Unused",
0x4B	:"Unused",
0x4C	:"Unused",
0x4D	:"Unused",
0x4E	:"Unused",
0x4F	:"Unused",
0x50	:"Unused",
0x51	:"Unused",
0x52	:"Unused",
0x53	:"Unused",
0x54	:"Unused",
0x55	:"Unused",
0x56	:"Unused",
0x57	:"Unused",
0x58	:"Unused",
0x59	:"Unused",
0x5A	:"Unused",
0x5B	:"Unused",
0x5C	:"Unused",
0x5D	:"Unused",
0x5E	:"Unused",
0x5F	:"Armenian endash (U+002D)",
0x60	:"Armenian small letter sep (U+055D)",
0x61	:"Unused",
0x62	:"Unused",
0x63	:"Unused",
0x64	:"Unused",
0x65	:"Unused",
0x66	:"Unused",
0x67	:"Unused",
0x68	:"Unused",
0x69	:"Unused",
0x6A	:"Unused",
0x6B	:"Unused",
0x6C	:"Unused",
0x6D	:"Unused",
0x6E	:"Unused",
0x6F	:"Unused",
0x70	:"Unused",
0x71	:"Unused",
0x72	:"Unused",
0x73	:"Unused",
0x74	:"Unused",
0x75	:"Unused",
0x76	:"Unused",
0x77	:"Unused",
0x78	:"Unused",
0x79	:"Unused",
0x7A	:"Unused",
0x7B	:"Unused",
0x7C	:"Unused",
0x7D	:"Unused",
0x7E	:"Armenian exclamation diacritic (U+055C)",
0x7F	:"Unused",
0x80	:"Armenian capital letter ayb (U+0531)",
0x81	:"Armenian small letter ayb (U+0561)",
0x82	:"Armenian capital letter ben (U+0532)",
0x83	:"Armenian small letter ben (U+0562)",
0x84	:"Armenian capital letter gim (U+0533)",
0x85	:"Armenian small letter gim (U+0563)",
0x86	:"Armenian capital letter da (U+0534)",
0x87	:"Armenian small letter da (U+0564)",
0x88	:"Armenian capital letter yech (U+0535)",
0x89	:"Armenian small letter yech (U+0565)",
0x8A	:"Armenian capital letter za (U+0536)",
0x8B	:"Armenian small letter za (U+0566)",
0x8C	:"Armenian capital letter e (U+0537)",
0x8D	:"Armenian small letter e (U+0567)",
0x8E	:"Armenian capital letter at (U+0538)",
0x8F	:"Armenian small letter at (U+0568)",
0x90	:"Armenian capital letter to (U+0539)",
0x91	:"Armenian small letter to (U+0569)",
0x92	:"Armenian capital letter zhe (U+053A)",
0x93	:"Armenian small letter zhe (U+056A)",
0x94	:"Armenian capital letter ini (U+053B)",
0x95	:"Armenian small letter ini (U+056B)",
0x96	:"Armenian capital letter lyun (U+053C)",
0x97	:"Armenian small letter lyun (U+056C)",
0x98	:"Armenian capital letter khe (U+053D)",
0x99	:"Armenian small letter khe (U+056D)",
0x9A	:"Armenian capital letter tsa (U+053E)",
0x9B	:"Armenian small letter tsa (U+056E)",
0x9C	:"Armenian capital letter ken (U+053F)",
0x9D	:"Armenian small letter ken (U+056F)",
0x9E	:"Armenian capital letter ho (U+0540)",
0x9F	:"Armenian small letter ho (U+0570)",
0xA0	:"Armenian capital letter dza (U+0541)",
0xA1	:"Armenian small letter dza (U+0571)",
0xA2	:"Armenian capital letter ghat (U+0542)",
0xA3	:"Armenian small letter ghat (U+0572)",
0xA4	:"Armenian capital letter tche (U+0543)",
0xA5	:"Armenian small letter tche (U+0573)",
0xA6	:"Armenian capital letter men (U+0544)",
0xA7	:"Armenian small letter men (U+0574)",
0xA8	:"Armenian capital letter hi (U+0545)",
0xA9	:"Armenian small letter hi (U+0575)",
0xAA	:"Armenian capital letter nu (U+0546)",
0xAB	:"Armenian small letter nu (U+0576)",
0xAC	:"Armenian capital letter sha (U+0547)",
0xAD	:"Armenian small letter sha (U+0577)",
0xAE	:"Armenian left quote (U+00AB)",
0xAF	:"Armenian right quote (U+00BB)",
0xB0	:"Unused",
0xB1	:"Unused",
0xB2	:"Unused",
0xB3	:"Unused",
0xB4	:"Unused",
0xB5	:"Unused",
0xB6	:"Unused",
0xB7	:"Unused",
0xB8	:"Unused",
0xB9	:"Unused",
0xBA	:"Unused",
0xBB	:"Unused",
0xBC	:"Unused",
0xBD	:"Unused",
0xBE	:"Unused",
0xBF	:"Unused",
0xC0	:"Unused",
0xC1	:"Unused",
0xC2	:"Unused",
0xC3	:"Unused",
0xC4	:"Unused",
0xC5	:"Unused",
0xC6	:"Unused",
0xC7	:"Unused",
0xC8	:"Unused",
0xC9	:"Unused",
0xCA	:"Unused",
0xCB	:"Unused",
0xCC	:"Unused",
0xCD	:"Unused",
0xCE	:"Unused",
0xCF	:"Unused",
0xD0	:"Unused",
0xD1	:"Unused",
0xD2	:"Unused",
0xD3	:"Unused",
0xD4	:"Unused",
0xD5	:"Unused",
0xD6	:"Unused",
0xD7	:"Unused",
0xD8	:"Unused",
0xD9	:"Unused",
0xDA	:"Unused",
0xDB	:"Unused",
0xDC	:"Armenian eternity symbol (no Unicode codepoint)",
0xDD	:"Armenian yentamna (U+058A)",
0xDE	:"Armenian ellipsis (U+2026)",
0xDF	:"Armenian question diacritic (U+055E)",
0xE0	:"Armenian capital letter vo (U+0548)",
0xE1	:"Armenian small letter vo (U+0578)",
0xE2	:"Armenian capital letter cha (U+0549)",
0xE3	:"Armenian small letter cha (U+0579)",
0xE4	:"Armenian capital letter pe (U+054A)",
0xE5	:"Armenian small letter pe (U+057A)",
0xE6	:"Armenian capital letter je (U+054B)",
0xE7	:"Armenian small letter je (U+057B)",
0xE8	:"Armenian capital letter ra (U+054C)",
0xE9	:"Armenian small letter ra (U+057C)",
0xEA	:"Armenian capital letter se (U+054D)",
0xEB	:"Armenian small letter se (U+057D)",
0xEC	:"Armenian capital letter vev (U+054E)",
0xED	:"Armenian small letter vev (U+057E)",
0xEE	:"Armenian capital letter tyun (U+054F)",
0xEF	:"Armenian small letter tyun (U+057F)",
0xF0	:"Armenian capital letter re (U+0550)",
0xF1	:"Armenian small letter re (U+0580)",
0xF2	:"Armenian capital letter tso (U+0551)",
0xF3	:"Armenian small letter tso (U+0581)",
0xF4	:"Armenian capital letter vyun (U+0552)",
0xF5	:"Armenian small letter vyun (U+0582)",
0xF6	:"Armenian capital letter pyur (U+0553)",
0xF7	:"Armenian small letter pyur (U+0583)",
0xF8	:"Armenian capital letter ke (U+0554)",
0xF9	:"Armenian small letter ke (U+0584)",
0xFA	:"Armenian capital letter o (U+0555)",
0xFB	:"Armenian small letter o (U+0585)",
0xFC	:"Armenian capital letter fe (U+0556)",
0xFD	:"Armenian small letter fe (U+0586)",
0xFE	:"Armenian apostrophe (U+055A)",
0xFF	:"Unused"
}

#Atari ST encoding
ataristxtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"Latin capital letter c with cedilla (U+00C7)",
0x81	:"Latin small letter u with diaeresis (U+00FC)",
0x82	:"Latin small letter e with acute (U+00E9)",
0x83	:"Latin small letter a with circumflex (U+00E2)",
0x84	:"Latin small letter a with diaeresis (U+00E4)",
0x85	:"Latin small letter a with grave (U+00E0)",
0x86	:"Latin small letter a with ring above (U+00E5)",
0x87	:"Latin small letter c with cedilla (U+00E7)",
0x88	:"Latin small letter e with circumflex (U+00EA)",
0x89	:"Latin small letter e with diaeresis (U+00EB)",
0x8A	:"Latin small letter e with grave (U+00E8)",
0x8B	:"Latin small letter i with diaeresis (U+00EF)",
0x8C	:"Latin small letter i with circumflex (U+00EE)",
0x8D	:"Latin small letter i with grave (U+00EC)",
0x8E	:"Latin capital letter a with diaeresis (U+00C4)",
0x8F	:"Latin capital letter a with ring above (U+00C5)",
0x90	:"Latin capital letter e with acute (U+00C9)",
0x91	:"Latin small ligature ae (U+00E6)",
0x92	:"Latin capital ligature ae (U+00C6)",
0x93	:"Latin small letter o with circumflex (U+00F4)",
0x94	:"Latin small letter o with diaeresis (U+00F6)",
0x95	:"Latin small letter o with grave (U+00F2)",
0x96	:"Latin small letter u with circumflex (U+00FB)",
0x97	:"Latin small letter u with grave (U+00F9)",
0x98	:"Latin small letter y with diaeresis (U+00FF)",
0x99	:"Latin small letter o with diaeresis (U+00D6)",
0x9A	:"Latin small letter u with diaeresis (U+00DC)",
0x9B	:"cent sign (U+00A2)",
0x9C	:"pound sign (U+00A3)",
0x9D	:"yen sign (U+00A5)",
0x9E	:"Latin small letter sharp s (U+00DF)",
0x9F	:"Latin small letter f with hook (U+0192)",
0xA0	:"Latin small letter a with acute (U+00E1)",
0xA1	:"Latin small letter i with acute (U+00ED)",
0xA2	:"Latin small letter o with acute (U+00F3)",
0xA3	:"Latin small letter u with acute (U+00FA)",
0xA4	:"Latin small letter n with tilde (U+00F1)",
0xA5	:"Latin capital letter n with tilde (U+00D1)",
0xA6	:"feminine ordinal indicator (U+00AA)",
0xA7	:"masculine ordinal indicator (U+00BA)",
0xA8	:"inverted question mark (U+00BF)",
0xA9	:"reversed not sign (U+2310)",
0xAA	:"not sign (U+00AC)",
0xAB	:"vulgar fraction one half (U+00BD)",
0xAC	:"vulgar fraction one quarter (U+00BC)",
0xAD	:"inverted exclamation mark (U+00A1)",
0xAE	:"left-pointing double angle quotation mark (U+00AB)",
0xAF	:"right-pointing double angle quotation mark (U+00BB)",
0xB0	:"Latin small letter a with tilde (U+00E3)",
0xB1	:"Latin small letter o with tilde (U+00F5)",
0xB2	:"Latin capital letter o with stroke (U+00D8)",
0xB3	:"Latin small letter o with stroke (U+00F8)",
0xB4	:"Latin small ligature oe (U+0153)",
0xB5	:"Latin capital ligature oe (U+0152)",
0xB6	:"Latin capital letter a with grave (U+00C0)",
0xB7	:"Latin capital letter a with tilde (U+00C3)",
0xB8	:"Latin capital letter o with tilde (U+00D5)",
0xB9	:"spacing diaeresis (U+00A8)",
0xBA	:"spacing acute accent (U+00B4)",
0xBB	:"dagger (U+2020)",
0xBC	:"pilcrow sign (U+00B6)",
0xBD	:"copyright sign (U+00A9)",
0xBE	:"registered sign (U+00AE)",
0xBF	:"trade mark sign (U+2122)",
0xC0	:"Latin small ligature ij (U+0133)",
0xC1	:"Latin capital ligature ij (U+0132)",
0xC2	:"Hebrew letter alef (U+05D0)",
0xC3	:"Hebrew letter bet (U+05D1)",
0xC4	:"Hebrew letter gimel (U+05D2)",
0xC5	:"Hebrew letter dalet (U+05D3)",
0xC6	:"Hebrew letter he (U+05D4)",
0xC7	:"Hebrew letter vav (U+05D5)",
0xC8	:"Hebrew letter zayin (U+05D6)",
0xC9	:"Hebrew letter het (U+05D7)",
0xCA	:"Hebrew letter tet (U+05D8)",
0xCB	:"Hebrew letter yod (U+05D9)",
0xCC	:"Hebrew letter kaf (U+05DB)",
0xCD	:"Hebrew letter lamed (U+05DC)",
0xCE	:"Hebrew letter mem (U+05DE)",
0xCF	:"Hebrew letter nun (U+05E0)",
0xD0	:"Hebrew letter samekh (U+05E1)",
0xD1	:"Hebrew letter ayin (U+05E2)",
0xD2	:"Hebrew letter pe (U+05E4)",
0xD3	:"Hebrew letter tsadi (U+05E6)",
0xD4	:"Hebrew letter qof (U+05E7)",
0xD5	:"Hebrew letter resh (U+05E8)",
0xD6	:"Hebrew letter shin (U+05E9)",
0xD7	:"Hebrew letter tav (U+05EA)",
0xD8	:"Hebrew letter final nun (U+05DF)",
0xD9	:"Hebrew letter final kaf (U+05DA)",
0xDA	:"Hebrew letter final mem (U+05DD)",
0xDB	:"Hebrew letter final pe (U+05E3)",
0xDC	:"Hebrew letter final tsadi (U+05E5)",
0xDD	:"section sign (U+00A7)",
0xDE	:"logical and (U+2227)",
0xDF	:"infinity (U+221E)",
0xE0	:"greek small letter alpha (U+03B1)",
0xE1	:"greek small letter beta (U+03B2)",
0xE2	:"greek capital letter gamma (U+0393)",
0xE3	:"greek small letter pi (U+03C0)",
0xE4	:"greek capital letter sigma (U+03A3)",
0xE5	:"greek small letter sigma (U+03C3)",
0xE6	:"micro sign (U+00B5)",
0xE7	:"greek small letter tau (U+03C4)",
0xE8	:"greek capital letter phi (U+03A6)",
0xE9	:"greek capital letter theta (U+0398)",
0xEA	:"greek capital letter omega (U+03A9)",
0xEB	:"greek small letter delta (U+03B4)",
0xEC	:"contour integral (U+222E)",
0xED	:"greek small letter phi (U+03C6)",
0xEE	:"element of sign (U+2208)",
0xEF	:"intersection (U+2229)",
0xF0	:"identical to (U+2261)",
0xF1	:"plus-minus sign (U+00B1)",
0xF2	:"greater-than or equal to (U+2265)",
0xF3	:"less-than or equal to (U+2264)",
0xF4	:"top half integral (U+2320)",
0xF5	:"bottom half integral (U+2321)",
0xF6	:"division sign (U+00F7)",
0xF7	:"almost equal to (U+2248)",
0xF8	:"degree sign (U+00B0)",
0xF9	:"bullet operator (U+2219)",
0xFA	:"middle dot (U+00B7)",
0xFB	:"square root (U+221A)",
0xFC	:"superscript Latin small letter n (U+207F)",
0xFD	:"superscript two (U+00B2)",
0xFE	:"superscript three (U+00B3)",
0xFF	:"macron (U+00AF)"
}


#Guarani encoding for Linux console by Pino Zollo (zp4kfx@amsat.org).
#Homepage at http://www.qsl.net/zp4kfx/Linux/index.html.
guaranixtbl={\
0x00	:"NUL (ASCII control character)",
0x01	:"SOH (ASCII control character)",
0x02	:"STX (ASCII control character)",
0x03	:"ETX (ASCII control character)",
0x04	:"EOT (ASCII control character)",
0x05	:"ENQ (ASCII control character)",
0x06	:"ACK (ASCII control character)",
0x07	:"BEL (ASCII control character)",
0x08	:"Backspace (ASCII control character)",
0x09	:"Tab (ASCII control character)",
0x0a	:"Newline",
0x0b	:"VT (ASCII control character)",
0x0c	:"FF (ASCII control character)",
0x0d	:"Carriage return",
0x0e	:"SO (ASCII control character)",
0x0f	:"SI (ASCII control character)",
0x10	:"DLE (ASCII control character)",
0x11	:"DC1 (ASCII control character)",
0x12	:"DC2 (ASCII control character)",
0x13	:"DC3 (ASCII control character)",
0x14	:"DC4 (ASCII control character)",
0x15	:"NAK (ASCII control character)",
0x16	:"SYN (ASCII control character)",
0x17	:"ETB (ASCII control character)",
0x18	:"CAN (ASCII control character)",
0x19	:"EM (ASCII control character)",
0x1a	:"SUB (ASCII control character)",
0x1b	:"ESC (ASCII control character)",
0x1c	:"FS (ASCII control character)",
0x1d	:"GS (ASCII control character)",
0x1e	:"RS (ASCII control character)",
0x1f	:"US (ASCII control character)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"<Control> (U+007F)",
0x80	:"Latin capital letter i with tilde (U+0128)",
0x81	:"Latin small letter u with tilde (U+0169)",
0x82	:"Latin small letter e with acute (U+00E9)",
0x83	:"Latin small letter a with circumflex (U+00E2)",
0x84	:"Latin small letter a with tilde (U+00E3)",
0x85	:"Latin small letter a with grave (U+00E0)",
0x86	:"Latin small letter g + combining tilde (U+0067 0x0303)",
0x87	:"Latin small letter e with grave (U+00E8)",
0x88	:"Latin small letter e with circumflex (U+00EA)",
0x89	:"Latin small letter e with tilde (U+1EBD)",
0x8A	:"Latin small letter e with grave (U+00E8)",
0x8B	:"Latin small letter i with tilde (U+0129)",
0x8C	:"Latin small letter i with circumflex (U+00EE)",
0x8D	:"Latin small letter i with grave (U+00EC)",
0x8E	:"Latin capital letter a with circumflex (U+00C2)",
0x8F	:"Latin capital letter a with tilde (U+00C3)",
0x90	:"Latin capital letter e with acute (U+00C9)",
0x91	:"Latin capital letter u with tilde (U+0168)",
0x92	:"Latin capital letter e with tilde (U+1EBC)",
0x93	:"Latin small letter o with circumflex (U+00F4)",
0x94	:"Latin small letter o with tilde (U+00F5)",
0x95	:"Latin small letter o with grave (U+00F2)",
0x96	:"Latin small letter u with circumflex (U+00FB)",
0x97	:"Latin small letter u with grave (U+00F9)",
0x98	:"Latin small letter y with tilde (U+1EF9)",
0x99	:"Latin capital letter o with tilde (U+00D5)",
0x9A	:"Latin capital letter u with circumflex (U+00DB)",
0x9B	:"Latin capital letter u with tilde (U+0168)",
0x9C	:"Latin capital letter y with tilde (U+1EF8)",
0x9D	:"Latin capital letter a with acute (U+00C1)",
0x9E	:"Latin capital letter i with acute (U+00CD)",
0x9F	:"Latin capital letter o with acute (U+00D3)",
0xA0	:"Latin small letter a with acute (U+00E1)",
0xA1	:"Latin small letter i with acute (U+00ED)",
0xA2	:"Latin small letter o with acute (U+00F3)",
0xA3	:"Latin small letter u with acute (U+00FA)",
0xA4	:"Latin small letter n with tilde (U+00F1)",
0xA5	:"Latin capital letter n with tilde (U+00D1)",
0xA6	:"feminine ordinal indicator (U+00AA)",
0xA7	:"masculine ordinal indicator (U+00BA)",
0xA8	:"inverted question mark (U+00BF)",
0xA9	:"not sign (U+00AC)",
0xAA	:"reversed not sign (U+2310)",
0xAB	:"vulgar fraction one half (U+00BD)",
0xAC	:"vulgar fraction one quarter (U+00BC)",
0xAD	:"inverted exclamation mark (U+00A1)",
0xAE	:"left-pointing double angle quotation mark (U+00AB)",
0xAF	:"right-pointing double angle quotation mark (U+00BB)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"box drawings vertical single and left double (U+2561)",
0xB6	:"box drawings vertical double and left single (U+2562)",
0xB7	:"box drawings down double and left single (U+2556)",
0xB8	:"box drawings down single and left double (U+2555)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255D)",
0xBD	:"box drawings up double and left single (U+255C)",
0xBE	:"box drawings up single and left double (U+255B)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252C)",
0xC3	:"box drawings light vertical and right (U+251C)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253C)",
0xC6	:"box drawings vertical single and right double (U+255E)",
0xC7	:"box drawings vertical double and right single (U+255F)",
0xC8	:"box drawings double up and right (U+255A)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256C)",
0xCF	:"box drawings up single and horizontal double (U+2567)",
0xD0	:"box drawings up double and horizontal single (U+2568)",
0xD1	:"box drawings down single and horizontal double (U+2564)",
0xD2	:"box drawings down double and horizontal single (U+2565)",
0xD3	:"box drawings up double and right single (U+2559)",
0xD4	:"box drawings up single and right double (U+2558)",
0xD5	:"box drawings down single and right double (U+2552)",
0xD6	:"box drawings down double and right single (U+2553)",
0xD7	:"box drawings vertical double and horizontal single (U+256B)",
0xD8	:"box drawings vertical single and horizontal double (U+256A)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250C)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"left half block (U+258C)",
0xDE	:"right half block (U+2590)",
0xDF	:"upper half block (U+2580)",
0xE0	:"Latin capital letter u with acute (U+00DA)",
0xE1	:"Latin capital letter y with acute (U+00DD)",
0xE2	:"Latin small letter y with acute (U+00FD)",
0xE3	:"Latin small letter y with grave (U+1EF3)",
0xE4	:"Latin capital letter g + combining tilde (U+0047 0x0303)",
0xE5	:"greek small letter sigma (U+03C3)",
0xE6	:"micro sign (U+00B5)",
0xE7	:"greek small letter gamma (U+03B3)",
0xE8	:"replacement character (U+FFFD)",
0xE9	:"greek small letter theta (U+03B8)",
0xEA	:"greek capital letter omega (U+03A9)",
0xEB	:"greek small letter delta (U+03B4)",
0xEC	:"infinity (U+221E)",
0xED	:"empty set (U+2205)",
0xEE	:"element of (U+2208)",
0xEF	:"intersection (U+2229)",
0xF0	:"identical to (U+2261)",
0xF1	:"plus-minus sign (U+00B1)",
0xF2	:"greater-than or equal to (U+2265)",
0xF3	:"less-than or equal to (U+2264)",
0xF4	:"top half integral (U+2320)",
0xF5	:"bottom half integral (U+2321)",
0xF6	:"division sign (U+00F7)",
0xF7	:"almost equal to (U+2248)",
0xF8	:"degree sign (U+00B0)",
0xF9	:"dot operator (U+22C5)",
0xFA	:"dot operator (U+22C5)",
0xFB	:"square root (U+221A)",
0xFC	:"superscript Latin small letter n (U+207F)",
0xFD	:"superscript two (U+00B2)",
0xFE	:"black small square (U+25AA)",
0xFF	:"replacement character (U+FFFD)"
}

#GSM0388
gsm0388xtbl={\
0x00	:"commercial at (U+0040)",
0x01	:"pound sign (U+00A3)",
0x02	:"dollar sign (U+0024)",
0x03	:"yen sign (U+00A5)",
0x04	:"Latin small letter e with grave (U+00E8)",
0x05	:"Latin small letter e with acute (U+00E9)",
0x06	:"Latin small letter u with grave (U+00F9)",
0x07	:"Latin small letter i with grave (U+00EC)",
0x08	:"Latin small letter o with grave (U+00F2)",
0x09	:"Latin small letter c with cedilla (U+00E7)",
0x0A	:"line feed (U+000A)",
0x0B	:"Latin capital letter o with stroke (U+00D8)",
0x0C	:"Latin small letter o with stroke (U+00F8)",
0x0D	:"carriage return (U+000D)",
0x0E	:"Latin capital letter a with ring above (U+00C5)",
0x0F	:"Latin small letter a with ring above (U+00E5)",
0x10	:"greek capital letter delta (U+0394)",
0x11	:"low line (U+005F)",
0x12	:"greek capital letter phi (U+03A6)",
0x13	:"greek capital letter gamma (U+0393)",
0x14	:"greek capital letter lamda (U+039B)",
0x15	:"greek capital letter omega (U+03A9)",
0x16	:"greek capital letter pi (U+03A0)",
0x17	:"greek capital letter psi (U+03A8)",
0x18	:"greek capital letter sigma (U+03A3)",
0x19	:"greek capital letter theta (U+0398)",
0x1A	:"greek capital letter xi (U+039E)",
0x1B	:"escape to extension table",
0x1C	:"Latin capital letter ae (U+00C6)",
0x1D	:"Latin small letter ae (U+00E6)",
0x1E	:"Latin small letter sharp s (german) (U+00DF)",
0x1F	:"Latin capital letter e with acute (U+00C9)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"currency sign (U+00A4)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"inverted exclamation mark (U+00A1)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"Latin capital letter a with diaeresis (U+00C4)",
0x5C	:"Latin capital letter o with diaeresis (U+00D6)",
0x5D	:"Latin capital letter n with tilde (U+00D1)",
0x5E	:"Latin capital letter u with diaeresis (U+00DC)",
0x5F	:"section sign (U+00A7)",
0x60	:"inverted question mark (U+00BF)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"Latin small letter a with diaeresis (U+00E4)",
0x7C	:"Latin small letter o with diaeresis (U+00F6)",
0x7D	:"Latin small letter n with tilde (U+00F1)",
0x7E	:"Latin small letter u with diaeresis (U+00FC)",
0x7F	:"Latin small letter a with grave (U+00E0)",
0x80	:"Unused (7-bit encoding)",
0x81	:"Unused (7-bit encoding)",
0x82	:"Unused (7-bit encoding)",
0x83	:"Unused (7-bit encoding)",
0x84	:"Unused (7-bit encoding)",
0x85	:"Unused (7-bit encoding)",
0x86	:"Unused (7-bit encoding)",
0x87	:"Unused (7-bit encoding)",
0x88	:"Unused (7-bit encoding)",
0x89	:"Unused (7-bit encoding)",
0x8A	:"Unused (7-bit encoding)",
0x8B	:"Unused (7-bit encoding)",
0x8C	:"Unused (7-bit encoding)",
0x8D	:"Unused (7-bit encoding)",
0x8E	:"Unused (7-bit encoding)",
0x8F	:"Unused (7-bit encoding)",
0x90	:"Unused (7-bit encoding)",
0x91	:"Unused (7-bit encoding)",
0x92	:"Unused (7-bit encoding)",
0x93	:"Unused (7-bit encoding)",
0x94	:"Unused (7-bit encoding)",
0x95	:"Unused (7-bit encoding)",
0x96	:"Unused (7-bit encoding)",
0x97	:"Unused (7-bit encoding)",
0x98	:"Unused (7-bit encoding)",
0x99	:"Unused (7-bit encoding)",
0x9A	:"Unused (7-bit encoding)",
0x9B	:"Unused (7-bit encoding)",
0x9C	:"Unused (7-bit encoding)",
0x9D	:"Unused (7-bit encoding)",
0x9E	:"Unused (7-bit encoding)",
0x9F	:"Unused (7-bit encoding)",
0xA0	:"Unused (7-bit encoding)",
0xA1	:"Unused (7-bit encoding)",
0xA2	:"Unused (7-bit encoding)",
0xA3	:"Unused (7-bit encoding)",
0xA4	:"Unused (7-bit encoding)",
0xA5	:"Unused (7-bit encoding)",
0xA6	:"Unused (7-bit encoding)",
0xA7	:"Unused (7-bit encoding)",
0xA8	:"Unused (7-bit encoding)",
0xA9	:"Unused (7-bit encoding)",
0xAA	:"Unused (7-bit encoding)",
0xAB	:"Unused (7-bit encoding)",
0xAC	:"Unused (7-bit encoding)",
0xAD	:"Unused (7-bit encoding)",
0xAE	:"Unused (7-bit encoding)",
0xAF	:"Unused (7-bit encoding)",
0xB0	:"Unused (7-bit encoding)",
0xB1	:"Unused (7-bit encoding)",
0xB2	:"Unused (7-bit encoding)",
0xB3	:"Unused (7-bit encoding)",
0xB4	:"Unused (7-bit encoding)",
0xB5	:"Unused (7-bit encoding)",
0xB6	:"Unused (7-bit encoding)",
0xB7	:"Unused (7-bit encoding)",
0xB8	:"Unused (7-bit encoding)",
0xB9	:"Unused (7-bit encoding)",
0xBA	:"Unused (7-bit encoding)",
0xBB	:"Unused (7-bit encoding)",
0xBC	:"Unused (7-bit encoding)",
0xBD	:"Unused (7-bit encoding)",
0xBE	:"Unused (7-bit encoding)",
0xBF	:"Unused (7-bit encoding)",
0xC0	:"Unused (7-bit encoding)",
0xC1	:"Unused (7-bit encoding)",
0xC2	:"Unused (7-bit encoding)",
0xC3	:"Unused (7-bit encoding)",
0xC4	:"Unused (7-bit encoding)",
0xC5	:"Unused (7-bit encoding)",
0xC6	:"Unused (7-bit encoding)",
0xC7	:"Unused (7-bit encoding)",
0xC8	:"Unused (7-bit encoding)",
0xC9	:"Unused (7-bit encoding)",
0xCA	:"Unused (7-bit encoding)",
0xCB	:"Unused (7-bit encoding)",
0xCC	:"Unused (7-bit encoding)",
0xCD	:"Unused (7-bit encoding)",
0xCE	:"Unused (7-bit encoding)",
0xCF	:"Unused (7-bit encoding)",
0xD0	:"Unused (7-bit encoding)",
0xD1	:"Unused (7-bit encoding)",
0xD2	:"Unused (7-bit encoding)",
0xD3	:"Unused (7-bit encoding)",
0xD4	:"Unused (7-bit encoding)",
0xD5	:"Unused (7-bit encoding)",
0xD6	:"Unused (7-bit encoding)",
0xD7	:"Unused (7-bit encoding)",
0xD8	:"Unused (7-bit encoding)",
0xD9	:"Unused (7-bit encoding)",
0xDA	:"Unused (7-bit encoding)",
0xDB	:"Unused (7-bit encoding)",
0xDC	:"Unused (7-bit encoding)",
0xDD	:"Unused (7-bit encoding)",
0xDE	:"Unused (7-bit encoding)",
0xDF	:"Unused (7-bit encoding)",
0xE0	:"Unused (7-bit encoding)",
0xE1	:"Unused (7-bit encoding)",
0xE2	:"Unused (7-bit encoding)",
0xE3	:"Unused (7-bit encoding)",
0xE4	:"Unused (7-bit encoding)",
0xE5	:"Unused (7-bit encoding)",
0xE6	:"Unused (7-bit encoding)",
0xE7	:"Unused (7-bit encoding)",
0xE8	:"Unused (7-bit encoding)",
0xE9	:"Unused (7-bit encoding)",
0xEA	:"Unused (7-bit encoding)",
0xEB	:"Unused (7-bit encoding)",
0xEC	:"Unused (7-bit encoding)",
0xED	:"Unused (7-bit encoding)",
0xEE	:"Unused (7-bit encoding)",
0xEF	:"Unused (7-bit encoding)",
0xF0	:"Unused (7-bit encoding)",
0xF1	:"Unused (7-bit encoding)",
0xF2	:"Unused (7-bit encoding)",
0xF3	:"Unused (7-bit encoding)",
0xF4	:"Unused (7-bit encoding)",
0xF5	:"Unused (7-bit encoding)",
0xF6	:"Unused (7-bit encoding)",
0xF7	:"Unused (7-bit encoding)",
0xF8	:"Unused (7-bit encoding)",
0xF9	:"Unused (7-bit encoding)",
0xFA	:"Unused (7-bit encoding)",
0xFB	:"Unused (7-bit encoding)",
0xFC	:"Unused (7-bit encoding)",
0xFD	:"Unused (7-bit encoding)",
0xFE	:"Unused (7-bit encoding)",
0xFF	:"Unused (7-bit encoding)"
}


#MS Codepage 874 (Thai)
msw874xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"euro sign (U+20AC)",
0x81	:"Unused",
0x82	:"Unused",
0x83	:"Unused",
0x84	:"Unused",
0x85	:"horizontal ellipsis (U+2026)",
0x86	:"Unused",
0x87	:"Unused",
0x88	:"Unused",
0x89	:"Unused",
0x8A	:"Unused",
0x8B	:"Unused",
0x8C	:"Unused",
0x8D	:"Unused",
0x8E	:"Unused",
0x8F	:"Unused",
0x90	:"Unused",
0x91	:"left single quotation mark (U+2018)",
0x92	:"right single quotation mark (U+2019)",
0x93	:"left double quotation mark (U+201C)",
0x94	:"right double quotation mark (U+201D)",
0x95	:"bullet (U+2022)",
0x96	:"en dash (U+2013)",
0x97	:"em dash (U+2014)",
0x98	:"Unused",
0x99	:"Unused",
0x9A	:"Unused",
0x9B	:"Unused",
0x9C	:"Unused",
0x9D	:"Unused",
0x9E	:"Unused",
0x9F	:"Unused",
0xA0	:"no-break space (U+00A0)",
0xA1	:"thai character ko kai (U+0E01)",
0xA2	:"thai character kho khai (U+0E02)",
0xA3	:"thai character kho khuat (U+0E03)",
0xA4	:"thai character kho khwai (U+0E04)",
0xA5	:"thai character kho khon (U+0E05)",
0xA6	:"thai character kho rakhang (U+0E06)",
0xA7	:"thai character ngo ngu (U+0E07)",
0xA8	:"thai character cho chan (U+0E08)",
0xA9	:"thai character cho ching (U+0E09)",
0xAA	:"thai character cho chang (U+0E0A)",
0xAB	:"thai character so so (U+0E0B)",
0xAC	:"thai character cho choe (U+0E0C)",
0xAD	:"thai character yo ying (U+0E0D)",
0xAE	:"thai character do chada (U+0E0E)",
0xAF	:"thai character to patak (U+0E0F)",
0xB0	:"thai character tho than (U+0E10)",
0xB1	:"thai character tho nangmontho (U+0E11)",
0xB2	:"thai character tho phuthao (U+0E12)",
0xB3	:"thai character no nen (U+0E13)",
0xB4	:"thai character do dek (U+0E14)",
0xB5	:"thai character to tao (U+0E15)",
0xB6	:"thai character tho thung (U+0E16)",
0xB7	:"thai character tho thahan (U+0E17)",
0xB8	:"thai character tho thong (U+0E18)",
0xB9	:"thai character no nu (U+0E19)",
0xBA	:"thai character bo baimai (U+0E1A)",
0xBB	:"thai character po pla (U+0E1B)",
0xBC	:"thai character pho phung (U+0E1C)",
0xBD	:"thai character fo fa (U+0E1D)",
0xBE	:"thai character pho phan (U+0E1E)",
0xBF	:"thai character fo fan (U+0E1F)",
0xC0	:"thai character pho samphao (U+0E20)",
0xC1	:"thai character mo ma (U+0E21)",
0xC2	:"thai character yo yak (U+0E22)",
0xC3	:"thai character ro rua (U+0E23)",
0xC4	:"thai character ru (U+0E24)",
0xC5	:"thai character lo ling (U+0E25)",
0xC6	:"thai character lu (U+0E26)",
0xC7	:"thai character wo waen (U+0E27)",
0xC8	:"thai character so sala (U+0E28)",
0xC9	:"thai character so rusi (U+0E29)",
0xCA	:"thai character so sua (U+0E2A)",
0xCB	:"thai character ho hip (U+0E2B)",
0xCC	:"thai character lo chula (U+0E2C)",
0xCD	:"thai character o ang (U+0E2D)",
0xCE	:"thai character ho nokhuk (U+0E2E)",
0xCF	:"thai character paiyannoi (U+0E2F)",
0xD0	:"thai character sara a (U+0E30)",
0xD1	:"thai character mai han-akat (U+0E31)",
0xD2	:"thai character sara aa (U+0E32)",
0xD3	:"thai character sara am (U+0E33)",
0xD4	:"thai character sara i (U+0E34)",
0xD5	:"thai character sara ii (U+0E35)",
0xD6	:"thai character sara ue (U+0E36)",
0xD7	:"thai character sara uee (U+0E37)",
0xD8	:"thai character sara u (U+0E38)",
0xD9	:"thai character sara uu (U+0E39)",
0xDA	:"thai character phinthu (U+0E3A)",
0xDB	:"Unused",
0xDC	:"Unused",
0xDD	:"Unused",
0xDE	:"Unused",
0xDF	:"thai currency symbol baht (U+0E3F)",
0xE0	:"thai character sara e (U+0E40)",
0xE1	:"thai character sara ae (U+0E41)",
0xE2	:"thai character sara o (U+0E42)",
0xE3	:"thai character sara ai maimuan (U+0E43)",
0xE4	:"thai character sara ai maimalai (U+0E44)",
0xE5	:"thai character lakkhangyao (U+0E45)",
0xE6	:"thai character maiyamok (U+0E46)",
0xE7	:"thai character maitaikhu (U+0E47)",
0xE8	:"thai character mai ek (U+0E48)",
0xE9	:"thai character mai tho (U+0E49)",
0xEA	:"thai character mai tri (U+0E4A)",
0xEB	:"thai character mai chattawa (U+0E4B)",
0xEC	:"thai character thanthakhat (U+0E4C)",
0xED	:"thai character nikhahit (U+0E4D)",
0xEE	:"thai character yamakkan (U+0E4E)",
0xEF	:"thai character fongman (U+0E4F)",
0xF0	:"thai digit zero (U+0E50)",
0xF1	:"thai digit one (U+0E51)",
0xF2	:"thai digit two (U+0E52)",
0xF3	:"thai digit three (U+0E53)",
0xF4	:"thai digit four (U+0E54)",
0xF5	:"thai digit five (U+0E55)",
0xF6	:"thai digit six (U+0E56)",
0xF7	:"thai digit seven (U+0E57)",
0xF8	:"thai digit eight (U+0E58)",
0xF9	:"thai digit nine (U+0E59)",
0xFA	:"thai character angkhankhu (U+0E5A)",
0xFB	:"thai character khomut (U+0E5B)",
0xFC	:"Unused",
0xFD	:"Unused",
0xFE	:"Unused",
0xFF	:"Unused"
}

# MS DOS CP 850 (Multilingual Latin 1)
msd850xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000a)",
0x0B	:"vertical tabulation (U+000b)",
0x0C	:"form feed (U+000c)",
0x0D	:"carriage return (U+000d)",
0x0E	:"shift out (U+000e)",
0x0F	:"shift in (U+000f)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001a)",
0x1B	:"escape (U+001b)",
0x1C	:"file separator (U+001c)",
0x1D	:"group separator (U+001d)",
0x1E	:"record separator (U+001e)",
0x1F	:"unit separator (U+001f)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002a)",
0x2B	:"plus sign (U+002b)",
0x2C	:"comma (U+002c)",
0x2D	:"hyphen-minus (U+002d)",
0x2E	:"full stop (U+002e)",
0x2F	:"solidus (U+002f)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003a)",
0x3B	:"semicolon (U+003b)",
0x3C	:"less-than sign (U+003c)",
0x3D	:"equals sign (U+003d)",
0x3E	:"greater-than sign (U+003e)",
0x3F	:"question mark (U+003f)",
0x40	:"commercial at (U+0040)",
0x41	:"latin capital letter a (U+0041)",
0x42	:"latin capital letter b (U+0042)",
0x43	:"latin capital letter c (U+0043)",
0x44	:"latin capital letter d (U+0044)",
0x45	:"latin capital letter e (U+0045)",
0x46	:"latin capital letter f (U+0046)",
0x47	:"latin capital letter g (U+0047)",
0x48	:"latin capital letter h (U+0048)",
0x49	:"latin capital letter i (U+0049)",
0x4A	:"latin capital letter j (U+004a)",
0x4B	:"latin capital letter k (U+004b)",
0x4C	:"latin capital letter l (U+004c)",
0x4D	:"latin capital letter m (U+004d)",
0x4E	:"latin capital letter n (U+004e)",
0x4F	:"latin capital letter o (U+004f)",
0x50	:"latin capital letter p (U+0050)",
0x51	:"latin capital letter q (U+0051)",
0x52	:"latin capital letter r (U+0052)",
0x53	:"latin capital letter s (U+0053)",
0x54	:"latin capital letter t (U+0054)",
0x55	:"latin capital letter u (U+0055)",
0x56	:"latin capital letter v (U+0056)",
0x57	:"latin capital letter w (U+0057)",
0x58	:"latin capital letter x (U+0058)",
0x59	:"latin capital letter y (U+0059)",
0x5A	:"latin capital letter z (U+005a)",
0x5B	:"left square bracket (U+005b)",
0x5C	:"reverse solidus (U+005c)",
0x5D	:"right square bracket (U+005d)",
0x5E	:"circumflex accent (U+005e)",
0x5F	:"low line (U+005f)",
0x60	:"grave accent (U+0060)",
0x61	:"latin small letter a (U+0061)",
0x62	:"latin small letter b (U+0062)",
0x63	:"latin small letter c (U+0063)",
0x64	:"latin small letter d (U+0064)",
0x65	:"latin small letter e (U+0065)",
0x66	:"latin small letter f (U+0066)",
0x67	:"latin small letter g (U+0067)",
0x68	:"latin small letter h (U+0068)",
0x69	:"latin small letter i (U+0069)",
0x6A	:"latin small letter j (U+006a)",
0x6B	:"latin small letter k (U+006b)",
0x6C	:"latin small letter l (U+006c)",
0x6D	:"latin small letter m (U+006d)",
0x6E	:"latin small letter n (U+006e)",
0x6F	:"latin small letter o (U+006f)",
0x70	:"latin small letter p (U+0070)",
0x71	:"latin small letter q (U+0071)",
0x72	:"latin small letter r (U+0072)",
0x73	:"latin small letter s (U+0073)",
0x74	:"latin small letter t (U+0074)",
0x75	:"latin small letter u (U+0075)",
0x76	:"latin small letter v (U+0076)",
0x77	:"latin small letter w (U+0077)",
0x78	:"latin small letter x (U+0078)",
0x79	:"latin small letter y (U+0079)",
0x7A	:"latin small letter z (U+007a)",
0x7B	:"left curly bracket (U+007b)",
0x7C	:"vertical line (U+007c)",
0x7D	:"right curly bracket (U+007d)",
0x7E	:"tilde (U+007e)",
0x7F	:"delete (U+007f)",
0x80	:"latin capital letter c with cedilla (U+00c7)",
0x81	:"latin small letter u with diaeresis (U+00fc)",
0x82	:"latin small letter e with acute (U+00e9)",
0x83	:"latin small letter a with circumflex (U+00e2)",
0x84	:"latin small letter a with diaeresis (U+00e4)",
0x85	:"latin small letter a with grave (U+00e0)",
0x86	:"latin small letter a with ring above (U+00e5)",
0x87	:"latin small letter c with cedilla (U+00e7)",
0x88	:"latin small letter e with circumflex (U+00ea)",
0x89	:"latin small letter e with diaeresis (U+00eb)",
0x8A	:"latin small letter e with grave (U+00e8)",
0x8B	:"latin small letter i with diaeresis (U+00ef)",
0x8C	:"latin small letter i with circumflex (U+00ee)",
0x8D	:"latin small letter i with grave (U+00ec)",
0x8E	:"latin capital letter a with diaeresis (U+00c4)",
0x8F	:"latin capital letter a with ring above (U+00c5)",
0x90	:"latin capital letter e with acute (U+00c9)",
0x91	:"latin small ligature ae (U+00e6)",
0x92	:"latin capital ligature ae (U+00c6)",
0x93	:"latin small letter o with circumflex (U+00f4)",
0x94	:"latin small letter o with diaeresis (U+00f6)",
0x95	:"latin small letter o with grave (U+00f2)",
0x96	:"latin small letter u with circumflex (U+00fb)",
0x97	:"latin small letter u with grave (U+00f9)",
0x98	:"latin small letter y with diaeresis (U+00ff)",
0x99	:"latin capital letter o with diaeresis (U+00d6)",
0x9A	:"latin capital letter u with diaeresis (U+00dc)",
0x9B	:"latin small letter o with stroke (U+00f8)",
0x9C	:"pound sign (U+00a3)",
0x9D	:"latin capital letter o with stroke (U+00d8)",
0x9E	:"multiplication sign (U+00d7)",
0x9F	:"latin small letter f with hook (U+0192)",
0xA0	:"latin small letter a with acute (U+00e1)",
0xA1	:"latin small letter i with acute (U+00ed)",
0xA2	:"latin small letter o with acute (U+00f3)",
0xA3	:"latin small letter u with acute (U+00fa)",
0xA4	:"latin small letter n with tilde (U+00f1)",
0xA5	:"latin capital letter n with tilde (U+00d1)",
0xA6	:"feminine ordinal indicator (U+00aa)",
0xA7	:"masculine ordinal indicator (U+00ba)",
0xA8	:"inverted question mark (U+00bf)",
0xA9	:"registered sign (U+00ae)",
0xAA	:"not sign (U+00ac)",
0xAB	:"vulgar fraction one half (U+00bd)",
0xAC	:"vulgar fraction one quarter (U+00bc)",
0xAD	:"inverted exclamation mark (U+00a1)",
0xAE	:"left-pointing double angle quotation mark (U+00ab)",
0xAF	:"right-pointing double angle quotation mark (U+00bb)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"latin capital letter a with acute (U+00c1)",
0xB6	:"latin capital letter a with circumflex (U+00c2)",
0xB7	:"latin capital letter a with grave (U+00c0)",
0xB8	:"copyright sign (U+00a9)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255d)",
0xBD	:"cent sign (U+00a2)",
0xBE	:"yen sign (U+00a5)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252c)",
0xC3	:"box drawings light vertical and right (U+251c)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253c)",
0xC6	:"latin small letter a with tilde (U+00e3)",
0xC7	:"latin capital letter a with tilde (U+00c3)",
0xC8	:"box drawings double up and right (U+255a)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256c)",
0xCF	:"currency sign (U+00a4)",
0xD0	:"latin small letter eth (U+00f0)",
0xD1	:"latin capital letter eth (U+00d0)",
0xD2	:"latin capital letter e with circumflex (U+00ca)",
0xD3	:"latin capital letter e with diaeresis (U+00cb)",
0xD4	:"latin capital letter e with grave (U+00c8)",
0xD5	:"latin small letter dotless i (U+0131)",
0xD6	:"latin capital letter i with acute (U+00cd)",
0xD7	:"latin capital letter i with circumflex (U+00ce)",
0xD8	:"latin capital letter i with diaeresis (U+00cf)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250c)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"broken bar (U+00a6)",
0xDE	:"latin capital letter i with grave (U+00cc)",
0xDF	:"upper half block (U+2580)",
0xE0	:"latin capital letter o with acute (U+00d3)",
0xE1	:"latin small letter sharp s (U+00df)",
0xE2	:"latin capital letter o with circumflex (U+00d4)",
0xE3	:"latin capital letter o with grave (U+00d2)",
0xE4	:"latin small letter o with tilde (U+00f5)",
0xE5	:"latin capital letter o with tilde (U+00d5)",
0xE6	:"micro sign (U+00b5)",
0xE7	:"latin small letter thorn (U+00fe)",
0xE8	:"latin capital letter thorn (U+00de)",
0xE9	:"latin capital letter u with acute (U+00da)",
0xEA	:"latin capital letter u with circumflex (U+00db)",
0xEB	:"latin capital letter u with grave (U+00d9)",
0xEC	:"latin small letter y with acute (U+00fd)",
0xED	:"latin capital letter y with acute (U+00dd)",
0xEE	:"macron (U+00af)",
0xEF	:"acute accent (U+00b4)",
0xF0	:"soft hyphen (U+00ad)",
0xF1	:"plus-minus sign (U+00b1)",
0xF2	:"double low line (U+2017)",
0xF3	:"vulgar fraction three quarters (U+00be)",
0xF4	:"pilcrow sign (U+00b6)",
0xF5	:"section sign (U+00a7)",
0xF6	:"division sign (U+00f7)",
0xF7	:"cedilla (U+00b8)",
0xF8	:"degree sign (U+00b0)",
0xF9	:"diaeresis (U+00a8)",
0xFA	:"middle dot (U+00b7)",
0xFB	:"superscript one (U+00b9)",
0xFC	:"superscript three (U+00b3)",
0xFD	:"superscript two (U+00b2)",
0xFE	:"black square (U+25a0)",
0xFF	:"no-break space (U+00a0)",
}


#CP10029 Mac Central Europe (MacLatin2)
macLatin2xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"Latin capital letter a with diaeresis (U+00C4)",
0x81	:"Latin capital letter a with macron (U+0100)",
0x82	:"Latin small letter a with macron (U+0101)",
0x83	:"Latin capital letter e with acute (U+00C9)",
0x84	:"Latin capital letter a with ogonek (U+0104)",
0x85	:"Latin capital letter o with diaeresis (U+00D6)",
0x86	:"Latin capital letter u with diaeresis (U+00DC)",
0x87	:"Latin small letter a with acute (U+00E1)",
0x88	:"Latin small letter a with ogonek (U+0105)",
0x89	:"Latin capital letter c with caron (U+010C)",
0x8A	:"Latin small letter a with diaeresis (U+00E4)",
0x8B	:"Latin small letter c with caron (U+010D)",
0x8C	:"Latin capital letter c with acute (U+0106)",
0x8D	:"Latin small letter c with acute (U+0107)",
0x8E	:"Latin small letter e with acute (U+00E9)",
0x8F	:"Latin capital letter z with acute (U+0179)",
0x90	:"Latin small letter z with acute (U+017A)",
0x91	:"Latin capital letter d with caron (U+010E)",
0x92	:"Latin small letter i with acute (U+00ED)",
0x93	:"Latin small letter d with caron (U+010F)",
0x94	:"Latin capital letter e with macron (U+0112)",
0x95	:"Latin small letter e with macron (U+0113)",
0x96	:"Latin capital letter e with dot above (U+0116)",
0x97	:"Latin small letter o with acute (U+00F3)",
0x98	:"Latin small letter e with dot above (U+0117)",
0x99	:"Latin small letter o with circumflex (U+00F4)",
0x9A	:"Latin small letter o with diaeresis (U+00F6)",
0x9B	:"Latin small letter o with tilde (U+00F5)",
0x9C	:"Latin small letter u with acute (U+00FA)",
0x9D	:"Latin capital letter e with caron (U+011A)",
0x9E	:"Latin small letter e with caron (U+011B)",
0x9F	:"Latin small letter u with diaeresis (U+00FC)",
0xA0	:"dagger (U+2020)",
0xA1	:"degree sign (U+00B0)",
0xA2	:"Latin capital letter e with ogonek (U+0118)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"section sign (U+00A7)",
0xA5	:"bullet (U+2022)",
0xA6	:"pilcrow sign (U+00B6)",
0xA7	:"Latin small letter sharp s (U+00DF)",
0xA8	:"registered sign (U+00AE)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"trade mark sign (U+2122)",
0xAB	:"Latin small letter e with ogonek (U+0119)",
0xAC	:"diaeresis (U+00A8)",
0xAD	:"not equal to (U+2260)",
0xAE	:"Latin small letter g with cedilla (U+0123)",
0xAF	:"Latin capital letter i with ogonek (U+012E)",
0xB0	:"Latin small letter i with ogonek (U+012F)",
0xB1	:"Latin capital letter i with macron (U+012A)",
0xB2	:"less-than or equal to (U+2264)",
0xB3	:"greater-than or equal to (U+2265)",
0xB4	:"Latin small letter i with macron (U+012B)",
0xB5	:"Latin capital letter k with cedilla (U+0136)",
0xB6	:"partial differential (U+2202)",
0xB7	:"n-ary summation (U+2211)",
0xB8	:"Latin small letter l with stroke (U+0142)",
0xB9	:"Latin capital letter l with cedilla (U+013B)",
0xBA	:"Latin small letter l with cedilla (U+013C)",
0xBB	:"Latin capital letter l with caron (U+013D)",
0xBC	:"Latin small letter l with caron (U+013E)",
0xBD	:"Latin capital letter l with acute (U+0139)",
0xBE	:"Latin small letter l with acute (U+013A)",
0xBF	:"Latin capital letter n with cedilla (U+0145)",
0xC0	:"Latin small letter n with cedilla (U+0146)",
0xC1	:"Latin capital letter n with acute (U+0143)",
0xC2	:"not sign (U+00AC)",
0xC3	:"square root (U+221A)",
0xC4	:"Latin small letter n with acute (U+0144)",
0xC5	:"Latin capital letter n with caron (U+0147)",
0xC6	:"increment (U+2206)",
0xC7	:"left-pointing double angle quotation mark (U+00AB)",
0xC8	:"right-pointing double angle quotation mark (U+00BB)",
0xC9	:"horizontal ellipsis (U+2026)",
0xCA	:"no-break space (U+00A0)",
0xCB	:"Latin small letter n with caron (U+0148)",
0xCC	:"Latin capital letter o with double acute (U+0150)",
0xCD	:"Latin capital letter o with tilde (U+00D5)",
0xCE	:"Latin small letter o with double acute (U+0151)",
0xCF	:"Latin capital letter o with macron (U+014C)",
0xD0	:"en dash (U+2013)",
0xD1	:"em dash (U+2014)",
0xD2	:"left double quotation mark (U+201C)",
0xD3	:"right double quotation mark (U+201D)",
0xD4	:"left single quotation mark (U+2018)",
0xD5	:"right single quotation mark (U+2019)",
0xD6	:"division sign (U+00F7)",
0xD7	:"lozenge (U+25CA)",
0xD8	:"Latin small letter o with macron (U+014D)",
0xD9	:"Latin capital letter r with acute (U+0154)",
0xDA	:"Latin small letter r with acute (U+0155)",
0xDB	:"Latin capital letter r with caron (U+0158)",
0xDC	:"single left-pointing angle quotation mark (U+2039)",
0xDD	:"single right-pointing angle quotation mark (U+203A)",
0xDE	:"Latin small letter r with caron (U+0159)",
0xDF	:"Latin capital letter r with cedilla (U+0156)",
0xE0	:"Latin small letter r with cedilla (U+0157)",
0xE1	:"Latin capital letter s with caron (U+0160)",
0xE2	:"single low-9 quotation mark (U+201A)",
0xE3	:"double low-9 quotation mark (U+201E)",
0xE4	:"Latin small letter s with caron (U+0161)",
0xE5	:"Latin capital letter s with acute (U+015A)",
0xE6	:"Latin small letter s with acute (U+015B)",
0xE7	:"Latin capital letter a with acute (U+00C1)",
0xE8	:"Latin capital letter t with caron (U+0164)",
0xE9	:"Latin small letter t with caron (U+0165)",
0xEA	:"Latin capital letter i with acute (U+00CD)",
0xEB	:"Latin capital letter z with caron (U+017D)",
0xEC	:"Latin small letter z with caron (U+017E)",
0xED	:"Latin capital letter u with macron (U+016A)",
0xEE	:"Latin capital letter o with acute (U+00D3)",
0xEF	:"Latin capital letter o with circumflex (U+00D4)",
0xF0	:"Latin small letter u with macron (U+016B)",
0xF1	:"Latin capital letter u with ring above (U+016E)",
0xF2	:"Latin capital letter u with acute (U+00DA)",
0xF3	:"Latin small letter u with ring above (U+016F)",
0xF4	:"Latin capital letter u with double acute (U+0170)",
0xF5	:"Latin small letter u with double acute (U+0171)",
0xF6	:"Latin capital letter u with ogonek (U+0172)",
0xF7	:"Latin small letter u with ogonek (U+0173)",
0xF8	:"Latin capital letter y with acute (U+00DD)",
0xF9	:"Latin small letter y with acute (U+00FD)",
0xFA	:"Latin small letter k with cedilla (U+0137)",
0xFB	:"Latin capital letter z with dot above (U+017B)",
0xFC	:"Latin capital letter l with stroke (U+0141)",
0xFD	:"Latin small letter z with dot above (U+017C)",
0xFE	:"Latin capital letter g with cedilla (U+0122)",
0xFF	:"caron (U+02C7)"
}

#MIK (Bulgarian)
mikxtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"SPACE (U+0020)",
0x21	:"EXCLAMATION MARK (U+0021)",
0x22	:"QUOTATION MARK (U+0022)",
0x23	:"NUMBER SIGN (U+0023)",
0x24	:"DOLLAR SIGN (U+0024)",
0x25	:"PERCENT SIGN (U+0025)",
0x26	:"AMPERSAND (U+0026)",
0x27	:"APOSTROPHE (U+0027)",
0x28	:"LEFT PARENTHESIS (U+0028)",
0x29	:"RIGHT PARENTHESIS (U+0029)",
0x2A	:"ASTERISK (U+002A)",
0x2B	:"PLUS SIGN (U+002B)",
0x2C	:"COMMA (U+002C)",
0x2D	:"HYPHEN-MINUS (U+002D)",
0x2E	:"FULL STOP (U+002E)",
0x2F	:"SOLIDUS (U+002F)",
0x30	:"DIGIT ZERO (U+0030)",
0x31	:"DIGIT ONE (U+0031)",
0x32	:"DIGIT TWO (U+0032)",
0x33	:"DIGIT THREE (U+0033)",
0x34	:"DIGIT FOUR (U+0034)",
0x35	:"DIGIT FIVE (U+0035)",
0x36	:"DIGIT SIX (U+0036)",
0x37	:"DIGIT SEVEN (U+0037)",
0x38	:"DIGIT EIGHT (U+0038)",
0x39	:"DIGIT NINE (U+0039)",
0x3A	:"COLON (U+003A)",
0x3B	:"SEMICOLON (U+003B)",
0x3C	:"LESS-THAN SIGN (U+003C)",
0x3D	:"EQUALS SIGN (U+003D)",
0x3E	:"GREATER-THAN SIGN (U+003E)",
0x3F	:"QUESTION MARK (U+003F)",
0x40	:"COMMERCIAL AT (U+0040)",
0x41	:"Latin capital letter A (U+0041)",
0x42	:"Latin capital letter B (U+0042)",
0x43	:"Latin capital letter C (U+0043)",
0x44	:"Latin capital letter D (U+0044)",
0x45	:"Latin capital letter E (U+0045)",
0x46	:"Latin capital letter F (U+0046)",
0x47	:"Latin capital letter G (U+0047)",
0x48	:"Latin capital letter H (U+0048)",
0x49	:"Latin capital letter I (U+0049)",
0x4A	:"Latin capital letter J (U+004A)",
0x4B	:"Latin capital letter K (U+004B)",
0x4C	:"Latin capital letter L (U+004C)",
0x4D	:"Latin capital letter M (U+004D)",
0x4E	:"Latin capital letter N (U+004E)",
0x4F	:"Latin capital letter O (U+004F)",
0x50	:"Latin capital letter P (U+0050)",
0x51	:"Latin capital letter Q (U+0051)",
0x52	:"Latin capital letter R (U+0052)",
0x53	:"Latin capital letter S (U+0053)",
0x54	:"Latin capital letter T (U+0054)",
0x55	:"Latin capital letter U (U+0055)",
0x56	:"Latin capital letter V (U+0056)",
0x57	:"Latin capital letter W (U+0057)",
0x58	:"Latin capital letter X (U+0058)",
0x59	:"Latin capital letter Y (U+0059)",
0x5A	:"Latin capital letter Z (U+005A)",
0x5B	:"LEFT SQUARE BRACKET (U+005B)",
0x5C	:"REVERSE SOLIDUS (U+005C)",
0x5D	:"RIGHT SQUARE BRACKET (U+005D)",
0x5E	:"CIRCUMFLEX ACCENT (U+005E)",
0x5F	:"LOW LINE (U+005F)",
0x60	:"GRAVE ACCENT (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter C (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter F (U+0066)",
0x67	:"Latin small letter G (U+0067)",
0x68	:"Latin small letter H (U+0068)",
0x69	:"Latin small letter I (U+0069)",
0x6A	:"Latin small letter J (U+006A)",
0x6B	:"Latin small letter K (U+006B)",
0x6C	:"Latin small letter L (U+006C)",
0x6D	:"Latin small letter M (U+006D)",
0x6E	:"Latin small letter N (U+006E)",
0x6F	:"Latin small letter O (U+006F)",
0x70	:"Latin small letter P (U+0070)",
0x71	:"Latin small letter Q (U+0071)",
0x72	:"Latin small letter R (U+0072)",
0x73	:"Latin small letter S (U+0073)",
0x74	:"Latin small letter T (U+0074)",
0x75	:"Latin small letter U (U+0075)",
0x76	:"Latin small letter V (U+0076)",
0x77	:"Latin small letter W (U+0077)",
0x78	:"Latin small letter X (U+0078)",
0x79	:"Latin small letter Y (U+0079)",
0x7A	:"Latin small letter Z (U+007A)",
0x7B	:"LEFT CURLY BRACKET (U+007B)",
0x7C	:"VERTICAL LINE (U+007C)",
0x7D	:"RIGHT CURLY BRACKET (U+007D)",
0x7E	:"TILDE (U+007E)",
0x7F	:"Unused",
0x80	:"Cyrillic capital letter A (U+0410)",
0x81	:"Cyrillic capital letter BE (U+0411)",
0x82	:"Cyrillic capital letter VE (U+0412)",
0x83	:"Cyrillic capital letter GHE (U+0413)",
0x84	:"Cyrillic capital letter DE (U+0414)",
0x85	:"Cyrillic capital letter IE (U+0415)",
0x86	:"Cyrillic capital letter ZHE (U+0416)",
0x87	:"Cyrillic capital letter ZE (U+0417)",
0x88	:"Cyrillic capital letter I (U+0418)",
0x89	:"Cyrillic capital letter SHORT I (U+0419)",
0x8A	:"Cyrillic capital letter KA (U+041A)",
0x8B	:"Cyrillic capital letter EL (U+041B)",
0x8C	:"Cyrillic capital letter EM (U+041C)",
0x8D	:"Cyrillic capital letter EN (U+041D)",
0x8E	:"Cyrillic capital letter O (U+041E)",
0x8F	:"Cyrillic capital letter PE (U+041F)",
0x90	:"Cyrillic capital letter ER (U+0420)",
0x91	:"Cyrillic capital letter ES (U+0421)",
0x92	:"Cyrillic capital letter TE (U+0422)",
0x93	:"Cyrillic capital letter U (U+0423)",
0x94	:"Cyrillic capital letter EF (U+0424)",
0x95	:"Cyrillic capital letter HA (U+0425)",
0x96	:"Cyrillic capital letter TSE (U+0426)",
0x97	:"Cyrillic capital letter CHE (U+0427)",
0x98	:"Cyrillic capital letter SHA (U+0428)",
0x99	:"Cyrillic capital letter SHCHA (U+0429)",
0x9A	:"Cyrillic capital letter HARD SIGN (U+042A)",
0x9B	:"Cyrillic capital letter YERU (U+042B)",
0x9C	:"Cyrillic capital letter SOFT SIGN (U+042C)",
0x9D	:"Cyrillic capital letter E (U+042D)",
0x9E	:"Cyrillic capital letter YU (U+042E)",
0x9F	:"Cyrillic capital letter YA (U+042F)",
0xA0	:"Cyrillic small letter a (U+0430)",
0xA1	:"Cyrillic small letter bE (U+0431)",
0xA2	:"Cyrillic small letter VE (U+0432)",
0xA3	:"Cyrillic small letter GHE (U+0433)",
0xA4	:"Cyrillic small letter dE (U+0434)",
0xA5	:"Cyrillic small letter IE (U+0435)",
0xA6	:"Cyrillic small letter ZHE (U+0436)",
0xA7	:"Cyrillic small letter ZE (U+0437)",
0xA8	:"Cyrillic small letter I (U+0438)",
0xA9	:"Cyrillic small letter SHORT I (U+0439)",
0xAA	:"Cyrillic small letter KA (U+043A)",
0xAB	:"Cyrillic small letter eL (U+043B)",
0xAC	:"Cyrillic small letter eM (U+043C)",
0xAD	:"Cyrillic small letter eN (U+043D)",
0xAE	:"Cyrillic small letter O (U+043E)",
0xAF	:"Cyrillic small letter PE (U+043F)",
0xB0	:"Cyrillic small letter eR (U+0440)",
0xB1	:"Cyrillic small letter eS (U+0441)",
0xB2	:"Cyrillic small letter TE (U+0442)",
0xB3	:"Cyrillic small letter U (U+0443)",
0xB4	:"Cyrillic small letter eF (U+0444)",
0xB5	:"Cyrillic small letter HA (U+0445)",
0xB6	:"Cyrillic small letter TSE (U+0446)",
0xB7	:"Cyrillic small letter CHE (U+0447)",
0xB8	:"Cyrillic small letter SHA (U+0448)",
0xB9	:"Cyrillic small letter SHCHA (U+0449)",
0xBA	:"Cyrillic small letter HARD SIGN (U+044A)",
0xBB	:"Cyrillic small letter YERU (U+044B)",
0xBC	:"Cyrillic small letter SOFT SIGN (U+044C)",
0xBD	:"Cyrillic small letter e (U+044D)",
0xBE	:"Cyrillic small letter YU (U+044E)",
0xBF	:"Cyrillic small letter YA (U+044F)",
0xC0	:"BOX DRAWINGS LIGHT UP AND RIGHT (U+2514)",
0xC1	:"BOX DRAWINGS LIGHT UP AND HORIZONTAL (U+2534)",
0xC2	:"BOX DRAWINGS LIGHT DOWN AND HORIZONTAL (U+252C)",
0xC3	:"BOX DRAWINGS LIGHT VERTICAL AND RIGHT (U+251C)",
0xC4	:"BOX DRAWINGS LIGHT HORIZONTAL (U+2500)",
0xC5	:"BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL (U+253C)",
0xC6	:"BOX DRAWINGS DOUBLE VERTICAL AND LEFT (U+2563)",
0xC7	:"BOX DRAWINGS DOUBLE VERTICAL (U+2551)",
0xC8	:"BOX DRAWINGS DOUBLE UP AND RIGHT (U+255A)",
0xC9	:"BOX DRAWINGS DOUBLE DOWN AND RIGHT (U+2554)",
0xCA	:"BOX DRAWINGS DOUBLE UP AND HORIZONTAL (U+2569)",
0xCB	:"BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL (U+2566)",
0xCC	:"BOX DRAWINGS DOUBLE VERTICAL AND RIGHT (U+2560)",
0xCD	:"BOX DRAWINGS DOUBLE HORIZONTAL (U+2550)",
0xCE	:"BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL (U+256C)",
0xCF	:"BOX DRAWINGS LIGHT DOWN AND LEFT (U+2510)",
0xD0	:"LIGHT SHADE (U+2591)",
0xD1	:"MEDIUM SHADE (U+2592)",
0xD2	:"DARK SHADE (U+2593)",
0xD3	:"BOX DRAWINGS LIGHT VERTICAL (U+2502)",
0xD4	:"BOX DRAWINGS LIGHT VERTICAL AND LEFT (U+2524)",
0xD5	:"NUMERO SIGN (U+2116)",
0xD6	:"SECTION SIGN (U+00A7)",
0xD7	:"BOX DRAWINGS DOUBLE DOWN AND LEFT (U+2557)",
0xD8	:"BOX DRAWINGS DOUBLE UP AND LEFT (U+255D)",
0xD9	:"BOX DRAWINGS LIGHT UP AND LEFT (U+2518)",
0xDA	:"BOX DRAWINGS LIGHT DOWN AND RIGHT (U+250C)",
0xDB	:"FULL BLOCK (U+2588)",
0xDC	:"LOWER HALF BLOCK (U+2584)",
0xDD	:"LEFT HALF BLOCK (U+258C)",
0xDE	:"RIGHT HALF BLOCK (U+2590)",
0xDF	:"UPPER HALF BLOCK (U+2580)",
0xE0	:"Greek small letter aLPHA (U+03B1)",
0xE1	:"Greek small letter bETA (U+03B2)",
0xE2	:"Greek capital letter GAMMA (U+0393)",
0xE3	:"Greek small letter PI (U+03C0)",
0xE4	:"Greek capital letter SIGMA (U+03A3)",
0xE5	:"Greek small letter SIGMA (U+03C3)",
0xE6	:"Greek small letter MU (U+03BC)",
0xE7	:"Greek small letter TAU (U+03C4)",
0xE8	:"Greek capital letter PHI (U+03A6)",
0xE9	:"Greek capital letter THETA (U+0398)",
0xEA	:"Greek capital letter OMEGA (U+03A9)",
0xEB	:"Greek small letter dELTA (U+03B4)",
0xEC	:"INFINITY (U+221E)",
0xED	:"EMPTY SET (U+2205)",
0xEE	:"ELEMENT OF (U+2208)",
0xEF	:"INTERSECTION (U+2229)",
0xF0	:"IDENTICAL TO (U+2261)",
0xF1	:"PLUS-MINUS SIGN (U+00B1)",
0xF2	:"GREATER-THAN OR EQUAL TO (U+2265)",
0xF3	:"LESS-THAN OR EQUAL TO (U+2264)",
0xF4	:"TOP HALF INTEGRAL (U+2320)",
0xF5	:"BOTTOM HALF INTEGRAL (U+2321)",
0xF6	:"DIVISION SIGN (U+00F7)",
0xF7	:"ALMOST EQUAL TO (U+2248)",
0xF8	:"DEGREE SIGN (U+00B0)",
0xF9	:"BULLET OPERATOR (U+2219)",
0xFA	:"MIDDLE DOT (U+00B7)",
0xFB	:"SQUARE ROOT (U+221A)",
0xFC	:"SUPERSCRIPT Latin small letter N (U+207F)",
0xFD	:"SUPERSCRIPT TWO (U+00B2)",
0xFE	:"BLACK SQUARE (U+25A0)",
0xFF	:"NO-BREAK SPACE (U+00A0)"
}

#CP10007 MacCyrillic
maccyrillicxtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"cyrillic capital letter a (U+0410)",
0x81	:"cyrillic capital letter be (U+0411)",
0x82	:"cyrillic capital letter ve (U+0412)",
0x83	:"cyrillic capital letter ghe (U+0413)",
0x84	:"cyrillic capital letter de (U+0414)",
0x85	:"cyrillic capital letter ie (U+0415)",
0x86	:"cyrillic capital letter zhe (U+0416)",
0x87	:"cyrillic capital letter ze (U+0417)",
0x88	:"cyrillic capital letter i (U+0418)",
0x89	:"cyrillic capital letter short i (U+0419)",
0x8A	:"cyrillic capital letter ka (U+041A)",
0x8B	:"cyrillic capital letter el (U+041B)",
0x8C	:"cyrillic capital letter em (U+041C)",
0x8D	:"cyrillic capital letter en (U+041D)",
0x8E	:"cyrillic capital letter o (U+041E)",
0x8F	:"cyrillic capital letter pe (U+041F)",
0x90	:"cyrillic capital letter er (U+0420)",
0x91	:"cyrillic capital letter es (U+0421)",
0x92	:"cyrillic capital letter te (U+0422)",
0x93	:"cyrillic capital letter u (U+0423)",
0x94	:"cyrillic capital letter ef (U+0424)",
0x95	:"cyrillic capital letter ha (U+0425)",
0x96	:"cyrillic capital letter tse (U+0426)",
0x97	:"cyrillic capital letter che (U+0427)",
0x98	:"cyrillic capital letter sha (U+0428)",
0x99	:"cyrillic capital letter shcha (U+0429)",
0x9A	:"cyrillic capital letter hard sign (U+042A)",
0x9B	:"cyrillic capital letter yeru (U+042B)",
0x9C	:"cyrillic capital letter soft sign (U+042C)",
0x9D	:"cyrillic capital letter e (U+042D)",
0x9E	:"cyrillic capital letter yu (U+042E)",
0x9F	:"cyrillic capital letter ya (U+042F)",
0xA0	:"dagger (U+2020)",
0xA1	:"degree sign (U+00B0)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"section sign (U+00A7)",
0xA5	:"bullet (U+2022)",
0xA6	:"pilcrow sign (U+00B6)",
0xA7	:"cyrillic capital letter byelorussian-ukrainian i (U+0406)",
0xA8	:"registered sign (U+00AE)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"trade mark sign (U+2122)",
0xAB	:"cyrillic capital letter dje (U+0402)",
0xAC	:"cyrillic small letter dje (U+0452)",
0xAD	:"not equal to (U+2260)",
0xAE	:"cyrillic capital letter gje (U+0403)",
0xAF	:"cyrillic small letter gje (U+0453)",
0xB0	:"infinity (U+221E)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"less-than or equal to (U+2264)",
0xB3	:"greater-than or equal to (U+2265)",
0xB4	:"cyrillic small letter byelorussian-ukrainian i (U+0456)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"partial differential (U+2202)",
0xB7	:"cyrillic capital letter je (U+0408)",
0xB8	:"cyrillic capital letter ukrainian ie (U+0404)",
0xB9	:"cyrillic small letter ukrainian ie (U+0454)",
0xBA	:"cyrillic capital letter yi (U+0407)",
0xBB	:"cyrillic small letter yi (U+0457)",
0xBC	:"cyrillic capital letter lje (U+0409)",
0xBD	:"cyrillic small letter lje (U+0459)",
0xBE	:"cyrillic capital letter nje (U+040A)",
0xBF	:"cyrillic small letter nje (U+045A)",
0xC0	:"cyrillic small letter je (U+0458)",
0xC1	:"cyrillic capital letter dze (U+0405)",
0xC2	:"not sign (U+00AC)",
0xC3	:"square root (U+221A)",
0xC4	:"Latin small letter f with hook (U+0192)",
0xC5	:"almost equal to (U+2248)",
0xC6	:"increment (U+2206)",
0xC7	:"left-pointing double angle quotation mark (U+00AB)",
0xC8	:"right-pointing double angle quotation mark (U+00BB)",
0xC9	:"horizontal ellipsis (U+2026)",
0xCA	:"no-break space (U+00A0)",
0xCB	:"cyrillic capital letter tshe (U+040B)",
0xCC	:"cyrillic small letter tshe (U+045B)",
0xCD	:"cyrillic capital letter kje (U+040C)",
0xCE	:"cyrillic small letter kje (U+045C)",
0xCF	:"cyrillic small letter dze (U+0455)",
0xD0	:"en dash (U+2013)",
0xD1	:"em dash (U+2014)",
0xD2	:"left double quotation mark (U+201C)",
0xD3	:"right double quotation mark (U+201D)",
0xD4	:"left single quotation mark (U+2018)",
0xD5	:"right single quotation mark (U+2019)",
0xD6	:"division sign (U+00F7)",
0xD7	:"double low-9 quotation mark (U+201E)",
0xD8	:"cyrillic capital letter short u (U+040E)",
0xD9	:"cyrillic small letter short u (U+045E)",
0xDA	:"cyrillic capital letter dzhe (U+040F)",
0xDB	:"cyrillic small letter dzhe (U+045F)",
0xDC	:"numero sign (U+2116)",
0xDD	:"cyrillic capital letter io (U+0401)",
0xDE	:"cyrillic small letter io (U+0451)",
0xDF	:"cyrillic small letter ya (U+044F)",
0xE0	:"cyrillic small letter a (U+0430)",
0xE1	:"cyrillic small letter be (U+0431)",
0xE2	:"cyrillic small letter ve (U+0432)",
0xE3	:"cyrillic small letter ghe (U+0433)",
0xE4	:"cyrillic small letter de (U+0434)",
0xE5	:"cyrillic small letter ie (U+0435)",
0xE6	:"cyrillic small letter zhe (U+0436)",
0xE7	:"cyrillic small letter ze (U+0437)",
0xE8	:"cyrillic small letter i (U+0438)",
0xE9	:"cyrillic small letter short i (U+0439)",
0xEA	:"cyrillic small letter ka (U+043A)",
0xEB	:"cyrillic small letter el (U+043B)",
0xEC	:"cyrillic small letter em (U+043C)",
0xED	:"cyrillic small letter en (U+043D)",
0xEE	:"cyrillic small letter o (U+043E)",
0xEF	:"cyrillic small letter pe (U+043F)",
0xF0	:"cyrillic small letter er (U+0440)",
0xF1	:"cyrillic small letter es (U+0441)",
0xF2	:"cyrillic small letter te (U+0442)",
0xF3	:"cyrillic small letter u (U+0443)",
0xF4	:"cyrillic small letter ef (U+0444)",
0xF5	:"cyrillic small letter ha (U+0445)",
0xF6	:"cyrillic small letter tse (U+0446)",
0xF7	:"cyrillic small letter che (U+0447)",
0xF8	:"cyrillic small letter sha (U+0448)",
0xF9	:"cyrillic small letter shcha (U+0449)",
0xFA	:"cyrillic small letter hard sign (U+044A)",
0xFB	:"cyrillic small letter yeru (U+044B)",
0xFC	:"cyrillic small letter soft sign (U+044C)",
0xFD	:"cyrillic small letter e (U+044D)",
0xFE	:"cyrillic small letter yu (U+044E)",
0xFF	:"currency sign (U+00A4)"
}

#CP10006 MacGreek
macgreekxtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"Latin capital letter a with diaeresis (U+00C4)",
0x81	:"superscript one (U+00B9)",
0x82	:"superscript two (U+00B2)",
0x83	:"Latin capital letter e with acute (U+00C9)",
0x84	:"superscript three (U+00B3)",
0x85	:"Latin capital letter o with diaeresis (U+00D6)",
0x86	:"Latin capital letter u with diaeresis (U+00DC)",
0x87	:"greek dialytika tonos (U+0385)",
0x88	:"Latin small letter a with grave (U+00E0)",
0x89	:"Latin small letter a with circumflex (U+00E2)",
0x8A	:"Latin small letter a with diaeresis (U+00E4)",
0x8B	:"greek tonos (U+0384)",
0x8C	:"diaeresis (U+00A8)",
0x8D	:"Latin small letter c with cedilla (U+00E7)",
0x8E	:"Latin small letter e with acute (U+00E9)",
0x8F	:"Latin small letter e with grave (U+00E8)",
0x90	:"Latin small letter e with circumflex (U+00EA)",
0x91	:"Latin small letter e with diaeresis (U+00EB)",
0x92	:"pound sign (U+00A3)",
0x93	:"trade mark sign (U+2122)",
0x94	:"Latin small letter i with circumflex (U+00EE)",
0x95	:"Latin small letter i with diaeresis (U+00EF)",
0x96	:"bullet (U+2022)",
0x97	:"vulgar fraction one half (U+00BD)",
0x98	:"per mille sign (U+2030)",
0x99	:"Latin small letter o with circumflex (U+00F4)",
0x9A	:"Latin small letter o with diaeresis (U+00F6)",
0x9B	:"broken bar (U+00A6)",
0x9C	:"soft hyphen (U+00AD)",
0x9D	:"Latin small letter u with grave (U+00F9)",
0x9E	:"Latin small letter u with circumflex (U+00FB)",
0x9F	:"Latin small letter u with diaeresis (U+00FC)",
0xA0	:"dagger (U+2020)",
0xA1	:"greek capital letter gamma (U+0393)",
0xA2	:"greek capital letter delta (U+0394)",
0xA3	:"greek capital letter theta (U+0398)",
0xA4	:"greek capital letter lambda (U+039B)",
0xA5	:"greek capital letter xi (U+039E)",
0xA6	:"greek capital letter pi (U+03A0)",
0xA7	:"Latin small letter sharp s (U+00DF)",
0xA8	:"registered sign (U+00AE)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"greek capital letter sigma (U+03A3)",
0xAB	:"greek capital letter iota with dialytika (U+03AA)",
0xAC	:"section sign (U+00A7)",
0xAD	:"not equal to (U+2260)",
0xAE	:"degree sign (U+00B0)",
0xAF	:"greek ano teleia (U+0387)",
0xB0	:"greek capital letter alpha (U+0391)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"less-than or equal to (U+2264)",
0xB3	:"greater-than or equal to (U+2265)",
0xB4	:"yen sign (U+00A5)",
0xB5	:"greek capital letter beta (U+0392)",
0xB6	:"greek capital letter epsilon (U+0395)",
0xB7	:"greek capital letter zeta (U+0396)",
0xB8	:"greek capital letter eta (U+0397)",
0xB9	:"greek capital letter iota (U+0399)",
0xBA	:"greek capital letter kappa (U+039A)",
0xBB	:"greek capital letter mu (U+039C)",
0xBC	:"greek capital letter phi (U+03A6)",
0xBD	:"greek capital letter upsilon with dialytika (U+03AB)",
0xBE	:"greek capital letter psi (U+03A8)",
0xBF	:"greek capital letter omega (U+03A9)",
0xC0	:"greek small letter alpha with tonos (U+03AC)",
0xC1	:"greek capital letter nu (U+039D)",
0xC2	:"not sign (U+00AC)",
0xC3	:"greek capital letter omicron (U+039F)",
0xC4	:"greek capital letter rho (U+03A1)",
0xC5	:"almost equal to (U+2248)",
0xC6	:"greek capital letter tau (U+03A4)",
0xC7	:"left-pointing double angle quotation mark (U+00AB)",
0xC8	:"right-pointing double angle quotation mark (U+00BB)",
0xC9	:"horizontal ellipsis (U+2026)",
0xCA	:"no-break space (U+00A0)",
0xCB	:"greek capital letter upsilon (U+03A5)",
0xCC	:"greek capital letter chi (U+03A7)",
0xCD	:"greek capital letter alpha with tonos (U+0386)",
0xCE	:"greek capital letter epsilon with tonos (U+0388)",
0xCF	:"Latin small ligature oe (U+0153)",
0xD0	:"en dash (U+2013)",
0xD1	:"horizontal bar (U+2015)",
0xD2	:"left double quotation mark (U+201C)",
0xD3	:"right double quotation mark (U+201D)",
0xD4	:"left single quotation mark (U+2018)",
0xD5	:"right single quotation mark (U+2019)",
0xD6	:"division sign (U+00F7)",
0xD7	:"greek capital letter eta with tonos (U+0389)",
0xD8	:"greek capital letter iota with tonos (U+038A)",
0xD9	:"greek capital letter omicron with tonos (U+038C)",
0xDA	:"greek capital letter upsilon with tonos (U+038E)",
0xDB	:"greek small letter epsilon with tonos (U+03AD)",
0xDC	:"greek small letter eta with tonos (U+03AE)",
0xDD	:"greek small letter iota with tonos (U+03AF)",
0xDE	:"greek small letter omicron with tonos (U+03CC)",
0xDF	:"greek capital letter omega with tonos (U+038F)",
0xE0	:"greek small letter upsilon with tonos (U+03CD)",
0xE1	:"greek small letter alpha (U+03B1)",
0xE2	:"greek small letter beta (U+03B2)",
0xE3	:"greek small letter psi (U+03C8)",
0xE4	:"greek small letter delta (U+03B4)",
0xE5	:"greek small letter epsilon (U+03B5)",
0xE6	:"greek small letter phi (U+03C6)",
0xE7	:"greek small letter gamma (U+03B3)",
0xE8	:"greek small letter eta (U+03B7)",
0xE9	:"greek small letter iota (U+03B9)",
0xEA	:"greek small letter xi (U+03BE)",
0xEB	:"greek small letter kappa (U+03BA)",
0xEC	:"greek small letter lambda (U+03BB)",
0xED	:"greek small letter mu (U+03BC)",
0xEE	:"greek small letter nu (U+03BD)",
0xEF	:"greek small letter omicron (U+03BF)",
0xF0	:"greek small letter pi (U+03C0)",
0xF1	:"greek small letter omega with tonos (U+03CE)",
0xF2	:"greek small letter rho (U+03C1)",
0xF3	:"greek small letter sigma (U+03C3)",
0xF4	:"greek small letter tau (U+03C4)",
0xF5	:"greek small letter theta (U+03B8)",
0xF6	:"greek small letter omega (U+03C9)",
0xF7	:"greek small letter final sigma (U+03C2)",
0xF8	:"greek small letter chi (U+03C7)",
0xF9	:"greek small letter upsilon (U+03C5)",
0xFA	:"greek small letter zeta (U+03B6)",
0xFB	:"greek small letter iota with dialytika (U+03CA)",
0xFC	:"greek small letter upsilon with dialytika (U+03CB)",
0xFD	:"greek small letter iota with dialytika and tonos (U+0390)",
0xFE	:"greek small letter upsilon with dialytika and tonos (U+03B0)",
0xFF	:"Unused"
}

#CP10079 MacIcelandic
macicelandicxtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"Latin capital letter a with diaeresis (U+00C4)",
0x81	:"Latin capital letter a with ring above (U+00C5)",
0x82	:"Latin capital letter c with cedilla (U+00C7)",
0x83	:"Latin capital letter e with acute (U+00C9)",
0x84	:"Latin capital letter n with tilde (U+00D1)",
0x85	:"Latin capital letter o with diaeresis (U+00D6)",
0x86	:"Latin capital letter u with diaeresis (U+00DC)",
0x87	:"Latin small letter a with acute (U+00E1)",
0x88	:"Latin small letter a with grave (U+00E0)",
0x89	:"Latin small letter a with circumflex (U+00E2)",
0x8A	:"Latin small letter a with diaeresis (U+00E4)",
0x8B	:"Latin small letter a with tilde (U+00E3)",
0x8C	:"Latin small letter a with ring above (U+00E5)",
0x8D	:"Latin small letter c with cedilla (U+00E7)",
0x8E	:"Latin small letter e with acute (U+00E9)",
0x8F	:"Latin small letter e with grave (U+00E8)",
0x90	:"Latin small letter e with circumflex (U+00EA)",
0x91	:"Latin small letter e with diaeresis (U+00EB)",
0x92	:"Latin small letter i with acute (U+00ED)",
0x93	:"Latin small letter i with grave (U+00EC)",
0x94	:"Latin small letter i with circumflex (U+00EE)",
0x95	:"Latin small letter i with diaeresis (U+00EF)",
0x96	:"Latin small letter n with tilde (U+00F1)",
0x97	:"Latin small letter o with acute (U+00F3)",
0x98	:"Latin small letter o with grave (U+00F2)",
0x99	:"Latin small letter o with circumflex (U+00F4)",
0x9A	:"Latin small letter o with diaeresis (U+00F6)",
0x9B	:"Latin small letter o with tilde (U+00F5)",
0x9C	:"Latin small letter u with acute (U+00FA)",
0x9D	:"Latin small letter u with grave (U+00F9)",
0x9E	:"Latin small letter u with circumflex (U+00FB)",
0x9F	:"Latin small letter u with diaeresis (U+00FC)",
0xA0	:"Latin capital letter y with acute (U+00DD)",
0xA1	:"degree sign (U+00B0)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"section sign (U+00A7)",
0xA5	:"bullet (U+2022)",
0xA6	:"pilcrow sign (U+00B6)",
0xA7	:"Latin small letter sharp s (U+00DF)",
0xA8	:"registered sign (U+00AE)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"trade mark sign (U+2122)",
0xAB	:"acute accent (U+00B4)",
0xAC	:"diaeresis (U+00A8)",
0xAD	:"not equal to (U+2260)",
0xAE	:"Latin capital ligature ae (U+00C6)",
0xAF	:"Latin capital letter o with stroke (U+00D8)",
0xB0	:"infinity (U+221E)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"less-than or equal to (U+2264)",
0xB3	:"greater-than or equal to (U+2265)",
0xB4	:"yen sign (U+00A5)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"partial differential (U+2202)",
0xB7	:"n-ary summation (U+2211)",
0xB8	:"n-ary product (U+220F)",
0xB9	:"greek small letter pi (U+03C0)",
0xBA	:"integral (U+222B)",
0xBB	:"feminine ordinal indicator (U+00AA)",
0xBC	:"masculine ordinal indicator (U+00BA)",
0xBD	:"ohm sign (U+2126)",
0xBE	:"Latin small ligature ae (U+00E6)",
0xBF	:"Latin small letter o with stroke (U+00F8)",
0xC0	:"inverted question mark (U+00BF)",
0xC1	:"inverted exclamation mark (U+00A1)",
0xC2	:"not sign (U+00AC)",
0xC3	:"square root (U+221A)",
0xC4	:"Latin small letter f with hook (U+0192)",
0xC5	:"almost equal to (U+2248)",
0xC6	:"increment (U+2206)",
0xC7	:"left-pointing double angle quotation mark (U+00AB)",
0xC8	:"right-pointing double angle quotation mark (U+00BB)",
0xC9	:"horizontal ellipsis (U+2026)",
0xCA	:"no-break space (U+00A0)",
0xCB	:"Latin capital letter a with grave (U+00C0)",
0xCC	:"Latin capital letter a with tilde (U+00C3)",
0xCD	:"Latin capital letter o with tilde (U+00D5)",
0xCE	:"Latin capital ligature oe (U+0152)",
0xCF	:"Latin small ligature oe (U+0153)",
0xD0	:"en dash (U+2013)",
0xD1	:"em dash (U+2014)",
0xD2	:"left double quotation mark (U+201C)",
0xD3	:"right double quotation mark (U+201D)",
0xD4	:"left single quotation mark (U+2018)",
0xD5	:"right single quotation mark (U+2019)",
0xD6	:"division sign (U+00F7)",
0xD7	:"lozenge (U+25CA)",
0xD8	:"Latin small letter y with diaeresis (U+00FF)",
0xD9	:"Latin capital letter y with diaeresis (U+0178)",
0xDA	:"fraction slash (U+2044)",
0xDB	:"currency sign (U+00A4)",
0xDC	:"Latin capital letter eth (U+00D0)",
0xDD	:"Latin small letter eth (U+00F0)",
0xDE	:"Latin capital letter thorn (U+00DE)",
0xDF	:"Latin small letter thorn (U+00FE)",
0xE0	:"Latin small letter y with acute (U+00FD)",
0xE1	:"middle dot (U+00B7)",
0xE2	:"single low-9 quotation mark (U+201A)",
0xE3	:"double low-9 quotation mark (U+201E)",
0xE4	:"per mille sign (U+2030)",
0xE5	:"Latin capital letter a with circumflex (U+00C2)",
0xE6	:"Latin capital letter e with circumflex (U+00CA)",
0xE7	:"Latin capital letter a with acute (U+00C1)",
0xE8	:"Latin capital letter e with diaeresis (U+00CB)",
0xE9	:"Latin capital letter e with grave (U+00C8)",
0xEA	:"Latin capital letter i with acute (U+00CD)",
0xEB	:"Latin capital letter i with circumflex (U+00CE)",
0xEC	:"Latin capital letter i with diaeresis (U+00CF)",
0xED	:"Latin capital letter i with grave (U+00CC)",
0xEE	:"Latin capital letter o with acute (U+00D3)",
0xEF	:"Latin capital letter o with circumflex (U+00D4)",
0xF0	:"Unused",
0xF1	:"Latin capital letter o with grave (U+00D2)",
0xF2	:"Latin capital letter u with acute (U+00DA)",
0xF3	:"Latin capital letter u with circumflex (U+00DB)",
0xF4	:"Latin capital letter u with grave (U+00D9)",
0xF5	:"Latin small letter dotless i (U+0131)",
0xF6	:"modifier letter circumflex accent (U+02C6)",
0xF7	:"small tilde (U+02DC)",
0xF8	:"macron (U+00AF)",
0xF9	:"breve (U+02D8)",
0xFA	:"dot above (U+02D9)",
0xFB	:"ring above (U+02DA)",
0xFC	:"cedilla (U+00B8)",
0xFD	:"double acute accent (U+02DD)",
0xFE	:"ogonek (U+02DB)",
0xFF	:"caron (U+02C7)"
}

#CP10000 MacRoman
macromanxtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"Latin capital letter a with diaeresis (U+00C4)",
0x81	:"Latin capital letter a with ring above (U+00C5)",
0x82	:"Latin capital letter c with cedilla (U+00C7)",
0x83	:"Latin capital letter e with acute (U+00C9)",
0x84	:"Latin capital letter n with tilde (U+00D1)",
0x85	:"Latin capital letter o with diaeresis (U+00D6)",
0x86	:"Latin capital letter u with diaeresis (U+00DC)",
0x87	:"Latin small letter a with acute (U+00E1)",
0x88	:"Latin small letter a with grave (U+00E0)",
0x89	:"Latin small letter a with circumflex (U+00E2)",
0x8A	:"Latin small letter a with diaeresis (U+00E4)",
0x8B	:"Latin small letter a with tilde (U+00E3)",
0x8C	:"Latin small letter a with ring above (U+00E5)",
0x8D	:"Latin small letter c with cedilla (U+00E7)",
0x8E	:"Latin small letter e with acute (U+00E9)",
0x8F	:"Latin small letter e with grave (U+00E8)",
0x90	:"Latin small letter e with circumflex (U+00EA)",
0x91	:"Latin small letter e with diaeresis (U+00EB)",
0x92	:"Latin small letter i with acute (U+00ED)",
0x93	:"Latin small letter i with grave (U+00EC)",
0x94	:"Latin small letter i with circumflex (U+00EE)",
0x95	:"Latin small letter i with diaeresis (U+00EF)",
0x96	:"Latin small letter n with tilde (U+00F1)",
0x97	:"Latin small letter o with acute (U+00F3)",
0x98	:"Latin small letter o with grave (U+00F2)",
0x99	:"Latin small letter o with circumflex (U+00F4)",
0x9A	:"Latin small letter o with diaeresis (U+00F6)",
0x9B	:"Latin small letter o with tilde (U+00F5)",
0x9C	:"Latin small letter u with acute (U+00FA)",
0x9D	:"Latin small letter u with grave (U+00F9)",
0x9E	:"Latin small letter u with circumflex (U+00FB)",
0x9F	:"Latin small letter u with diaeresis (U+00FC)",
0xA0	:"dagger (U+2020)",
0xA1	:"degree sign (U+00B0)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"section sign (U+00A7)",
0xA5	:"bullet (U+2022)",
0xA6	:"pilcrow sign (U+00B6)",
0xA7	:"Latin small letter sharp s (U+00DF)",
0xA8	:"registered sign (U+00AE)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"trade mark sign (U+2122)",
0xAB	:"acute accent (U+00B4)",
0xAC	:"diaeresis (U+00A8)",
0xAD	:"not equal to (U+2260)",
0xAE	:"Latin capital ligature ae (U+00C6)",
0xAF	:"Latin capital letter o with stroke (U+00D8)",
0xB0	:"infinity (U+221E)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"less-than or equal to (U+2264)",
0xB3	:"greater-than or equal to (U+2265)",
0xB4	:"yen sign (U+00A5)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"partial differential (U+2202)",
0xB7	:"n-ary summation (U+2211)",
0xB8	:"n-ary product (U+220F)",
0xB9	:"greek small letter pi (U+03C0)",
0xBA	:"integral (U+222B)",
0xBB	:"feminine ordinal indicator (U+00AA)",
0xBC	:"masculine ordinal indicator (U+00BA)",
0xBD	:"ohm sign (U+2126)",
0xBE	:"Latin small ligature ae (U+00E6)",
0xBF	:"Latin small letter o with stroke (U+00F8)",
0xC0	:"inverted question mark (U+00BF)",
0xC1	:"inverted exclamation mark (U+00A1)",
0xC2	:"not sign (U+00AC)",
0xC3	:"square root (U+221A)",
0xC4	:"Latin small letter f with hook (U+0192)",
0xC5	:"almost equal to (U+2248)",
0xC6	:"increment (U+2206)",
0xC7	:"left-pointing double angle quotation mark (U+00AB)",
0xC8	:"right-pointing double angle quotation mark (U+00BB)",
0xC9	:"horizontal ellipsis (U+2026)",
0xCA	:"no-break space (U+00A0)",
0xCB	:"Latin capital letter a with grave (U+00C0)",
0xCC	:"Latin capital letter a with tilde (U+00C3)",
0xCD	:"Latin capital letter o with tilde (U+00D5)",
0xCE	:"Latin capital ligature oe (U+0152)",
0xCF	:"Latin small ligature oe (U+0153)",
0xD0	:"en dash (U+2013)",
0xD1	:"em dash (U+2014)",
0xD2	:"left double quotation mark (U+201C)",
0xD3	:"right double quotation mark (U+201D)",
0xD4	:"left single quotation mark (U+2018)",
0xD5	:"right single quotation mark (U+2019)",
0xD6	:"division sign (U+00F7)",
0xD7	:"lozenge (U+25CA)",
0xD8	:"Latin small letter y with diaeresis (U+00FF)",
0xD9	:"Latin capital letter y with diaeresis (U+0178)",
0xDA	:"fraction slash (U+2044)",
0xDB	:"currency sign (U+00A4)",
0xDC	:"single left-pointing angle quotation mark (U+2039)",
0xDD	:"single right-pointing angle quotation mark (U+203A)",
0xDE	:"Latin small ligature fi (U+FB01)",
0xDF	:"Latin small ligature fl (U+FB02)",
0xE0	:"double dagger (U+2021)",
0xE1	:"middle dot (U+00B7)",
0xE2	:"single low-9 quotation mark (U+201A)",
0xE3	:"double low-9 quotation mark (U+201E)",
0xE4	:"per mille sign (U+2030)",
0xE5	:"Latin capital letter a with circumflex (U+00C2)",
0xE6	:"Latin capital letter e with circumflex (U+00CA)",
0xE7	:"Latin capital letter a with acute (U+00C1)",
0xE8	:"Latin capital letter e with diaeresis (U+00CB)",
0xE9	:"Latin capital letter e with grave (U+00C8)",
0xEA	:"Latin capital letter i with acute (U+00CD)",
0xEB	:"Latin capital letter i with circumflex (U+00CE)",
0xEC	:"Latin capital letter i with diaeresis (U+00CF)",
0xED	:"Latin capital letter i with grave (U+00CC)",
0xEE	:"Latin capital letter o with acute (U+00D3)",
0xEF	:"Latin capital letter o with circumflex (U+00D4)",
0xF0	:"Unused",
0xF1	:"Latin capital letter o with grave (U+00D2)",
0xF2	:"Latin capital letter u with acute (U+00DA)",
0xF3	:"Latin capital letter u with circumflex (U+00DB)",
0xF4	:"Latin capital letter u with grave (U+00D9)",
0xF5	:"Latin small letter dotless i (U+0131)",
0xF6	:"modifier letter circumflex accent (U+02C6)",
0xF7	:"small tilde (U+02DC)",
0xF8	:"macron (U+00AF)",
0xF9	:"breve (U+02D8)",
0xFA	:"dot above (U+02D9)",
0xFB	:"ring above (U+02DA)",
0xFC	:"cedilla (U+00B8)",
0xFD	:"double acute accent (U+02DD)",
0xFE	:"ogonek (U+02DB)",
0xFF	:"caron (U+02C7)"
}

#Mac Thai (pre OS X)
macthaixtbl={\
0x00	:" (U+)",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"Unused",
0x80	:"left-pointing double angle quotation mark (U+00AB)",
0x81	:"right-pointing double angle quotation mark (U+00BB)",
0x82	:"horizontal ellipsis (U+2026)",
0x83	:"thai character mai ek, low left position (U+0E48+0xF875)",
0x84	:"thai character mai tho, low left position (U+0E49+0xF875)",
0x85	:"thai character mai tri, low left position (U+0E4A+0xF875)",
0x86	:"thai character mai chattawa, low left position (U+0E4B+0xF875)",
0x87	:"thai character thanthakhat, low left position (U+0E4C+0xF875)",
0x88	:"thai character mai ek, low position (U+0E48+0xF873)",
0x89	:"thai character mai tho, low position (U+0E49+0xF873)",
0x8A	:"thai character mai tri, low position (U+0E4A+0xF873)",
0x8B	:"thai character mai chattawa, low position (U+0E4B+0xF873)",
0x8C	:"thai character thanthakhat, low position (U+0E4C+0xF873)",
0x8D	:"left double quotation mark (U+201C)",
0x8E	:"right double quotation mark (U+201D)",
0x8F	:"thai character nikhahit, left position (U+0E4D+0xF874)",
0x90	:"Unused",
0x91	:"bullet (U+2022)",
0x92	:"thai character mai han-akat, left position (U+0E31+0xF874)",
0x93	:"thai character maitaikhu, left position (U+0E47+0xF874)",
0x94	:"thai character sara i, left position (U+0E34+0xF874)",
0x95	:"thai character sara ii, left position (U+0E35+0xF874)",
0x96	:"thai character sara ue, left position (U+0E36+0xF874)",
0x97	:"thai character sara uee, left position (U+0E37+0xF874)",
0x98	:"thai character mai ek, left position (U+0E48+0xF874)",
0x99	:"thai character mai tho, left position (U+0E49+0xF874)",
0x9A	:"thai character mai tri, left position (U+0E4A+0xF874)",
0x9B	:"thai character mai chattawa, left position (U+0E4B+0xF874)",
0x9C	:"thai character thanthakhat, left position (U+0E4C+0xF874)",
0x9D	:"left single quotation mark (U+2018)",
0x9E	:"right single quotation mark (U+2019)",
0x9F	:"Unused",
0xA0	:"no-break space (U+00A0)",
0xA1	:"thai character ko kai (U+0E01)",
0xA2	:"thai character kho khai (U+0E02)",
0xA3	:"thai character kho khuat (U+0E03)",
0xA4	:"thai character kho khwai (U+0E04)",
0xA5	:"thai character kho khon (U+0E05)",
0xA6	:"thai character kho rakhang (U+0E06)",
0xA7	:"thai character ngo ngu (U+0E07)",
0xA8	:"thai character cho chan (U+0E08)",
0xA9	:"thai character cho ching (U+0E09)",
0xAA	:"thai character cho chang (U+0E0A)",
0xAB	:"thai character so so (U+0E0B)",
0xAC	:"thai character cho choe (U+0E0C)",
0xAD	:"thai character yo ying (U+0E0D)",
0xAE	:"thai character do chada (U+0E0E)",
0xAF	:"thai character to patak (U+0E0F)",
0xB0	:"thai character tho than (U+0E10)",
0xB1	:"thai character tho nangmontho (U+0E11)",
0xB2	:"thai character tho phuthao (U+0E12)",
0xB3	:"thai character no nen (U+0E13)",
0xB4	:"thai character do dek (U+0E14)",
0xB5	:"thai character to tao (U+0E15)",
0xB6	:"thai character tho thung (U+0E16)",
0xB7	:"thai character tho thahan (U+0E17)",
0xB8	:"thai character tho thong (U+0E18)",
0xB9	:"thai character no nu (U+0E19)",
0xBA	:"thai character bo baimai (U+0E1A)",
0xBB	:"thai character po pla (U+0E1B)",
0xBC	:"thai character pho phung (U+0E1C)",
0xBD	:"thai character fo fa (U+0E1D)",
0xBE	:"thai character pho phan (U+0E1E)",
0xBF	:"thai character fo fan (U+0E1F)",
0xC0	:"thai character pho samphao (U+0E20)",
0xC1	:"thai character mo ma (U+0E21)",
0xC2	:"thai character yo yak (U+0E22)",
0xC3	:"thai character ro rua (U+0E23)",
0xC4	:"thai character ru (U+0E24)",
0xC5	:"thai character lo ling (U+0E25)",
0xC6	:"thai character lu (U+0E26)",
0xC7	:"thai character wo waen (U+0E27)",
0xC8	:"thai character so sala (U+0E28)",
0xC9	:"thai character so rusi (U+0E29)",
0xCA	:"thai character so sua (U+0E2A)",
0xCB	:"thai character ho hip (U+0E2B)",
0xCC	:"thai character lo chula (U+0E2C)",
0xCD	:"thai character o ang (U+0E2D)",
0xCE	:"thai character ho nokhuk (U+0E2E)",
0xCF	:"thai character paiyannoi (U+0E2F)",
0xD0	:"thai character sara a (U+0E30)",
0xD1	:"thai character mai han-akat (U+0E31)",
0xD2	:"thai character sara aa (U+0E32)",
0xD3	:"thai character sara am (U+0E33)",
0xD4	:"thai character sara i (U+0E34)",
0xD5	:"thai character sara ii (U+0E35)",
0xD6	:"thai character sara ue (U+0E36)",
0xD7	:"thai character sara uee (U+0E37)",
0xD8	:"thai character sara u (U+0E38)",
0xD9	:"thai character sara uu (U+0E39)",
0xDA	:"thai character phinthu (U+0E3A)",
0xDB	:"word joiner # (U+2060)",
0xDC	:"zero width space (U+200B)",
0xDD	:"en dash (U+2013)",
0xDE	:"em dash (U+2014)",
0xDF	:"thai currency symbol baht (U+0E3F)",
0xE0	:"thai character sara e (U+0E40)",
0xE1	:"thai character sara ae (U+0E41)",
0xE2	:"thai character sara o (U+0E42)",
0xE3	:"thai character sara ai maimuan (U+0E43)",
0xE4	:"thai character sara ai maimalai (U+0E44)",
0xE5	:"thai character lakkhangyao (U+0E45)",
0xE6	:"thai character maiyamok (U+0E46)",
0xE7	:"thai character maitaikhu (U+0E47)",
0xE8	:"thai character mai ek (U+0E48)",
0xE9	:"thai character mai tho (U+0E49)",
0xEA	:"thai character mai tri (U+0E4A)",
0xEB	:"thai character mai chattawa (U+0E4B)",
0xEC	:"thai character thanthakhat (U+0E4C)",
0xED	:"thai character nikhahit (U+0E4D)",
0xEE	:"trade mark sign (U+2122)",
0xEF	:"thai character fongman (U+0E4F)",
0xF0	:"thai digit zero (U+0E50)",
0xF1	:"thai digit one (U+0E51)",
0xF2	:"thai digit two (U+0E52)",
0xF3	:"thai digit three (U+0E53)",
0xF4	:"thai digit four (U+0E54)",
0xF5	:"thai digit five (U+0E55)",
0xF6	:"thai digit six (U+0E56)",
0xF7	:"thai digit seven (U+0E57)",
0xF8	:"thai digit eight (U+0E58)",
0xF9	:"thai digit nine (U+0E59)",
0xFA	:"registered sign (U+00AE)",
0xFB	:"copyright sign (U+00A9)",
0xFC	:"Unused",
0xFD	:"Unused",
0xFE	:"Unused",
0xFF	:"Unused"
}

#Mac Inuit
macinuitxtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"Unused",
0x80	:"canadian syllabics i (U+1403)",
0x81	:"canadian syllabics ii (U+1404)",
0x82	:"canadian syllabics o (U+1405)",
0x83	:"canadian syllabics oo (U+1406)",
0x84	:"canadian syllabics a (U+140A)",
0x85	:"canadian syllabics aa (U+140B)",
0x86	:"canadian syllabics pi (U+1431)",
0x87	:"canadian syllabics pii (U+1432)",
0x88	:"canadian syllabics po (U+1433)",
0x89	:"canadian syllabics poo (U+1434)",
0x8A	:"canadian syllabics pa (U+1438)",
0x8B	:"canadian syllabics paa (U+1439)",
0x8C	:"canadian syllabics p (U+1449)",
0x8D	:"canadian syllabics ti (U+144E)",
0x8E	:"canadian syllabics tii (U+144F)",
0x8F	:"canadian syllabics to (U+1450)",
0x90	:"canadian syllabics too (U+1451)",
0x91	:"canadian syllabics ta (U+1455)",
0x92	:"canadian syllabics taa (U+1456)",
0x93	:"canadian syllabics t (U+1466)",
0x94	:"canadian syllabics ki (U+146D)",
0x95	:"canadian syllabics kii (U+146E)",
0x96	:"canadian syllabics ko (U+146F)",
0x97	:"canadian syllabics koo (U+1470)",
0x98	:"canadian syllabics ka (U+1472)",
0x99	:"canadian syllabics kaa (U+1473)",
0x9A	:"canadian syllabics k (U+1483)",
0x9B	:"canadian syllabics ci (U+148B)",
0x9C	:"canadian syllabics cii (U+148C)",
0x9D	:"canadian syllabics co (U+148D)",
0x9E	:"canadian syllabics coo (U+148E)",
0x9F	:"canadian syllabics ca (U+1490)",
0xA0	:"canadian syllabics caa (U+1491)",
0xA1	:"degree sign (U+00B0)",
0xA2	:"canadian syllabics c (U+14A1)",
0xA3	:"canadian syllabics mi (U+14A5)",
0xA4	:"canadian syllabics mii (U+14A6)",
0xA5	:"bullet (U+2022)",
0xA6	:"pilcrow sign (U+00B6)",
0xA7	:"canadian syllabics mo (U+14A7)",
0xA8	:"registered sign (U+00AE)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"trade mark sign (U+2122)",
0xAB	:"canadian syllabics moo (U+14A8)",
0xAC	:"canadian syllabics ma (U+14AA)",
0xAD	:"canadian syllabics maa (U+14AB)",
0xAE	:"canadian syllabics m (U+14BB)",
0xAF	:"canadian syllabics ni (U+14C2)",
0xB0	:"canadian syllabics nii (U+14C3)",
0xB1	:"canadian syllabics no (U+14C4)",
0xB2	:"canadian syllabics noo (U+14C5)",
0xB3	:"canadian syllabics na (U+14C7)",
0xB4	:"canadian syllabics naa (U+14C8)",
0xB5	:"canadian syllabics n (U+14D0)",
0xB6	:"canadian syllabics si (U+14EF)",
0xB7	:"canadian syllabics sii (U+14F0)",
0xB8	:"canadian syllabics so (U+14F1)",
0xB9	:"canadian syllabics soo (U+14F2)",
0xBA	:"canadian syllabics sa (U+14F4)",
0xBB	:"canadian syllabics saa (U+14F5)",
0xBC	:"canadian syllabics s (U+1505)",
0xBD	:"canadian syllabics li (U+14D5)",
0xBE	:"canadian syllabics lii (U+14D6)",
0xBF	:"canadian syllabics lo (U+14D7)",
0xC0	:"canadian syllabics loo (U+14D8)",
0xC1	:"canadian syllabics la (U+14DA)",
0xC2	:"canadian syllabics laa (U+14DB)",
0xC3	:"canadian syllabics l (U+14EA)",
0xC4	:"canadian syllabics yi (U+1528)",
0xC5	:"canadian syllabics yii (U+1529)",
0xC6	:"canadian syllabics yo (U+152A)",
0xC7	:"canadian syllabics yoo (U+152B)",
0xC8	:"canadian syllabics ya (U+152D)",
0xC9	:"horizontal ellipsis (U+2026)",
0xCA	:"no-break space (U+00A0)",
0xCB	:"canadian syllabics yaa (U+152E)",
0xCC	:"canadian syllabics y (U+153E)",
0xCD	:"canadian syllabics fi (U+1555)",
0xCE	:"canadian syllabics fii (U+1556)",
0xCF	:"canadian syllabics fo (U+1557)",
0xD0	:"en dash (U+2013)",
0xD1	:"em dash (U+2014)",
0xD2	:"left double quotation mark (U+201C)",
0xD3	:"right double quotation mark (U+201D)",
0xD4	:"left single quotation mark (U+2018)",
0xD5	:"right single quotation mark (U+2019)",
0xD6	:"canadian syllabics foo (U+1558)",
0xD7	:"canadian syllabics fa (U+1559)",
0xD8	:"canadian syllabics faa (U+155A)",
0xD9	:"canadian syllabics f (U+155D)",
0xDA	:"canadian syllabics ri (U+1546)",
0xDB	:"canadian syllabics rii (U+1547)",
0xDC	:"canadian syllabics ro (U+1548)",
0xDD	:"canadian syllabics roo (U+1549)",
0xDE	:"canadian syllabics ra (U+154B)",
0xDF	:"canadian syllabics raa (U+154C)",
0xE0	:"canadian syllabics r (U+1550)",
0xE1	:"canadian syllabics qi (U+157F)",
0xE2	:"canadian syllabics qii (U+1580)",
0xE3	:"canadian syllabics qo (U+1581)",
0xE4	:"canadian syllabics qoo (U+1582)",
0xE5	:"canadian syllabics qa (U+1583)",
0xE6	:"canadian syllabics qaa (U+1584)",
0xE7	:"canadian syllabics q (U+1585)",
0xE8	:"canadian syllabics ngi (U+158F)",
0xE9	:"canadian syllabics ngii (U+1590)",
0xEA	:"canadian syllabics ngo (U+1591)",
0xEB	:"canadian syllabics ngoo (U+1592)",
0xEC	:"canadian syllabics nga (U+1593)",
0xED	:"canadian syllabics ngaa (U+1594)",
0xEE	:"canadian syllabics ng (U+1595)",
0xEF	:"canadian syllabics nngi (U+1671)",
0xF0	:"canadian syllabics nngii (U+1672)",
0xF1	:"canadian syllabics nngo (U+1673)",
0xF2	:"canadian syllabics nngoo (U+1674)",
0xF3	:"canadian syllabics nnga (U+1675)",
0xF4	:"canadian syllabics nngaa (U+1676)",
0xF5	:"canadian syllabics nng (U+1596)",
0xF6	:"canadian syllabics lhi (U+15A0)",
0xF7	:"canadian syllabics lhii (U+15A1)",
0xF8	:"canadian syllabics lho (U+15A2)",
0xF9	:"canadian syllabics lhoo (U+15A3)",
0xFA	:"canadian syllabics lha (U+15A4)",
0xFB	:"canadian syllabics lhaa (U+15A5)",
0xFC	:"canadian syllabics lh (U+15A6)",
0xFD	:"canadian syllabics nunavut h (U+157C)",
0xFE	:"Latin capital letter l with stroke (U+0141)",
0xFF	:"Latin small letter l with stroke (U+0142)"
}


#MacTurkish
macturkishxtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"Unused",
0x80	:"Latin capital letter a with diaeresis (U+00C4)",
0x81	:"Latin capital letter a with ring above (U+00C5)",
0x82	:"Latin capital letter c with cedilla (U+00C7)",
0x83	:"Latin capital letter e with acute (U+00C9)",
0x84	:"Latin capital letter n with tilde (U+00D1)",
0x85	:"Latin capital letter o with diaeresis (U+00D6)",
0x86	:"Latin capital letter u with diaeresis (U+00DC)",
0x87	:"Latin small letter a with acute (U+00E1)",
0x88	:"Latin small letter a with grave (U+00E0)",
0x89	:"Latin small letter a with circumflex (U+00E2)",
0x8A	:"Latin small letter a with diaeresis (U+00E4)",
0x8B	:"Latin small letter a with tilde (U+00E3)",
0x8C	:"Latin small letter a with ring above (U+00E5)",
0x8D	:"Latin small letter c with cedilla (U+00E7)",
0x8E	:"Latin small letter e with acute (U+00E9)",
0x8F	:"Latin small letter e with grave (U+00E8)",
0x90	:"Latin small letter e with circumflex (U+00EA)",
0x91	:"Latin small letter e with diaeresis (U+00EB)",
0x92	:"Latin small letter i with acute (U+00ED)",
0x93	:"Latin small letter i with grave (U+00EC)",
0x94	:"Latin small letter i with circumflex (U+00EE)",
0x95	:"Latin small letter i with diaeresis (U+00EF)",
0x96	:"Latin small letter n with tilde (U+00F1)",
0x97	:"Latin small letter o with acute (U+00F3)",
0x98	:"Latin small letter o with grave (U+00F2)",
0x99	:"Latin small letter o with circumflex (U+00F4)",
0x9A	:"Latin small letter o with diaeresis (U+00F6)",
0x9B	:"Latin small letter o with tilde (U+00F5)",
0x9C	:"Latin small letter u with acute (U+00FA)",
0x9D	:"Latin small letter u with grave (U+00F9)",
0x9E	:"Latin small letter u with circumflex (U+00FB)",
0x9F	:"Latin small letter u with diaeresis (U+00FC)",
0xA0	:"dagger (U+2020)",
0xA1	:"degree sign (U+00B0)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"section sign (U+00A7)",
0xA5	:"bullet (U+2022)",
0xA6	:"pilcrow sign (U+00B6)",
0xA7	:"Latin small letter sharp s (U+00DF)",
0xA8	:"registered sign (U+00AE)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"trade mark sign (U+2122)",
0xAB	:"acute accent (U+00B4)",
0xAC	:"diaeresis (U+00A8)",
0xAD	:"not equal to (U+2260)",
0xAE	:"Latin capital letter ae (U+00C6)",
0xAF	:"Latin capital letter o with stroke (U+00D8)",
0xB0	:"infinity (U+221E)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"less-than or equal to (U+2264)",
0xB3	:"greater-than or equal to (U+2265)",
0xB4	:"yen sign (U+00A5)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"partial differential (U+2202)",
0xB7	:"n-ary summation (U+2211)",
0xB8	:"n-ary product (U+220F)",
0xB9	:"greek small letter pi (U+03C0)",
0xBA	:"integral (U+222B)",
0xBB	:"feminine ordinal indicator (U+00AA)",
0xBC	:"masculine ordinal indicator (U+00BA)",
0xBD	:"greek capital letter omega (U+03A9)",
0xBE	:"Latin small letter ae (U+00E6)",
0xBF	:"Latin small letter o with stroke (U+00F8)",
0xC0	:"inverted question mark (U+00BF)",
0xC1	:"inverted exclamation mark (U+00A1)",
0xC2	:"not sign (U+00AC)",
0xC3	:"square root (U+221A)",
0xC4	:"Latin small letter f with hook (U+0192)",
0xC5	:"almost equal to (U+2248)",
0xC6	:"increment (U+2206)",
0xC7	:"left-pointing double angle quotation mark (U+00AB)",
0xC8	:"right-pointing double angle quotation mark (U+00BB)",
0xC9	:"horizontal ellipsis (U+2026)",
0xCA	:"no-break space (U+00A0)",
0xCB	:"Latin capital letter a with grave (U+00C0)",
0xCC	:"Latin capital letter a with tilde (U+00C3)",
0xCD	:"Latin capital letter o with tilde (U+00D5)",
0xCE	:"Latin capital ligature oe (U+0152)",
0xCF	:"Latin small ligature oe (U+0153)",
0xD0	:"en dash (U+2013)",
0xD1	:"em dash (U+2014)",
0xD2	:"left double quotation mark (U+201C)",
0xD3	:"right double quotation mark (U+201D)",
0xD4	:"left single quotation mark (U+2018)",
0xD5	:"right single quotation mark (U+2019)",
0xD6	:"division sign (U+00F7)",
0xD7	:"lozenge (U+25CA)",
0xD8	:"Latin small letter y with diaeresis (U+00FF)",
0xD9	:"Latin capital letter y with diaeresis (U+0178)",
0xDA	:"Latin capital letter g with breve (U+011E)",
0xDB	:"Latin small letter g with breve (U+011F)",
0xDC	:"Latin capital letter i with dot above (U+0130)",
0xDD	:"Latin small letter dotless i (U+0131)",
0xDE	:"Latin capital letter s with cedilla (U+015E)",
0xDF	:"Latin small letter s with cedilla (U+015F)",
0xE0	:"double dagger (U+2021)",
0xE1	:"middle dot (U+00B7)",
0xE2	:"single low-9 quotation mark (U+201A)",
0xE3	:"double low-9 quotation mark (U+201E)",
0xE4	:"per mille sign (U+2030)",
0xE5	:"Latin capital letter a with circumflex (U+00C2)",
0xE6	:"Latin capital letter e with circumflex (U+00CA)",
0xE7	:"Latin capital letter a with acute (U+00C1)",
0xE8	:"Latin capital letter e with diaeresis (U+00CB)",
0xE9	:"Latin capital letter e with grave (U+00C8)",
0xEA	:"Latin capital letter i with acute (U+00CD)",
0xEB	:"Latin capital letter i with circumflex (U+00CE)",
0xEC	:"Latin capital letter i with diaeresis (U+00CF)",
0xED	:"Latin capital letter i with grave (U+00CC)",
0xEE	:"Latin capital letter o with acute (U+00D3)",
0xEF	:"Latin capital letter o with circumflex (U+00D4)",
0xF0	:"apple logo (U+F8FF)",
0xF1	:"Latin capital letter o with grave (U+00D2)",
0xF2	:"Latin capital letter u with acute (U+00DA)",
0xF3	:"Latin capital letter u with circumflex (U+00DB)",
0xF4	:"Latin capital letter u with grave (U+00D9)",
0xF5	:"undefined1 (U+F8A0)",
0xF6	:"modifier letter circumflex accent (U+02C6)",
0xF7	:"small tilde (U+02DC)",
0xF8	:"macron (U+00AF)",
0xF9	:"breve (U+02D8)",
0xFA	:"dot above (U+02D9)",
0xFB	:"ring above (U+02DA)",
0xFC	:"cedilla (U+00B8)",
0xFD	:"double acute accent (U+02DD)",
0xFE	:"ogonek (U+02DB)",
0xFF	:"caron (U+02C7)"
}


#ISIRI 2900 Iran obsolete
isiri2900xtbl={\
0x00	:"<control> (U+0000)",
0x01	:"<control> (U+0001)",
0x02	:"<control> (U+0002)",
0x03	:"<control> (U+0003)",
0x04	:"<control> (U+0004)",
0x05	:"<control> (U+0005)",
0x06	:"<control> (U+0006)",
0x07	:"<control> (U+0007)",
0x08	:"<control> (U+0008)",
0x09	:"<control> (U+0009)",
0x0A	:"<control> (U+000A)",
0x0B	:"<control> (U+000B)",
0x0C	:"<control> (U+000C)",
0x0D	:"<control> (U+000D)",
0x0E	:"<control> (U+000E)",
0x0F	:"<control> (U+000F)",
0x10	:"<control> (U+0010)",
0x11	:"<control> (U+0011)",
0x12	:"<control> (U+0012)",
0x13	:"<control> (U+0013)",
0x14	:"<control> (U+0014)",
0x15	:"<control> (U+0015)",
0x16	:"<control> (U+0016)",
0x17	:"<control> (U+0017)",
0x18	:"<control> (U+0018)",
0x19	:"<control> (U+0019)",
0x1A	:"<control> (U+001A)",
0x1B	:"<control> (U+001B)",
0x1C	:"<control> (U+001C)",
0x1D	:"<control> (U+001D)",
0x1E	:"<control> (U+001E)",
0x1F	:"<control> (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"equals sign (U+003D)",
0x24	:"currency sign (U+00A4)",
0x25	:"Arabic percent sign (U+066A)",
0x26	:"colon (U+003A)",
0x27	:"Arabic question mark (U+061F)",
0x28	:"right parenthesis (U+0029)",
0x29	:"left parenthesis (U+0028)",
0x2A	:"multiplication sign (U+00D7)",
0x2B	:"plus sign (U+002B)",
0x2C	:"Arabic comma (U+060C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"Arabic decimal separator (U+066B)",
0x30	:"extended Arabic-indic digit zero (U+06F0)",
0x31	:"extended Arabic-indic digit one (U+06F1)",
0x32	:"extended Arabic-indic digit two (U+06F2)",
0x33	:"extended Arabic-indic digit three (U+06F3)",
0x34	:"extended Arabic-indic digit four (U+06F4)",
0x35	:"extended Arabic-indic digit five (U+06F5)",
0x36	:"extended Arabic-indic digit six (U+06F6)",
0x37	:"extended Arabic-indic digit seven (U+06F7)",
0x38	:"extended Arabic-indic digit eight (U+06F8)",
0x39	:"extended Arabic-indic digit nine (U+06F9)",
0x3A	:"Arabic letter alef with madda above (U+0622)",
0x3B	:"Arabic letter alef (U+0627)",
0x3C	:"Arabic letter hamza (U+0621)",
0x3D	:"Arabic letter alef with hamza above (U+0623)",
0x3E	:"Arabic letter waw with hamza above (U+0624)",
0x3F	:"Arabic letter yeh with hamza above, initial-medial form (U+0626)",
0x40	:"Arabic letter beh, initial-medial form (U+0628)",
0x41	:"Arabic letter beh, final-isolated form (U+0628)",
0x42	:"Arabic letter peh, initial-medial form (U+067E)",
0x43	:"Arabic letter peh, final-isolated form (U+067E)",
0x44	:"Arabic letter teh, initial-medial form (U+062A)",
0x45	:"Arabic letter teh, final-isolated form (U+062A)",
0x46	:"Arabic letter theh, initial-medial form (U+062B)",
0x47	:"Arabic letter theh, final-isolated form (U+062B)",
0x48	:"Arabic letter jeem, initial-medial form (U+062C)",
0x49	:"Arabic letter jeem, final-isolated form (U+062C)",
0x4A	:"Arabic letter tcheh, initial-medial form (U+0686)",
0x4B	:"Arabic letter tcheh, final-isolated form (U+0686)",
0x4C	:"Arabic letter hah, initial-medial form (U+062D)",
0x4D	:"Arabic letter hah, final-isolated form (U+062D)",
0x4E	:"Arabic letter khah, initial-medial form (U+062E)",
0x4F	:"Arabic letter khah, final-isolated form (U+062E)",
0x50	:"Arabic letter dal, initial-medial form (U+062F)",
0x51	:"Arabic letter dal, final-isolated form (U+062F)",
0x52	:"Arabic letter thal, initial-medial form (U+0630)",
0x53	:"Arabic letter thal, final-isolated form (U+0630)",
0x54	:"Arabic letter reh, initial-medial form (U+0631)",
0x55	:"Arabic letter reh, final-isolated form (U+0631)",
0x56	:"Arabic letter zain, initial-medial form (U+0632)",
0x57	:"Arabic letter zain, final-isolated form (U+0632)",
0x58	:"Arabic letter jeh, initial-medial form (U+0698)",
0x59	:"Arabic letter jeh, final-isolated form (U+0698)",
0x5A	:"Arabic letter seen, initial-medial form (U+0633)",
0x5B	:"Arabic letter seen, final-isolated form (U+0633)",
0x5C	:"Arabic letter sheen, initial-medial form (U+0634)",
0x5D	:"Arabic letter sheen, final-isolated form (U+0634)",
0x5E	:"Arabic letter sad, initial-medial form (U+0635)",
0x5F	:"Arabic letter sad, final-isolated form (U+0635)",
0x60	:"Arabic letter dad, initial-medial form (U+0636)",
0x61	:"Arabic letter dad, final-isolated form (U+0636)",
0x62	:"Arabic letter tah, initial-medial form (U+0637)",
0x63	:"Arabic letter tah, final-isolated form (U+0637)",
0x64	:"Arabic letter zah, initial-medial form (U+0638)",
0x65	:"Arabic letter zah, final-isolated form (U+0638)",
0x66	:"Arabic letter ain, initial-medial form (U+0639)",
0x67	:"Arabic letter ain, final-isolated form (U+0639)",
0x68	:"Arabic letter ghain, initial-medial form (U+063A)",
0x69	:"Arabic letter ghain, final-isolated form (U+063A)",
0x6A	:"Arabic letter feh, initial-medial form (U+0641)",
0x6B	:"Arabic letter feh, final-isolated form (U+0641)",
0x6C	:"Arabic letter qaf, initial-medial form (U+0642)",
0x6D	:"Arabic letter qaf, final-isolated form (U+0642)",
0x6E	:"Arabic letter keheh, initial-medial form (U+06A9)",
0x6F	:"Arabic letter keheh, final-isolated form (U+06A9)",
0x70	:"Arabic letter gaf, initial-medial form (U+06AF)",
0x71	:"Arabic letter gaf, final-isolated form (U+06AF)",
0x72	:"Arabic letter lam, initial-medial form (U+0644)",
0x73	:"Arabic letter lam, final-isolated form (U+0644)",
0x74	:"Arabic letter meem, initial-medial form (U+0645)",
0x75	:"Arabic letter meem, final-isolated form (U+0645)",
0x76	:"Arabic letter noon, initial-medial form (U+0646)",
0x77	:"Arabic letter noon, final-isolated form (U+0646)",
0x78	:"Arabic letter waw, initial-medial form (U+0648)",
0x79	:"Arabic letter waw, final-isolated form (U+0648)",
0x7A	:"Arabic letter heh, initial-medial form (U+0647)",
0x7B	:"Arabic letter heh, final-isolated form (U+0647)",
0x7C	:"Arabic letter farsi yeh, initial-medial form (U+06CC)",
0x7D	:"Arabic letter farsi yeh, final-isolated form (U+06CC)",
0x7E	:"Unused",
0x7F	:"<control> (U+007F)",
0x80	:"Unused (7-bit encoding)",
0x81	:"Unused (7-bit encoding)",
0x82	:"Unused (7-bit encoding)",
0x83	:"Unused (7-bit encoding)",
0x84	:"Unused (7-bit encoding)",
0x85	:"Unused (7-bit encoding)",
0x86	:"Unused (7-bit encoding)",
0x87	:"Unused (7-bit encoding)",
0x88	:"Unused (7-bit encoding)",
0x89	:"Unused (7-bit encoding)",
0x8A	:"Unused (7-bit encoding)",
0x8B	:"Unused (7-bit encoding)",
0x8C	:"Unused (7-bit encoding)",
0x8D	:"Unused (7-bit encoding)",
0x8E	:"Unused (7-bit encoding)",
0x8F	:"Unused (7-bit encoding)",
0x90	:"Unused (7-bit encoding)",
0x91	:"Unused (7-bit encoding)",
0x92	:"Unused (7-bit encoding)",
0x93	:"Unused (7-bit encoding)",
0x94	:"Unused (7-bit encoding)",
0x95	:"Unused (7-bit encoding)",
0x96	:"Unused (7-bit encoding)",
0x97	:"Unused (7-bit encoding)",
0x98	:"Unused (7-bit encoding)",
0x99	:"Unused (7-bit encoding)",
0x9A	:"Unused (7-bit encoding)",
0x9B	:"Unused (7-bit encoding)",
0x9C	:"Unused (7-bit encoding)",
0x9D	:"Unused (7-bit encoding)",
0x9E	:"Unused (7-bit encoding)",
0x9F	:"Unused (7-bit encoding)",
0xA0	:"Unused (7-bit encoding)",
0xA1	:"Unused (7-bit encoding)",
0xA2	:"Unused (7-bit encoding)",
0xA3	:"Unused (7-bit encoding)",
0xA4	:"Unused (7-bit encoding)",
0xA5	:"Unused (7-bit encoding)",
0xA6	:"Unused (7-bit encoding)",
0xA7	:"Unused (7-bit encoding)",
0xA8	:"Unused (7-bit encoding)",
0xA9	:"Unused (7-bit encoding)",
0xAA	:"Unused (7-bit encoding)",
0xAB	:"Unused (7-bit encoding)",
0xAC	:"Unused (7-bit encoding)",
0xAD	:"Unused (7-bit encoding)",
0xAE	:"Unused (7-bit encoding)",
0xAF	:"Unused (7-bit encoding)",
0xB0	:"Unused (7-bit encoding)",
0xB1	:"Unused (7-bit encoding)",
0xB2	:"Unused (7-bit encoding)",
0xB3	:"Unused (7-bit encoding)",
0xB4	:"Unused (7-bit encoding)",
0xB5	:"Unused (7-bit encoding)",
0xB6	:"Unused (7-bit encoding)",
0xB7	:"Unused (7-bit encoding)",
0xB8	:"Unused (7-bit encoding)",
0xB9	:"Unused (7-bit encoding)",
0xBA	:"Unused (7-bit encoding)",
0xBB	:"Unused (7-bit encoding)",
0xBC	:"Unused (7-bit encoding)",
0xBD	:"Unused (7-bit encoding)",
0xBE	:"Unused (7-bit encoding)",
0xBF	:"Unused (7-bit encoding)",
0xC0	:"Unused (7-bit encoding)",
0xC1	:"Unused (7-bit encoding)",
0xC2	:"Unused (7-bit encoding)",
0xC3	:"Unused (7-bit encoding)",
0xC4	:"Unused (7-bit encoding)",
0xC5	:"Unused (7-bit encoding)",
0xC6	:"Unused (7-bit encoding)",
0xC7	:"Unused (7-bit encoding)",
0xC8	:"Unused (7-bit encoding)",
0xC9	:"Unused (7-bit encoding)",
0xCA	:"Unused (7-bit encoding)",
0xCB	:"Unused (7-bit encoding)",
0xCC	:"Unused (7-bit encoding)",
0xCD	:"Unused (7-bit encoding)",
0xCE	:"Unused (7-bit encoding)",
0xCF	:"Unused (7-bit encoding)",
0xD0	:"Unused (7-bit encoding)",
0xD1	:"Unused (7-bit encoding)",
0xD2	:"Unused (7-bit encoding)",
0xD3	:"Unused (7-bit encoding)",
0xD4	:"Unused (7-bit encoding)",
0xD5	:"Unused (7-bit encoding)",
0xD6	:"Unused (7-bit encoding)",
0xD7	:"Unused (7-bit encoding)",
0xD8	:"Unused (7-bit encoding)",
0xD9	:"Unused (7-bit encoding)",
0xDA	:"Unused (7-bit encoding)",
0xDB	:"Unused (7-bit encoding)",
0xDC	:"Unused (7-bit encoding)",
0xDD	:"Unused (7-bit encoding)",
0xDE	:"Unused (7-bit encoding)",
0xDF	:"Unused (7-bit encoding)",
0xE0	:"Unused (7-bit encoding)",
0xE1	:"Unused (7-bit encoding)",
0xE2	:"Unused (7-bit encoding)",
0xE3	:"Unused (7-bit encoding)",
0xE4	:"Unused (7-bit encoding)",
0xE5	:"Unused (7-bit encoding)",
0xE6	:"Unused (7-bit encoding)",
0xE7	:"Unused (7-bit encoding)",
0xE8	:"Unused (7-bit encoding)",
0xE9	:"Unused (7-bit encoding)",
0xEA	:"Unused (7-bit encoding)",
0xEB	:"Unused (7-bit encoding)",
0xEC	:"Unused (7-bit encoding)",
0xED	:"Unused (7-bit encoding)",
0xEE	:"Unused (7-bit encoding)",
0xEF	:"Unused (7-bit encoding)",
0xF0	:"Unused (7-bit encoding)",
0xF1	:"Unused (7-bit encoding)",
0xF2	:"Unused (7-bit encoding)",
0xF3	:"Unused (7-bit encoding)",
0xF4	:"Unused (7-bit encoding)",
0xF5	:"Unused (7-bit encoding)",
0xF6	:"Unused (7-bit encoding)",
0xF7	:"Unused (7-bit encoding)",
0xF8	:"Unused (7-bit encoding)",
0xF9	:"Unused (7-bit encoding)",
0xFA	:"Unused (7-bit encoding)",
0xFB	:"Unused (7-bit encoding)",
0xFC	:"Unused (7-bit encoding)",
0xFD	:"Unused (7-bit encoding)",
0xFE	:"Unused (7-bit encoding)",
0xFF	:"Unused (7-bit encoding)"
}

#ISIRI 3342 Iran current
isiri3342xtbl={\
0x00	:"<control> (U+0000)",
0x01	:"<control> (U+0001)",
0x02	:"<control> (U+0002)",
0x03	:"<control> (U+0003)",
0x04	:"<control> (U+0004)",
0x05	:"<control> (U+0005)",
0x06	:"<control> (U+0006)",
0x07	:"<control> (U+0007)",
0x08	:"<control> (U+0008)",
0x09	:"<control> (U+0009)",
0x0A	:"<control> (U+000A)",
0x0B	:"<control> (U+000B)",
0x0C	:"<control> (U+000C)",
0x0D	:"<control> (U+000D)",
0x0E	:"<control> (U+000E)",
0x0F	:"<control> (U+000F)",
0x10	:"<control> (U+0010)",
0x11	:"<control> (U+0011)",
0x12	:"<control> (U+0012)",
0x13	:"<control> (U+0013)",
0x14	:"<control> (U+0014)",
0x15	:"<control> (U+0015)",
0x16	:"<control> (U+0016)",
0x17	:"<control> (U+0017)",
0x18	:"<control> (U+0018)",
0x19	:"<control> (U+0019)",
0x1A	:"<control> (U+001A)",
0x1B	:"<control> (U+001B)",
0x1C	:"<control> (U+001C)",
0x1D	:"<control> (U+001D)",
0x1E	:"<control> (U+001E)",
0x1F	:"<control> (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"<control> (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"space (U+0020)",
0xA1	:"zero width non-joiner (U+200C)",
0xA2	:"zero width joiner (U+200D)",
0xA3	:"exclamation mark (U+0021)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"Arabic percent sign (U+066A)",
0xA6	:"full stop (U+002E)",
0xA7	:"Arabic thousands separator (U+066C)",
0xA8	:"right parenthesis (U+0029)",
0xA9	:"left parenthesis (U+0028)",
0xAA	:"multiplication sign (U+00D7)",
0xAB	:"plus sign (U+002B)",
0xAC	:"Arabic comma (U+060C)",
0xAD	:"hyphen-minus (U+002D)",
0xAE	:"Arabic decimal separator (U+066B)",
0xAF	:"solidus (U+002F)",
0xB0	:"extended Arabic-indic digit zero (U+06F0)",
0xB1	:"extended Arabic-indic digit one (U+06F1)",
0xB2	:"extended Arabic-indic digit two (U+06F2)",
0xB3	:"extended Arabic-indic digit three (U+06F3)",
0xB4	:"extended Arabic-indic digit four (U+06F4)",
0xB5	:"extended Arabic-indic digit five (U+06F5)",
0xB6	:"extended Arabic-indic digit six (U+06F6)",
0xB7	:"extended Arabic-indic digit seven (U+06F7)",
0xB8	:"extended Arabic-indic digit eight (U+06F8)",
0xB9	:"extended Arabic-indic digit nine (U+06F9)",
0xBA	:"colon (U+003A)",
0xBB	:"Arabic semicolon (U+061B)",
0xBC	:"less-than sign (U+003C)",
0xBD	:"equals sign (U+003D)",
0xBE	:"greater-than sign (U+003E)",
0xBF	:"Arabic question mark (U+061F)",
0xC0	:"Arabic letter alef with madda above (U+0622)",
0xC1	:"Arabic letter alef (U+0627)",
0xC2	:"Arabic letter hamza (U+0621)",
0xC3	:"Arabic letter beh (U+0628)",
0xC4	:"Arabic letter peh (U+067E)",
0xC5	:"Arabic letter teh (U+062A)",
0xC6	:"Arabic letter theh (U+062B)",
0xC7	:"Arabic letter jeem (U+062C)",
0xC8	:"Arabic letter tcheh (U+0686)",
0xC9	:"Arabic letter hah (U+062D)",
0xCA	:"Arabic letter khah (U+062E)",
0xCB	:"Arabic letter dal (U+062F)",
0xCC	:"Arabic letter thal (U+0630)",
0xCD	:"Arabic letter reh (U+0631)",
0xCE	:"Arabic letter zain (U+0632)",
0xCF	:"Arabic letter jeh (U+0698)",
0xD0	:"Arabic letter seen (U+0633)",
0xD1	:"Arabic letter sheen (U+0634)",
0xD2	:"Arabic letter sad (U+0635)",
0xD3	:"Arabic letter dad (U+0636)",
0xD4	:"Arabic letter tah (U+0637)",
0xD5	:"Arabic letter zah (U+0638)",
0xD6	:"Arabic letter ain (U+0639)",
0xD7	:"Arabic letter ghain (U+063A)",
0xD8	:"Arabic letter feh (U+0641)",
0xD9	:"Arabic letter qaf (U+0642)",
0xDA	:"Arabic letter keheh (U+06A9)",
0xDB	:"Arabic letter gaf (U+06AF)",
0xDC	:"Arabic letter lam (U+0644)",
0xDD	:"Arabic letter meem (U+0645)",
0xDE	:"Arabic letter noon (U+0646)",
0xDF	:"Arabic letter waw (U+0648)",
0xE0	:"Arabic letter heh (U+0647)",
0xE1	:"Arabic letter farsi yeh (U+06CC)",
0xE2	:"right square bracket (U+005D)",
0xE3	:"left square bracket (U+005B)",
0xE4	:"right curly bracket (U+007D)",
0xE5	:"left curly bracket (U+007B)",
0xE6	:"left-pointing double angle quotation mark (U+00AB)",
0xE7	:"right-pointing double angle quotation mark (U+00BB)",
0xE8	:"asterisk (U+002A)",
0xE9	:"Arabic tatweel (U+0640)",
0xEA	:"vertical line (U+007C)",
0xEB	:"reverse solidus (U+005C)",
0xEC	:"replacement character (U+FFFD)",
0xED	:"replacement character (U+FFFD)",
0xEE	:"replacement character (U+FFFD)",
0xEF	:"replacement character (U+FFFD)",
0xF0	:"Arabic fatha (U+064E)",
0xF1	:"Arabic kasra (U+0650)",
0xF2	:"Arabic damma (U+064F)",
0xF3	:"Arabic fathatan (U+064B)",
0xF4	:"Arabic kasratan (U+064D)",
0xF5	:"Arabic dammatan (U+064C)",
0xF6	:"Arabic shadda (U+0651)",
0xF7	:"Arabic sukun (U+0652)",
0xF8	:"Arabic letter alef with hamza above (U+0623)",
0xF9	:"Arabic letter waw with hamza above (U+0624)",
0xFA	:"Arabic letter alef with hamza below (U+0625)",
0xFB	:"Arabic letter yeh with hamza above (U+0626)",
0xFC	:"Arabic letter teh marbuta (U+0629)",
0xFD	:"Arabic letter kaf (U+0643)",
0xFE	:"Arabic letter yeh (U+064A)",
0xFF	:"replacement character (U+FFFD)"
}


#ISO-8859-1 [Afrikaans,Albanian,Basque,Catalan,Danish,Dutch,English,Estonian,Faroese,French,Finnish,German,Icelandic,Irish,Italian,Latin,Norwegian,Portuguese,Rhaeto-Romance,Scottish,Spanish,Swahili,Swedish]
iso8859_1xtbl = { \
0x00	:"NUL (ASCII control character)",
0x01	:"SOH (ASCII control character)",
0x02	:"STX (ASCII control character)",
0x03	:"ETX (ASCII control character)",
0x04	:"EOT (ASCII control character)",
0x05	:"ENQ (ASCII control character)",
0x06	:"ACK (ASCII control character)",
0x07	:"BEL (ASCII control character)",
0x08	:"Backspace (ASCII control character)",
0x09	:"Tab (ASCII control character)",
0x0a	:"Newline",
0x0b	:"VT (ASCII control character)",
0x0c	:"FF (ASCII control character)",
0x0d	:"Carriage return",
0x0e	:"SO (ASCII control character)",
0x0f	:"SI (ASCII control character)",
0x10	:"DLE (ASCII control character)",
0x11	:"DC1 (ASCII control character)",
0x12	:"DC2 (ASCII control character)",
0x13	:"DC3 (ASCII control character)",
0x14	:"DC4 (ASCII control character)",
0x15	:"NAK (ASCII control character)",
0x16	:"SYN (ASCII control character)",
0x17	:"ETB (ASCII control character)",
0x18	:"CAN (ASCII control character)",
0x19	:"EM (ASCII control character)",
0x1a	:"SUB (ASCII control character)",
0x1b	:"ESC (ASCII control character)",
0x1c	:"FS (ASCII control character)",
0x1d	:"GS (ASCII control character)",
0x1e	:"RS (ASCII control character)",
0x1f	:"US (ASCII control character)",
0x20	:"Space",
0x21	:"Exclamation point",
0x22	:"Double quote",
0x23	:"Pound sign",
0x24	:"Dollar sign",
0x25	:"Percent sign",
0x26	:"Ampersand",
0x27	:"Right single quote / apostrophe",
0x28	:"Left parenthesis",
0x29	:"Right parenthesis",
0x2a	:"Asterisk",
0x2b	:"Plus",
0x2c	:"Comma",
0x2d	:"Hyphen",
0x2e	:"Period",
0x2f	:"Slash",
0x30	:"Latin digit 0",
0x31	:"Latin digit 1",
0x32	:"Latin digit 2",
0x33	:"Latin digit 3",
0x34	:"Latin digit 4",
0x35	:"Latin digit 5",
0x36	:"Latin digit 6",
0x37	:"Latin digit 7",
0x38	:"Latin digit 8",
0x39	:"Latin digit 9",
0x3a	:"Colon",
0x3b	:"Semi-colon",
0x3c	:"Less-than",
0x3d	:"Equal-sign",
0x3e	:"Greater-than",
0x3f	:"Question mark",
0x40	:"At-sign",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5b	:"Left square bracket",
0x5c	:"Backslash",
0x5d	:"Right square bracket",
0x5e	:"Caret",
0x5f	:"Underscore",
0x60	:"Left single quote",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7b	:"Left curly bracket",
0x7c	:"Pipe",
0x7d	:"Right curly bracket",
0x7e	:"Tilde",
0x7f	:"DEL",
0x80	:"Padding character (pad)",
0x81	:"High octet preset (hop)",
0x82	:"Break permitted here (bph)",
0x83	:"No break here (nbh)",
0x84	:"Index (ind)",
0x85	:"Next line (nel)",
0x86	:"Start of selected area (ssa)",
0x87	:"End of selected area (esa)",
0x88	:"Character tabulation set (hts)",
0x89	:"Character tabulation with justification (htj)",
0x8A	:"Line tabulation set (vts)",
0x8B	:"Partial line forward (pld)",
0x8C	:"Partial line backward (plu)",
0x8D	:"Reverse line feed (ri)",
0x8E	:"Single-shift two (ss2)",
0x8F	:"Single-shift three (ss3)",
0x90	:"Device control string (dcs)",
0x91	:"Private use one (pu1)",
0x92	:"Private use two (pu2)",
0x93	:"Set transmit state (sts)",
0x94	:"Cancel character (cch)",
0x95	:"Message waiting (mw)",
0x96	:"Start of guarded area (spa)",
0x97	:"End of guarded area (epa)",
0x98	:"Start of string (sos)",
0x99	:"Single graphic character introducer (sgci)",
0x9A	:"Single character introducer (sci)",
0x9B	:"Control sequence introducer (csi)",
0x9C	:"String terminator (st)",
0x9D	:"Operating system command (osc)",
0x9E	:"Privacy message (pm)",
0x9F	:"Application program command (apc)",
0xA0	:"No-break space",
0xA1	:"Inverted exclamation mark",
0xA2	:"Cent sign",
0xA3	:"Pound sign",
0xA4	:"Currency sign",
0xA5	:"Yen sign",
0xA6	:"Broken bar",
0xA7	:"Section sign",
0xA8	:"Diaeresis",
0xA9	:"Copyright sign",
0xAA	:"Feminine ordinal indicator",
0xAB	:"Left-pointing double angle quotation mark",
0xAC	:"Not sign",
0xAD	:"Soft hyphen",
0xAE	:"Registered sign",
0xAF	:"Macron",
0xB0	:"Degree sign",
0xB1	:"Plus-minus sign",
0xB2	:"Superscript two",
0xB3	:"Superscript three",
0xB4	:"Acute accent",
0xB5	:"Micro sign",
0xB6	:"Pilcrow sign",
0xB7	:"Middle dot",
0xB8	:"Cedilla",
0xB9	:"Superscript one",
0xBA	:"Masculine ordinal indicator",
0xBB	:"Right-pointing double angle quotation mark",
0xBC	:"Vulgar fraction one quarter",
0xBD	:"Vulgar fraction one half",
0xBE	:"Vulgar fraction three quarters",
0xBF	:"Inverted question mark",
0xC0	:"Latin capital letter a with grave",
0xC1	:"Latin capital letter a with acute",
0xC2	:"Latin capital letter a with circumflex",
0xC3	:"Latin capital letter a with tilde",
0xC4	:"Latin capital letter a with diaeresis",
0xC5	:"Latin capital letter a with ring above",
0xC6	:"Latin capital letter ae",
0xC7	:"Latin capital letter c with cedilla",
0xC8	:"Latin capital letter e with grave",
0xC9	:"Latin capital letter e with acute",
0xCA	:"Latin capital letter e with circumflex",
0xCB	:"Latin capital letter e with diaeresis",
0xCC	:"Latin capital letter i with grave",
0xCD	:"Latin capital letter i with acute",
0xCE	:"Latin capital letter i with circumflex",
0xCF	:"Latin capital letter i with diaeresis",
0xD0	:"Latin capital letter eth (icelandic)",
0xD1	:"Latin capital letter n with tilde",
0xD2	:"Latin capital letter o with grave",
0xD3	:"Latin capital letter o with acute",
0xD4	:"Latin capital letter o with circumflex",
0xD5	:"Latin capital letter o with tilde",
0xD6	:"Latin capital letter o with diaeresis",
0xD7	:"Multiplication sign",
0xD8	:"Latin capital letter o with stroke",
0xD9	:"Latin capital letter u with grave",
0xDA	:"Latin capital letter u with acute",
0xDB	:"Latin capital letter u with circumflex",
0xDC	:"Latin capital letter u with diaeresis",
0xDD	:"Latin capital letter y with acute",
0xDE	:"Latin capital letter thorn (icelandic)",
0xDF	:"Latin small letter sharp s (german)",
0xE0	:"Latin small letter a with grave",
0xE1	:"Latin small letter a with acute",
0xE2	:"Latin small letter a with circumflex",
0xE3	:"Latin small letter a with tilde",
0xE4	:"Latin small letter a with diaeresis",
0xE5	:"Latin small letter a with ring above",
0xE6	:"Latin small letter ae",
0xE7	:"Latin small letter c with cedilla",
0xE8	:"Latin small letter e with grave",
0xE9	:"Latin small letter e with acute",
0xEA	:"Latin small letter e with circumflex",
0xEB	:"Latin small letter e with diaeresis",
0xEC	:"Latin small letter i with grave",
0xED	:"Latin small letter i with acute",
0xEE	:"Latin small letter i with circumflex",
0xEF	:"Latin small letter i with diaeresis",
0xF0	:"Latin small letter eth (icelandic)",
0xF1	:"Latin small letter n with tilde",
0xF2	:"Latin small letter o with grave",
0xF3	:"Latin small letter o with acute",
0xF4	:"Latin small letter o with circumflex",
0xF5	:"Latin small letter o with tilde",
0xF6	:"Latin small letter o with diaeresis",
0xF7	:"Division sign",
0xF8	:"Latin small letter o with stroke",
0xF9	:"Latin small letter u with grave",
0xFA	:"Latin small letter u with acute",
0xFB	:"Latin small letter u with circumflex",
0xFC	:"Latin small letter u with diaeresis",
0xFD	:"Latin small letter y with acute",
0xFE	:"Latin small letter thorn (icelandic)",
0xFF	:"Latin small letter y with diaeresis"
}

# ISO-8859-2 Eastern Europe [Bosnian,Croatian,Czech,German,English,Finnish,Hungarian,Polish,Romanian,Serbian,Slovak,Slovenian,Upper Sorbian,Lower Sorbian]
iso8859_2xtbl = { \
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"Unused",
0x80	:"Unused",
0x81	:"Unused",
0x82	:"Unused",
0x83	:"Unused",
0x84	:"Unused",
0x85	:"Unused",
0x86	:"Unused",
0x87	:"Unused",
0x88	:"Unused",
0x89	:"Unused",
0x8A	:"Unused",
0x8B	:"Unused",
0x8C	:"Unused",
0x8D	:"Unused",
0x8E	:"Unused",
0x8F	:"Unused",
0x90	:"Unused",
0x91	:"Unused",
0x92	:"Unused",
0x93	:"Unused",
0x94	:"Unused",
0x95	:"Unused",
0x96	:"Unused",
0x97	:"Unused",
0x98	:"Unused",
0x99	:"Unused",
0x9A	:"Unused",
0x9B	:"Unused",
0x9C	:"Unused",
0x9D	:"Unused",
0x9E	:"Unused",
0x9F	:"Unused",
0xA0	:"no-break space (U+00A0)",
0xA1	:"Latin capital letter a with ogonek (U+0104)",
0xA2	:"breve (U+02D8)",
0xA3	:"Latin capital letter l with stroke (U+0141)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"Latin capital letter l with caron (U+013D)",
0xA6	:"Latin capital letter s with acute (U+015A)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"Latin capital letter s with caron (U+0160)",
0xAA	:"Latin capital letter s with cedilla (U+015E)",
0xAB	:"Latin capital letter t with caron (U+0164)",
0xAC	:"Latin capital letter z with acute (U+0179)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"Latin capital letter z with caron (U+017D)",
0xAF	:"Latin capital letter z with dot above (U+017B)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"Latin small letter a with ogonek (U+0105)",
0xB2	:"ogonek (U+02DB)",
0xB3	:"Latin small letter l with stroke (U+0142)",
0xB4	:"acute accent (U+00B4)",
0xB5	:"Latin small letter l with caron (U+013E)",
0xB6	:"Latin small letter s with acute (U+015B)",
0xB7	:"caron (U+02C7)",
0xB8	:"cedilla (U+00B8)",
0xB9	:"Latin small letter s with caron (U+0161)",
0xBA	:"Latin small letter s with cedilla (U+015F)",
0xBB	:"Latin small letter t with caron (U+0165)",
0xBC	:"Latin small letter z with acute (U+017A)",
0xBD	:"double acute accent (U+02DD)",
0xBE	:"Latin small letter z with caron (U+017E)",
0xBF	:"Latin small letter z with dot above (U+017C)",
0xC0	:"Latin capital letter r with acute (U+0154)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with breve (U+0102)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter l with acute (U+0139)",
0xC6	:"Latin capital letter c with acute (U+0106)",
0xC7	:"Latin capital letter c with cedilla (U+00C7)",
0xC8	:"Latin capital letter c with caron (U+010C)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with ogonek (U+0118)",
0xCB	:"Latin capital letter e with diaeresis (U+00CB)",
0xCC	:"Latin capital letter e with caron (U+011A)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with circumflex (U+00CE)",
0xCF	:"Latin capital letter d with caron (U+010E)",
0xD0	:"Latin capital letter d with stroke (U+0110)",
0xD1	:"Latin capital letter n with acute (U+0143)",
0xD2	:"Latin capital letter n with caron (U+0147)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin capital letter o with double acute (U+0150)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"multiplication sign (U+00D7)",
0xD8	:"Latin capital letter r with caron (U+0158)",
0xD9	:"Latin capital letter u with ring above (U+016E)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin capital letter u with double acute (U+0170)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter y with acute (U+00DD)",
0xDE	:"Latin capital letter t with cedilla (U+0162)",
0xDF	:"Latin small letter sharp s (U+00DF)",
0xE0	:"Latin small letter r with acute (U+0155)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with breve (U+0103)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter l with acute (U+013A)",
0xE6	:"Latin small letter c with acute (U+0107)",
0xE7	:"Latin small letter c with cedilla (U+00E7)",
0xE8	:"Latin small letter c with caron (U+010D)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with ogonek (U+0119)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"Latin small letter e with caron (U+011B)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter d with caron (U+010F)",
0xF0	:"Latin small letter d with stroke (U+0111)",
0xF1	:"Latin small letter n with acute (U+0144)",
0xF2	:"Latin small letter n with caron (U+0148)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with double acute (U+0151)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"division sign (U+00F7)",
0xF8	:"Latin small letter r with caron (U+0159)",
0xF9	:"Latin small letter u with ring above (U+016F)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with double acute (U+0171)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter y with acute (U+00FD)",
0xFE	:"Latin small letter t with cedilla (U+0163)",
0xFF	:"dot above (U+02D9)"
}

# ISO-8859-3  [Esperanto, Maltese, Turkish (replaced by Latin-9)]
iso8859_3xtbl = { \
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0a	:"line feed (U+000a)",
0x0b	:"vertical tabulation (U+000b)",
0x0c	:"form feed (U+000c)",
0x0d	:"carriage return (U+000d)",
0x0e	:"shift out (U+000e)",
0x0f	:"shift in (U+000f)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1a	:"substitute (U+001a)",
0x1b	:"escape (U+001b)",
0x1c	:"file separator (U+001c)",
0x1d	:"group separator (U+001d)",
0x1e	:"record separator (U+001e)",
0x1f	:"unit separator (U+001f)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2a	:"asterisk (U+002a)",
0x2b	:"plus sign (U+002b)",
0x2c	:"comma (U+002c)",
0x2d	:"hyphen-minus (U+002d)",
0x2e	:"full stop (U+002e)",
0x2f	:"solidus (U+002f)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3a	:"colon (U+003a)",
0x3b	:"semicolon (U+003b)",
0x3c	:"less-than sign (U+003c)",
0x3d	:"equals sign (U+003d)",
0x3e	:"greater-than sign (U+003e)",
0x3f	:"question mark (U+003f)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4a	:"Latin capital letter j (U+004a)",
0x4b	:"Latin capital letter k (U+004b)",
0x4c	:"Latin capital letter l (U+004c)",
0x4d	:"Latin capital letter m (U+004d)",
0x4e	:"Latin capital letter n (U+004e)",
0x4f	:"Latin capital letter o (U+004f)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5a	:"Latin capital letter z (U+005a)",
0x5b	:"left square bracket (U+005b)",
0x5c	:"reverse solidus (U+005c)",
0x5d	:"right square bracket (U+005d)",
0x5e	:"circumflex accent (U+005e)",
0x5f	:"low line (U+005f)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6a	:"Latin small letter j (U+006a)",
0x6b	:"Latin small letter k (U+006b)",
0x6c	:"Latin small letter l (U+006c)",
0x6d	:"Latin small letter m (U+006d)",
0x6e	:"Latin small letter n (U+006e)",
0x6f	:"Latin small letter o (U+006f)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7a	:"Latin small letter z (U+007a)",
0x7b	:"left curly bracket (U+007b)",
0x7c	:"vertical line (U+007c)",
0x7d	:"right curly bracket (U+007d)",
0x7e	:"tilde (U+007e)",
0x7f	:"delete (U+007f)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8a	:"<control> (U+008a)",
0x8b	:"<control> (U+008b)",
0x8c	:"<control> (U+008c)",
0x8d	:"<control> (U+008d)",
0x8e	:"<control> (U+008e)",
0x8f	:"<control> (U+008f)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9a	:"<control> (U+009a)",
0x9b	:"<control> (U+009b)",
0x9c	:"<control> (U+009c)",
0x9d	:"<control> (U+009d)",
0x9e	:"<control> (U+009e)",
0x9f	:"<control> (U+009f)",
0xa0	:"no-break space (U+00a0)",
0xa1	:"Latin capital letter h with stroke (U+0126)",
0xa2	:"breve (U+02d8)",
0xa3	:"pound sign (U+00a3)",
0xa4	:"currency sign (U+00a4)",
0xa6	:"Latin capital letter h with circumflex (U+0124)",
0xa7	:"section sign (U+00a7)",
0xa8	:"diaeresis (U+00a8)",
0xa9	:"Latin capital letter i with dot above (U+0130)",
0xaa	:"Latin capital letter s with cedilla (U+015e)",
0xab	:"Latin capital letter g with breve (U+011e)",
0xac	:"Latin capital letter j with circumflex (U+0134)",
0xad	:"soft hyphen (U+00ad)",
0xaf	:"Latin capital letter z with dot above (U+017b)",
0xb0	:"degree sign (U+00b0)",
0xb1	:"Latin small letter h with stroke (U+0127)",
0xb2	:"superscript two (U+00b2)",
0xb3	:"superscript three (U+00b3)",
0xb4	:"acute accent (U+00b4)",
0xb5	:"micro sign (U+00b5)",
0xb6	:"Latin small letter h with circumflex (U+0125)",
0xb7	:"middle dot (U+00b7)",
0xb8	:"cedilla (U+00b8)",
0xb9	:"Latin small letter dotless i (U+0131)",
0xba	:"Latin small letter s with cedilla (U+015f)",
0xbb	:"Latin small letter g with breve (U+011f)",
0xbc	:"Latin small letter j with circumflex (U+0135)",
0xbd	:"vulgar fraction one half (U+00bd)",
0xbf	:"Latin small letter z with dot above (U+017c)",
0xc0	:"Latin capital letter a with grave (U+00c0)",
0xc1	:"Latin capital letter a with acute (U+00c1)",
0xc2	:"Latin capital letter a with circumflex (U+00c2)",
0xc4	:"Latin capital letter a with diaeresis (U+00c4)",
0xc5	:"Latin capital letter c with dot above (U+010a)",
0xc6	:"Latin capital letter c with circumflex (U+0108)",
0xc7	:"Latin capital letter c with cedilla (U+00c7)",
0xc8	:"Latin capital letter e with grave (U+00c8)",
0xc9	:"Latin capital letter e with acute (U+00c9)",
0xca	:"Latin capital letter e with circumflex (U+00ca)",
0xcb	:"Latin capital letter e with diaeresis (U+00cb)",
0xcc	:"Latin capital letter i with grave (U+00cc)",
0xcd	:"Latin capital letter i with acute (U+00cd)",
0xce	:"Latin capital letter i with circumflex (U+00ce)",
0xcf	:"Latin capital letter i with diaeresis (U+00cf)",
0xd1	:"Latin capital letter n with tilde (U+00d1)",
0xd2	:"Latin capital letter o with grave (U+00d2)",
0xd3	:"Latin capital letter o with acute (U+00d3)",
0xd4	:"Latin capital letter o with circumflex (U+00d4)",
0xd5	:"Latin capital letter g with dot above (U+0120)",
0xd6	:"Latin capital letter o with diaeresis (U+00d6)",
0xd7	:"multiplication sign (U+00d7)",
0xd8	:"Latin capital letter g with circumflex (U+011c)",
0xd9	:"Latin capital letter u with grave (U+00d9)",
0xda	:"Latin capital letter u with acute (U+00da)",
0xdb	:"Latin capital letter u with circumflex (U+00db)",
0xdc	:"Latin capital letter u with diaeresis (U+00dc)",
0xdd	:"Latin capital letter u with breve (U+016c)",
0xde	:"Latin capital letter s with circumflex (U+015c)",
0xdf	:"Latin small letter sharp s (U+00df)",
0xe0	:"Latin small letter a with grave (U+00e0)",
0xe1	:"Latin small letter a with acute (U+00e1)",
0xe2	:"Latin small letter a with circumflex (U+00e2)",
0xe4	:"Latin small letter a with diaeresis (U+00e4)",
0xe5	:"Latin small letter c with dot above (U+010b)",
0xe6	:"Latin small letter c with circumflex (U+0109)",
0xe7	:"Latin small letter c with cedilla (U+00e7)",
0xe8	:"Latin small letter e with grave (U+00e8)",
0xe9	:"Latin small letter e with acute (U+00e9)",
0xea	:"Latin small letter e with circumflex (U+00ea)",
0xeb	:"Latin small letter e with diaeresis (U+00eb)",
0xec	:"Latin small letter i with grave (U+00ec)",
0xed	:"Latin small letter i with acute (U+00ed)",
0xee	:"Latin small letter i with circumflex (U+00ee)",
0xef	:"Latin small letter i with diaeresis (U+00ef)",
0xf1	:"Latin small letter n with tilde (U+00f1)",
0xf2	:"Latin small letter o with grave (U+00f2)",
0xf3	:"Latin small letter o with acute (U+00f3)",
0xf4	:"Latin small letter o with circumflex (U+00f4)",
0xf5	:"Latin small letter g with dot above (U+0121)",
0xf6	:"Latin small letter o with diaeresis (U+00f6)",
0xf7	:"division sign (U+00f7)",
0xf8	:"Latin small letter g with circumflex (U+011d)",
0xf9	:"Latin small letter u with grave (U+00f9)",
0xfa	:"Latin small letter u with acute (U+00fa)",
0xfb	:"Latin small letter u with circumflex (U+00fb)",
0xfc	:"Latin small letter u with diaeresis (U+00fc)",
0xfd	:"Latin small letter u with breve (U+016d)",
0xfe	:"Latin small letter s with circumflex (U+015d)",
0xff	:"dot above (U+02d9)"
}

#iso-8859-4 North European [Estonian,Greenlandic Eskimo,Latvian, Lithuanian,Sami]
iso8859_4xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0a	:"line feed (U+000a)",
0x0b	:"vertical tabulation (U+000b)",
0x0c	:"form feed (U+000c)",
0x0d	:"carriage return (U+000d)",
0x0e	:"shift out (U+000e)",
0x0f	:"shift in (U+000f)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1a	:"substitute (U+001a)",
0x1b	:"escape (U+001b)",
0x1c	:"file separator (U+001c)",
0x1d	:"group separator (U+001d)",
0x1e	:"record separator (U+001e)",
0x1f	:"unit separator (U+001f)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2a	:"asterisk (U+002a)",
0x2b	:"plus sign (U+002b)",
0x2c	:"comma (U+002c)",
0x2d	:"hyphen-minus (U+002d)",
0x2e	:"full stop (U+002e)",
0x2f	:"solidus (U+002f)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3a	:"colon (U+003a)",
0x3b	:"semicolon (U+003b)",
0x3c	:"less-than sign (U+003c)",
0x3d	:"equals sign (U+003d)",
0x3e	:"greater-than sign (U+003e)",
0x3f	:"question mark (U+003f)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4a	:"Latin capital letter j (U+004a)",
0x4b	:"Latin capital letter k (U+004b)",
0x4c	:"Latin capital letter l (U+004c)",
0x4d	:"Latin capital letter m (U+004d)",
0x4e	:"Latin capital letter n (U+004e)",
0x4f	:"Latin capital letter o (U+004f)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5a	:"Latin capital letter z (U+005a)",
0x5b	:"left square bracket (U+005b)",
0x5c	:"reverse solidus (U+005c)",
0x5d	:"right square bracket (U+005d)",
0x5e	:"circumflex accent (U+005e)",
0x5f	:"low line (U+005f)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6a	:"Latin small letter j (U+006a)",
0x6b	:"Latin small letter k (U+006b)",
0x6c	:"Latin small letter l (U+006c)",
0x6d	:"Latin small letter m (U+006d)",
0x6e	:"Latin small letter n (U+006e)",
0x6f	:"Latin small letter o (U+006f)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7a	:"Latin small letter z (U+007a)",
0x7b	:"left curly bracket (U+007b)",
0x7c	:"vertical line (U+007c)",
0x7d	:"right curly bracket (U+007d)",
0x7e	:"tilde (U+007e)",
0x7f	:"delete (U+007f)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8a	:"<control> (U+008a)",
0x8b	:"<control> (U+008b)",
0x8c	:"<control> (U+008c)",
0x8d	:"<control> (U+008d)",
0x8e	:"<control> (U+008e)",
0x8f	:"<control> (U+008f)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9a	:"<control> (U+009a)",
0x9b	:"<control> (U+009b)",
0x9c	:"<control> (U+009c)",
0x9d	:"<control> (U+009d)",
0x9e	:"<control> (U+009e)",
0x9f	:"<control> (U+009f)",
0xa0	:"no-break space (U+00a0)",
0xa1	:"Latin capital letter a with ogonek (U+0104)",
0xa2	:"Latin small letter kra (U+0138)",
0xa3	:"Latin capital letter r with cedilla (U+0156)",
0xa4	:"currency sign (U+00a4)",
0xa5	:"Latin capital letter i with tilde (U+0128)",
0xa6	:"Latin capital letter l with cedilla (U+013b)",
0xa7	:"section sign (U+00a7)",
0xa8	:"diaeresis (U+00a8)",
0xa9	:"Latin capital letter s with caron (U+0160)",
0xaa	:"Latin capital letter e with macron (U+0112)",
0xab	:"Latin capital letter g with cedilla (U+0122)",
0xac	:"Latin capital letter t with stroke (U+0166)",
0xad	:"soft hyphen (U+00ad)",
0xae	:"Latin capital letter z with caron (U+017d)",
0xaf	:"macron (U+00af)",
0xb0	:"degree sign (U+00b0)",
0xb1	:"Latin small letter a with ogonek (U+0105)",
0xb2	:"ogonek (U+02db)",
0xb3	:"Latin small letter r with cedilla (U+0157)",
0xb4	:"acute accent (U+00b4)",
0xb5	:"Latin small letter i with tilde (U+0129)",
0xb6	:"Latin small letter l with cedilla (U+013c)",
0xb7	:"caron (U+02c7)",
0xb8	:"cedilla (U+00b8)",
0xb9	:"Latin small letter s with caron (U+0161)",
0xba	:"Latin small letter e with macron (U+0113)",
0xbb	:"Latin small letter g with cedilla (U+0123)",
0xbc	:"Latin small letter t with stroke (U+0167)",
0xbd	:"Latin capital letter eng (U+014a)",
0xbe	:"Latin small letter z with caron (U+017e)",
0xbf	:"Latin small letter eng (U+014b)",
0xc0	:"Latin capital letter a with macron (U+0100)",
0xc1	:"Latin capital letter a with acute (U+00c1)",
0xc2	:"Latin capital letter a with circumflex (U+00c2)",
0xc3	:"Latin capital letter a with tilde (U+00c3)",
0xc4	:"Latin capital letter a with diaeresis (U+00c4)",
0xc5	:"Latin capital letter a with ring above (U+00c5)",
0xc6	:"Latin capital letter ae (U+00c6)",
0xc7	:"Latin capital letter i with ogonek (U+012e)",
0xc8	:"Latin capital letter c with caron (U+010c)",
0xc9	:"Latin capital letter e with acute (U+00c9)",
0xca	:"Latin capital letter e with ogonek (U+0118)",
0xcb	:"Latin capital letter e with diaeresis (U+00cb)",
0xcc	:"Latin capital letter e with dot above (U+0116)",
0xcd	:"Latin capital letter i with acute (U+00cd)",
0xce	:"Latin capital letter i with circumflex (U+00ce)",
0xcf	:"Latin capital letter i with macron (U+012a)",
0xd0	:"Latin capital letter d with stroke (U+0110)",
0xd1	:"Latin capital letter n with cedilla (U+0145)",
0xd2	:"Latin capital letter o with macron (U+014c)",
0xd3	:"Latin capital letter k with cedilla (U+0136)",
0xd4	:"Latin capital letter o with circumflex (U+00d4)",
0xd5	:"Latin capital letter o with tilde (U+00d5)",
0xd6	:"Latin capital letter o with diaeresis (U+00d6)",
0xd7	:"multiplication sign (U+00d7)",
0xd8	:"Latin capital letter o with stroke (U+00d8)",
0xd9	:"Latin capital letter u with ogonek (U+0172)",
0xda	:"Latin capital letter u with acute (U+00da)",
0xdb	:"Latin capital letter u with circumflex (U+00db)",
0xdc	:"Latin capital letter u with diaeresis (U+00dc)",
0xdd	:"Latin capital letter u with tilde (U+0168)",
0xde	:"Latin capital letter u with macron (U+016a)",
0xdf	:"Latin small letter sharp s (U+00df)",
0xe0	:"Latin small letter a with macron (U+0101)",
0xe1	:"Latin small letter a with acute (U+00e1)",
0xe2	:"Latin small letter a with circumflex (U+00e2)",
0xe3	:"Latin small letter a with tilde (U+00e3)",
0xe4	:"Latin small letter a with diaeresis (U+00e4)",
0xe5	:"Latin small letter a with ring above (U+00e5)",
0xe6	:"Latin small letter ae (U+00e6)",
0xe7	:"Latin small letter i with ogonek (U+012f)",
0xe8	:"Latin small letter c with caron (U+010d)",
0xe9	:"Latin small letter e with acute (U+00e9)",
0xea	:"Latin small letter e with ogonek (U+0119)",
0xeb	:"Latin small letter e with diaeresis (U+00eb)",
0xec	:"Latin small letter e with dot above (U+0117)",
0xed	:"Latin small letter i with acute (U+00ed)",
0xee	:"Latin small letter i with circumflex (U+00ee)",
0xef	:"Latin small letter i with macron (U+012b)",
0xf0	:"Latin small letter d with stroke (U+0111)",
0xf1	:"Latin small letter n with cedilla (U+0146)",
0xf2	:"Latin small letter o with macron (U+014d)",
0xf3	:"Latin small letter k with cedilla (U+0137)",
0xf4	:"Latin small letter o with circumflex (U+00f4)",
0xf5	:"Latin small letter o with tilde (U+00f5)",
0xf6	:"Latin small letter o with diaeresis (U+00f6)",
0xf7	:"division sign (U+00f7)",
0xf8	:"Latin small letter o with stroke (U+00f8)",
0xf9	:"Latin small letter u with ogonek (U+0173)",
0xfa	:"Latin small letter u with acute (U+00fa)",
0xfb	:"Latin small letter u with circumflex (U+00fb)",
0xfc	:"Latin small letter u with diaeresis (U+00fc)",
0xfd	:"Latin small letter u with tilde (U+0169)",
0xfe	:"Latin small letter u with macron (U+016b)",
0xff	:"dot above (U+02d9)"
}

#iso-8859-5 [Latin/Cyrillic - Belorussian,Bulgarian,Russian, Ukrainian]
iso8859_5xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0a	:"line feed (U+000a)",
0x0b	:"vertical tabulation (U+000b)",
0x0c	:"form feed (U+000c)",
0x0d	:"carriage return (U+000d)",
0x0e	:"shift out (U+000e)",
0x0f	:"shift in (U+000f)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1a	:"substitute (U+001a)",
0x1b	:"escape (U+001b)",
0x1c	:"file separator (U+001c)",
0x1d	:"group separator (U+001d)",
0x1e	:"record separator (U+001e)",
0x1f	:"unit separator (U+001f)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2a	:"asterisk (U+002a)",
0x2b	:"plus sign (U+002b)",
0x2c	:"comma (U+002c)",
0x2d	:"hyphen-minus (U+002d)",
0x2e	:"full stop (U+002e)",
0x2f	:"solidus (U+002f)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3a	:"colon (U+003a)",
0x3b	:"semicolon (U+003b)",
0x3c	:"less-than sign (U+003c)",
0x3d	:"equals sign (U+003d)",
0x3e	:"greater-than sign (U+003e)",
0x3f	:"question mark (U+003f)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4a	:"Latin capital letter j (U+004a)",
0x4b	:"Latin capital letter k (U+004b)",
0x4c	:"Latin capital letter l (U+004c)",
0x4d	:"Latin capital letter m (U+004d)",
0x4e	:"Latin capital letter n (U+004e)",
0x4f	:"Latin capital letter o (U+004f)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5a	:"Latin capital letter z (U+005a)",
0x5b	:"left square bracket (U+005b)",
0x5c	:"reverse solidus (U+005c)",
0x5d	:"right square bracket (U+005d)",
0x5e	:"circumflex accent (U+005e)",
0x5f	:"low line (U+005f)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6a	:"Latin small letter j (U+006a)",
0x6b	:"Latin small letter k (U+006b)",
0x6c	:"Latin small letter l (U+006c)",
0x6d	:"Latin small letter m (U+006d)",
0x6e	:"Latin small letter n (U+006e)",
0x6f	:"Latin small letter o (U+006f)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7a	:"Latin small letter z (U+007a)",
0x7b	:"left curly bracket (U+007b)",
0x7c	:"vertical line (U+007c)",
0x7d	:"right curly bracket (U+007d)",
0x7e	:"tilde (U+007e)",
0x7f	:"delete (U+007f)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8a	:"<control> (U+008a)",
0x8b	:"<control> (U+008b)",
0x8c	:"<control> (U+008c)",
0x8d	:"<control> (U+008d)",
0x8e	:"<control> (U+008e)",
0x8f	:"<control> (U+008f)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9a	:"<control> (U+009a)",
0x9b	:"<control> (U+009b)",
0x9c	:"<control> (U+009c)",
0x9d	:"<control> (U+009d)",
0x9e	:"<control> (U+009e)",
0x9f	:"<control> (U+009f)",
0xa0	:"no-break space (U+00a0)",
0xa1	:"cyrillic capital letter io (U+0401)",
0xa2	:"cyrillic capital letter dje (U+0402)",
0xa3	:"cyrillic capital letter gje (U+0403)",
0xa4	:"cyrillic capital letter ukrainian ie (U+0404)",
0xa5	:"cyrillic capital letter dze (U+0405)",
0xa6	:"cyrillic capital letter byelorussian-ukrainian i (U+0406)",
0xa7	:"cyrillic capital letter yi (U+0407)",
0xa8	:"cyrillic capital letter je (U+0408)",
0xa9	:"cyrillic capital letter lje (U+0409)",
0xaa	:"cyrillic capital letter nje (U+040a)",
0xab	:"cyrillic capital letter tshe (U+040b)",
0xac	:"cyrillic capital letter kje (U+040c)",
0xad	:"soft hyphen (U+00ad)",
0xae	:"cyrillic capital letter short u (U+040e)",
0xaf	:"cyrillic capital letter dzhe (U+040f)",
0xb0	:"cyrillic capital letter a (U+0410)",
0xb1	:"cyrillic capital letter be (U+0411)",
0xb2	:"cyrillic capital letter ve (U+0412)",
0xb3	:"cyrillic capital letter ghe (U+0413)",
0xb4	:"cyrillic capital letter de (U+0414)",
0xb5	:"cyrillic capital letter ie (U+0415)",
0xb6	:"cyrillic capital letter zhe (U+0416)",
0xb7	:"cyrillic capital letter ze (U+0417)",
0xb8	:"cyrillic capital letter i (U+0418)",
0xb9	:"cyrillic capital letter short i (U+0419)",
0xba	:"cyrillic capital letter ka (U+041a)",
0xbb	:"cyrillic capital letter el (U+041b)",
0xbc	:"cyrillic capital letter em (U+041c)",
0xbd	:"cyrillic capital letter en (U+041d)",
0xbe	:"cyrillic capital letter o (U+041e)",
0xbf	:"cyrillic capital letter pe (U+041f)",
0xc0	:"cyrillic capital letter er (U+0420)",
0xc1	:"cyrillic capital letter es (U+0421)",
0xc2	:"cyrillic capital letter te (U+0422)",
0xc3	:"cyrillic capital letter u (U+0423)",
0xc4	:"cyrillic capital letter ef (U+0424)",
0xc5	:"cyrillic capital letter ha (U+0425)",
0xc6	:"cyrillic capital letter tse (U+0426)",
0xc7	:"cyrillic capital letter che (U+0427)",
0xc8	:"cyrillic capital letter sha (U+0428)",
0xc9	:"cyrillic capital letter shcha (U+0429)",
0xca	:"cyrillic capital letter hard sign (U+042a)",
0xcb	:"cyrillic capital letter yeru (U+042b)",
0xcc	:"cyrillic capital letter soft sign (U+042c)",
0xcd	:"cyrillic capital letter e (U+042d)",
0xce	:"cyrillic capital letter yu (U+042e)",
0xcf	:"cyrillic capital letter ya (U+042f)",
0xd0	:"cyrillic small letter a (U+0430)",
0xd1	:"cyrillic small letter be (U+0431)",
0xd2	:"cyrillic small letter ve (U+0432)",
0xd3	:"cyrillic small letter ghe (U+0433)",
0xd4	:"cyrillic small letter de (U+0434)",
0xd5	:"cyrillic small letter ie (U+0435)",
0xd6	:"cyrillic small letter zhe (U+0436)",
0xd7	:"cyrillic small letter ze (U+0437)",
0xd8	:"cyrillic small letter i (U+0438)",
0xd9	:"cyrillic small letter short i (U+0439)",
0xda	:"cyrillic small letter ka (U+043a)",
0xdb	:"cyrillic small letter el (U+043b)",
0xdc	:"cyrillic small letter em (U+043c)",
0xdd	:"cyrillic small letter en (U+043d)",
0xde	:"cyrillic small letter o (U+043e)",
0xdf	:"cyrillic small letter pe (U+043f)",
0xe0	:"cyrillic small letter er (U+0440)",
0xe1	:"cyrillic small letter es (U+0441)",
0xe2	:"cyrillic small letter te (U+0442)",
0xe3	:"cyrillic small letter u (U+0443)",
0xe4	:"cyrillic small letter ef (U+0444)",
0xe5	:"cyrillic small letter ha (U+0445)",
0xe6	:"cyrillic small letter tse (U+0446)",
0xe7	:"cyrillic small letter che (U+0447)",
0xe8	:"cyrillic small letter sha (U+0448)",
0xe9	:"cyrillic small letter shcha (U+0449)",
0xea	:"cyrillic small letter hard sign (U+044a)",
0xeb	:"cyrillic small letter yeru (U+044b)",
0xec	:"cyrillic small letter soft sign (U+044c)",
0xed	:"cyrillic small letter e (U+044d)",
0xee	:"cyrillic small letter yu (U+044e)",
0xef	:"cyrillic small letter ya (U+044f)",
0xf0	:"numero sign (U+2116)",
0xf1	:"cyrillic small letter io (U+0451)",
0xf2	:"cyrillic small letter dje (U+0452)",
0xf3	:"cyrillic small letter gje (U+0453)",
0xf4	:"cyrillic small letter ukrainian ie (U+0454)",
0xf5	:"cyrillic small letter dze (U+0455)",
0xf6	:"cyrillic small letter byelorussian-ukrainian i (U+0456)",
0xf7	:"cyrillic small letter yi (U+0457)",
0xf8	:"cyrillic small letter je (U+0458)",
0xf9	:"cyrillic small letter lje (U+0459)",
0xfa	:"cyrillic small letter nje (U+045a)",
0xfb	:"cyrillic small letter tshe (U+045b)",
0xfc	:"cyrillic small letter kje (U+045c)",
0xfd	:"section sign (U+00a7)",
0xfe	:"cyrillic small letter short u (U+045e)",
0xff	:"cyrillic small letter dzhe (U+045f)"
}

#iso-8859-6 [Arabic] Missing many needed glyphs so never widely used
iso8859_6xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0a	:"line feed (U+000a)",
0x0b	:"vertical tabulation (U+000b)",
0x0c	:"form feed (U+000c)",
0x0d	:"carriage return (U+000d)",
0x0e	:"shift out (U+000e)",
0x0f	:"shift in (U+000f)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1a	:"substitute (U+001a)",
0x1b	:"escape (U+001b)",
0x1c	:"file separator (U+001c)",
0x1d	:"group separator (U+001d)",
0x1e	:"record separator (U+001e)",
0x1f	:"unit separator (U+001f)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2a	:"asterisk (U+002a)",
0x2b	:"plus sign (U+002b)",
0x2c	:"comma (U+002c)",
0x2d	:"hyphen-minus (U+002d)",
0x2e	:"full stop (U+002e)",
0x2f	:"solidus (U+002f)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3a	:"colon (U+003a)",
0x3b	:"semicolon (U+003b)",
0x3c	:"less-than sign (U+003c)",
0x3d	:"equals sign (U+003d)",
0x3e	:"greater-than sign (U+003e)",
0x3f	:"question mark (U+003f)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4a	:"Latin capital letter j (U+004a)",
0x4b	:"Latin capital letter k (U+004b)",
0x4c	:"Latin capital letter l (U+004c)",
0x4d	:"Latin capital letter m (U+004d)",
0x4e	:"Latin capital letter n (U+004e)",
0x4f	:"Latin capital letter o (U+004f)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5a	:"Latin capital letter z (U+005a)",
0x5b	:"left square bracket (U+005b)",
0x5c	:"reverse solidus (U+005c)",
0x5d	:"right square bracket (U+005d)",
0x5e	:"circumflex accent (U+005e)",
0x5f	:"low line (U+005f)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6a	:"Latin small letter j (U+006a)",
0x6b	:"Latin small letter k (U+006b)",
0x6c	:"Latin small letter l (U+006c)",
0x6d	:"Latin small letter m (U+006d)",
0x6e	:"Latin small letter n (U+006e)",
0x6f	:"Latin small letter o (U+006f)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7a	:"Latin small letter z (U+007a)",
0x7b	:"left curly bracket (U+007b)",
0x7c	:"vertical line (U+007c)",
0x7d	:"right curly bracket (U+007d)",
0x7e	:"tilde (U+007e)",
0x7f	:"delete (U+007f)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8a	:"<control> (U+008a)",
0x8b	:"<control> (U+008b)",
0x8c	:"<control> (U+008c)",
0x8d	:"<control> (U+008d)",
0x8e	:"<control> (U+008e)",
0x8f	:"<control> (U+008f)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9a	:"<control> (U+009a)",
0x9b	:"<control> (U+009b)",
0x9c	:"<control> (U+009c)",
0x9d	:"<control> (U+009d)",
0x9e	:"<control> (U+009e)",
0x9f	:"<control> (U+009f)",
0xa0	:"no-break space (U+00a0)",
0xa1	:"Unused",
0xa2	:"Unused",
0xa3	:"Unused",
0xa4	:"currency sign (U+00a4)",
0xa5	:"Unused",
0xa6	:"Unused",
0xa7	:"Unused",
0xa8	:"Unused",
0xa9	:"Unused",
0xaa	:"Unused",
0xab	:"Unused",
0xac	:"Arabic comma (U+060c)",
0xad	:"soft hyphen (U+00ad)",
0xae	:"Unused",
0xaf	:"Unused",
0xb0	:"Unused",
0xb1	:"Unused",
0xb2	:"Unused",
0xb3	:"Unused",
0xb4	:"Unused",
0xb5	:"Unused",
0xb6	:"Unused",
0xb7	:"Unused",
0xb8	:"Unused",
0xb9	:"Unused",
0xba	:"Unused",
0xbb	:"Arabic semicolon (U+061b)",
0xbc	:"Unused",
0xbd	:"Unused",
0xbe	:"Unused",
0xbf	:"Arabic question mark (U+061f)",
0xc0	:"Unused",
0xc1	:"Arabic letter hamza (U+0621)",
0xc2	:"Arabic letter alef with madda above (U+0622)",
0xc3	:"Arabic letter alef with hamza above (U+0623)",
0xc4	:"Arabic letter waw with hamza above (U+0624)",
0xc5	:"Arabic letter alef with hamza below (U+0625)",
0xc6	:"Arabic letter yeh with hamza above (U+0626)",
0xc7	:"Arabic letter alef (U+0627)",
0xc8	:"Arabic letter beh (U+0628)",
0xc9	:"Arabic letter teh marbuta (U+0629)",
0xca	:"Arabic letter teh (U+062a)",
0xcb	:"Arabic letter theh (U+062b)",
0xcc	:"Arabic letter jeem (U+062c)",
0xcd	:"Arabic letter hah (U+062d)",
0xce	:"Arabic letter khah (U+062e)",
0xcf	:"Arabic letter dal (U+062f)",
0xd0	:"Arabic letter thal (U+0630)",
0xd1	:"Arabic letter reh (U+0631)",
0xd2	:"Arabic letter zain (U+0632)",
0xd3	:"Arabic letter seen (U+0633)",
0xd4	:"Arabic letter sheen (U+0634)",
0xd5	:"Arabic letter sad (U+0635)",
0xd6	:"Arabic letter dad (U+0636)",
0xd7	:"Arabic letter tah (U+0637)",
0xd8	:"Arabic letter zah (U+0638)",
0xd9	:"Arabic letter ain (U+0639)",
0xda	:"Arabic letter ghain (U+063a)",
0xdb	:"Unused",
0xdc	:"Unused",
0xdd	:"Unused",
0xde	:"Unused",
0xdf	:"Unused",
0xe0	:"Arabic tatweel (U+0640)",
0xe1	:"Arabic letter feh (U+0641)",
0xe2	:"Arabic letter qaf (U+0642)",
0xe3	:"Arabic letter kaf (U+0643)",
0xe4	:"Arabic letter lam (U+0644)",
0xe5	:"Arabic letter meem (U+0645)",
0xe6	:"Arabic letter noon (U+0646)",
0xe7	:"Arabic letter heh (U+0647)",
0xe8	:"Arabic letter waw (U+0648)",
0xe9	:"Arabic letter alef maksura (U+0649)",
0xea	:"Arabic letter yeh (U+064a)",
0xeb	:"Arabic fathatan (U+064b)",
0xec	:"Arabic dammatan (U+064c)",
0xed	:"Arabic kasratan (U+064d)",
0xee	:"Arabic fatha (U+064e)",
0xef	:"Arabic damma (U+064f)",
0xf0	:"Arabic kasra (U+0650)",
0xf1	:"Arabic shadda (U+0651)",
0xf2	:"Arabic sukun (U+0652)",
0xf3	:"Unused",
0xf4	:"Unused",
0xf5	:"Unused",
0xf6	:"Unused",
0xf7	:"Unused",
0xf8	:"Unused",
0xf9	:"Unused",
0xfa	:"Unused",
0xfb	:"Unused",
0xfc	:"Unused",
0xfd	:"Unused",
0xfe	:"Unused",
0xff	:"Unused"
}

#ISO-8859-7 Greek
iso8859_7xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"left single quotation mark (U+2018)",
0xA2	:"right single quotation mark (U+2019)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"Unused",
0xA5	:"Unused",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"Unused",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"Unused",
0xAF	:"horizontal bar (U+2015)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"Greek tonos (U+0384)",
0xB5	:"Greek dialytika tonos (U+0385)",
0xB6	:"Greek capital letter alpha with tonos (U+0386)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"Greek capital letter epsilon with tonos (U+0388)",
0xB9	:"Greek capital letter eta with tonos (U+0389)",
0xBA	:"Greek capital letter iota with tonos (U+038A)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"Greek capital letter omicron with tonos (U+038C)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"Greek capital letter upsilon with tonos (U+038E)",
0xBF	:"Greek capital letter omega with tonos (U+038F)",
0xC0	:"Greek small letter iota with dialytika and tonos (U+0390)",
0xC1	:"Greek capital letter alpha (U+0391)",
0xC2	:"Greek capital letter beta (U+0392)",
0xC3	:"Greek capital letter gamma (U+0393)",
0xC4	:"Greek capital letter delta (U+0394)",
0xC5	:"Greek capital letter epsilon (U+0395)",
0xC6	:"Greek capital letter zeta (U+0396)",
0xC7	:"Greek capital letter eta (U+0397)",
0xC8	:"Greek capital letter theta (U+0398)",
0xC9	:"Greek capital letter iota (U+0399)",
0xCA	:"Greek capital letter kappa (U+039A)",
0xCB	:"Greek capital letter lamda (U+039B)",
0xCC	:"Greek capital letter mu (U+039C)",
0xCD	:"Greek capital letter nu (U+039D)",
0xCE	:"Greek capital letter xi (U+039E)",
0xCF	:"Greek capital letter omicron (U+039F)",
0xD0	:"Greek capital letter pi (U+03A0)",
0xD1	:"Greek capital letter rho (U+03A1)",
0xD2	:"Unused",
0xD3	:"Greek capital letter sigma (U+03A3)",
0xD4	:"Greek capital letter tau (U+03A4)",
0xD5	:"Greek capital letter upsilon (U+03A5)",
0xD6	:"Greek capital letter phi (U+03A6)",
0xD7	:"Greek capital letter chi (U+03A7)",
0xD8	:"Greek capital letter psi (U+03A8)",
0xD9	:"Greek capital letter omega (U+03A9)",
0xDA	:"Greek capital letter iota with dialytika (U+03AA)",
0xDB	:"Greek capital letter upsilon with dialytika (U+03AB)",
0xDC	:"Greek small letter alpha with tonos (U+03AC)",
0xDD	:"Greek small letter epsilon with tonos (U+03AD)",
0xDE	:"Greek small letter eta with tonos (U+03AE)",
0xDF	:"Greek small letter iota with tonos (U+03AF)",
0xE0	:"Greek small letter upsilon with dialytika and tonos (U+03B0)",
0xE1	:"Greek small letter alpha (U+03B1)",
0xE2	:"Greek small letter beta (U+03B2)",
0xE3	:"Greek small letter gamma (U+03B3)",
0xE4	:"Greek small letter delta (U+03B4)",
0xE5	:"Greek small letter epsilon (U+03B5)",
0xE6	:"Greek small letter zeta (U+03B6)",
0xE7	:"Greek small letter eta (U+03B7)",
0xE8	:"Greek small letter theta (U+03B8)",
0xE9	:"Greek small letter iota (U+03B9)",
0xEA	:"Greek small letter kappa (U+03BA)",
0xEB	:"Greek small letter lamda (U+03BB)",
0xEC	:"Greek small letter mu (U+03BC)",
0xED	:"Greek small letter nu (U+03BD)",
0xEE	:"Greek small letter xi (U+03BE)",
0xEF	:"Greek small letter omicron (U+03BF)",
0xF0	:"Greek small letter pi (U+03C0)",
0xF1	:"Greek small letter rho (U+03C1)",
0xF2	:"Greek small letter final sigma (U+03C2)",
0xF3	:"Greek small letter sigma (U+03C3)",
0xF4	:"Greek small letter tau (U+03C4)",
0xF5	:"Greek small letter upsilon (U+03C5)",
0xF6	:"Greek small letter phi (U+03C6)",
0xF7	:"Greek small letter chi (U+03C7)",
0xF8	:"Greek small letter psi (U+03C8)",
0xF9	:"Greek small letter omega (U+03C9)",
0xFA	:"Greek small letter iota with dialytika (U+03CA)",
0xFB	:"Greek small letter upsilon with dialytika (U+03CB)",
0xFC	:"Greek small letter omicron with tonos (U+03CC)",
0xFD	:"Greek small letter upsilon with tonos (U+03CD)",
0xFE	:"Greek small letter omega with tonos (U+03CE)",
0xFF	:"Unused",
}

#ISO-8859-8 Hebrew
iso8859_8xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"Unused",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"yen sign (U+00A5)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"multiplication sign (U+00D7)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"macron (U+00AF)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"acute accent (U+00B4)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"cedilla (U+00B8)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"division sign (U+00F7)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"vulgar fraction one quarter (U+00BC)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"vulgar fraction three quarters (U+00BE)",
0xBF	:"Unused",
0xC0	:"Unused",
0xC1	:"Unused",
0xC2	:"Unused",
0xC3	:"Unused",
0xC4	:"Unused",
0xC5	:"Unused",
0xC6	:"Unused",
0xC7	:"Unused",
0xC8	:"Unused",
0xC9	:"Unused",
0xCA	:"Unused",
0xCB	:"Unused",
0xCC	:"Unused",
0xCD	:"Unused",
0xCE	:"Unused",
0xCF	:"Unused",
0xD0	:"Unused",
0xD1	:"Unused",
0xD2	:"Unused",
0xD3	:"Unused",
0xD4	:"Unused",
0xD5	:"Unused",
0xD6	:"Unused",
0xD7	:"Unused",
0xD8	:"Unused",
0xD9	:"Unused",
0xDA	:"Unused",
0xDB	:"Unused",
0xDC	:"Unused",
0xDD	:"Unused",
0xDE	:"Unused",
0xDF	:"double low line (U+2017)",
0xE0	:"hebrew letter alef (U+05D0)",
0xE1	:"hebrew letter bet (U+05D1)",
0xE2	:"hebrew letter gimel (U+05D2)",
0xE3	:"hebrew letter dalet (U+05D3)",
0xE4	:"hebrew letter he (U+05D4)",
0xE5	:"hebrew letter vav (U+05D5)",
0xE6	:"hebrew letter zayin (U+05D6)",
0xE7	:"hebrew letter het (U+05D7)",
0xE8	:"hebrew letter tet (U+05D8)",
0xE9	:"hebrew letter yod (U+05D9)",
0xEA	:"hebrew letter final kaf (U+05DA)",
0xEB	:"hebrew letter kaf (U+05DB)",
0xEC	:"hebrew letter lamed (U+05DC)",
0xED	:"hebrew letter final mem (U+05DD)",
0xEE	:"hebrew letter mem (U+05DE)",
0xEF	:"hebrew letter final nun (U+05DF)",
0xF0	:"hebrew letter nun (U+05E0)",
0xF1	:"hebrew letter samekh (U+05E1)",
0xF2	:"hebrew letter ayin (U+05E2)",
0xF3	:"hebrew letter final pe (U+05E3)",
0xF4	:"hebrew letter pe (U+05E4)",
0xF5	:"hebrew letter final tsadi (U+05E5)",
0xF6	:"hebrew letter tsadi (U+05E6)",
0xF7	:"hebrew letter qof (U+05E7)",
0xF8	:"hebrew letter resh (U+05E8)",
0xF9	:"hebrew letter shin (U+05E9)",
0xFA	:"hebrew letter tav (U+05EA)",
0xFB	:"Unused",
0xFC	:"Unused",
0xFD	:"left-to-right mark (U+200E)",
0xFE	:"right-to-left mark (U+200F)",
0xFF	:"Unused",
}

#ISO-8859-9
iso8859_9xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"inverted exclamation mark (U+00A1)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"yen sign (U+00A5)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"feminine ordinal indicator (U+00AA)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"macron (U+00AF)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"acute accent (U+00B4)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"cedilla (U+00B8)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"masculine ordinal indicator (U+00BA)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"vulgar fraction one quarter (U+00BC)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"vulgar fraction three quarters (U+00BE)",
0xBF	:"inverted question mark (U+00BF)",
0xC0	:"Latin capital letter a with grave (U+00C0)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with tilde (U+00C3)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter a with ring above (U+00C5)",
0xC6	:"Latin capital letter ae (U+00C6)",
0xC7	:"Latin capital letter c with cedilla (U+00C7)",
0xC8	:"Latin capital letter e with grave (U+00C8)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with circumflex (U+00CA)",
0xCB	:"Latin capital letter e with diaeresis (U+00CB)",
0xCC	:"Latin capital letter i with grave (U+00CC)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with circumflex (U+00CE)",
0xCF	:"Latin capital letter i with diaeresis (U+00CF)",
0xD0	:"Latin capital letter g with breve (U+011E)",
0xD1	:"Latin capital letter n with tilde (U+00D1)",
0xD2	:"Latin capital letter o with grave (U+00D2)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin capital letter o with tilde (U+00D5)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"multiplication sign (U+00D7)",
0xD8	:"Latin capital letter o with stroke (U+00D8)",
0xD9	:"Latin capital letter u with grave (U+00D9)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin capital letter u with circumflex (U+00DB)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter i with dot above (U+0130)",
0xDE	:"Latin capital letter s with cedilla (U+015E)",
0xDF	:"Latin small letter sharp s (U+00DF)",
0xE0	:"Latin small letter a with grave (U+00E0)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with tilde (U+00E3)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter a with ring above (U+00E5)",
0xE6	:"Latin small letter ae (U+00E6)",
0xE7	:"Latin small letter c with cedilla (U+00E7)",
0xE8	:"Latin small letter e with grave (U+00E8)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with circumflex (U+00EA)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"Latin small letter i with grave (U+00EC)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter i with diaeresis (U+00EF)",
0xF0	:"Latin small letter g with breve (U+011F)",
0xF1	:"Latin small letter n with tilde (U+00F1)",
0xF2	:"Latin small letter o with grave (U+00F2)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with tilde (U+00F5)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"division sign (U+00F7)",
0xF8	:"Latin small letter o with stroke (U+00F8)",
0xF9	:"Latin small letter u with grave (U+00F9)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with circumflex (U+00FB)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter dotless i (U+0131)",
0xFE	:"Latin small letter s with cedilla (U+015F)",
0xFF	:"Latin small letter y with diaeresis (U+00FF)",
}

#ISO-8859-10 Nordic
iso8859_10xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"Latin capital letter a with ogonek (U+0104)",
0xA2	:"Latin capital letter e with macron (U+0112)",
0xA3	:"Latin capital letter g with cedilla (U+0122)",
0xA4	:"Latin capital letter i with macron (U+012A)",
0xA5	:"Latin capital letter i with tilde (U+0128)",
0xA6	:"Latin capital letter k with cedilla (U+0136)",
0xA7	:"section sign (U+00A7)",
0xA8	:"Latin capital letter l with cedilla (U+013B)",
0xA9	:"Latin capital letter d with stroke (U+0110)",
0xAA	:"Latin capital letter s with caron (U+0160)",
0xAB	:"Latin capital letter t with stroke (U+0166)",
0xAC	:"Latin capital letter z with caron (U+017D)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"Latin capital letter u with macron (U+016A)",
0xAF	:"Latin capital letter eng (U+014A)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"Latin small letter a with ogonek (U+0105)",
0xB2	:"Latin small letter e with macron (U+0113)",
0xB3	:"Latin small letter g with cedilla (U+0123)",
0xB4	:"Latin small letter i with macron (U+012B)",
0xB5	:"Latin small letter i with tilde (U+0129)",
0xB6	:"Latin small letter k with cedilla (U+0137)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"Latin small letter l with cedilla (U+013C)",
0xB9	:"Latin small letter d with stroke (U+0111)",
0xBA	:"Latin small letter s with caron (U+0161)",
0xBB	:"Latin small letter t with stroke (U+0167)",
0xBC	:"Latin small letter z with caron (U+017E)",
0xBD	:"horizontal bar (U+2015)",
0xBE	:"Latin small letter u with macron (U+016B)",
0xBF	:"Latin small letter eng (U+014B)",
0xC0	:"Latin capital letter a with macron (U+0100)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with tilde (U+00C3)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter a with ring above (U+00C5)",
0xC6	:"Latin capital letter ae (U+00C6)",
0xC7	:"Latin capital letter i with ogonek (U+012E)",
0xC8	:"Latin capital letter c with caron (U+010C)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with ogonek (U+0118)",
0xCB	:"Latin capital letter e with diaeresis (U+00CB)",
0xCC	:"Latin capital letter e with dot above (U+0116)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with circumflex (U+00CE)",
0xCF	:"Latin capital letter i with diaeresis (U+00CF)",
0xD0	:"Latin capital letter eth (icelandic) (U+00D0)",
0xD1	:"Latin capital letter n with cedilla (U+0145)",
0xD2	:"Latin capital letter o with macron (U+014C)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin capital letter o with tilde (U+00D5)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"Latin capital letter u with tilde (U+0168)",
0xD8	:"Latin capital letter o with stroke (U+00D8)",
0xD9	:"Latin capital letter u with ogonek (U+0172)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin capital letter u with circumflex (U+00DB)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter y with acute (U+00DD)",
0xDE	:"Latin capital letter thorn (icelandic) (U+00DE)",
0xDF	:"Latin small letter sharp s (german) (U+00DF)",
0xE0	:"Latin small letter a with macron (U+0101)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with tilde (U+00E3)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter a with ring above (U+00E5)",
0xE6	:"Latin small letter ae (U+00E6)",
0xE7	:"Latin small letter i with ogonek (U+012F)",
0xE8	:"Latin small letter c with caron (U+010D)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with ogonek (U+0119)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"Latin small letter e with dot above (U+0117)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter i with diaeresis (U+00EF)",
0xF0	:"Latin small letter eth (icelandic) (U+00F0)",
0xF1	:"Latin small letter n with cedilla (U+0146)",
0xF2	:"Latin small letter o with macron (U+014D)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with tilde (U+00F5)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"Latin small letter u with tilde (U+0169)",
0xF8	:"Latin small letter o with stroke (U+00F8)",
0xF9	:"Latin small letter u with ogonek (U+0173)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with circumflex (U+00FB)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter y with acute (U+00FD)",
0xFE	:"Latin small letter thorn (icelandic) (U+00FE)",
0xFF	:"Latin small letter kra (U+0138)",
}

#ISO-8859-11 Thai
iso8859_11xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"thai character ko kai (U+0E01)",
0xA2	:"thai character kho khai (U+0E02)",
0xA3	:"thai character kho khuat (U+0E03)",
0xA4	:"thai character kho khwai (U+0E04)",
0xA5	:"thai character kho khon (U+0E05)",
0xA6	:"thai character kho rakhang (U+0E06)",
0xA7	:"thai character ngo ngu (U+0E07)",
0xA8	:"thai character cho chan (U+0E08)",
0xA9	:"thai character cho ching (U+0E09)",
0xAA	:"thai character cho chang (U+0E0A)",
0xAB	:"thai character so so (U+0E0B)",
0xAC	:"thai character cho choe (U+0E0C)",
0xAD	:"thai character yo ying (U+0E0D)",
0xAE	:"thai character do chada (U+0E0E)",
0xAF	:"thai character to patak (U+0E0F)",
0xB0	:"thai character tho than (U+0E10)",
0xB1	:"thai character tho nangmontho (U+0E11)",
0xB2	:"thai character tho phuthao (U+0E12)",
0xB3	:"thai character no nen (U+0E13)",
0xB4	:"thai character do dek (U+0E14)",
0xB5	:"thai character to tao (U+0E15)",
0xB6	:"thai character tho thung (U+0E16)",
0xB7	:"thai character tho thahan (U+0E17)",
0xB8	:"thai character tho thong (U+0E18)",
0xB9	:"thai character no nu (U+0E19)",
0xBA	:"thai character bo baimai (U+0E1A)",
0xBB	:"thai character po pla (U+0E1B)",
0xBC	:"thai character pho phung (U+0E1C)",
0xBD	:"thai character fo fa (U+0E1D)",
0xBE	:"thai character pho phan (U+0E1E)",
0xBF	:"thai character fo fan (U+0E1F)",
0xC0	:"thai character pho samphao (U+0E20)",
0xC1	:"thai character mo ma (U+0E21)",
0xC2	:"thai character yo yak (U+0E22)",
0xC3	:"thai character ro rua (U+0E23)",
0xC4	:"thai character ru (U+0E24)",
0xC5	:"thai character lo ling (U+0E25)",
0xC6	:"thai character lu (U+0E26)",
0xC7	:"thai character wo waen (U+0E27)",
0xC8	:"thai character so sala (U+0E28)",
0xC9	:"thai character so rusi (U+0E29)",
0xCA	:"thai character so sua (U+0E2A)",
0xCB	:"thai character ho hip (U+0E2B)",
0xCC	:"thai character lo chula (U+0E2C)",
0xCD	:"thai character o ang (U+0E2D)",
0xCE	:"thai character ho nokhuk (U+0E2E)",
0xCF	:"thai character paiyannoi (U+0E2F)",
0xD0	:"thai character sara a (U+0E30)",
0xD1	:"thai character mai han-akat (U+0E31)",
0xD2	:"thai character sara aa (U+0E32)",
0xD3	:"thai character sara am (U+0E33)",
0xD4	:"thai character sara i (U+0E34)",
0xD5	:"thai character sara ii (U+0E35)",
0xD6	:"thai character sara ue (U+0E36)",
0xD7	:"thai character sara uee (U+0E37)",
0xD8	:"thai character sara u (U+0E38)",
0xD9	:"thai character sara uu (U+0E39)",
0xDA	:"thai character phinthu (U+0E3A)",
0xDB	:"Unused",
0xDC	:"Unused",
0xDD	:"Unused",
0xDE	:"Unused",
0xDF	:"thai currency symbol baht (U+0E3F)",
0xE0	:"thai character sara e (U+0E40)",
0xE1	:"thai character sara ae (U+0E41)",
0xE2	:"thai character sara o (U+0E42)",
0xE3	:"thai character sara ai maimuan (U+0E43)",
0xE4	:"thai character sara ai maimalai (U+0E44)",
0xE5	:"thai character lakkhangyao (U+0E45)",
0xE6	:"thai character maiyamok (U+0E46)",
0xE7	:"thai character maitaikhu (U+0E47)",
0xE8	:"thai character mai ek (U+0E48)",
0xE9	:"thai character mai tho (U+0E49)",
0xEA	:"thai character mai tri (U+0E4A)",
0xEB	:"thai character mai chattawa (U+0E4B)",
0xEC	:"thai character thanthakhat (U+0E4C)",
0xED	:"thai character nikhahit (U+0E4D)",
0xEE	:"thai character yamakkan (U+0E4E)",
0xEF	:"thai character fongman (U+0E4F)",
0xF0	:"thai digit zero (U+0E50)",
0xF1	:"thai digit one (U+0E51)",
0xF2	:"thai digit two (U+0E52)",
0xF3	:"thai digit three (U+0E53)",
0xF4	:"thai digit four (U+0E54)",
0xF5	:"thai digit five (U+0E55)",
0xF6	:"thai digit six (U+0E56)",
0xF7	:"thai digit seven (U+0E57)",
0xF8	:"thai digit eight (U+0E58)",
0xF9	:"thai digit nine (U+0E59)",
0xFA	:"thai character angkhankhu (U+0E5A)",
0xFB	:"thai character khomut (U+0E5B)",
0xFC	:"Unused",
0xFD	:"Unused",
0xFE	:"Unused",
0xFF	:"Unused",
}

#ISO-8859-12 is not missing - it doesn't exist. It would have been Devanagari but was abandoned.

#ISO-8859-13 Baltic Rim
iso8859_13xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"right double quotation mark (U+201D)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"double low-9 quotation mark (U+201E)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"Latin capital letter o with stroke (U+00D8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"Latin capital letter r with cedilla (U+0156)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"Latin capital letter ae (U+00C6)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"left double quotation mark (U+201C)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"Latin small letter o with stroke (U+00F8)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"Latin small letter r with cedilla (U+0157)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"vulgar fraction one quarter (U+00BC)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"vulgar fraction three quarters (U+00BE)",
0xBF	:"Latin small letter ae (U+00E6)",
0xC0	:"Latin capital letter a with ogonek (U+0104)",
0xC1	:"Latin capital letter i with ogonek (U+012E)",
0xC2	:"Latin capital letter a with macron (U+0100)",
0xC3	:"Latin capital letter c with acute (U+0106)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter a with ring above (U+00C5)",
0xC6	:"Latin capital letter e with ogonek (U+0118)",
0xC7	:"Latin capital letter e with macron (U+0112)",
0xC8	:"Latin capital letter c with caron (U+010C)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter z with acute (U+0179)",
0xCB	:"Latin capital letter e with dot above (U+0116)",
0xCC	:"Latin capital letter g with cedilla (U+0122)",
0xCD	:"Latin capital letter k with cedilla (U+0136)",
0xCE	:"Latin capital letter i with macron (U+012A)",
0xCF	:"Latin capital letter l with cedilla (U+013B)",
0xD0	:"Latin capital letter s with caron (U+0160)",
0xD1	:"Latin capital letter n with acute (U+0143)",
0xD2	:"Latin capital letter n with cedilla (U+0145)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with macron (U+014C)",
0xD5	:"Latin capital letter o with tilde (U+00D5)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"multiplication sign (U+00D7)",
0xD8	:"Latin capital letter u with ogonek (U+0172)",
0xD9	:"Latin capital letter l with stroke (U+0141)",
0xDA	:"Latin capital letter s with acute (U+015A)",
0xDB	:"Latin capital letter u with macron (U+016A)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter z with dot above (U+017B)",
0xDE	:"Latin capital letter z with caron (U+017D)",
0xDF	:"Latin small letter sharp s (german) (U+00DF)",
0xE0	:"Latin small letter a with ogonek (U+0105)",
0xE1	:"Latin small letter i with ogonek (U+012F)",
0xE2	:"Latin small letter a with macron (U+0101)",
0xE3	:"Latin small letter c with acute (U+0107)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter a with ring above (U+00E5)",
0xE6	:"Latin small letter e with ogonek (U+0119)",
0xE7	:"Latin small letter e with macron (U+0113)",
0xE8	:"Latin small letter c with caron (U+010D)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter z with acute (U+017A)",
0xEB	:"Latin small letter e with dot above (U+0117)",
0xEC	:"Latin small letter g with cedilla (U+0123)",
0xED	:"Latin small letter k with cedilla (U+0137)",
0xEE	:"Latin small letter i with macron (U+012B)",
0xEF	:"Latin small letter l with cedilla (U+013C)",
0xF0	:"Latin small letter s with caron (U+0161)",
0xF1	:"Latin small letter n with acute (U+0144)",
0xF2	:"Latin small letter n with cedilla (U+0146)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with macron (U+014D)",
0xF5	:"Latin small letter o with tilde (U+00F5)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"division sign (U+00F7)",
0xF8	:"Latin small letter u with ogonek (U+0173)",
0xF9	:"Latin small letter l with stroke (U+0142)",
0xFA	:"Latin small letter s with acute (U+015B)",
0xFB	:"Latin small letter u with macron (U+016B)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter z with dot above (U+017C)",
0xFE	:"Latin small letter z with caron (U+017E)",
0xFF	:"right single quotation mark (U+2019)",
}

#ISO-8859-14 Celtic
iso8859_14xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"Latin capital letter b with dot above (U+1E02)",
0xA2	:"Latin small letter b with dot above (U+1E03)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"Latin capital letter c with dot above (U+010A)",
0xA5	:"Latin small letter c with dot above (U+010B)",
0xA6	:"Latin capital letter d with dot above (U+1E0A)",
0xA7	:"section sign (U+00A7)",
0xA8	:"Latin capital letter w with grave (U+1E80)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"Latin capital letter w with acute (U+1E82)",
0xAB	:"Latin small letter d with dot above (U+1E0B)",
0xAC	:"Latin capital letter y with grave (U+1EF2)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"Latin capital letter y with diaeresis (U+0178)",
0xB0	:"Latin capital letter f with dot above (U+1E1E)",
0xB1	:"Latin small letter f with dot above (U+1E1F)",
0xB2	:"Latin capital letter g with dot above (U+0120)",
0xB3	:"Latin small letter g with dot above (U+0121)",
0xB4	:"Latin capital letter m with dot above (U+1E40)",
0xB5	:"Latin small letter m with dot above (U+1E41)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"Latin capital letter p with dot above (U+1E56)",
0xB8	:"Latin small letter w with grave (U+1E81)",
0xB9	:"Latin small letter p with dot above (U+1E57)",
0xBA	:"Latin small letter w with acute (U+1E83)",
0xBB	:"Latin capital letter s with dot above (U+1E60)",
0xBC	:"Latin small letter y with grave (U+1EF3)",
0xBD	:"Latin capital letter w with diaeresis (U+1E84)",
0xBE	:"Latin small letter w with diaeresis (U+1E85)",
0xBF	:"Latin small letter s with dot above (U+1E61)",
0xC0	:"Latin capital letter a with grave (U+00C0)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with tilde (U+00C3)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter a with ring above (U+00C5)",
0xC6	:"Latin capital letter ae (U+00C6)",
0xC7	:"Latin capital letter c with cedilla (U+00C7)",
0xC8	:"Latin capital letter e with grave (U+00C8)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with circumflex (U+00CA)",
0xCB	:"Latin capital letter e with diaeresis (U+00CB)",
0xCC	:"Latin capital letter i with grave (U+00CC)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with circumflex (U+00CE)",
0xCF	:"Latin capital letter i with diaeresis (U+00CF)",
0xD0	:"Latin capital letter w with circumflex (U+0174)",
0xD1	:"Latin capital letter n with tilde (U+00D1)",
0xD2	:"Latin capital letter o with grave (U+00D2)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin capital letter o with tilde (U+00D5)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"Latin capital letter t with dot above (U+1E6A)",
0xD8	:"Latin capital letter o with stroke (U+00D8)",
0xD9	:"Latin capital letter u with grave (U+00D9)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin capital letter u with circumflex (U+00DB)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter y with acute (U+00DD)",
0xDE	:"Latin capital letter y with circumflex (U+0176)",
0xDF	:"Latin small letter sharp s (U+00DF)",
0xE0	:"Latin small letter a with grave (U+00E0)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with tilde (U+00E3)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter a with ring above (U+00E5)",
0xE6	:"Latin small letter ae (U+00E6)",
0xE7	:"Latin small letter c with cedilla (U+00E7)",
0xE8	:"Latin small letter e with grave (U+00E8)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with circumflex (U+00EA)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"Latin small letter i with grave (U+00EC)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter i with diaeresis (U+00EF)",
0xF0	:"Latin small letter w with circumflex (U+0175)",
0xF1	:"Latin small letter n with tilde (U+00F1)",
0xF2	:"Latin small letter o with grave (U+00F2)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with tilde (U+00F5)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"Latin small letter t with dot above (U+1E6B)",
0xF8	:"Latin small letter o with stroke (U+00F8)",
0xF9	:"Latin small letter u with grave (U+00F9)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with circumflex (U+00FB)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter y with acute (U+00FD)",
0xFE	:"Latin small letter y with circumflex (U+0177)",
0xFF	:"Latin small letter y with diaeresis (U+00FF)",
}

#ISO-8859-15 Western Europe (= ISO-8859-1 with a few changes)
iso8859_15xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"inverted exclamation mark (U+00A1)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"euro sign (U+20AC)",
0xA5	:"yen sign (U+00A5)",
0xA6	:"Latin capital letter s with caron (U+0160)",
0xA7	:"section sign (U+00A7)",
0xA8	:"Latin small letter s with caron (U+0161)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"feminine ordinal indicator (U+00AA)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"macron (U+00AF)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"Latin capital letter z with caron (U+017D)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"Latin small letter z with caron (U+017E)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"masculine ordinal indicator (U+00BA)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"Latin capital ligature oe (U+0152)",
0xBD	:"Latin small ligature oe (U+0153)",
0xBE	:"Latin capital letter y with diaeresis (U+0178)",
0xBF	:"inverted question mark (U+00BF)",
0xC0	:"Latin capital letter a with grave (U+00C0)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with tilde (U+00C3)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter a with ring above (U+00C5)",
0xC6	:"Latin capital letter ae (U+00C6)",
0xC7	:"Latin capital letter c with cedilla (U+00C7)",
0xC8	:"Latin capital letter e with grave (U+00C8)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with circumflex (U+00CA)",
0xCB	:"Latin capital letter e with diaeresis (U+00CB)",
0xCC	:"Latin capital letter i with grave (U+00CC)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with circumflex (U+00CE)",
0xCF	:"Latin capital letter i with diaeresis (U+00CF)",
0xD0	:"Latin capital letter eth (U+00D0)",
0xD1	:"Latin capital letter n with tilde (U+00D1)",
0xD2	:"Latin capital letter o with grave (U+00D2)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin capital letter o with tilde (U+00D5)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"multiplication sign (U+00D7)",
0xD8	:"Latin capital letter o with stroke (U+00D8)",
0xD9	:"Latin capital letter u with grave (U+00D9)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin capital letter u with circumflex (U+00DB)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter y with acute (U+00DD)",
0xDE	:"Latin capital letter thorn (U+00DE)",
0xDF	:"Latin small letter sharp s (U+00DF)",
0xE0	:"Latin small letter a with grave (U+00E0)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with tilde (U+00E3)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter a with ring above (U+00E5)",
0xE6	:"Latin small letter ae (U+00E6)",
0xE7	:"Latin small letter c with cedilla (U+00E7)",
0xE8	:"Latin small letter e with grave (U+00E8)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with circumflex (U+00EA)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"Latin small letter i with grave (U+00EC)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter i with diaeresis (U+00EF)",
0xF0	:"Latin small letter eth (U+00F0)",
0xF1	:"Latin small letter n with tilde (U+00F1)",
0xF2	:"Latin small letter o with grave (U+00F2)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with tilde (U+00F5)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"division sign (U+00F7)",
0xF8	:"Latin small letter o with stroke (U+00F8)",
0xF9	:"Latin small letter u with grave (U+00F9)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with circumflex (U+00FB)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter y with acute (U+00FD)",
0xFE	:"Latin small letter thorn (U+00FE)",
0xFF	:"Latin small letter y with diaeresis (U+00FF)",
}

#ISO-8859-16 South-Eastern Europe
iso8859_16xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"Latin capital letter a with ogonek (U+0104)",
0xA2	:"Latin small letter a with ogonek (U+0105)",
0xA3	:"Latin capital letter l with stroke (U+0141)",
0xA4	:"euro sign (U+20AC)",
0xA5	:"double low-9 quotation mark (U+201E)",
0xA6	:"Latin capital letter s with caron (U+0160)",
0xA7	:"section sign (U+00A7)",
0xA8	:"Latin small letter s with caron (U+0161)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"Latin capital letter s with comma below (U+0218)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"Latin capital letter z with acute (U+0179)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"Latin small letter z with acute (U+017A)",
0xAF	:"Latin capital letter z with dot above (U+017B)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"Latin capital letter c with caron (U+010C)",
0xB3	:"Latin small letter l with stroke (U+0142)",
0xB4	:"Latin capital letter z with caron (U+017D)",
0xB5	:"right double quotation mark (U+201D)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"Latin small letter z with caron (U+017E)",
0xB9	:"Latin small letter c with caron (U+010D)",
0xBA	:"Latin small letter s with comma below (U+0219)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"Latin capital ligature oe (U+0152)",
0xBD	:"Latin small ligature oe (U+0153)",
0xBE	:"Latin capital letter y with diaeresis (U+0178)",
0xBF	:"Latin small letter z with dot above (U+017C)",
0xC0	:"Latin capital letter a with grave (U+00C0)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with breve (U+0102)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter c with acute (U+0106)",
0xC6	:"Latin capital letter ae (U+00C6)",
0xC7	:"Latin capital letter c with cedilla (U+00C7)",
0xC8	:"Latin capital letter e with grave (U+00C8)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with circumflex (U+00CA)",
0xCB	:"Latin capital letter e with diaeresis (U+00CB)",
0xCC	:"Latin capital letter i with grave (U+00CC)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with circumflex (U+00CE)",
0xCF	:"Latin capital letter i with diaeresis (U+00CF)",
0xD0	:"Latin capital letter d with stroke (U+0110)",
0xD1	:"Latin capital letter n with acute (U+0143)",
0xD2	:"Latin capital letter o with grave (U+00D2)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin capital letter o with double acute (U+0150)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"Latin capital letter s with acute (U+015A)",
0xD8	:"Latin capital letter u with double acute (U+0170)",
0xD9	:"Latin capital letter u with grave (U+00D9)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin capital letter u with circumflex (U+00DB)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter e with ogonek (U+0118)",
0xDE	:"Latin capital letter t with comma below (U+021A)",
0xDF	:"Latin small letter sharp s (U+00DF)",
0xE0	:"Latin small letter a with grave (U+00E0)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with breve (U+0103)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter c with acute (U+0107)",
0xE6	:"Latin small letter ae (U+00E6)",
0xE7	:"Latin small letter c with cedilla (U+00E7)",
0xE8	:"Latin small letter e with grave (U+00E8)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with circumflex (U+00EA)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"Latin small letter i with grave (U+00EC)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter i with diaeresis (U+00EF)",
0xF0	:"Latin small letter d with stroke (U+0111)",
0xF1	:"Latin small letter n with acute (U+0144)",
0xF2	:"Latin small letter o with grave (U+00F2)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with double acute (U+0151)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"Latin small letter s with acute (U+015B)",
0xF8	:"Latin small letter u with double acute (U+0171)",
0xF9	:"Latin small letter u with grave (U+00F9)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with circumflex (U+00FB)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter e with ogonek (U+0119)",
0xFE	:"Latin small letter t with comma below (U+021B)",
0xFF	:"Latin small letter y with diaeresis (U+00FF)",
}

#The original KOI8 encoding defined by GOST 19768-74.
koi8axtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"SPACE (U+0020)",
0x21	:"EXCLAMATION MARK (U+0021)",
0x22	:"QUOTATION MARK (U+0022)",
0x23	:"NUMBER SIGN (U+0023)",
0x24	:"CURRENCY SIGN (U+00A4)",
0x25	:"PERCENT SIGN (U+0025)",
0x26	:"AMPERSAND (U+0026)",
0x27	:"APOSTROPHE (U+0027)",
0x28	:"LEFT PARENTHESIS (U+0028)",
0x29	:"RIGHT PARENTHESIS (U+0029)",
0x2A	:"ASTERISK (U+002A)",
0x2B	:"PLUS SIGN (U+002B)",
0x2C	:"COMMA (U+002C)",
0x2D	:"HYPHEN-MINUS (U+002D)",
0x2E	:"FULL STOP (U+002E)",
0x2F	:"SOLIDUS (U+002F)",
0x30	:"DIGIT ZERO (U+0030)",
0x31	:"DIGIT ONE (U+0031)",
0x32	:"DIGIT TWO (U+0032)",
0x33	:"DIGIT THREE (U+0033)",
0x34	:"DIGIT FOUR (U+0034)",
0x35	:"DIGIT FIVE (U+0035)",
0x36	:"DIGIT SIX (U+0036)",
0x37	:"DIGIT SEVEN (U+0037)",
0x38	:"DIGIT EIGHT (U+0038)",
0x39	:"DIGIT NINE (U+0039)",
0x3A	:"COLON (U+003A)",
0x3B	:"SEMICOLON (U+003B)",
0x3C	:"LESS-THAN SIGN (U+003C)",
0x3D	:"EQUALS SIGN (U+003D)",
0x3E	:"GREATER-THAN SIGN (U+003E)",
0x3F	:"QUESTION MARK (U+003F)",
0x40	:"COMMERCIAL AT (U+0040)",
0x41	:"Latin capital letter A (U+0041)",
0x42	:"Latin capital letter B (U+0042)",
0x43	:"Latin capital letter C (U+0043)",
0x44	:"Latin capital letter D (U+0044)",
0x45	:"Latin capital letter E (U+0045)",
0x46	:"Latin capital letter F (U+0046)",
0x47	:"Latin capital letter G (U+0047)",
0x48	:"Latin capital letter H (U+0048)",
0x49	:"Latin capital letter I (U+0049)",
0x4A	:"Latin capital letter J (U+004A)",
0x4B	:"Latin capital letter K (U+004B)",
0x4C	:"Latin capital letter L (U+004C)",
0x4D	:"Latin capital letter M (U+004D)",
0x4E	:"Latin capital letter N (U+004E)",
0x4F	:"Latin capital letter O (U+004F)",
0x50	:"Latin capital letter P (U+0050)",
0x51	:"Latin capital letter Q (U+0051)",
0x52	:"Latin capital letter R (U+0052)",
0x53	:"Latin capital letter S (U+0053)",
0x54	:"Latin capital letter T (U+0054)",
0x55	:"Latin capital letter U (U+0055)",
0x56	:"Latin capital letter V (U+0056)",
0x57	:"Latin capital letter W (U+0057)",
0x58	:"Latin capital letter X (U+0058)",
0x59	:"Latin capital letter Y (U+0059)",
0x5A	:"Latin capital letter Z (U+005A)",
0x5B	:"LEFT SQUARE BRACKET (U+005B)",
0x5C	:"REVERSE SOLIDUS (U+005C)",
0x5D	:"RIGHT SQUARE BRACKET (U+005D)",
0x5E	:"CIRCUMFLEX ACCENT (U+005E)",
0x5F	:"LOW LINE (U+005F)",
0x60	:"GRAVE ACCENT (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter C (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter F (U+0066)",
0x67	:"Latin small letter G (U+0067)",
0x68	:"Latin small letter H (U+0068)",
0x69	:"Latin small letter I (U+0069)",
0x6A	:"Latin small letter J (U+006A)",
0x6B	:"Latin small letter K (U+006B)",
0x6C	:"Latin small letter L (U+006C)",
0x6D	:"Latin small letter M (U+006D)",
0x6E	:"Latin small letter N (U+006E)",
0x6F	:"Latin small letter O (U+006F)",
0x70	:"Latin small letter P (U+0070)",
0x71	:"Latin small letter Q (U+0071)",
0x72	:"Latin small letter R (U+0072)",
0x73	:"Latin small letter S (U+0073)",
0x74	:"Latin small letter T (U+0074)",
0x75	:"Latin small letter U (U+0075)",
0x76	:"Latin small letter V (U+0076)",
0x77	:"Latin small letter W (U+0077)",
0x78	:"Latin small letter X (U+0078)",
0x79	:"Latin small letter Y (U+0079)",
0x7A	:"Latin small letter Z (U+007A)",
0x7B	:"LEFT CURLY BRACKET (U+007B)",
0x7C	:"VERTICAL LINE (U+007C)",
0x7D	:"RIGHT CURLY BRACKET (U+007D)",
0x7E	:"TILDE (U+007E)",
0x7F	:"Unused",
0x80	:"Unused",
0x81	:"Unused",
0x82	:"Unused",
0x83	:"Unused",
0x84	:"Unused",
0x85	:"Unused",
0x86	:"Unused",
0x87	:"Unused",
0x88	:"Unused",
0x89	:"Unused",
0x8A	:"Unused",
0x8B	:"Unused",
0x8C	:"Unused",
0x8D	:"Unused",
0x8E	:"Unused",
0x8F	:"Unused",
0x90	:"Unused",
0x91	:"Unused",
0x92	:"Unused",
0x93	:"Unused",
0x94	:"Unused",
0x95	:"Unused",
0x96	:"Unused",
0x97	:"Unused",
0x98	:"Unused",
0x99	:"Unused",
0x9A	:"Unused",
0x9B	:"Unused",
0x9C	:"Unused",
0x9D	:"Unused",
0x9E	:"Unused",
0x9F	:"Unused",
0xA0	:"Unused",
0xA1	:"Unused",
0xA2	:"Unused",
0xA3	:"Unused",
0xA4	:"Unused",
0xA5	:"Unused",
0xA6	:"Unused",
0xA7	:"Unused",
0xA8	:"Unused",
0xA9	:"Unused",
0xAA	:"Unused",
0xAB	:"Unused",
0xAC	:"Unused",
0xAD	:"Unused",
0xAE	:"Unused",
0xAF	:"Unused",
0xB0	:"Unused",
0xB1	:"Unused",
0xB2	:"Unused",
0xB3	:"Unused",
0xB4	:"Unused",
0xB5	:"Unused",
0xB6	:"Unused",
0xB7	:"Unused",
0xB8	:"Unused",
0xB9	:"Unused",
0xBA	:"Unused",
0xBB	:"Unused",
0xBC	:"Unused",
0xBD	:"Unused",
0xBE	:"Unused",
0xBF	:"Unused",
0xC0	:"Cyrillic small letter YU (U+044E)",
0xC1	:"Cyrillic small letter a (U+0430)",
0xC2	:"Cyrillic small letter bE (U+0431)",
0xC3	:"Cyrillic small letter TSE (U+0446)",
0xC4	:"Cyrillic small letter dE (U+0434)",
0xC5	:"Cyrillic small letter IE (U+0435)",
0xC6	:"Cyrillic small letter eF (U+0444)",
0xC7	:"Cyrillic small letter GHE (U+0433)",
0xC8	:"Cyrillic small letter HA (U+0445)",
0xC9	:"Cyrillic small letter I (U+0438)",
0xCA	:"Cyrillic small letter SHORT I (U+0439)",
0xCB	:"Cyrillic small letter KA (U+043A)",
0xCC	:"Cyrillic small letter eL (U+043B)",
0xCD	:"Cyrillic small letter eM (U+043C)",
0xCE	:"Cyrillic small letter eN (U+043D)",
0xCF	:"Cyrillic small letter O (U+043E)",
0xD0	:"Cyrillic small letter PE (U+043F)",
0xD1	:"Cyrillic small letter YA (U+044F)",
0xD2	:"Cyrillic small letter eR (U+0440)",
0xD3	:"Cyrillic small letter eS (U+0441)",
0xD4	:"Cyrillic small letter TE (U+0442)",
0xD5	:"Cyrillic small letter U (U+0443)",
0xD6	:"Cyrillic small letter ZHE (U+0436)",
0xD7	:"Cyrillic small letter VE (U+0432)",
0xD8	:"Cyrillic small letter SOFT SIGN (U+044C)",
0xD9	:"Cyrillic small letter YERU (U+044B)",
0xDA	:"Cyrillic small letter ZE (U+0437)",
0xDB	:"Cyrillic small letter SHA (U+0448)",
0xDC	:"Cyrillic small letter e (U+044D)",
0xDD	:"Cyrillic small letter SHCHA (U+0449)",
0xDE	:"Cyrillic small letter CHE (U+0447)",
0xDF	:"Cyrillic small letter HARD SIGN (U+044A)",
0xE0	:"Cyrillic capital letter YU (U+042E)",
0xE1	:"Cyrillic capital letter A (U+0410)",
0xE2	:"Cyrillic capital letter BE (U+0411)",
0xE3	:"Cyrillic capital letter TSE (U+0426)",
0xE4	:"Cyrillic capital letter DE (U+0414)",
0xE5	:"Cyrillic capital letter IE (U+0415)",
0xE6	:"Cyrillic capital letter EF (U+0424)",
0xE7	:"Cyrillic capital letter GHE (U+0413)",
0xE8	:"Cyrillic capital letter HA (U+0425)",
0xE9	:"Cyrillic capital letter I (U+0418)",
0xEA	:"Cyrillic capital letter SHORT I (U+0419)",
0xEB	:"Cyrillic capital letter KA (U+041A)",
0xEC	:"Cyrillic capital letter EL (U+041B)",
0xED	:"Cyrillic capital letter EM (U+041C)",
0xEE	:"Cyrillic capital letter EN (U+041D)",
0xEF	:"Cyrillic capital letter O (U+041E)",
0xF0	:"Cyrillic capital letter PE (U+041F)",
0xF1	:"Cyrillic capital letter YA (U+042F)",
0xF2	:"Cyrillic capital letter ER (U+0420)",
0xF3	:"Cyrillic capital letter ES (U+0421)",
0xF4	:"Cyrillic capital letter TE (U+0422)",
0xF5	:"Cyrillic capital letter U (U+0423)",
0xF6	:"Cyrillic capital letter ZHE (U+0416)",
0xF7	:"Cyrillic capital letter VE (U+0412)",
0xF8	:"Cyrillic capital letter SOFT SIGN (U+042C)",
0xF9	:"Cyrillic capital letter YERU (U+042B)",
0xFA	:"Cyrillic capital letter ZE (U+0417)",
0xFB	:"Cyrillic capital letter SHA (U+0428)",
0xFC	:"Cyrillic capital letter E (U+042D)",
0xFD	:"Cyrillic capital letter SHCHA (U+0429)",
0xFE	:"Cyrillic capital letter CHE (U+0427)",
0xFF	:"Unused"
}

#KOI8-B (Cyrillic - letter only subset of KOI8-R)
koi8bxtbl={\
0x00	:"Unused",
0x01	:"Unused",
0x02	:"Unused",
0x03	:"Unused",
0x04	:"Unused",
0x05	:"Unused",
0x06	:"Unused",
0x07	:"Unused",
0x08	:"Unused",
0x09	:"Unused",
0x0A	:"Unused",
0x0B	:"Unused",
0x0C	:"Unused",
0x0D	:"Unused",
0x0E	:"Unused",
0x0F	:"Unused",
0x10	:"Unused",
0x11	:"Unused",
0x12	:"Unused",
0x13	:"Unused",
0x14	:"Unused",
0x15	:"Unused",
0x16	:"Unused",
0x17	:"Unused",
0x18	:"Unused",
0x19	:"Unused",
0x1A	:"Unused",
0x1B	:"Unused",
0x1C	:"Unused",
0x1D	:"Unused",
0x1E	:"Unused",
0x1F	:"Unused",
0x20	:"SPACE (U+0020)",
0x21	:"EXCLAMATION MARK (U+0021)",
0x22	:"QUOTATION MARK (U+0022)",
0x23	:"NUMBER SIGN (U+0023)",
0x24	:"DOLLAR SIGN (U+0024)",
0x25	:"PERCENT SIGN (U+0025)",
0x26	:"AMPERSAND (U+0026)",
0x27	:"APOSTROPHE (U+0027)",
0x28	:"LEFT PARENTHESIS (U+0028)",
0x29	:"RIGHT PARENTHESIS (U+0029)",
0x2A	:"ASTERISK (U+002A)",
0x2B	:"PLUS SIGN (U+002B)",
0x2C	:"COMMA (U+002C)",
0x2D	:"HYPHEN-MINUS (U+002D)",
0x2E	:"FULL STOP (U+002E)",
0x2F	:"SOLIDUS (U+002F)",
0x30	:"DIGIT ZERO (U+0030)",
0x31	:"DIGIT ONE (U+0031)",
0x32	:"DIGIT TWO (U+0032)",
0x33	:"DIGIT THREE (U+0033)",
0x34	:"DIGIT FOUR (U+0034)",
0x35	:"DIGIT FIVE (U+0035)",
0x36	:"DIGIT SIX (U+0036)",
0x37	:"DIGIT SEVEN (U+0037)",
0x38	:"DIGIT EIGHT (U+0038)",
0x39	:"DIGIT NINE (U+0039)",
0x3A	:"COLON (U+003A)",
0x3B	:"SEMICOLON (U+003B)",
0x3C	:"LESS-THAN SIGN (U+003C)",
0x3D	:"EQUALS SIGN (U+003D)",
0x3E	:"GREATER-THAN SIGN (U+003E)",
0x3F	:"QUESTION MARK (U+003F)",
0x40	:"COMMERCIAL AT (U+0040)",
0x41	:"Latin capital letter A (U+0041)",
0x42	:"Latin capital letter B (U+0042)",
0x43	:"Latin capital letter C (U+0043)",
0x44	:"Latin capital letter D (U+0044)",
0x45	:"Latin capital letter E (U+0045)",
0x46	:"Latin capital letter F (U+0046)",
0x47	:"Latin capital letter G (U+0047)",
0x48	:"Latin capital letter H (U+0048)",
0x49	:"Latin capital letter I (U+0049)",
0x4A	:"Latin capital letter J (U+004A)",
0x4B	:"Latin capital letter K (U+004B)",
0x4C	:"Latin capital letter L (U+004C)",
0x4D	:"Latin capital letter M (U+004D)",
0x4E	:"Latin capital letter N (U+004E)",
0x4F	:"Latin capital letter O (U+004F)",
0x50	:"Latin capital letter P (U+0050)",
0x51	:"Latin capital letter Q (U+0051)",
0x52	:"Latin capital letter R (U+0052)",
0x53	:"Latin capital letter S (U+0053)",
0x54	:"Latin capital letter T (U+0054)",
0x55	:"Latin capital letter U (U+0055)",
0x56	:"Latin capital letter V (U+0056)",
0x57	:"Latin capital letter W (U+0057)",
0x58	:"Latin capital letter X (U+0058)",
0x59	:"Latin capital letter Y (U+0059)",
0x5A	:"Latin capital letter Z (U+005A)",
0x5B	:"LEFT SQUARE BRACKET (U+005B)",
0x5C	:"REVERSE SOLIDUS (U+005C)",
0x5D	:"RIGHT SQUARE BRACKET (U+005D)",
0x5E	:"CIRCUMFLEX ACCENT (U+005E)",
0x5F	:"LOW LINE (U+005F)",
0x60	:"GRAVE ACCENT (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter C (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter F (U+0066)",
0x67	:"Latin small letter G (U+0067)",
0x68	:"Latin small letter H (U+0068)",
0x69	:"Latin small letter I (U+0069)",
0x6A	:"Latin small letter J (U+006A)",
0x6B	:"Latin small letter K (U+006B)",
0x6C	:"Latin small letter L (U+006C)",
0x6D	:"Latin small letter M (U+006D)",
0x6E	:"Latin small letter N (U+006E)",
0x6F	:"Latin small letter O (U+006F)",
0x70	:"Latin small letter P (U+0070)",
0x71	:"Latin small letter Q (U+0071)",
0x72	:"Latin small letter R (U+0072)",
0x73	:"Latin small letter S (U+0073)",
0x74	:"Latin small letter T (U+0074)",
0x75	:"Latin small letter U (U+0075)",
0x76	:"Latin small letter V (U+0076)",
0x77	:"Latin small letter W (U+0077)",
0x78	:"Latin small letter X (U+0078)",
0x79	:"Latin small letter Y (U+0079)",
0x7A	:"Latin small letter Z (U+007A)",
0x7B	:"LEFT CURLY BRACKET (U+007B)",
0x7C	:"VERTICAL LINE (U+007C)",
0x7D	:"RIGHT CURLY BRACKET (U+007D)",
0x7E	:"TILDE (U+007E)",
0x7F	:"Unused",
0x80	:"Unused",
0x81	:"Unused",
0x82	:"Unused",
0x83	:"Unused",
0x84	:"Unused",
0x85	:"Unused",
0x86	:"Unused",
0x87	:"Unused",
0x88	:"Unused",
0x89	:"Unused",
0x8A	:"Unused",
0x8B	:"Unused",
0x8C	:"Unused",
0x8D	:"Unused",
0x8E	:"Unused",
0x8F	:"Unused",
0x90	:"Unused",
0x91	:"Unused",
0x92	:"Unused",
0x93	:"Unused",
0x94	:"Unused",
0x95	:"Unused",
0x96	:"Unused",
0x97	:"Unused",
0x98	:"Unused",
0x99	:"Unused",
0x9A	:"Unused",
0x9B	:"Unused",
0x9C	:"Unused",
0x9D	:"Unused",
0x9E	:"Unused",
0x9F	:"Unused",
0xA0	:"Unused",
0xA1	:"Unused",
0xA2	:"Unused",
0xA3	:"Cyrillic small letter IO (U+0451)",
0xA4	:"Unused",
0xA5	:"Unused",
0xA6	:"Unused",
0xA7	:"Unused",
0xA8	:"Unused",
0xA9	:"Unused",
0xAA	:"Unused",
0xAB	:"Unused",
0xAC	:"Unused",
0xAD	:"Unused",
0xAE	:"Unused",
0xAF	:"Unused",
0xB0	:"Unused",
0xB1	:"Unused",
0xB2	:"Unused",
0xB3	:"Cyrillic capital letter IO (U+0401)",
0xB4	:"Unused",
0xB5	:"Unused",
0xB6	:"Unused",
0xB7	:"Unused",
0xB8	:"Unused",
0xB9	:"Unused",
0xBA	:"Unused",
0xBB	:"Unused",
0xBC	:"Unused",
0xBD	:"Unused",
0xBE	:"Unused",
0xBF	:"Unused",
0xC0	:"Cyrillic small letter YU (U+044E)",
0xC1	:"Cyrillic small letter a (U+0430)",
0xC2	:"Cyrillic small letter bE (U+0431)",
0xC3	:"Cyrillic small letter TSE (U+0446)",
0xC4	:"Cyrillic small letter dE (U+0434)",
0xC5	:"Cyrillic small letter IE (U+0435)",
0xC6	:"Cyrillic small letter eF (U+0444)",
0xC7	:"Cyrillic small letter GHE (U+0433)",
0xC8	:"Cyrillic small letter HA (U+0445)",
0xC9	:"Cyrillic small letter I (U+0438)",
0xCA	:"Cyrillic small letter SHORT I (U+0439)",
0xCB	:"Cyrillic small letter KA (U+043A)",
0xCC	:"Cyrillic small letter eL (U+043B)",
0xCD	:"Cyrillic small letter eM (U+043C)",
0xCE	:"Cyrillic small letter eN (U+043D)",
0xCF	:"Cyrillic small letter O (U+043E)",
0xD0	:"Cyrillic small letter PE (U+043F)",
0xD1	:"Cyrillic small letter YA (U+044F)",
0xD2	:"Cyrillic small letter eR (U+0440)",
0xD3	:"Cyrillic small letter eS (U+0441)",
0xD4	:"Cyrillic small letter TE (U+0442)",
0xD5	:"Cyrillic small letter U (U+0443)",
0xD6	:"Cyrillic small letter ZHE (U+0436)",
0xD7	:"Cyrillic small letter VE (U+0432)",
0xD8	:"Cyrillic small letter SOFT SIGN (U+044C)",
0xD9	:"Cyrillic small letter YERU (U+044B)",
0xDA	:"Cyrillic small letter ZE (U+0437)",
0xDB	:"Cyrillic small letter SHA (U+0448)",
0xDC	:"Cyrillic small letter e (U+044D)",
0xDD	:"Cyrillic small letter SHCHA (U+0449)",
0xDE	:"Cyrillic small letter CHE (U+0447)",
0xDF	:"Cyrillic small letter HARD SIGN (U+044A)",
0xE0	:"Cyrillic capital letter YU (U+042E)",
0xE1	:"Cyrillic capital letter A (U+0410)",
0xE2	:"Cyrillic capital letter BE (U+0411)",
0xE3	:"Cyrillic capital letter TSE (U+0426)",
0xE4	:"Cyrillic capital letter DE (U+0414)",
0xE5	:"Cyrillic capital letter IE (U+0415)",
0xE6	:"Cyrillic capital letter EF (U+0424)",
0xE7	:"Cyrillic capital letter GHE (U+0413)",
0xE8	:"Cyrillic capital letter HA (U+0425)",
0xE9	:"Cyrillic capital letter I (U+0418)",
0xEA	:"Cyrillic capital letter SHORT I (U+0419)",
0xEB	:"Cyrillic capital letter KA (U+041A)",
0xEC	:"Cyrillic capital letter EL (U+041B)",
0xED	:"Cyrillic capital letter EM (U+041C)",
0xEE	:"Cyrillic capital letter EN (U+041D)",
0xEF	:"Cyrillic capital letter O (U+041E)",
0xF0	:"Cyrillic capital letter PE (U+041F)",
0xF1	:"Cyrillic capital letter YA (U+042F)",
0xF2	:"Cyrillic capital letter ER (U+0420)",
0xF3	:"Cyrillic capital letter ES (U+0421)",
0xF4	:"Cyrillic capital letter TE (U+0422)",
0xF5	:"Cyrillic capital letter U (U+0423)",
0xF6	:"Cyrillic capital letter ZHE (U+0416)",
0xF7	:"Cyrillic capital letter VE (U+0412)",
0xF8	:"Cyrillic capital letter SOFT SIGN (U+042C)",
0xF9	:"Cyrillic capital letter YERU (U+042B)",
0xFA	:"Cyrillic capital letter ZE (U+0417)",
0xFB	:"Cyrillic capital letter SHA (U+0428)",
0xFC	:"Cyrillic capital letter E (U+042D)",
0xFD	:"Cyrillic capital letter SHCHA (U+0429)",
0xFE	:"Cyrillic capital letter CHE (U+0427)",
0xFF	:"Cyrillic capital letter HARD SIGN (U+042A)"
}

#KOI8-R (Cyrillic)
koi8rxtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"box drawings light horizontal (U+2500)",
0x81	:"box drawings light vertical (U+2502)",
0x82	:"box drawings light down and right (U+250C)",
0x83	:"box drawings light down and left (U+2510)",
0x84	:"box drawings light up and right (U+2514)",
0x85	:"box drawings light up and left (U+2518)",
0x86	:"box drawings light vertical and right (U+251C)",
0x87	:"box drawings light vertical and left (U+2524)",
0x88	:"box drawings light down and horizontal (U+252C)",
0x89	:"box drawings light up and horizontal (U+2534)",
0x8A	:"box drawings light vertical and horizontal (U+253C)",
0x8B	:"upper half block (U+2580)",
0x8C	:"lower half block (U+2584)",
0x8D	:"full block (U+2588)",
0x8E	:"left half block (U+258C)",
0x8F	:"right half block (U+2590)",
0x90	:"light shade (U+2591)",
0x91	:"medium shade (U+2592)",
0x92	:"dark shade (U+2593)",
0x93	:"top half integral (U+2320)",
0x94	:"black square (U+25A0)",
0x95	:"bullet operator (U+2219)",
0x96	:"square root (U+221A)",
0x97	:"almost equal to (U+2248)",
0x98	:"less-than or equal to (U+2264)",
0x99	:"greater-than or equal to (U+2265)",
0x9A	:"no-break space (U+00A0)",
0x9B	:"bottom half integral (U+2321)",
0x9C	:"degree sign (U+00B0)",
0x9D	:"superscript two (U+00B2)",
0x9E	:"middle dot (U+00B7)",
0x9F	:"division sign (U+00F7)",
0xA0	:"box drawings double horizontal (U+2550)",
0xA1	:"box drawings double vertical (U+2551)",
0xA2	:"box drawings down single and right double (U+2552)",
0xA3	:"cyrillic small letter io (U+0451)",
0xA4	:"box drawings down double and right single (U+2553)",
0xA5	:"box drawings double down and right (U+2554)",
0xA6	:"box drawings down single and left double (U+2555)",
0xA7	:"box drawings down double and left single (U+2556)",
0xA8	:"box drawings double down and left (U+2557)",
0xA9	:"box drawings up single and right double (U+2558)",
0xAA	:"box drawings up double and right single (U+2559)",
0xAB	:"box drawings double up and right (U+255A)",
0xAC	:"box drawings up single and left double (U+255B)",
0xAD	:"box drawings up double and left single (U+255C)",
0xAE	:"box drawings double up and left (U+255D)",
0xAF	:"box drawings vertical single and right double (U+255E)",
0xB0	:"box drawings vertical double and right single (U+255F)",
0xB1	:"box drawings double vertical and right (U+2560)",
0xB2	:"box drawings vertical single and left double (U+2561)",
0xB3	:"cyrillic capital letter io (U+0401)",
0xB4	:"box drawings vertical double and left single (U+2562)",
0xB5	:"box drawings double vertical and left (U+2563)",
0xB6	:"box drawings down single and horizontal double (U+2564)",
0xB7	:"box drawings down double and horizontal single (U+2565)",
0xB8	:"box drawings double down and horizontal (U+2566)",
0xB9	:"box drawings up single and horizontal double (U+2567)",
0xBA	:"box drawings up double and horizontal single (U+2568)",
0xBB	:"box drawings double up and horizontal (U+2569)",
0xBC	:"box drawings vertical single and horizontal double (U+256A)",
0xBD	:"box drawings vertical double and horizontal single (U+256B)",
0xBE	:"box drawings double vertical and horizontal (U+256C)",
0xBF	:"copyright sign (U+00A9)",
0xC0	:"cyrillic small letter yu (U+044E)",
0xC1	:"cyrillic small letter a (U+0430)",
0xC2	:"cyrillic small letter be (U+0431)",
0xC3	:"cyrillic small letter tse (U+0446)",
0xC4	:"cyrillic small letter de (U+0434)",
0xC5	:"cyrillic small letter ie (U+0435)",
0xC6	:"cyrillic small letter ef (U+0444)",
0xC7	:"cyrillic small letter ghe (U+0433)",
0xC8	:"cyrillic small letter ha (U+0445)",
0xC9	:"cyrillic small letter i (U+0438)",
0xCA	:"cyrillic small letter short i (U+0439)",
0xCB	:"cyrillic small letter ka (U+043A)",
0xCC	:"cyrillic small letter el (U+043B)",
0xCD	:"cyrillic small letter em (U+043C)",
0xCE	:"cyrillic small letter en (U+043D)",
0xCF	:"cyrillic small letter o (U+043E)",
0xD0	:"cyrillic small letter pe (U+043F)",
0xD1	:"cyrillic small letter ya (U+044F)",
0xD2	:"cyrillic small letter er (U+0440)",
0xD3	:"cyrillic small letter es (U+0441)",
0xD4	:"cyrillic small letter te (U+0442)",
0xD5	:"cyrillic small letter u (U+0443)",
0xD6	:"cyrillic small letter zhe (U+0436)",
0xD7	:"cyrillic small letter ve (U+0432)",
0xD8	:"cyrillic small letter soft sign (U+044C)",
0xD9	:"cyrillic small letter yeru (U+044B)",
0xDA	:"cyrillic small letter ze (U+0437)",
0xDB	:"cyrillic small letter sha (U+0448)",
0xDC	:"cyrillic small letter e (U+044D)",
0xDD	:"cyrillic small letter shcha (U+0449)",
0xDE	:"cyrillic small letter che (U+0447)",
0xDF	:"cyrillic small letter hard sign (U+044A)",
0xE0	:"cyrillic capital letter yu (U+042E)",
0xE1	:"cyrillic capital letter a (U+0410)",
0xE2	:"cyrillic capital letter be (U+0411)",
0xE3	:"cyrillic capital letter tse (U+0426)",
0xE4	:"cyrillic capital letter de (U+0414)",
0xE5	:"cyrillic capital letter ie (U+0415)",
0xE6	:"cyrillic capital letter ef (U+0424)",
0xE7	:"cyrillic capital letter ghe (U+0413)",
0xE8	:"cyrillic capital letter ha (U+0425)",
0xE9	:"cyrillic capital letter i (U+0418)",
0xEA	:"cyrillic capital letter short i (U+0419)",
0xEB	:"cyrillic capital letter ka (U+041A)",
0xEC	:"cyrillic capital letter el (U+041B)",
0xED	:"cyrillic capital letter em (U+041C)",
0xEE	:"cyrillic capital letter en (U+041D)",
0xEF	:"cyrillic capital letter o (U+041E)",
0xF0	:"cyrillic capital letter pe (U+041F)",
0xF1	:"cyrillic capital letter ya (U+042F)",
0xF2	:"cyrillic capital letter er (U+0420)",
0xF3	:"cyrillic capital letter es (U+0421)",
0xF4	:"cyrillic capital letter te (U+0422)",
0xF5	:"cyrillic capital letter u (U+0423)",
0xF6	:"cyrillic capital letter zhe (U+0416)",
0xF7	:"cyrillic capital letter ve (U+0412)",
0xF8	:"cyrillic capital letter soft sign (U+042C)",
0xF9	:"cyrillic capital letter yeru (U+042B)",
0xFA	:"cyrillic capital letter ze (U+0417)",
0xFB	:"cyrillic capital letter sha (U+0428)",
0xFC	:"cyrillic capital letter e (U+042D)",
0xFD	:"cyrillic capital letter shcha (U+0429)",
0xFE	:"cyrillic capital letter che (U+0427)",
0xFF	:"cyrillic capital letter hard sign (U+042A)"
}

#KOI8-U (Ukrainian)
koi8uxtbl={\
0x00	:"<control> (U+0000)",
0x01	:"<control> (U+0001)",
0x02	:"<control> (U+0002)",
0x03	:"<control> (U+0003)",
0x04	:"<control> (U+0004)",
0x05	:"<control> (U+0005)",
0x06	:"<control> (U+0006)",
0x07	:"<control> (U+0007)",
0x08	:"<control> (U+0008)",
0x09	:"<control> (U+0009)",
0x0A	:"<control> (U+000A)",
0x0B	:"<control> (U+000B)",
0x0C	:"<control> (U+000C)",
0x0D	:"<control> (U+000D)",
0x0E	:"<control> (U+000E)",
0x0F	:"<control> (U+000F)",
0x10	:"<control> (U+0010)",
0x11	:"<control> (U+0011)",
0x12	:"<control> (U+0012)",
0x13	:"<control> (U+0013)",
0x14	:"<control> (U+0014)",
0x15	:"<control> (U+0015)",
0x16	:"<control> (U+0016)",
0x17	:"<control> (U+0017)",
0x18	:"<control> (U+0018)",
0x19	:"<control> (U+0019)",
0x1A	:"<control> (U+001A)",
0x1B	:"<control> (U+001B)",
0x1C	:"<control> (U+001C)",
0x1D	:"<control> (U+001D)",
0x1E	:"<control> (U+001E)",
0x1F	:"<control> (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"<control> (U+007F)",
0x80	:"box drawings light horizontal (U+2500)",
0x81	:"box drawings light vertical (U+2502)",
0x82	:"box drawings light down and right (U+250C)",
0x83	:"box drawings light down and left (U+2510)",
0x84	:"box drawings light up and right (U+2514)",
0x85	:"box drawings light up and left (U+2518)",
0x86	:"box drawings light vertical and right (U+251C)",
0x87	:"box drawings light vertical and left (U+2524)",
0x88	:"box drawings light down and horizontal (U+252C)",
0x89	:"box drawings light up and horizontal (U+2534)",
0x8A	:"box drawings light vertical and horizontal (U+253C)",
0x8B	:"upper half block (U+2580)",
0x8C	:"lower half block (U+2584)",
0x8D	:"full block (U+2588)",
0x8E	:"left half block (U+258C)",
0x8F	:"right half block (U+2590)",
0x90	:"light shade (U+2591)",
0x91	:"medium shade (U+2592)",
0x92	:"dark shade (U+2593)",
0x93	:"top half integral (U+2320)",
0x94	:"black square (U+25A0)",
0x95	:"bullet operator (U+2219)",
0x96	:"square root (U+221A)",
0x97	:"almost equal to (U+2248)",
0x98	:"less than or equal to (U+2264)",
0x99	:"greater than or equal to (U+2265)",
0x9A	:"no-break space (U+00A0)",
0x9B	:"bottom half integral (U+2321)",
0x9C	:"degree sign (U+00B0)",
0x9D	:"superscript two (U+00B2)",
0x9E	:"middle dot (U+00B7)",
0x9F	:"division sign (U+00F7)",
0xA0	:"box drawings double horizontal (U+2550)",
0xA1	:"box drawings double vertical (U+2551)",
0xA2	:"box drawings down single and right double (U+2552)",
0xA3	:"cyrillic small letter io (U+0451)",
0xA4	:"cyrillic small letter ukrainian ie (U+0454)",
0xA5	:"box drawings double down and right (U+2554)",
0xA6	:"cyrillic small letter byelorussian-ukrainian i (U+0456)",
0xA7	:"cyrillic small letter yi (ukrainian) (U+0457)",
0xA8	:"box drawings double down and left (U+2557)",
0xA9	:"box drawings up single and right double (U+2558)",
0xAA	:"box drawings up double and right single (U+2559)",
0xAB	:"box drawings double up and right (U+255A)",
0xAC	:"box drawings up single and left double (U+255B)",
0xAD	:"cyrillic small letter ghe with upturn (U+0491)",
0xAE	:"box drawings double up and left (U+255D)",
0xAF	:"box drawings vertical single and right double (U+255E)",
0xB0	:"box drawings vertical double and right single (U+255F)",
0xB1	:"box drawings double vertical and right (U+2560)",
0xB2	:"box drawings vertical single and left double (U+2561)",
0xB3	:"cyrillic capital letter io (U+0401)",
0xB4	:"cyrillic capital letter ukrainian ie (U+0404)",
0xB5	:"box drawings double vertical and left (U+2563)",
0xB6	:"cyrillic capital letter byelorussian-ukrainian i (U+0406)",
0xB7	:"cyrillic capital letter yi (ukrainian) (U+0407)",
0xB8	:"box drawings double down and horizontal (U+2566)",
0xB9	:"box drawings up single and horizontal double (U+2567)",
0xBA	:"box drawings up double and horizontal single (U+2568)",
0xBB	:"box drawings double up and horizontal (U+2569)",
0xBC	:"box drawings vertical single and horizontal double (U+256A)",
0xBD	:"cyrillic capital letter ghe with upturn (U+0490)",
0xBE	:"box drawings double vertical and horizontal (U+256C)",
0xBF	:"copyright sign (U+00A9)",
0xC0	:"cyrillic small letter yu (U+044E)",
0xC1	:"cyrillic small letter a (U+0430)",
0xC2	:"cyrillic small letter be (U+0431)",
0xC3	:"cyrillic small letter tse (U+0446)",
0xC4	:"cyrillic small letter de (U+0434)",
0xC5	:"cyrillic small letter ie (U+0435)",
0xC6	:"cyrillic small letter ef (U+0444)",
0xC7	:"cyrillic small letter ghe (U+0433)",
0xC8	:"cyrillic small letter kha (U+0445)",
0xC9	:"cyrillic small letter i (U+0438)",
0xCA	:"cyrillic small letter short i (U+0439)",
0xCB	:"cyrillic small letter ka (U+043A)",
0xCC	:"cyrillic small letter el (U+043B)",
0xCD	:"cyrillic small letter em (U+043C)",
0xCE	:"cyrillic small letter en (U+043D)",
0xCF	:"cyrillic small letter o (U+043E)",
0xD0	:"cyrillic small letter pe (U+043F)",
0xD1	:"cyrillic small letter ya (U+044F)",
0xD2	:"cyrillic small letter er (U+0440)",
0xD3	:"cyrillic small letter es (U+0441)",
0xD4	:"cyrillic small letter te (U+0442)",
0xD5	:"cyrillic small letter u (U+0443)",
0xD6	:"cyrillic small letter zhe (U+0436)",
0xD7	:"cyrillic small letter ve (U+0432)",
0xD8	:"cyrillic small letter soft sign (U+044C)",
0xD9	:"cyrillic small letter yeru (U+044B)",
0xDA	:"cyrillic small letter ze (U+0437)",
0xDB	:"cyrillic small letter sha (U+0448)",
0xDC	:"cyrillic small letter e (U+044D)",
0xDD	:"cyrillic small letter shcha (U+0449)",
0xDE	:"cyrillic small letter che (U+0447)",
0xDF	:"cyrillic small letter hard sign (U+044A)",
0xE0	:"cyrillic capital letter yu (U+042E)",
0xE1	:"cyrillic capital letter a (U+0410)",
0xE2	:"cyrillic capital letter be (U+0411)",
0xE3	:"cyrillic capital letter tse (U+0426)",
0xE4	:"cyrillic capital letter de (U+0414)",
0xE5	:"cyrillic capital letter ie (U+0415)",
0xE6	:"cyrillic capital letter ef (U+0424)",
0xE7	:"cyrillic capital letter ghe (U+0413)",
0xE8	:"cyrillic capital letter kha (U+0425)",
0xE9	:"cyrillic capital letter i (U+0418)",
0xEA	:"cyrillic capital letter short i (U+0419)",
0xEB	:"cyrillic capital letter ka (U+041A)",
0xEC	:"cyrillic capital letter el (U+041B)",
0xED	:"cyrillic capital letter em (U+041C)",
0xEE	:"cyrillic capital letter en (U+041D)",
0xEF	:"cyrillic capital letter o (U+041E)",
0xF0	:"cyrillic capital letter pe (U+041F)",
0xF1	:"cyrillic capital letter ya (U+042F)",
0xF2	:"cyrillic capital letter er (U+0420)",
0xF3	:"cyrillic capital letter es (U+0421)",
0xF4	:"cyrillic capital letter te (U+0422)",
0xF5	:"cyrillic capital letter u (U+0423)",
0xF6	:"cyrillic capital letter zhe (U+0416)",
0xF7	:"cyrillic capital letter ve (U+0412)",
0xF8	:"cyrillic capital letter soft sign (U+042C)",
0xF9	:"cyrillic capital letter yeru (U+042B)",
0xFA	:"cyrillic capital letter ze (U+0417)",
0xFB	:"cyrillic capital letter sha (U+0428)",
0xFC	:"cyrillic capital letter e (U+042D)",
0xFD	:"cyrillic capital letter shcha (U+0429)",
0xFE	:"cyrillic capital letter che (U+0427)",
0xFF	:"cyrillic capital letter hard sign (U+042A)"
}

#MS-DOS CP860 (Portuguese)
msd860xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"Latin capital letter c with cedilla (U+00C7)",
0x81	:"Latin small letter u with diaeresis (U+00FC)",
0x82	:"Latin small letter e with acute (U+00E9)",
0x83	:"Latin small letter a with circumflex (U+00E2)",
0x84	:"Latin small letter a with tilde (U+00E3)",
0x85	:"Latin small letter a with grave (U+00E0)",
0x86	:"Latin capital letter a with acute (U+00C1)",
0x87	:"Latin small letter c with cedilla (U+00E7)",
0x88	:"Latin small letter e with circumflex (U+00EA)",
0x89	:"Latin capital letter e with circumflex (U+00CA)",
0x8A	:"Latin small letter e with grave (U+00E8)",
0x8B	:"Latin capital letter i with acute (U+00CD)",
0x8C	:"Latin capital letter o with circumflex (U+00D4)",
0x8D	:"Latin small letter i with grave (U+00EC)",
0x8E	:"Latin capital letter a with tilde (U+00C3)",
0x8F	:"Latin capital letter a with circumflex (U+00C2)",
0x90	:"Latin capital letter e with acute (U+00C9)",
0x91	:"Latin capital letter a with grave (U+00C0)",
0x92	:"Latin capital letter e with grave (U+00C8)",
0x93	:"Latin small letter o with circumflex (U+00F4)",
0x94	:"Latin small letter o with tilde (U+00F5)",
0x95	:"Latin small letter o with grave (U+00F2)",
0x96	:"Latin capital letter u with acute (U+00DA)",
0x97	:"Latin small letter u with grave (U+00F9)",
0x98	:"Latin capital letter i with grave (U+00CC)",
0x99	:"Latin capital letter o with tilde (U+00D5)",
0x9A	:"Latin capital letter u with diaeresis (U+00DC)",
0x9B	:"cent sign (U+00A2)",
0x9C	:"pound sign (U+00A3)",
0x9D	:"Latin capital letter u with grave (U+00D9)",
0x9E	:"peseta sign (U+20A7)",
0x9F	:"Latin capital letter o with acute (U+00D3)",
0xA0	:"Latin small letter a with acute (U+00E1)",
0xA1	:"Latin small letter i with acute (U+00ED)",
0xA2	:"Latin small letter o with acute (U+00F3)",
0xA3	:"Latin small letter u with acute (U+00FA)",
0xA4	:"Latin small letter n with tilde (U+00F1)",
0xA5	:"Latin capital letter n with tilde (U+00D1)",
0xA6	:"feminine ordinal indicator (U+00AA)",
0xA7	:"masculine ordinal indicator (U+00BA)",
0xA8	:"inverted question mark (U+00BF)",
0xA9	:"Latin capital letter o with grave (U+00D2)",
0xAA	:"not sign (U+00AC)",
0xAB	:"vulgar fraction one half (U+00BD)",
0xAC	:"vulgar fraction one quarter (U+00BC)",
0xAD	:"inverted exclamation mark (U+00A1)",
0xAE	:"left-pointing double angle quotation mark (U+00AB)",
0xAF	:"right-pointing double angle quotation mark (U+00BB)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"box drawings vertical single and left double (U+2561)",
0xB6	:"box drawings vertical double and left single (U+2562)",
0xB7	:"box drawings down double and left single (U+2556)",
0xB8	:"box drawings down single and left double (U+2555)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255D)",
0xBD	:"box drawings up double and left single (U+255C)",
0xBE	:"box drawings up single and left double (U+255B)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252C)",
0xC3	:"box drawings light vertical and right (U+251C)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253C)",
0xC6	:"box drawings vertical single and right double (U+255E)",
0xC7	:"box drawings vertical double and right single (U+255F)",
0xC8	:"box drawings double up and right (U+255A)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256C)",
0xCF	:"box drawings up single and horizontal double (U+2567)",
0xD0	:"box drawings up double and horizontal single (U+2568)",
0xD1	:"box drawings down single and horizontal double (U+2564)",
0xD2	:"box drawings down double and horizontal single (U+2565)",
0xD3	:"box drawings up double and right single (U+2559)",
0xD4	:"box drawings up single and right double (U+2558)",
0xD5	:"box drawings down single and right double (U+2552)",
0xD6	:"box drawings down double and right single (U+2553)",
0xD7	:"box drawings vertical double and horizontal single (U+256B)",
0xD8	:"box drawings vertical single and horizontal double (U+256A)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250C)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"left half block (U+258C)",
0xDE	:"right half block (U+2590)",
0xDF	:"upper half block (U+2580)",
0xE0	:"Greek small letter alpha (U+03B1)",
0xE1	:"Latin small letter sharp s (U+00DF)",
0xE2	:"Greek capital letter gamma (U+0393)",
0xE3	:"Greek small letter pi (U+03C0)",
0xE4	:"Greek capital letter sigma (U+03A3)",
0xE5	:"Greek small letter sigma (U+03C3)",
0xE6	:"micro sign (U+00B5)",
0xE7	:"Greek small letter tau (U+03C4)",
0xE8	:"Greek capital letter phi (U+03A6)",
0xE9	:"Greek capital letter theta (U+0398)",
0xEA	:"Greek capital letter omega (U+03A9)",
0xEB	:"Greek small letter delta (U+03B4)",
0xEC	:"infinity (U+221E)",
0xED	:"Greek small letter phi (U+03C6)",
0xEE	:"Greek small letter epsilon (U+03B5)",
0xEF	:"intersection (U+2229)",
0xF0	:"identical to (U+2261)",
0xF1	:"plus-minus sign (U+00B1)",
0xF2	:"greater-than or equal to (U+2265)",
0xF3	:"less-than or equal to (U+2264)",
0xF4	:"top half integral (U+2320)",
0xF5	:"bottom half integral (U+2321)",
0xF6	:"division sign (U+00F7)",
0xF7	:"almost equal to (U+2248)",
0xF8	:"degree sign (U+00B0)",
0xF9	:"bullet operator (U+2219)",
0xFA	:"middle dot (U+00B7)",
0xFB	:"square root (U+221A)",
0xFC	:"superscript Latin small letter n (U+207F)",
0xFD	:"superscript two (U+00B2)",
0xFE	:"black square (U+25A0)",
0xFF	:"no-break space (U+00A0)"
}

#MS-DOS CP861 (Icelandic/Nordic)
msd861xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"Latin capital letter c with cedilla (U+00C7)",
0x81	:"Latin small letter u with diaeresis (U+00FC)",
0x82	:"Latin small letter e with acute (U+00E9)",
0x83	:"Latin small letter a with circumflex (U+00E2)",
0x84	:"Latin small letter a with diaeresis (U+00E4)",
0x85	:"Latin small letter a with grave (U+00E0)",
0x86	:"Latin small letter a with ring above (U+00E5)",
0x87	:"Latin small letter c with cedilla (U+00E7)",
0x88	:"Latin small letter e with circumflex (U+00EA)",
0x89	:"Latin small letter e with diaeresis (U+00EB)",
0x8A	:"Latin small letter e with grave (U+00E8)",
0x8B	:"Latin capital letter eth (U+00D0)",
0x8C	:"Latin small letter eth (U+00F0)",
0x8D	:"Latin capital letter thorn (U+00DE)",
0x8E	:"Latin capital letter a with diaeresis (U+00C4)",
0x8F	:"Latin capital letter a with ring above (U+00C5)",
0x90	:"Latin capital letter e with acute (U+00C9)",
0x91	:"Latin small ligature ae (U+00E6)",
0x92	:"Latin capital ligature ae (U+00C6)",
0x93	:"Latin small letter o with circumflex (U+00F4)",
0x94	:"Latin small letter o with diaeresis (U+00F6)",
0x95	:"Latin small letter thorn (U+00FE)",
0x96	:"Latin small letter u with circumflex (U+00FB)",
0x97	:"Latin capital letter y with acute (U+00DD)",
0x98	:"Latin small letter y with acute (U+00FD)",
0x99	:"Latin capital letter o with diaeresis (U+00D6)",
0x9A	:"Latin capital letter u with diaeresis (U+00DC)",
0x9B	:"Latin small letter o with stroke (U+00F8)",
0x9C	:"pound sign (U+00A3)",
0x9D	:"Latin capital letter o with stroke (U+00D8)",
0x9E	:"peseta sign (U+20A7)",
0x9F	:"Latin small letter f with hook (U+0192)",
0xA0	:"Latin small letter a with acute (U+00E1)",
0xA1	:"Latin small letter i with acute (U+00ED)",
0xA2	:"Latin small letter o with acute (U+00F3)",
0xA3	:"Latin small letter u with acute (U+00FA)",
0xA4	:"Latin capital letter a with acute (U+00C1)",
0xA5	:"Latin capital letter i with acute (U+00CD)",
0xA6	:"Latin capital letter o with acute (U+00D3)",
0xA7	:"Latin capital letter u with acute (U+00DA)",
0xA8	:"inverted question mark (U+00BF)",
0xA9	:"reversed not sign (U+2310)",
0xAA	:"not sign (U+00AC)",
0xAB	:"vulgar fraction one half (U+00BD)",
0xAC	:"vulgar fraction one quarter (U+00BC)",
0xAD	:"inverted exclamation mark (U+00A1)",
0xAE	:"left-pointing double angle quotation mark (U+00AB)",
0xAF	:"right-pointing double angle quotation mark (U+00BB)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"box drawings vertical single and left double (U+2561)",
0xB6	:"box drawings vertical double and left single (U+2562)",
0xB7	:"box drawings down double and left single (U+2556)",
0xB8	:"box drawings down single and left double (U+2555)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255D)",
0xBD	:"box drawings up double and left single (U+255C)",
0xBE	:"box drawings up single and left double (U+255B)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252C)",
0xC3	:"box drawings light vertical and right (U+251C)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253C)",
0xC6	:"box drawings vertical single and right double (U+255E)",
0xC7	:"box drawings vertical double and right single (U+255F)",
0xC8	:"box drawings double up and right (U+255A)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256C)",
0xCF	:"box drawings up single and horizontal double (U+2567)",
0xD0	:"box drawings up double and horizontal single (U+2568)",
0xD1	:"box drawings down single and horizontal double (U+2564)",
0xD2	:"box drawings down double and horizontal single (U+2565)",
0xD3	:"box drawings up double and right single (U+2559)",
0xD4	:"box drawings up single and right double (U+2558)",
0xD5	:"box drawings down single and right double (U+2552)",
0xD6	:"box drawings down double and right single (U+2553)",
0xD7	:"box drawings vertical double and horizontal single (U+256B)",
0xD8	:"box drawings vertical single and horizontal double (U+256A)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250C)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"left half block (U+258C)",
0xDE	:"right half block (U+2590)",
0xDF	:"upper half block (U+2580)",
0xE0	:"Greek small letter alpha (U+03B1)",
0xE1	:"Latin small letter sharp s (U+00DF)",
0xE2	:"Greek capital letter gamma (U+0393)",
0xE3	:"Greek small letter pi (U+03C0)",
0xE4	:"Greek capital letter sigma (U+03A3)",
0xE5	:"Greek small letter sigma (U+03C3)",
0xE6	:"micro sign (U+00B5)",
0xE7	:"Greek small letter tau (U+03C4)",
0xE8	:"Greek capital letter phi (U+03A6)",
0xE9	:"Greek capital letter theta (U+0398)",
0xEA	:"Greek capital letter omega (U+03A9)",
0xEB	:"Greek small letter delta (U+03B4)",
0xEC	:"infinity (U+221E)",
0xED	:"Greek small letter phi (U+03C6)",
0xEE	:"Greek small letter epsilon (U+03B5)",
0xEF	:"intersection (U+2229)",
0xF0	:"identical to (U+2261)",
0xF1	:"plus-minus sign (U+00B1)",
0xF2	:"greater-than or equal to (U+2265)",
0xF3	:"less-than or equal to (U+2264)",
0xF4	:"top half integral (U+2320)",
0xF5	:"bottom half integral (U+2321)",
0xF6	:"division sign (U+00F7)",
0xF7	:"almost equal to (U+2248)",
0xF8	:"degree sign (U+00B0)",
0xF9	:"bullet operator (U+2219)",
0xFA	:"middle dot (U+00B7)",
0xFB	:"square root (U+221A)",
0xFC	:"superscript Latin small letter n (U+207F)",
0xFD	:"superscript two (U+00B2)",
0xFE	:"black square (U+25A0)",
0xFF	:"no-break space (U+00A0)"
}

#MS-DOS CP862 (Hebrew)
msd862xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"Hebrew letter alef (U+05D0)",
0x81	:"Hebrew letter bet (U+05D1)",
0x82	:"Hebrew letter gimel (U+05D2)",
0x83	:"Hebrew letter dalet (U+05D3)",
0x84	:"Hebrew letter he (U+05D4)",
0x85	:"Hebrew letter vav (U+05D5)",
0x86	:"Hebrew letter zayin (U+05D6)",
0x87	:"Hebrew letter het (U+05D7)",
0x88	:"Hebrew letter tet (U+05D8)",
0x89	:"Hebrew letter yod (U+05D9)",
0x8A	:"Hebrew letter final kaf (U+05DA)",
0x8B	:"Hebrew letter kaf (U+05DB)",
0x8C	:"Hebrew letter lamed (U+05DC)",
0x8D	:"Hebrew letter final mem (U+05DD)",
0x8E	:"Hebrew letter mem (U+05DE)",
0x8F	:"Hebrew letter final nun (U+05DF)",
0x90	:"Hebrew letter nun (U+05E0)",
0x91	:"Hebrew letter samekh (U+05E1)",
0x92	:"Hebrew letter ayin (U+05E2)",
0x93	:"Hebrew letter final pe (U+05E3)",
0x94	:"Hebrew letter pe (U+05E4)",
0x95	:"Hebrew letter final tsadi (U+05E5)",
0x96	:"Hebrew letter tsadi (U+05E6)",
0x97	:"Hebrew letter qof (U+05E7)",
0x98	:"Hebrew letter resh (U+05E8)",
0x99	:"Hebrew letter shin (U+05E9)",
0x9A	:"Hebrew letter tav (U+05EA)",
0x9B	:"cent sign (U+00A2)",
0x9C	:"pound sign (U+00A3)",
0x9D	:"yen sign (U+00A5)",
0x9E	:"peseta sign (U+20A7)",
0x9F	:"Latin small letter f with hook (U+0192)",
0xA0	:"Latin small letter a with acute (U+00E1)",
0xA1	:"Latin small letter i with acute (U+00ED)",
0xA2	:"Latin small letter o with acute (U+00F3)",
0xA3	:"Latin small letter u with acute (U+00FA)",
0xA4	:"Latin small letter n with tilde (U+00F1)",
0xA5	:"Latin capital letter n with tilde (U+00D1)",
0xA6	:"feminine ordinal indicator (U+00AA)",
0xA7	:"masculine ordinal indicator (U+00BA)",
0xA8	:"inverted question mark (U+00BF)",
0xA9	:"reversed not sign (U+2310)",
0xAA	:"not sign (U+00AC)",
0xAB	:"vulgar fraction one half (U+00BD)",
0xAC	:"vulgar fraction one quarter (U+00BC)",
0xAD	:"inverted exclamation mark (U+00A1)",
0xAE	:"left-pointing double angle quotation mark (U+00AB)",
0xAF	:"right-pointing double angle quotation mark (U+00BB)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"box drawings vertical single and left double (U+2561)",
0xB6	:"box drawings vertical double and left single (U+2562)",
0xB7	:"box drawings down double and left single (U+2556)",
0xB8	:"box drawings down single and left double (U+2555)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255D)",
0xBD	:"box drawings up double and left single (U+255C)",
0xBE	:"box drawings up single and left double (U+255B)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252C)",
0xC3	:"box drawings light vertical and right (U+251C)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253C)",
0xC6	:"box drawings vertical single and right double (U+255E)",
0xC7	:"box drawings vertical double and right single (U+255F)",
0xC8	:"box drawings double up and right (U+255A)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256C)",
0xCF	:"box drawings up single and horizontal double (U+2567)",
0xD0	:"box drawings up double and horizontal single (U+2568)",
0xD1	:"box drawings down single and horizontal double (U+2564)",
0xD2	:"box drawings down double and horizontal single (U+2565)",
0xD3	:"box drawings up double and right single (U+2559)",
0xD4	:"box drawings up single and right double (U+2558)",
0xD5	:"box drawings down single and right double (U+2552)",
0xD6	:"box drawings down double and right single (U+2553)",
0xD7	:"box drawings vertical double and horizontal single (U+256B)",
0xD8	:"box drawings vertical single and horizontal double (U+256A)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250C)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"left half block (U+258C)",
0xDE	:"right half block (U+2590)",
0xDF	:"upper half block (U+2580)",
0xE0	:"Greek small letter alpha (U+03B1)",
0xE1	:"Latin small letter sharp s (german) (U+00DF)",
0xE2	:"Greek capital letter gamma (U+0393)",
0xE3	:"Greek small letter pi (U+03C0)",
0xE4	:"Greek capital letter sigma (U+03A3)",
0xE5	:"Greek small letter sigma (U+03C3)",
0xE6	:"micro sign (U+00B5)",
0xE7	:"Greek small letter tau (U+03C4)",
0xE8	:"Greek capital letter phi (U+03A6)",
0xE9	:"Greek capital letter theta (U+0398)",
0xEA	:"Greek capital letter omega (U+03A9)",
0xEB	:"Greek small letter delta (U+03B4)",
0xEC	:"infinity (U+221E)",
0xED	:"Greek small letter phi (U+03C6)",
0xEE	:"Greek small letter epsilon (U+03B5)",
0xEF	:"intersection (U+2229)",
0xF0	:"identical to (U+2261)",
0xF1	:"plus-minus sign (U+00B1)",
0xF2	:"greater-than or equal to (U+2265)",
0xF3	:"less-than or equal to (U+2264)",
0xF4	:"top half integral (U+2320)",
0xF5	:"bottom half integral (U+2321)",
0xF6	:"division sign (U+00F7)",
0xF7	:"almost equal to (U+2248)",
0xF8	:"degree sign (U+00B0)",
0xF9	:"bullet operator (U+2219)",
0xFA	:"middle dot (U+00B7)",
0xFB	:"square root (U+221A)",
0xFC	:"superscript Latin small letter n (U+207F)",
0xFD	:"superscript two (U+00B2)",
0xFE	:"black square (U+25A0)",
0xFF	:"no-break space (U+00A0)"
}

#MS-DOS CP863 (Canadian French)
msd863xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"latin capital letter a (U+0041)",
0x42	:"latin capital letter b (U+0042)",
0x43	:"latin capital letter c (U+0043)",
0x44	:"latin capital letter d (U+0044)",
0x45	:"latin capital letter e (U+0045)",
0x46	:"latin capital letter f (U+0046)",
0x47	:"latin capital letter g (U+0047)",
0x48	:"latin capital letter h (U+0048)",
0x49	:"latin capital letter i (U+0049)",
0x4A	:"latin capital letter j (U+004A)",
0x4B	:"latin capital letter k (U+004B)",
0x4C	:"latin capital letter l (U+004C)",
0x4D	:"latin capital letter m (U+004D)",
0x4E	:"latin capital letter n (U+004E)",
0x4F	:"latin capital letter o (U+004F)",
0x50	:"latin capital letter p (U+0050)",
0x51	:"latin capital letter q (U+0051)",
0x52	:"latin capital letter r (U+0052)",
0x53	:"latin capital letter s (U+0053)",
0x54	:"latin capital letter t (U+0054)",
0x55	:"latin capital letter u (U+0055)",
0x56	:"latin capital letter v (U+0056)",
0x57	:"latin capital letter w (U+0057)",
0x58	:"latin capital letter x (U+0058)",
0x59	:"latin capital letter y (U+0059)",
0x5A	:"latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"latin small letter a (U+0061)",
0x62	:"latin small letter b (U+0062)",
0x63	:"latin small letter c (U+0063)",
0x64	:"latin small letter d (U+0064)",
0x65	:"latin small letter e (U+0065)",
0x66	:"latin small letter f (U+0066)",
0x67	:"latin small letter g (U+0067)",
0x68	:"latin small letter h (U+0068)",
0x69	:"latin small letter i (U+0069)",
0x6A	:"latin small letter j (U+006A)",
0x6B	:"latin small letter k (U+006B)",
0x6C	:"latin small letter l (U+006C)",
0x6D	:"latin small letter m (U+006D)",
0x6E	:"latin small letter n (U+006E)",
0x6F	:"latin small letter o (U+006F)",
0x70	:"latin small letter p (U+0070)",
0x71	:"latin small letter q (U+0071)",
0x72	:"latin small letter r (U+0072)",
0x73	:"latin small letter s (U+0073)",
0x74	:"latin small letter t (U+0074)",
0x75	:"latin small letter u (U+0075)",
0x76	:"latin small letter v (U+0076)",
0x77	:"latin small letter w (U+0077)",
0x78	:"latin small letter x (U+0078)",
0x79	:"latin small letter y (U+0079)",
0x7A	:"latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"latin capital letter c with cedilla (U+00C7)",
0x81	:"latin small letter u with diaeresis (U+00FC)",
0x82	:"latin small letter e with acute (U+00E9)",
0x83	:"latin small letter a with circumflex (U+00E2)",
0x84	:"latin capital letter a with circumflex (U+00C2)",
0x85	:"latin small letter a with grave (U+00E0)",
0x86	:"pilcrow sign (U+00B6)",
0x87	:"latin small letter c with cedilla (U+00E7)",
0x88	:"latin small letter e with circumflex (U+00EA)",
0x89	:"latin small letter e with diaeresis (U+00EB)",
0x8A	:"latin small letter e with grave (U+00E8)",
0x8B	:"latin small letter i with diaeresis (U+00EF)",
0x8C	:"latin small letter i with circumflex (U+00EE)",
0x8D	:"double low line (U+2017)",
0x8E	:"latin capital letter a with grave (U+00C0)",
0x8F	:"section sign (U+00A7)",
0x90	:"latin capital letter e with acute (U+00C9)",
0x91	:"latin capital letter e with grave (U+00C8)",
0x92	:"latin capital letter e with circumflex (U+00CA)",
0x93	:"latin small letter o with circumflex (U+00F4)",
0x94	:"latin capital letter e with diaeresis (U+00CB)",
0x95	:"latin capital letter i with diaeresis (U+00CF)",
0x96	:"latin small letter u with circumflex (U+00FB)",
0x97	:"latin small letter u with grave (U+00F9)",
0x98	:"currency sign (U+00A4)",
0x99	:"latin capital letter o with circumflex (U+00D4)",
0x9A	:"latin capital letter u with diaeresis (U+00DC)",
0x9B	:"cent sign (U+00A2)",
0x9C	:"pound sign (U+00A3)",
0x9D	:"latin capital letter u with grave (U+00D9)",
0x9E	:"latin capital letter u with circumflex (U+00DB)",
0x9F	:"latin small letter f with hook (U+0192)",
0xA0	:"broken bar (U+00A6)",
0xA1	:"acute accent (U+00B4)",
0xA2	:"latin small letter o with acute (U+00F3)",
0xA3	:"latin small letter u with acute (U+00FA)",
0xA4	:"diaeresis (U+00A8)",
0xA5	:"cedilla (U+00B8)",
0xA6	:"superscript three (U+00B3)",
0xA7	:"macron (U+00AF)",
0xA8	:"latin capital letter i with circumflex (U+00CE)",
0xA9	:"reversed not sign (U+2310)",
0xAA	:"not sign (U+00AC)",
0xAB	:"vulgar fraction one half (U+00BD)",
0xAC	:"vulgar fraction one quarter (U+00BC)",
0xAD	:"vulgar fraction three quarters (U+00BE)",
0xAE	:"left-pointing double angle quotation mark (U+00AB)",
0xAF	:"right-pointing double angle quotation mark (U+00BB)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"box drawings vertical single and left double (U+2561)",
0xB6	:"box drawings vertical double and left single (U+2562)",
0xB7	:"box drawings down double and left single (U+2556)",
0xB8	:"box drawings down single and left double (U+2555)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255D)",
0xBD	:"box drawings up double and left single (U+255C)",
0xBE	:"box drawings up single and left double (U+255B)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252C)",
0xC3	:"box drawings light vertical and right (U+251C)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253C)",
0xC6	:"box drawings vertical single and right double (U+255E)",
0xC7	:"box drawings vertical double and right single (U+255F)",
0xC8	:"box drawings double up and right (U+255A)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256C)",
0xCF	:"box drawings up single and horizontal double (U+2567)",
0xD0	:"box drawings up double and horizontal single (U+2568)",
0xD1	:"box drawings down single and horizontal double (U+2564)",
0xD2	:"box drawings down double and horizontal single (U+2565)",
0xD3	:"box drawings up double and right single (U+2559)",
0xD4	:"box drawings up single and right double (U+2558)",
0xD5	:"box drawings down single and right double (U+2552)",
0xD6	:"box drawings down double and right single (U+2553)",
0xD7	:"box drawings vertical double and horizontal single (U+256B)",
0xD8	:"box drawings vertical single and horizontal double (U+256A)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250C)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"left half block (U+258C)",
0xDE	:"right half block (U+2590)",
0xDF	:"upper half block (U+2580)",
0xE0	:"greek small letter alpha (U+03B1)",
0xE1	:"latin small letter sharp s (U+00DF)",
0xE2	:"greek capital letter gamma (U+0393)",
0xE3	:"greek small letter pi (U+03C0)",
0xE4	:"greek capital letter sigma (U+03A3)",
0xE5	:"greek small letter sigma (U+03C3)",
0xE6	:"micro sign (U+00B5)",
0xE7	:"greek small letter tau (U+03C4)",
0xE8	:"greek capital letter phi (U+03A6)",
0xE9	:"greek capital letter theta (U+0398)",
0xEA	:"greek capital letter omega (U+03A9)",
0xEB	:"greek small letter delta (U+03B4)",
0xEC	:"infinity (U+221E)",
0xED	:"greek small letter phi (U+03C6)",
0xEE	:"greek small letter epsilon (U+03B5)",
0xEF	:"intersection (U+2229)",
0xF0	:"identical to (U+2261)",
0xF1	:"plus-minus sign (U+00B1)",
0xF2	:"greater-than or equal to (U+2265)",
0xF3	:"less-than or equal to (U+2264)",
0xF4	:"top half integral (U+2320)",
0xF5	:"bottom half integral (U+2321)",
0xF6	:"division sign (U+00F7)",
0xF7	:"almost equal to (U+2248)",
0xF8	:"degree sign (U+00B0)",
0xF9	:"bullet operator (U+2219)",
0xFA	:"middle dot (U+00B7)",
0xFB	:"square root (U+221A)",
0xFC	:"superscript latin small letter n (U+207F)",
0xFD	:"superscript two (U+00B2)",
0xFE	:"black square (U+25A0)",
0xFF	:"no-break space (U+00A0)"
}

#MSDOS864 (Arabic) 
msd864xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"Arabic percent sign (U+066A)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"degree sign (U+00B0)",
0x81	:"middle dot (U+00B7)",
0x82	:"bullet operator (U+2219)",
0x83	:"square root (U+221A)",
0x84	:"medium shade (U+2592)",
0x85	:"forms light horizontal (U+2500)",
0x86	:"forms light vertical (U+2502)",
0x87	:"forms light vertical and horizontal (U+253C)",
0x88	:"forms light vertical and left (U+2524)",
0x89	:"forms light down and horizontal (U+252C)",
0x8A	:"forms light vertical and right (U+251C)",
0x8B	:"forms light up and horizontal (U+2534)",
0x8C	:"forms light down and left (U+2510)",
0x8D	:"forms light down and right (U+250C)",
0x8E	:"forms light up and right (U+2514)",
0x8F	:"forms light up and left (U+2518)",
0x90	:"greek small beta (U+03B2)",
0x91	:"infinity (U+221E)",
0x92	:"greek small phi (U+03C6)",
0x93	:"plus-or-minus sign (U+00B1)",
0x94	:"fraction 1/2 (U+00BD)",
0x95	:"fraction 1/4 (U+00BC)",
0x96	:"almost equal to (U+2248)",
0x97	:"left pointing guillemet (U+00AB)",
0x98	:"right pointing guillemet (U+00BB)",
0x99	:"Arabic ligature lam with alef with hamza above isolated form (U+FEF7)",
0x9A	:"Arabic ligature lam with alef with hamza above final form (U+FEF8)",
0x9B	:"Unused",
0x9C	:"Unused",
0x9D	:"Arabic ligature lam with alef isolated form (U+FEFB)",
0x9E	:"Arabic ligature lam with alef final form (U+FEFC)",
0x9F	:"Unused",
0xA0	:"non-breaking space (U+00A0)",
0xA1	:"soft hyphen (U+00AD)",
0xA2	:"Arabic letter alef with madda above final form (U+FE82)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"Arabic letter alef with hamza above final form (U+FE84)",
0xA6	:"Unused",
0xA7	:"Unused",
0xA8	:"Arabic letter alef final form (U+FE8E)",
0xA9	:"Arabic letter beh isolated form (U+FE8F)",
0xAA	:"Arabic letter teh isolated form (U+FE95)",
0xAB	:"Arabic letter theh isolated form (U+FE99)",
0xAC	:"Arabic comma (U+060C)",
0xAD	:"Arabic letter jeem isolated form (U+FE9D)",
0xAE	:"Arabic letter hah isolated form (U+FEA1)",
0xAF	:"Arabic letter khah isolated form (U+FEA5)",
0xB0	:"Arabic-indic digit zero (U+0660)",
0xB1	:"Arabic-indic digit one (U+0661)",
0xB2	:"Arabic-indic digit two (U+0662)",
0xB3	:"Arabic-indic digit three (U+0663)",
0xB4	:"Arabic-indic digit four (U+0664)",
0xB5	:"Arabic-indic digit five (U+0665)",
0xB6	:"Arabic-indic digit six (U+0666)",
0xB7	:"Arabic-indic digit seven (U+0667)",
0xB8	:"Arabic-indic digit eight (U+0668)",
0xB9	:"Arabic-indic digit nine (U+0669)",
0xBA	:"Arabic letter feh isolated form (U+FED1)",
0xBB	:"Arabic semicolon (U+061B)",
0xBC	:"Arabic letter seen isolated form (U+FEB1)",
0xBD	:"Arabic letter sheen isolated form (U+FEB5)",
0xBE	:"Arabic letter sad isolated form (U+FEB9)",
0xBF	:"Arabic question mark (U+061F)",
0xC0	:"cent sign (U+00A2)",
0xC1	:"Arabic letter hamza isolated form (U+FE80)",
0xC2	:"Arabic letter alef with madda above isolated form (U+FE81)",
0xC3	:"Arabic letter alef with hamza above isolated form (U+FE83)",
0xC4	:"Arabic letter waw with hamza above isolated form (U+FE85)",
0xC5	:"Arabic letter ain final form (U+FECA)",
0xC6	:"Arabic letter yeh with hamza above initial form (U+FE8B)",
0xC7	:"Arabic letter alef isolated form (U+FE8D)",
0xC8	:"Arabic letter beh initial form (U+FE91)",
0xC9	:"Arabic letter teh marbuta isolated form (U+FE93)",
0xCA	:"Arabic letter teh initial form (U+FE97)",
0xCB	:"Arabic letter theh initial form (U+FE9B)",
0xCC	:"Arabic letter jeem initial form (U+FE9F)",
0xCD	:"Arabic letter hah initial form (U+FEA3)",
0xCE	:"Arabic letter khah initial form (U+FEA7)",
0xCF	:"Arabic letter dal isolated form (U+FEA9)",
0xD0	:"Arabic letter thal isolated form (U+FEAB)",
0xD1	:"Arabic letter reh isolated form (U+FEAD)",
0xD2	:"Arabic letter zain isolated form (U+FEAF)",
0xD3	:"Arabic letter seen initial form (U+FEB3)",
0xD4	:"Arabic letter sheen initial form (U+FEB7)",
0xD5	:"Arabic letter sad initial form (U+FEBB)",
0xD6	:"Arabic letter dad initial form (U+FEBF)",
0xD7	:"Arabic letter tah isolated form (U+FEC1)",
0xD8	:"Arabic letter zah isolated form (U+FEC5)",
0xD9	:"Arabic letter ain initial form (U+FECB)",
0xDA	:"Arabic letter ghain initial form (U+FECF)",
0xDB	:"broken vertical bar (U+00A6)",
0xDC	:"not sign (U+00AC)",
0xDD	:"division sign (U+00F7)",
0xDE	:"multiplication sign (U+00D7)",
0xDF	:"Arabic letter ain isolated form (U+FEC9)",
0xE0	:"Arabic tatweel (U+0640)",
0xE1	:"Arabic letter feh initial form (U+FED3)",
0xE2	:"Arabic letter qaf initial form (U+FED7)",
0xE3	:"Arabic letter kaf initial form (U+FEDB)",
0xE4	:"Arabic letter lam initial form (U+FEDF)",
0xE5	:"Arabic letter meem initial form (U+FEE3)",
0xE6	:"Arabic letter noon initial form (U+FEE7)",
0xE7	:"Arabic letter heh initial form (U+FEEB)",
0xE8	:"Arabic letter waw isolated form (U+FEED)",
0xE9	:"Arabic letter alef maksura isolated form (U+FEEF)",
0xEA	:"Arabic letter yeh initial form (U+FEF3)",
0xEB	:"Arabic letter dad isolated form (U+FEBD)",
0xEC	:"Arabic letter ain medial form (U+FECC)",
0xED	:"Arabic letter ghain final form (U+FECE)",
0xEE	:"Arabic letter ghain isolated form (U+FECD)",
0xEF	:"Arabic letter meem isolated form (U+FEE1)",
0xF0	:"Arabic shadda medial form (U+FE7D)",
0xF1	:"Arabic shaddah (U+0651)",
0xF2	:"Arabic letter noon isolated form (U+FEE5)",
0xF3	:"Arabic letter heh isolated form (U+FEE9)",
0xF4	:"Arabic letter heh medial form (U+FEEC)",
0xF5	:"Arabic letter alef maksura final form (U+FEF0)",
0xF6	:"Arabic letter yeh final form (U+FEF2)",
0xF7	:"Arabic letter ghain medial form (U+FED0)",
0xF8	:"Arabic letter qaf isolated form (U+FED5)",
0xF9	:"Arabic ligature lam with alef with madda above isolated form (U+FEF5)",
0xFA	:"Arabic ligature lam with alef with madda above final form (U+FEF6)",
0xFB	:"Arabic letter lam isolated form (U+FEDD)",
0xFC	:"Arabic letter kaf isolated form (U+FED9)",
0xFD	:"Arabic letter yeh isolated form (U+FEF1)",
0xFE	:"black square (U+25A0)",
0xFF	:"Unused"
}

#MS-DOS CP865
msd865xtbl={\
0x00	:"NUL (ASCII control character)",
0x01	:"SOH (ASCII control character)",
0x02	:"STX (ASCII control character)",
0x03	:"ETX (ASCII control character)",
0x04	:"EOT (ASCII control character)",
0x05	:"ENQ (ASCII control character)",
0x06	:"ACK (ASCII control character)",
0x07	:"BEL (ASCII control character)",
0x08	:"Backspace (ASCII control character)",
0x09	:"Tab (ASCII control character)",
0x0a	:"Newline",
0x0b	:"VT (ASCII control character)",
0x0c	:"FF (ASCII control character)",
0x0d	:"Carriage return",
0x0e	:"SO (ASCII control character)",
0x0f	:"SI (ASCII control character)",
0x10	:"DLE (ASCII control character)",
0x11	:"DC1 (ASCII control character)",
0x12	:"DC2 (ASCII control character)",
0x13	:"DC3 (ASCII control character)",
0x14	:"DC4 (ASCII control character)",
0x15	:"NAK (ASCII control character)",
0x16	:"SYN (ASCII control character)",
0x17	:"ETB (ASCII control character)",
0x18	:"CAN (ASCII control character)",
0x19	:"EM (ASCII control character)",
0x1a	:"SUB (ASCII control character)",
0x1b	:"ESC (ASCII control character)",
0x1c	:"FS (ASCII control character)",
0x1d	:"GS (ASCII control character)",
0x1e	:"RS (ASCII control character)",
0x1f	:"US (ASCII control character)",
0x20	:"Space",
0x21	:"Exclamation point",
0x22	:"Double quote",
0x23	:"Pound sign",
0x24	:"Dollar sign",
0x25	:"Percent sign",
0x26	:"Ampersand",
0x27	:"Right single quote / apostrophe",
0x28	:"Left parenthesis",
0x29	:"Right parenthesis",
0x2a	:"Asterisk",
0x2b	:"Plus",
0x2c	:"Comma",
0x2d	:"Hyphen",
0x2e	:"Period",
0x2f	:"Slash",
0x30	:"Latin digit 0",
0x31	:"Latin digit 1",
0x32	:"Latin digit 2",
0x33	:"Latin digit 3",
0x34	:"Latin digit 4",
0x35	:"Latin digit 5",
0x36	:"Latin digit 6",
0x37	:"Latin digit 7",
0x38	:"Latin digit 8",
0x39	:"Latin digit 9",
0x3a	:"Colon",
0x3b	:"Semi-colon",
0x3c	:"Less-than",
0x3d	:"Equal-sign",
0x3e	:"Greater-than",
0x3f	:"Question mark",
0x40	:"At-sign",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5b	:"Left square bracket",
0x5c	:"Backslash",
0x5d	:"Right square bracket",
0x5e	:"Caret",
0x5f	:"Underscore",
0x60	:"Left single quote",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7b	:"Left curly bracket",
0x7c	:"Pipe",
0x7d	:"Right curly bracket",
0x7e	:"Tilde",
0x7f	:"DEL",
0x80	:"Latin capital letter c with cedilla (U+00c7)",
0x81	:"Latin small letter u with diaeresis (U+00fc)",
0x82	:"Latin small letter e with acute (U+00e9)",
0x83	:"Latin small letter a with circumflex (U+00e2)",
0x84	:"Latin small letter a with diaeresis (U+00e4)",
0x85	:"Latin small letter a with grave (U+00e0)",
0x86	:"Latin small letter a with ring above (U+00e5)",
0x87	:"Latin small letter c with cedilla (U+00e7)",
0x88	:"Latin small letter e with circumflex (U+00ea)",
0x89	:"Latin small letter e with diaeresis (U+00eb)",
0x8A	:"Latin small letter e with grave (U+00e8)",
0x8B	:"Latin small letter i with diaeresis (U+00ef)",
0x8C	:"Latin small letter i with circumflex (U+00ee)",
0x8D	:"Latin small letter i with grave (U+00ec)",
0x8E	:"Latin capital letter a with diaeresis (U+00c4)",
0x8F	:"Latin capital letter a with ring above (U+00c5)",
0x90	:"Latin capital letter e with acute (U+00c9)",
0x91	:"Latin small ligature ae (U+00e6)",
0x92	:"Latin capital ligature ae (U+00c6)",
0x93	:"Latin small letter o with circumflex (U+00f4)",
0x94	:"Latin small letter o with diaeresis (U+00f6)",
0x95	:"Latin small letter o with grave (U+00f2)",
0x96	:"Latin small letter u with circumflex (U+00fb)",
0x97	:"Latin small letter u with grave (U+00f9)",
0x98	:"Latin small letter y with diaeresis (U+00ff)",
0x99	:"Latin capital letter o with diaeresis (U+00d6)",
0x9A	:"Latin capital letter u with diaeresis (U+00dc)",
0x9B	:"Latin small letter o with stroke (U+00f8)",
0x9C	:"pound sign (U+00a3)",
0x9D	:"Latin capital letter o with stroke (U+00d8)",
0x9E	:"peseta sign (U+20a7)",
0x9F	:"Latin small letter f with hook (U+0192)",
0xA0	:"Latin small letter a with acute (U+00e1)",
0xA1	:"Latin small letter i with acute (U+00ed)",
0xA2	:"Latin small letter o with acute (U+00f3)",
0xA3	:"Latin small letter u with acute (U+00fa)",
0xA4	:"Latin small letter n with tilde (U+00f1)",
0xA5	:"Latin capital letter n with tilde (U+00d1)",
0xA6	:"feminine ordinal indicator (U+00aa)",
0xA7	:"masculine ordinal indicator (U+00ba)",
0xA8	:"inverted question mark (U+00bf)",
0xA9	:"reversed not sign (U+2310)",
0xAA	:"not sign (U+00ac)",
0xAB	:"vulgar fraction one half (U+00bd)",
0xAC	:"vulgar fraction one quarter (U+00bc)",
0xAD	:"inverted exclamation mark (U+00a1)",
0xAE	:"left-pointing double angle quotation mark (U+00ab)",
0xAF	:"currency sign (U+00a4)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"box drawings vertical single and left double (U+2561)",
0xB6	:"box drawings vertical double and left single (U+2562)",
0xB7	:"box drawings down double and left single (U+2556)",
0xB8	:"box drawings down single and left double (U+2555)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255d)",
0xBD	:"box drawings up double and left single (U+255c)",
0xBE	:"box drawings up single and left double (U+255b)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252c)",
0xC3	:"box drawings light vertical and right (U+251c)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253c)",
0xC6	:"box drawings vertical single and right double (U+255e)",
0xC7	:"box drawings vertical double and right single (U+255f)",
0xC8	:"box drawings double up and right (U+255a)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256c)",
0xCF	:"box drawings up single and horizontal double (U+2567)",
0xD0	:"box drawings up double and horizontal single (U+2568)",
0xD1	:"box drawings down single and horizontal double (U+2564)",
0xD2	:"box drawings down double and horizontal single (U+2565)",
0xD3	:"box drawings up double and right single (U+2559)",
0xD4	:"box drawings up single and right double (U+2558)",
0xD5	:"box drawings down single and right double (U+2552)",
0xD6	:"box drawings down double and right single (U+2553)",
0xD7	:"box drawings vertical double and horizontal single (U+256b)",
0xD8	:"box drawings vertical single and horizontal double (U+256a)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250c)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"left half block (U+258c)",
0xDE	:"right half block (U+2590)",
0xDF	:"upper half block (U+2580)",
0xE0	:"greek small letter alpha (U+03b1)",
0xE1	:"Latin small letter sharp s (U+00df)",
0xE2	:"greek capital letter gamma (U+0393)",
0xE3	:"greek small letter pi (U+03c0)",
0xE4	:"greek capital letter sigma (U+03a3)",
0xE5	:"greek small letter sigma (U+03c3)",
0xE6	:"micro sign (U+00b5)",
0xE7	:"greek small letter tau (U+03c4)",
0xE8	:"greek capital letter phi (U+03a6)",
0xE9	:"greek capital letter theta (U+0398)",
0xEA	:"greek capital letter omega (U+03a9)",
0xEB	:"greek small letter delta (U+03b4)",
0xEC	:"infinity (U+221e)",
0xED	:"greek small letter phi (U+03c6)",
0xEE	:"greek small letter epsilon (U+03b5)",
0xEF	:"intersection (U+2229)",
0xF0	:"identical to (U+2261)",
0xF1	:"plus-minus sign (U+00b1)",
0xF2	:"greater-than or equal to (U+2265)",
0xF3	:"less-than or equal to (U+2264)",
0xF4	:"top half integral (U+2320)",
0xF5	:"bottom half integral (U+2321)",
0xF6	:"division sign (U+00f7)",
0xF7	:"almost equal to (U+2248)",
0xF8	:"degree sign (U+00b0)",
0xF9	:"bullet operator (U+2219)",
0xFA	:"middle dot (U+00b7)",
0xFB	:"square root (U+221a)",
0xFC	:"superscript Latin small letter n (U+207f)",
0xFD	:"superscript two (U+00b2)",
0xFE	:"black square (U+25a0)",
0xFF	:"no-break space (U+00a0)"
}


#MS-DOS CP866 cyrillic
msd866xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000a)",
0x0B	:"vertical tabulation (U+000b)",
0x0C	:"form feed (U+000c)",
0x0D	:"carriage return (U+000d)",
0x0E	:"shift out (U+000e)",
0x0F	:"shift in (U+000f)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001a)",
0x1B	:"escape (U+001b)",
0x1C	:"file separator (U+001c)",
0x1D	:"group separator (U+001d)",
0x1E	:"record separator (U+001e)",
0x1F	:"unit separator (U+001f)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002a)",
0x2B	:"plus sign (U+002b)",
0x2C	:"comma (U+002c)",
0x2D	:"hyphen-minus (U+002d)",
0x2E	:"full stop (U+002e)",
0x2F	:"solidus (U+002f)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003a)",
0x3B	:"semicolon (U+003b)",
0x3C	:"less-than sign (U+003c)",
0x3D	:"equals sign (U+003d)",
0x3E	:"greater-than sign (U+003e)",
0x3F	:"question mark (U+003f)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004a)",
0x4B	:"Latin capital letter k (U+004b)",
0x4C	:"Latin capital letter l (U+004c)",
0x4D	:"Latin capital letter m (U+004d)",
0x4E	:"Latin capital letter n (U+004e)",
0x4F	:"Latin capital letter o (U+004f)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005a)",
0x5B	:"left square bracket (U+005b)",
0x5C	:"reverse solidus (U+005c)",
0x5D	:"right square bracket (U+005d)",
0x5E	:"circumflex accent (U+005e)",
0x5F	:"low line (U+005f)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006a)",
0x6B	:"Latin small letter k (U+006b)",
0x6C	:"Latin small letter l (U+006c)",
0x6D	:"Latin small letter m (U+006d)",
0x6E	:"Latin small letter n (U+006e)",
0x6F	:"Latin small letter o (U+006f)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007a)",
0x7B	:"left curly bracket (U+007b)",
0x7C	:"vertical line (U+007c)",
0x7D	:"right curly bracket (U+007d)",
0x7E	:"tilde (U+007e)",
0x7F	:"delete (U+007f)",
0x80	:"cyrillic capital letter a (U+0410)",
0x81	:"cyrillic capital letter be (U+0411)",
0x82	:"cyrillic capital letter ve (U+0412)",
0x83	:"cyrillic capital letter ghe (U+0413)",
0x84	:"cyrillic capital letter de (U+0414)",
0x85	:"cyrillic capital letter ie (U+0415)",
0x86	:"cyrillic capital letter zhe (U+0416)",
0x87	:"cyrillic capital letter ze (U+0417)",
0x88	:"cyrillic capital letter i (U+0418)",
0x89	:"cyrillic capital letter short i (U+0419)",
0x8A	:"cyrillic capital letter ka (U+041a)",
0x8B	:"cyrillic capital letter el (U+041b)",
0x8C	:"cyrillic capital letter em (U+041c)",
0x8D	:"cyrillic capital letter en (U+041d)",
0x8E	:"cyrillic capital letter o (U+041e)",
0x8F	:"cyrillic capital letter pe (U+041f)",
0x90	:"cyrillic capital letter er (U+0420)",
0x91	:"cyrillic capital letter es (U+0421)",
0x92	:"cyrillic capital letter te (U+0422)",
0x93	:"cyrillic capital letter u (U+0423)",
0x94	:"cyrillic capital letter ef (U+0424)",
0x95	:"cyrillic capital letter ha (U+0425)",
0x96	:"cyrillic capital letter tse (U+0426)",
0x97	:"cyrillic capital letter che (U+0427)",
0x98	:"cyrillic capital letter sha (U+0428)",
0x99	:"cyrillic capital letter shcha (U+0429)",
0x9A	:"cyrillic capital letter hard sign (U+042a)",
0x9B	:"cyrillic capital letter yeru (U+042b)",
0x9C	:"cyrillic capital letter soft sign (U+042c)",
0x9D	:"cyrillic capital letter e (U+042d)",
0x9E	:"cyrillic capital letter yu (U+042e)",
0x9F	:"cyrillic capital letter ya (U+042f)",
0xA0	:"cyrillic small letter a (U+0430)",
0xA1	:"cyrillic small letter be (U+0431)",
0xA2	:"cyrillic small letter ve (U+0432)",
0xA3	:"cyrillic small letter ghe (U+0433)",
0xA4	:"cyrillic small letter de (U+0434)",
0xA5	:"cyrillic small letter ie (U+0435)",
0xA6	:"cyrillic small letter zhe (U+0436)",
0xA7	:"cyrillic small letter ze (U+0437)",
0xA8	:"cyrillic small letter i (U+0438)",
0xA9	:"cyrillic small letter short i (U+0439)",
0xAA	:"cyrillic small letter ka (U+043a)",
0xAB	:"cyrillic small letter el (U+043b)",
0xAC	:"cyrillic small letter em (U+043c)",
0xAD	:"cyrillic small letter en (U+043d)",
0xAE	:"cyrillic small letter o (U+043e)",
0xAF	:"cyrillic small letter pe (U+043f)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"box drawings vertical single and left double (U+2561)",
0xB6	:"box drawings vertical double and left single (U+2562)",
0xB7	:"box drawings down double and left single (U+2556)",
0xB8	:"box drawings down single and left double (U+2555)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255d)",
0xBD	:"box drawings up double and left single (U+255c)",
0xBE	:"box drawings up single and left double (U+255b)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252c)",
0xC3	:"box drawings light vertical and right (U+251c)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253c)",
0xC6	:"box drawings vertical single and right double (U+255e)",
0xC7	:"box drawings vertical double and right single (U+255f)",
0xC8	:"box drawings double up and right (U+255a)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256c)",
0xCF	:"box drawings up single and horizontal double (U+2567)",
0xD0	:"box drawings up double and horizontal single (U+2568)",
0xD1	:"box drawings down single and horizontal double (U+2564)",
0xD2	:"box drawings down double and horizontal single (U+2565)",
0xD3	:"box drawings up double and right single (U+2559)",
0xD4	:"box drawings up single and right double (U+2558)",
0xD5	:"box drawings down single and right double (U+2552)",
0xD6	:"box drawings down double and right single (U+2553)",
0xD7	:"box drawings vertical double and horizontal single (U+256b)",
0xD8	:"box drawings vertical single and horizontal double (U+256a)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250c)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"left half block (U+258c)",
0xDE	:"right half block (U+2590)",
0xDF	:"upper half block (U+2580)",
0xE0	:"cyrillic small letter er (U+0440)",
0xE1	:"cyrillic small letter es (U+0441)",
0xE2	:"cyrillic small letter te (U+0442)",
0xE3	:"cyrillic small letter u (U+0443)",
0xE4	:"cyrillic small letter ef (U+0444)",
0xE5	:"cyrillic small letter ha (U+0445)",
0xE6	:"cyrillic small letter tse (U+0446)",
0xE7	:"cyrillic small letter che (U+0447)",
0xE8	:"cyrillic small letter sha (U+0448)",
0xE9	:"cyrillic small letter shcha (U+0449)",
0xEA	:"cyrillic small letter hard sign (U+044a)",
0xEB	:"cyrillic small letter yeru (U+044b)",
0xEC	:"cyrillic small letter soft sign (U+044c)",
0xED	:"cyrillic small letter e (U+044d)",
0xEE	:"cyrillic small letter yu (U+044e)",
0xEF	:"cyrillic small letter ya (U+044f)",
0xF0	:"cyrillic capital letter io (U+0401)",
0xF1	:"cyrillic small letter io (U+0451)",
0xF2	:"cyrillic capital letter ukrainian ie (U+0404)",
0xF3	:"cyrillic small letter ukrainian ie (U+0454)",
0xF4	:"cyrillic capital letter yi (U+0407)",
0xF5	:"cyrillic small letter yi (U+0457)",
0xF6	:"cyrillic capital letter short u (U+040e)",
0xF7	:"cyrillic small letter short u (U+045e)",
0xF8	:"degree sign (U+00b0)",
0xF9	:"bullet operator (U+2219)",
0xFA	:"middle dot (U+00b7)",
0xFB	:"square root (U+221a)",
0xFC	:"numero sign (U+2116)",
0xFD	:"currency sign (U+00a4)",
0xFE	:"black square (U+25a0)",
0xFF	:"no-break space (U+00a0)"
}

#MS WINDOWS CP875 IBM Greek
msw875xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"control (U+009C)",
0x05	:"horizontal tabulation (U+0009)",
0x06	:"control (U+0086)",
0x07	:"delete (U+007F)",
0x08	:"control (U+0097)",
0x09	:"control (U+008D)",
0x0A	:"control (U+008E)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"control (U+009D)",
0x15	:"control (U+0085)",
0x16	:"backspace (U+0008)",
0x17	:"control (U+0087)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"control (U+0092)",
0x1B	:"control (U+008F)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"control (U+0080)",
0x21	:"control (U+0081)",
0x22	:"control (U+0082)",
0x23	:"control (U+0083)",
0x24	:"control (U+0084)",
0x25	:"line feed (U+000A)",
0x26	:"end of transmission block (U+0017)",
0x27	:"escape (U+001B)",
0x28	:"control (U+0088)",
0x29	:"control (U+0089)",
0x2A	:"control (U+008A)",
0x2B	:"control (U+008B)",
0x2C	:"control (U+008C)",
0x2D	:"enquiry (U+0005)",
0x2E	:"acknowledge (U+0006)",
0x2F	:"bell (U+0007)",
0x30	:"control (U+0090)",
0x31	:"control (U+0091)",
0x32	:"synchronous idle (U+0016)",
0x33	:"control (U+0093)",
0x34	:"control (U+0094)",
0x35	:"control (U+0095)",
0x36	:"control (U+0096)",
0x37	:"end of transmission (U+0004)",
0x38	:"control (U+0098)",
0x39	:"control (U+0099)",
0x3A	:"control (U+009A)",
0x3B	:"control (U+009B)",
0x3C	:"device control four (U+0014)",
0x3D	:"negative acknowledge (U+0015)",
0x3E	:"control (U+009E)",
0x3F	:"substitute (U+001A)",
0x40	:"space (U+0020)",
0x41	:"Greek capital letter alpha (U+0391)",
0x42	:"Greek capital letter beta (U+0392)",
0x43	:"Greek capital letter gamma (U+0393)",
0x44	:"Greek capital letter delta (U+0394)",
0x45	:"Greek capital letter epsilon (U+0395)",
0x46	:"Greek capital letter zeta (U+0396)",
0x47	:"Greek capital letter eta (U+0397)",
0x48	:"Greek capital letter theta (U+0398)",
0x49	:"Greek capital letter iota (U+0399)",
0x4A	:"left square bracket (U+005B)",
0x4B	:"full stop (U+002E)",
0x4C	:"less-than sign (U+003C)",
0x4D	:"left parenthesis (U+0028)",
0x4E	:"plus sign (U+002B)",
0x4F	:"exclamation mark (U+0021)",
0x50	:"ampersand (U+0026)",
0x51	:"Greek capital letter kappa (U+039A)",
0x52	:"Greek capital letter lamda (U+039B)",
0x53	:"Greek capital letter mu (U+039C)",
0x54	:"Greek capital letter nu (U+039D)",
0x55	:"Greek capital letter xi (U+039E)",
0x56	:"Greek capital letter omicron (U+039F)",
0x57	:"Greek capital letter pi (U+03A0)",
0x58	:"Greek capital letter rho (U+03A1)",
0x59	:"Greek capital letter sigma (U+03A3)",
0x5A	:"right square bracket (U+005D)",
0x5B	:"dollar sign (U+0024)",
0x5C	:"asterisk (U+002A)",
0x5D	:"right parenthesis (U+0029)",
0x5E	:"semicolon (U+003B)",
0x5F	:"circumflex accent (U+005E)",
0x60	:"hyphen-minus (U+002D)",
0x61	:"solidus (U+002F)",
0x62	:"Greek capital letter tau (U+03A4)",
0x63	:"Greek capital letter upsilon (U+03A5)",
0x64	:"Greek capital letter phi (U+03A6)",
0x65	:"Greek capital letter chi (U+03A7)",
0x66	:"Greek capital letter psi (U+03A8)",
0x67	:"Greek capital letter omega (U+03A9)",
0x68	:"Greek capital letter iota with dialytika (U+03AA)",
0x69	:"Greek capital letter upsilon with dialytika (U+03AB)",
0x6A	:"vertical line (U+007C)",
0x6B	:"comma (U+002C)",
0x6C	:"percent sign (U+0025)",
0x6D	:"low line (U+005F)",
0x6E	:"greater-than sign (U+003E)",
0x6F	:"question mark (U+003F)",
0x70	:"diaeresis (U+00A8)",
0x71	:"Greek capital letter alpha with tonos (U+0386)",
0x72	:"Greek capital letter epsilon with tonos (U+0388)",
0x73	:"Greek capital letter eta with tonos (U+0389)",
0x74	:"no-break space (U+00A0)",
0x75	:"Greek capital letter iota with tonos (U+038A)",
0x76	:"Greek capital letter omicron with tonos (U+038C)",
0x77	:"Greek capital letter upsilon with tonos (U+038E)",
0x78	:"Greek capital letter omega with tonos (U+038F)",
0x79	:"grave accent (U+0060)",
0x7A	:"colon (U+003A)",
0x7B	:"number sign (U+0023)",
0x7C	:"commercial at (U+0040)",
0x7D	:"apostrophe (U+0027)",
0x7E	:"equals sign (U+003D)",
0x7F	:"quotation mark (U+0022)",
0x80	:"Greek dialytika tonos (U+0385)",
0x81	:"Latin small letter a (U+0061)",
0x82	:"Latin small letter b (U+0062)",
0x83	:"Latin small letter c (U+0063)",
0x84	:"Latin small letter d (U+0064)",
0x85	:"Latin small letter e (U+0065)",
0x86	:"Latin small letter f (U+0066)",
0x87	:"Latin small letter g (U+0067)",
0x88	:"Latin small letter h (U+0068)",
0x89	:"Latin small letter i (U+0069)",
0x8A	:"Greek small letter alpha (U+03B1)",
0x8B	:"Greek small letter beta (U+03B2)",
0x8C	:"Greek small letter gamma (U+03B3)",
0x8D	:"Greek small letter delta (U+03B4)",
0x8E	:"Greek small letter epsilon (U+03B5)",
0x8F	:"Greek small letter zeta (U+03B6)",
0x90	:"degree sign (U+00B0)",
0x91	:"Latin small letter j (U+006A)",
0x92	:"Latin small letter k (U+006B)",
0x93	:"Latin small letter l (U+006C)",
0x94	:"Latin small letter m (U+006D)",
0x95	:"Latin small letter n (U+006E)",
0x96	:"Latin small letter o (U+006F)",
0x97	:"Latin small letter p (U+0070)",
0x98	:"Latin small letter q (U+0071)",
0x99	:"Latin small letter r (U+0072)",
0x9A	:"Greek small letter eta (U+03B7)",
0x9B	:"Greek small letter theta (U+03B8)",
0x9C	:"Greek small letter iota (U+03B9)",
0x9D	:"Greek small letter kappa (U+03BA)",
0x9E	:"Greek small letter lamda (U+03BB)",
0x9F	:"Greek small letter mu (U+03BC)",
0xA0	:"acute accent (U+00B4)",
0xA1	:"tilde (U+007E)",
0xA2	:"Latin small letter s (U+0073)",
0xA3	:"Latin small letter t (U+0074)",
0xA4	:"Latin small letter u (U+0075)",
0xA5	:"Latin small letter v (U+0076)",
0xA6	:"Latin small letter w (U+0077)",
0xA7	:"Latin small letter x (U+0078)",
0xA8	:"Latin small letter y (U+0079)",
0xA9	:"Latin small letter z (U+007A)",
0xAA	:"Greek small letter nu (U+03BD)",
0xAB	:"Greek small letter xi (U+03BE)",
0xAC	:"Greek small letter omicron (U+03BF)",
0xAD	:"Greek small letter pi (U+03C0)",
0xAE	:"Greek small letter rho (U+03C1)",
0xAF	:"Greek small letter sigma (U+03C3)",
0xB0	:"pound sign (U+00A3)",
0xB1	:"Greek small letter alpha with tonos (U+03AC)",
0xB2	:"Greek small letter epsilon with tonos (U+03AD)",
0xB3	:"Greek small letter eta with tonos (U+03AE)",
0xB4	:"Greek small letter iota with dialytika (U+03CA)",
0xB5	:"Greek small letter iota with tonos (U+03AF)",
0xB6	:"Greek small letter omicron with tonos (U+03CC)",
0xB7	:"Greek small letter upsilon with tonos (U+03CD)",
0xB8	:"Greek small letter upsilon with dialytika (U+03CB)",
0xB9	:"Greek small letter omega with tonos (U+03CE)",
0xBA	:"Greek small letter final sigma (U+03C2)",
0xBB	:"Greek small letter tau (U+03C4)",
0xBC	:"Greek small letter upsilon (U+03C5)",
0xBD	:"Greek small letter phi (U+03C6)",
0xBE	:"Greek small letter chi (U+03C7)",
0xBF	:"Greek small letter psi (U+03C8)",
0xC0	:"left curly bracket (U+007B)",
0xC1	:"Latin capital letter a (U+0041)",
0xC2	:"Latin capital letter b (U+0042)",
0xC3	:"Latin capital letter c (U+0043)",
0xC4	:"Latin capital letter d (U+0044)",
0xC5	:"Latin capital letter e (U+0045)",
0xC6	:"Latin capital letter f (U+0046)",
0xC7	:"Latin capital letter g (U+0047)",
0xC8	:"Latin capital letter h (U+0048)",
0xC9	:"Latin capital letter i (U+0049)",
0xCA	:"soft hyphen (U+00AD)",
0xCB	:"Greek small letter omega (U+03C9)",
0xCC	:"Greek small letter iota with dialytika and tonos (U+0390)",
0xCD	:"Greek small letter upsilon with dialytika and tonos (U+03B0)",
0xCE	:"left single quotation mark (U+2018)",
0xCF	:"horizontal bar (U+2015)",
0xD0	:"right curly bracket (U+007D)",
0xD1	:"Latin capital letter j (U+004A)",
0xD2	:"Latin capital letter k (U+004B)",
0xD3	:"Latin capital letter l (U+004C)",
0xD4	:"Latin capital letter m (U+004D)",
0xD5	:"Latin capital letter n (U+004E)",
0xD6	:"Latin capital letter o (U+004F)",
0xD7	:"Latin capital letter p (U+0050)",
0xD8	:"Latin capital letter q (U+0051)",
0xD9	:"Latin capital letter r (U+0052)",
0xDA	:"plus-minus sign (U+00B1)",
0xDB	:"vulgar fraction one half (U+00BD)",
0xDC	:"substitute (U+001A)",
0xDD	:"Greek ano teleia (U+0387)",
0xDE	:"right single quotation mark (U+2019)",
0xDF	:"broken bar (U+00A6)",
0xE0	:"reverse solidus (U+005C)",
0xE1	:"substitute (U+001A)",
0xE2	:"Latin capital letter s (U+0053)",
0xE3	:"Latin capital letter t (U+0054)",
0xE4	:"Latin capital letter u (U+0055)",
0xE5	:"Latin capital letter v (U+0056)",
0xE6	:"Latin capital letter w (U+0057)",
0xE7	:"Latin capital letter x (U+0058)",
0xE8	:"Latin capital letter y (U+0059)",
0xE9	:"Latin capital letter z (U+005A)",
0xEA	:"superscript two (U+00B2)",
0xEB	:"section sign (U+00A7)",
0xEC	:"substitute (U+001A)",
0xED	:"substitute (U+001A)",
0xEE	:"left-pointing double angle quotation mark (U+00AB)",
0xEF	:"not sign (U+00AC)",
0xF0	:"digit zero (U+0030)",
0xF1	:"digit one (U+0031)",
0xF2	:"digit two (U+0032)",
0xF3	:"digit three (U+0033)",
0xF4	:"digit four (U+0034)",
0xF5	:"digit five (U+0035)",
0xF6	:"digit six (U+0036)",
0xF7	:"digit seven (U+0037)",
0xF8	:"digit eight (U+0038)",
0xF9	:"digit nine (U+0039)",
0xFA	:"superscript three (U+00B3)",
0xFB	:"copyright sign (U+00A9)",
0xFC	:"substitute (U+001A)",
0xFD	:"substitute (U+001A)",
0xFE	:"right-pointing double angle quotation mark (U+00BB)",
0xFF	:"control (U+009F)"
}

#MS-DOS CP869 Modern Greek
msd869xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"undefined (U+)",
0x81	:"undefined (U+)",
0x82	:"undefined (U+)",
0x83	:"undefined (U+)",
0x84	:"undefined (U+)",
0x85	:"undefined (U+)",
0x86	:"Greek capital letter alpha with tonos (U+0386)",
0x87	:"undefined (U+)",
0x88	:"middle dot (U+00B7)",
0x89	:"not sign (U+00AC)",
0x8A	:"broken bar (U+00A6)",
0x8B	:"left single quotation mark (U+2018)",
0x8C	:"right single quotation mark (U+2019)",
0x8D	:"Greek capital letter epsilon with tonos (U+0388)",
0x8E	:"horizontal bar (U+2015)",
0x8F	:"Greek capital letter eta with tonos (U+0389)",
0x90	:"Greek capital letter iota with tonos (U+038A)",
0x91	:"Greek capital letter iota with dialytika (U+03AA)",
0x92	:"Greek capital letter omicron with tonos (U+038C)",
0x93	:"undefined (U+)",
0x94	:"undefined (U+)",
0x95	:"Greek capital letter upsilon with tonos (U+038E)",
0x96	:"Greek capital letter upsilon with dialytika (U+03AB)",
0x97	:"copyright sign (U+00A9)",
0x98	:"Greek capital letter omega with tonos (U+038F)",
0x99	:"superscript two (U+00B2)",
0x9A	:"superscript three (U+00B3)",
0x9B	:"Greek small letter alpha with tonos (U+03AC)",
0x9C	:"pound sign (U+00A3)",
0x9D	:"Greek small letter epsilon with tonos (U+03AD)",
0x9E	:"Greek small letter eta with tonos (U+03AE)",
0x9F	:"Greek small letter iota with tonos (U+03AF)",
0xA0	:"Greek small letter iota with dialytika (U+03CA)",
0xA1	:"Greek small letter iota with dialytika and tonos (U+0390)",
0xA2	:"Greek small letter omicron with tonos (U+03CC)",
0xA3	:"Greek small letter upsilon with tonos (U+03CD)",
0xA4	:"Greek capital letter alpha (U+0391)",
0xA5	:"Greek capital letter beta (U+0392)",
0xA6	:"Greek capital letter gamma (U+0393)",
0xA7	:"Greek capital letter delta (U+0394)",
0xA8	:"Greek capital letter epsilon (U+0395)",
0xA9	:"Greek capital letter zeta (U+0396)",
0xAA	:"Greek capital letter eta (U+0397)",
0xAB	:"vulgar fraction one half (U+00BD)",
0xAC	:"Greek capital letter theta (U+0398)",
0xAD	:"Greek capital letter iota (U+0399)",
0xAE	:"left-pointing double angle quotation mark (U+00AB)",
0xAF	:"right-pointing double angle quotation mark (U+00BB)",
0xB0	:"light shade (U+2591)",
0xB1	:"medium shade (U+2592)",
0xB2	:"dark shade (U+2593)",
0xB3	:"box drawings light vertical (U+2502)",
0xB4	:"box drawings light vertical and left (U+2524)",
0xB5	:"Greek capital letter kappa (U+039A)",
0xB6	:"Greek capital letter lamda (U+039B)",
0xB7	:"Greek capital letter mu (U+039C)",
0xB8	:"Greek capital letter nu (U+039D)",
0xB9	:"box drawings double vertical and left (U+2563)",
0xBA	:"box drawings double vertical (U+2551)",
0xBB	:"box drawings double down and left (U+2557)",
0xBC	:"box drawings double up and left (U+255D)",
0xBD	:"Greek capital letter xi (U+039E)",
0xBE	:"Greek capital letter omicron (U+039F)",
0xBF	:"box drawings light down and left (U+2510)",
0xC0	:"box drawings light up and right (U+2514)",
0xC1	:"box drawings light up and horizontal (U+2534)",
0xC2	:"box drawings light down and horizontal (U+252C)",
0xC3	:"box drawings light vertical and right (U+251C)",
0xC4	:"box drawings light horizontal (U+2500)",
0xC5	:"box drawings light vertical and horizontal (U+253C)",
0xC6	:"Greek capital letter pi (U+03A0)",
0xC7	:"Greek capital letter rho (U+03A1)",
0xC8	:"box drawings double up and right (U+255A)",
0xC9	:"box drawings double down and right (U+2554)",
0xCA	:"box drawings double up and horizontal (U+2569)",
0xCB	:"box drawings double down and horizontal (U+2566)",
0xCC	:"box drawings double vertical and right (U+2560)",
0xCD	:"box drawings double horizontal (U+2550)",
0xCE	:"box drawings double vertical and horizontal (U+256C)",
0xCF	:"Greek capital letter sigma (U+03A3)",
0xD0	:"Greek capital letter tau (U+03A4)",
0xD1	:"Greek capital letter upsilon (U+03A5)",
0xD2	:"Greek capital letter phi (U+03A6)",
0xD3	:"Greek capital letter chi (U+03A7)",
0xD4	:"Greek capital letter psi (U+03A8)",
0xD5	:"Greek capital letter omega (U+03A9)",
0xD6	:"Greek small letter alpha (U+03B1)",
0xD7	:"Greek small letter beta (U+03B2)",
0xD8	:"Greek small letter gamma (U+03B3)",
0xD9	:"box drawings light up and left (U+2518)",
0xDA	:"box drawings light down and right (U+250C)",
0xDB	:"full block (U+2588)",
0xDC	:"lower half block (U+2584)",
0xDD	:"Greek small letter delta (U+03B4)",
0xDE	:"Greek small letter epsilon (U+03B5)",
0xDF	:"upper half block (U+2580)",
0xE0	:"Greek small letter zeta (U+03B6)",
0xE1	:"Greek small letter eta (U+03B7)",
0xE2	:"Greek small letter theta (U+03B8)",
0xE3	:"Greek small letter iota (U+03B9)",
0xE4	:"Greek small letter kappa (U+03BA)",
0xE5	:"Greek small letter lamda (U+03BB)",
0xE6	:"Greek small letter mu (U+03BC)",
0xE7	:"Greek small letter nu (U+03BD)",
0xE8	:"Greek small letter xi (U+03BE)",
0xE9	:"Greek small letter omicron (U+03BF)",
0xEA	:"Greek small letter pi (U+03C0)",
0xEB	:"Greek small letter rho (U+03C1)",
0xEC	:"Greek small letter sigma (U+03C3)",
0xED	:"Greek small letter final sigma (U+03C2)",
0xEE	:"Greek small letter tau (U+03C4)",
0xEF	:"Greek tonos (U+0384)",
0xF0	:"soft hyphen (U+00AD)",
0xF1	:"plus-minus sign (U+00B1)",
0xF2	:"Greek small letter upsilon (U+03C5)",
0xF3	:"Greek small letter phi (U+03C6)",
0xF4	:"Greek small letter chi (U+03C7)",
0xF5	:"section sign (U+00A7)",
0xF6	:"Greek small letter psi (U+03C8)",
0xF7	:"Greek dialytika tonos (U+0385)",
0xF8	:"degree sign (U+00B0)",
0xF9	:"diaeresis (U+00A8)",
0xFA	:"Greek small letter omega (U+03C9)",
0xFB	:"Greek small letter upsilon with dialytika (U+03CB)",
0xFC	:"Greek small letter upsilon with dialytika and tonos (U+03B0)",
0xFD	:"Greek small letter omega with tonos (U+03CE)",
0xFE	:"black square (U+25A0)",
0xFF	:"no-break space (U+00A0)"
}

#Microsoft codepage 1250 "WinLatin1" Western Europe
msw1250xtbl = { \
0x00	:"Null",
0x01	:"Start of heading",
0x02	:"Start of text",
0x03	:"End of text",
0x04	:"End of transmission",
0x05	:"Enquiry",
0x06	:"Acknowledge",
0x07	:"Bell",
0x08	:"Backspace",
0x09	:"Horizontal tabulation",
0x0a	:"Line feed",
0x0b	:"Vertical tabulation",
0x0c	:"Form feed",
0x0d	:"Carriage return",
0x0e	:"Shift out",
0x0f	:"Shift in",
0x10	:"Data link escape",
0x11	:"Device control one",
0x12	:"Device control two",
0x13	:"Device control three",
0x14	:"Device control four",
0x15	:"Negative acknowledge",
0x16	:"Synchronous idle",
0x17	:"End of transmission block",
0x18	:"Cancel",
0x19	:"End of medium",
0x1a	:"Substitute",
0x1b	:"Escape",
0x1c	:"File separator",
0x1d	:"Group separator",
0x1e	:"Record separator",
0x1f	:"Unit separator",
0x20	:"Space",
0x21	:"Exclamation mark",
0x22	:"Quotation mark",
0x23	:"Number sign",
0x24	:"Dollar sign",
0x25	:"Percent sign",
0x26	:"Ampersand",
0x27	:"Apostrophe",
0x28	:"Left parenthesis",
0x29	:"Right parenthesis",
0x2a	:"Asterisk",
0x2b	:"Plus sign",
0x2c	:"Comma",
0x2d	:"Hyphen-minus",
0x2e	:"Full stop",
0x2f	:"Solidus",
0x30	:"Digit zero",
0x31	:"Digit one",
0x32	:"Digit two",
0x33	:"Digit three",
0x34	:"Digit four",
0x35	:"Digit five",
0x36	:"Digit six",
0x37	:"Digit seven",
0x38	:"Digit eight",
0x39	:"Digit nine",
0x3a	:"Colon",
0x3b	:"Semicolon",
0x3c	:"Less-than sign",
0x3d	:"Equals sign",
0x3e	:"Greater-than sign",
0x3f	:"Question mark",
0x40	:"Commercial at",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5b	:"Left square bracket",
0x5c	:"Reverse solidus",
0x5d	:"Right square bracket",
0x5e	:"Circumflex accent",
0x5f	:"Low line",
0x60	:"Grave accent",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7b	:"Left curly bracket",
0x7c	:"Vertical line",
0x7d	:"Right curly bracket",
0x7e	:"Tilde",
0x7f	:"(Unused)",
0x80	:"Euro sign",
0x81	:"(Unused)",
0x82	:"Single low-9 quotation mark",
0x83	:"(Unused)",
0x84	:"Double low-9 quotation mark",
0x85	:"Horizontal ellipsis",
0x86	:"Dagger",
0x87	:"Double dagger",
0x88	:"(Unused)",
0x89	:"Per mille sign",
0x8a	:"Latin capital letter s with caron",
0x8b	:"Single left-pointing angle quotation mark",
0x8c	:"Latin capital letter s with acute",
0x8d	:"Latin capital letter t with caron",
0x8e	:"Latin capital letter z with caron",
0x8f	:"Latin capital letter z with acute",
0x90	:"(Unused)",
0x91	:"Left single quotation mark",
0x92	:"Right single quotation mark",
0x93	:"Left double quotation mark",
0x94	:"Right double quotation mark",
0x95	:"Bullet",
0x96	:"En dash",
0x97	:"Em dash",
0x98	:"(Unused)",
0x99	:"Trade mark sign",
0x9a	:"Latin small letter s with caron",
0x9b	:"Single right-pointing angle quotation mark",
0x9c	:"Latin small letter s with acute",
0x9d	:"Latin small letter t with caron",
0x9e	:"Latin small letter z with caron",
0x9f	:"Latin small letter z with acute",
0xa0	:"No-break space",
0xa1	:"Caron",
0xa2	:"Breve",
0xa3	:"Latin capital letter l with stroke",
0xa4	:"Currency sign",
0xa5	:"Latin capital letter a with ogonek",
0xa6	:"Broken bar",
0xa7	:"Section sign",
0xa8	:"Diaeresis",
0xa9	:"Copyright sign",
0xaa	:"Latin capital letter s with cedilla",
0xab	:"Left-pointing double angle quotation mark",
0xac	:"Not sign",
0xad	:"Soft hyphen",
0xae	:"Registered sign",
0xaf	:"Latin capital letter z with dot above",
0xb0	:"Degree sign",
0xb1	:"Plus-minus sign",
0xb2	:"Ogonek",
0xb3	:"Latin small letter l with stroke",
0xb4	:"Acute accent",
0xb5	:"Micro sign",
0xb6	:"Pilcrow sign",
0xb7	:"Middle dot",
0xb8	:"Cedilla",
0xb9	:"Latin small letter a with ogonek",
0xba	:"Latin small letter s with cedilla",
0xbb	:"Right-pointing double angle quotation mark",
0xbc	:"Latin capital letter y with diaeresis",
0xbd	:"Double acute accent",
0xbe	:"Latin capital letter l with caron",
0xbf	:"Latin small letter z with dot above",
0xc0	:"Latin capital letter r with acute",
0xc1	:"Latin capital letter a with acute",
0xc2	:"Latin capital letter a with circumflex",
0xc3	:"Latin capital letter a with breve",
0xc4	:"Latin capital letter a with diaeresis",
0xc5	:"Latin capital letter l with acute",
0xc6	:"Latin capital letter c with acute",
0xc7	:"Latin capital letter c with cedilla",
0xc8	:"Latin capital letter c with caron",
0xc9	:"Latin capital letter e with acute",
0xca	:"Latin capital letter e with ogonek",
0xcb	:"Latin capital letter e with diaeresis",
0xcc	:"Latin capital letter e with caron",
0xcd	:"Latin capital letter i with acute",
0xce	:"Latin capital letter i with circumflex",
0xcf	:"Latin capital letter d with caron",
0xd0	:"Latin capital letter d with stroke",
0xd1	:"Latin capital letter n with acute",
0xd2	:"Latin capital letter n with caron",
0xd3	:"Latin capital letter o with acute",
0xd4	:"Latin capital letter o with circumflex",
0xd5	:"Latin capital letter o with double acute",
0xd6	:"Latin capital letter o with diaeresis",
0xd7	:"Multiplication sign",
0xd8	:"Latin capital letter r with caron",
0xd9	:"Latin capital letter u with ring above",
0xda	:"Latin capital letter u with acute",
0xdb	:"Latin capital letter u with double acute",
0xdc	:"Latin capital letter u with diaeresis",
0xdd	:"Latin capital letter y with acute",
0xde	:"Latin capital letter t with cedilla",
0xdf	:"Latin small letter sharp s",
0xe0	:"Latin small letter r with acute",
0xe1	:"Latin small letter a with acute",
0xe2	:"Latin small letter a with circumflex",
0xe3	:"Latin small letter a with breve",
0xe4	:"Latin small letter a with diaeresis",
0xe5	:"Latin small letter l with acute",
0xe6	:"Latin small letter c with acute",
0xe7	:"Latin small letter c with cedilla",
0xe8	:"Latin small letter c with caron",
0xe9	:"Latin small letter e with acute",
0xea	:"Latin small letter e with ogonek",
0xeb	:"Latin small letter e with diaeresis",
0xec	:"Latin small letter e with caron",
0xed	:"Latin small letter i with acute",
0xee	:"Latin small letter i with circumflex",
0xef	:"Latin small letter d with caron",
0xf0	:"Latin small letter d with stroke",
0xf1	:"Latin small letter n with acute",
0xf2	:"Latin small letter n with caron",
0xf3	:"Latin small letter o with acute",
0xf4	:"Latin small letter o with circumflex",
0xf5	:"Latin small letter o with double acute",
0xf6	:"Latin small letter o with diaeresis",
0xf7	:"Division sign",
0xf8	:"Latin small letter r with caron",
0xf9	:"Latin small letter u with ring above",
0xfa	:"Latin small letter u with acute",
0xfb	:"Latin small letter u with double acute",
0xfc	:"Latin small letter u with diaeresis",
0xfd	:"Latin small letter y with acute",
0xfe	:"Latin small letter t with cedilla",
0xff	:"Dot above"
}

#Microsoft codepage 1251  "Cyrllic" (mostly Bulgarian)
msw1251xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"cyrillic capital letter dje (U+0402)",
0x81	:"cyrillic capital letter gje (U+0403)",
0x82	:"single low-9 quotation mark (U+201A)",
0x83	:"cyrillic small letter gje (U+0453)",
0x84	:"double low-9 quotation mark (U+201E)",
0x85	:"horizontal ellipsis (U+2026)",
0x86	:"dagger (U+2020)",
0x87	:"double dagger (U+2021)",
0x88	:"euro sign (U+20AC)",
0x89	:"per mille sign (U+2030)",
0x8A	:"cyrillic capital letter lje (U+0409)",
0x8B	:"single left-pointing angle quotation mark (U+2039)",
0x8C	:"cyrillic capital letter nje (U+040A)",
0x8D	:"cyrillic capital letter kje (U+040C)",
0x8E	:"cyrillic capital letter tshe (U+040B)",
0x8F	:"cyrillic capital letter dzhe (U+040F)",
0x90	:"cyrillic small letter dje (U+0452)",
0x91	:"left single quotation mark (U+2018)",
0x92	:"right single quotation mark (U+2019)",
0x93	:"left double quotation mark (U+201C)",
0x94	:"right double quotation mark (U+201D)",
0x95	:"bullet (U+2022)",
0x96	:"en dash (U+2013)",
0x97	:"em dash (U+2014)",
0x98	:"undefined (U+      )",
0x99	:"trade mark sign (U+2122)",
0x9A	:"cyrillic small letter lje (U+0459)",
0x9B	:"single right-pointing angle quotation mark (U+203A)",
0x9C	:"cyrillic small letter nje (U+045A)",
0x9D	:"cyrillic small letter kje (U+045C)",
0x9E	:"cyrillic small letter tshe (U+045B)",
0x9F	:"cyrillic small letter dzhe (U+045F)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"cyrillic capital letter short u (U+040E)",
0xA2	:"cyrillic small letter short u (U+045E)",
0xA3	:"cyrillic capital letter je (U+0408)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"cyrillic capital letter ghe with upturn (U+0490)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"cyrillic capital letter io (U+0401)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"cyrillic capital letter ukrainian ie (U+0404)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"cyrillic capital letter yi (U+0407)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"cyrillic capital letter byelorussian-ukrainian i (U+0406)",
0xB3	:"cyrillic small letter byelorussian-ukrainian i (U+0456)",
0xB4	:"cyrillic small letter ghe with upturn (U+0491)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"cyrillic small letter io (U+0451)",
0xB9	:"numero sign (U+2116)",
0xBA	:"cyrillic small letter ukrainian ie (U+0454)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"cyrillic small letter je (U+0458)",
0xBD	:"cyrillic capital letter dze (U+0405)",
0xBE	:"cyrillic small letter dze (U+0455)",
0xBF	:"cyrillic small letter yi (U+0457)",
0xC0	:"cyrillic capital letter a (U+0410)",
0xC1	:"cyrillic capital letter be (U+0411)",
0xC2	:"cyrillic capital letter ve (U+0412)",
0xC3	:"cyrillic capital letter ghe (U+0413)",
0xC4	:"cyrillic capital letter de (U+0414)",
0xC5	:"cyrillic capital letter ie (U+0415)",
0xC6	:"cyrillic capital letter zhe (U+0416)",
0xC7	:"cyrillic capital letter ze (U+0417)",
0xC8	:"cyrillic capital letter i (U+0418)",
0xC9	:"cyrillic capital letter short i (U+0419)",
0xCA	:"cyrillic capital letter ka (U+041A)",
0xCB	:"cyrillic capital letter el (U+041B)",
0xCC	:"cyrillic capital letter em (U+041C)",
0xCD	:"cyrillic capital letter en (U+041D)",
0xCE	:"cyrillic capital letter o (U+041E)",
0xCF	:"cyrillic capital letter pe (U+041F)",
0xD0	:"cyrillic capital letter er (U+0420)",
0xD1	:"cyrillic capital letter es (U+0421)",
0xD2	:"cyrillic capital letter te (U+0422)",
0xD3	:"cyrillic capital letter u (U+0423)",
0xD4	:"cyrillic capital letter ef (U+0424)",
0xD5	:"cyrillic capital letter ha (U+0425)",
0xD6	:"cyrillic capital letter tse (U+0426)",
0xD7	:"cyrillic capital letter che (U+0427)",
0xD8	:"cyrillic capital letter sha (U+0428)",
0xD9	:"cyrillic capital letter shcha (U+0429)",
0xDA	:"cyrillic capital letter hard sign (U+042A)",
0xDB	:"cyrillic capital letter yeru (U+042B)",
0xDC	:"cyrillic capital letter soft sign (U+042C)",
0xDD	:"cyrillic capital letter e (U+042D)",
0xDE	:"cyrillic capital letter yu (U+042E)",
0xDF	:"cyrillic capital letter ya (U+042F)",
0xE0	:"cyrillic small letter a (U+0430)",
0xE1	:"cyrillic small letter be (U+0431)",
0xE2	:"cyrillic small letter ve (U+0432)",
0xE3	:"cyrillic small letter ghe (U+0433)",
0xE4	:"cyrillic small letter de (U+0434)",
0xE5	:"cyrillic small letter ie (U+0435)",
0xE6	:"cyrillic small letter zhe (U+0436)",
0xE7	:"cyrillic small letter ze (U+0437)",
0xE8	:"cyrillic small letter i (U+0438)",
0xE9	:"cyrillic small letter short i (U+0439)",
0xEA	:"cyrillic small letter ka (U+043A)",
0xEB	:"cyrillic small letter el (U+043B)",
0xEC	:"cyrillic small letter em (U+043C)",
0xED	:"cyrillic small letter en (U+043D)",
0xEE	:"cyrillic small letter o (U+043E)",
0xEF	:"cyrillic small letter pe (U+043F)",
0xF0	:"cyrillic small letter er (U+0440)",
0xF1	:"cyrillic small letter es (U+0441)",
0xF2	:"cyrillic small letter te (U+0442)",
0xF3	:"cyrillic small letter u (U+0443)",
0xF4	:"cyrillic small letter ef (U+0444)",
0xF5	:"cyrillic small letter ha (U+0445)",
0xF6	:"cyrillic small letter tse (U+0446)",
0xF7	:"cyrillic small letter che (U+0447)",
0xF8	:"cyrillic small letter sha (U+0448)",
0xF9	:"cyrillic small letter shcha (U+0449)",
0xFA	:"cyrillic small letter hard sign (U+044A)",
0xFB	:"cyrillic small letter yeru (U+044B)",
0xFC	:"cyrillic small letter soft sign (U+044C)",
0xFD	:"cyrillic small letter e (U+044D)",
0xFE	:"cyrillic small letter yu (U+044E)",
0xFF	:"cyrillic small letter ya (U+044F)",
}

#Microsoft codepage 1252  "WinLatin2"- Eastern Europe
msw1252xtbl = { \
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"euro sign (U+20AC)",
0x81	:"unused",
0x82	:"single low-9 quotation mark (U+201A)",
0x83	:"Latin small letter f with hook (U+0192)",
0x84	:"double low-9 quotation mark (U+201E)",
0x85	:"horizontal ellipsis (U+2026)",
0x86	:"dagger (U+2020)",
0x87	:"double dagger (U+2021)",
0x88	:"modifier letter circumflex accent (U+02C6)",
0x89	:"per mille sign (U+2030)",
0x8A	:"Latin capital letter s with caron (U+0160)",
0x8B	:"single left-pointing angle quotation mark (U+2039)",
0x8C	:"Latin capital ligature oe (U+0152)",
0x8D	:"unused",
0x8E	:"Latin capital letter z with caron (U+017D)",
0x8F	:"unused",
0x90	:"unused",
0x91	:"left single quotation mark (U+2018)",
0x92	:"right single quotation mark (U+2019)",
0x93	:"left double quotation mark (U+201C)",
0x94	:"right double quotation mark (U+201D)",
0x95	:"bullet (U+2022)",
0x96	:"en dash (U+2013)",
0x97	:"em dash (U+2014)",
0x98	:"small tilde (U+02DC)",
0x99	:"trade mark sign (U+2122)",
0x9A	:"Latin small letter s with caron (U+0161)",
0x9B	:"single right-pointing angle quotation mark (U+203A)",
0x9C	:"Latin small ligature oe (U+0153)",
0x9D	:"unused",
0x9E	:"Latin small letter z with caron (U+017E)",
0x9F	:"Latin capital letter y with diaeresis (U+0178)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"inverted exclamation mark (U+00A1)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"yen sign (U+00A5)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"feminine ordinal indicator (U+00AA)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"macron (U+00AF)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"acute accent (U+00B4)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"cedilla (U+00B8)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"masculine ordinal indicator (U+00BA)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"vulgar fraction one quarter (U+00BC)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"vulgar fraction three quarters (U+00BE)",
0xBF	:"inverted question mark (U+00BF)",
0xC0	:"Latin capital letter a with grave (U+00C0)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with tilde (U+00C3)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter a with ring above (U+00C5)",
0xC6	:"Latin capital letter ae (U+00C6)",
0xC7	:"Latin capital letter c with cedilla (U+00C7)",
0xC8	:"Latin capital letter e with grave (U+00C8)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with circumflex (U+00CA)",
0xCB	:"Latin capital letter e with diaeresis (U+00CB)",
0xCC	:"Latin capital letter i with grave (U+00CC)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with circumflex (U+00CE)",
0xCF	:"Latin capital letter i with diaeresis (U+00CF)",
0xD0	:"Latin capital letter eth (U+00D0)",
0xD1	:"Latin capital letter n with tilde (U+00D1)",
0xD2	:"Latin capital letter o with grave (U+00D2)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin capital letter o with tilde (U+00D5)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"multiplication sign (U+00D7)",
0xD8	:"Latin capital letter o with stroke (U+00D8)",
0xD9	:"Latin capital letter u with grave (U+00D9)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin capital letter u with circumflex (U+00DB)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter y with acute (U+00DD)",
0xDE	:"Latin capital letter thorn (U+00DE)",
0xDF	:"Latin small letter sharp s (U+00DF)",
0xE0	:"Latin small letter a with grave (U+00E0)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with tilde (U+00E3)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter a with ring above (U+00E5)",
0xE6	:"Latin small letter ae (U+00E6)",
0xE7	:"Latin small letter c with cedilla (U+00E7)",
0xE8	:"Latin small letter e with grave (U+00E8)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with circumflex (U+00EA)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"Latin small letter i with grave (U+00EC)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter i with diaeresis (U+00EF)",
0xF0	:"Latin small letter eth (U+00F0)",
0xF1	:"Latin small letter n with tilde (U+00F1)",
0xF2	:"Latin small letter o with grave (U+00F2)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with tilde (U+00F5)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"division sign (U+00F7)",
0xF8	:"Latin small letter o with stroke (U+00F8)",
0xF9	:"Latin small letter u with grave (U+00F9)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with circumflex (U+00FB)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter y with acute (U+00FD)",
0xFE	:"Latin small letter thorn (U+00FE)",
0xFF	:"Latin small letter y with diaeresis (U+00FF)"
}

#Microsoft Windows Codepage 1253 Greek
msw1253xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"euro sign (U+20AC)",
0x81	:"Unused",
0x82	:"single low-9 quotation mark (U+201A)",
0x83	:"Latin small letter f with hook (U+0192)",
0x84	:"double low-9 quotation mark (U+201E)",
0x85	:"horizontal ellipsis (U+2026)",
0x86	:"dagger (U+2020)",
0x87	:"double dagger (U+2021)",
0x88	:"undefined (U+)",
0x89	:"per mille sign (U+2030)",
0x8A	:"undefined (U+)",
0x8B	:"single left-pointing angle quotation mark (U+2039)",
0x8C	:"undefined (U+)",
0x8D	:"undefined (U+)",
0x8E	:"undefined (U+)",
0x8F	:"undefined (U+)",
0x90	:"undefined (U+)",
0x91	:"left single quotation mark (U+2018)",
0x92	:"right single quotation mark (U+2019)",
0x93	:"left double quotation mark (U+201C)",
0x94	:"right double quotation mark (U+201D)",
0x95	:"bullet (U+2022)",
0x96	:"en dash (U+2013)",
0x97	:"em dash (U+2014)",
0x98	:"undefined (U+)",
0x99	:"trade mark sign (U+2122)",
0x9A	:"undefined (U+)",
0x9B	:"single right-pointing angle quotation mark (U+203A)",
0x9C	:"undefined (U+)",
0x9D	:"undefined (U+)",
0x9E	:"undefined (U+)",
0x9F	:"undefined (U+)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"greek dialytika tonos (U+0385)",
0xA2	:"greek capital letter alpha with tonos (U+0386)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"yen sign (U+00A5)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"Unused",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"horizontal bar (U+2015)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"greek tonos (U+0384)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"greek capital letter epsilon with tonos (U+0388)",
0xB9	:"greek capital letter eta with tonos (U+0389)",
0xBA	:"greek capital letter iota with tonos (U+038A)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"greek capital letter omicron with tonos (U+038C)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"greek capital letter upsilon with tonos (U+038E)",
0xBF	:"greek capital letter omega with tonos (U+038F)",
0xC0	:"greek small letter iota with dialytika and tonos (U+0390)",
0xC1	:"greek capital letter alpha (U+0391)",
0xC2	:"greek capital letter beta (U+0392)",
0xC3	:"greek capital letter gamma (U+0393)",
0xC4	:"greek capital letter delta (U+0394)",
0xC5	:"greek capital letter epsilon (U+0395)",
0xC6	:"greek capital letter zeta (U+0396)",
0xC7	:"greek capital letter eta (U+0397)",
0xC8	:"greek capital letter theta (U+0398)",
0xC9	:"greek capital letter iota (U+0399)",
0xCA	:"greek capital letter kappa (U+039A)",
0xCB	:"greek capital letter lamda (U+039B)",
0xCC	:"greek capital letter mu (U+039C)",
0xCD	:"greek capital letter nu (U+039D)",
0xCE	:"greek capital letter xi (U+039E)",
0xCF	:"greek capital letter omicron (U+039F)",
0xD0	:"greek capital letter pi (U+03A0)",
0xD1	:"greek capital letter rho (U+03A1)",
0xD2	:"Unused",
0xD3	:"greek capital letter sigma (U+03A3)",
0xD4	:"greek capital letter tau (U+03A4)",
0xD5	:"greek capital letter upsilon (U+03A5)",
0xD6	:"greek capital letter phi (U+03A6)",
0xD7	:"greek capital letter chi (U+03A7)",
0xD8	:"greek capital letter psi (U+03A8)",
0xD9	:"greek capital letter omega (U+03A9)",
0xDA	:"greek capital letter iota with dialytika (U+03AA)",
0xDB	:"greek capital letter upsilon with dialytika (U+03AB)",
0xDC	:"greek small letter alpha with tonos (U+03AC)",
0xDD	:"greek small letter epsilon with tonos (U+03AD)",
0xDE	:"greek small letter eta with tonos (U+03AE)",
0xDF	:"greek small letter iota with tonos (U+03AF)",
0xE0	:"greek small letter upsilon with dialytika and tonos (U+03B0)",
0xE1	:"greek small letter alpha (U+03B1)",
0xE2	:"greek small letter beta (U+03B2)",
0xE3	:"greek small letter gamma (U+03B3)",
0xE4	:"greek small letter delta (U+03B4)",
0xE5	:"greek small letter epsilon (U+03B5)",
0xE6	:"greek small letter zeta (U+03B6)",
0xE7	:"greek small letter eta (U+03B7)",
0xE8	:"greek small letter theta (U+03B8)",
0xE9	:"greek small letter iota (U+03B9)",
0xEA	:"greek small letter kappa (U+03BA)",
0xEB	:"greek small letter lamda (U+03BB)",
0xEC	:"greek small letter mu (U+03BC)",
0xED	:"greek small letter nu (U+03BD)",
0xEE	:"greek small letter xi (U+03BE)",
0xEF	:"greek small letter omicron (U+03BF)",
0xF0	:"greek small letter pi (U+03C0)",
0xF1	:"greek small letter rho (U+03C1)",
0xF2	:"greek small letter final sigma (U+03C2)",
0xF3	:"greek small letter sigma (U+03C3)",
0xF4	:"greek small letter tau (U+03C4)",
0xF5	:"greek small letter upsilon (U+03C5)",
0xF6	:"greek small letter phi (U+03C6)",
0xF7	:"greek small letter chi (U+03C7)",
0xF8	:"greek small letter psi (U+03C8)",
0xF9	:"greek small letter omega (U+03C9)",
0xFA	:"greek small letter iota with dialytika (U+03CA)",
0xFB	:"greek small letter upsilon with dialytika (U+03CB)",
0xFC	:"greek small letter omicron with tonos (U+03CC)",
0xFD	:"greek small letter upsilon with tonos (U+03CD)",
0xFE	:"greek small letter omega with tonos (U+03CE)",
0xFF	:"Unused"
}

#Microsoft Windows Codepage 1254 Turkish
msw1254xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"euro sign (U+20AC)",
0x81	:"undefined (U+      )",
0x82	:"single low-9 quotation mark (U+201A)",
0x83	:"Latin small letter f with hook (U+0192)",
0x84	:"double low-9 quotation mark (U+201E)",
0x85	:"horizontal ellipsis (U+2026)",
0x86	:"dagger (U+2020)",
0x87	:"double dagger (U+2021)",
0x88	:"modifier letter circumflex accent (U+02C6)",
0x89	:"per mille sign (U+2030)",
0x8A	:"Latin capital letter s with caron (U+0160)",
0x8B	:"single left-pointing angle quotation mark (U+2039)",
0x8C	:"Latin capital ligature oe (U+0152)",
0x8D	:"undefined (U+      )",
0x8E	:"undefined (U+      )",
0x8F	:"undefined (U+      )",
0x90	:"undefined (U+      )",
0x91	:"left single quotation mark (U+2018)",
0x92	:"right single quotation mark (U+2019)",
0x93	:"left double quotation mark (U+201C)",
0x94	:"right double quotation mark (U+201D)",
0x95	:"bullet (U+2022)",
0x96	:"en dash (U+2013)",
0x97	:"em dash (U+2014)",
0x98	:"small tilde (U+02DC)",
0x99	:"trade mark sign (U+2122)",
0x9A	:"Latin small letter s with caron (U+0161)",
0x9B	:"single right-pointing angle quotation mark (U+203A)",
0x9C	:"Latin small ligature oe (U+0153)",
0x9D	:"undefined (U+      )",
0x9E	:"undefined (U+      )",
0x9F	:"Latin capital letter y with diaeresis (U+0178)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"inverted exclamation mark (U+00A1)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"yen sign (U+00A5)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"feminine ordinal indicator (U+00AA)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"macron (U+00AF)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"acute accent (U+00B4)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"cedilla (U+00B8)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"masculine ordinal indicator (U+00BA)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"vulgar fraction one quarter (U+00BC)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"vulgar fraction three quarters (U+00BE)",
0xBF	:"inverted question mark (U+00BF)",
0xC0	:"Latin capital letter a with grave (U+00C0)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with tilde (U+00C3)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter a with ring above (U+00C5)",
0xC6	:"Latin capital letter ae (U+00C6)",
0xC7	:"Latin capital letter c with cedilla (U+00C7)",
0xC8	:"Latin capital letter e with grave (U+00C8)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with circumflex (U+00CA)",
0xCB	:"Latin capital letter e with diaeresis (U+00CB)",
0xCC	:"Latin capital letter i with grave (U+00CC)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with circumflex (U+00CE)",
0xCF	:"Latin capital letter i with diaeresis (U+00CF)",
0xD0	:"Latin capital letter g with breve (U+011E)",
0xD1	:"Latin capital letter n with tilde (U+00D1)",
0xD2	:"Latin capital letter o with grave (U+00D2)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin capital letter o with tilde (U+00D5)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"multiplication sign (U+00D7)",
0xD8	:"Latin capital letter o with stroke (U+00D8)",
0xD9	:"Latin capital letter u with grave (U+00D9)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin capital letter u with circumflex (U+00DB)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter i with dot above (U+0130)",
0xDE	:"Latin capital letter s with cedilla (U+015E)",
0xDF	:"Latin small letter sharp s (U+00DF)",
0xE0	:"Latin small letter a with grave (U+00E0)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with tilde (U+00E3)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter a with ring above (U+00E5)",
0xE6	:"Latin small letter ae (U+00E6)",
0xE7	:"Latin small letter c with cedilla (U+00E7)",
0xE8	:"Latin small letter e with grave (U+00E8)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with circumflex (U+00EA)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"Latin small letter i with grave (U+00EC)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter i with diaeresis (U+00EF)",
0xF0	:"Latin small letter g with breve (U+011F)",
0xF1	:"Latin small letter n with tilde (U+00F1)",
0xF2	:"Latin small letter o with grave (U+00F2)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with tilde (U+00F5)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"division sign (U+00F7)",
0xF8	:"Latin small letter o with stroke (U+00F8)",
0xF9	:"Latin small letter u with grave (U+00F9)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with circumflex (U+00FB)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter dotless i (U+0131)",
0xFE	:"Latin small letter s with cedilla (U+015F)",
0xFF	:"Latin small letter y with diaeresis (U+00FF)",
}

#Microsoft Windows Codepage 1255 Hebrew
msw1255xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"euro sign (U+20AC)",
0x81	:"Unused",
0x82	:"single low-9 quotation mark (U+201A)",
0x83	:"Latin small letter f with hook (U+0192)",
0x84	:"double low-9 quotation mark (U+201E)",
0x85	:"horizontal ellipsis (U+2026)",
0x86	:"dagger (U+2020)",
0x87	:"double dagger (U+2021)",
0x88	:"modifier letter circumflex accent (U+02C6)",
0x89	:"per mille sign (U+2030)",
0x8A	:"Unused",
0x8B	:"single left-pointing angle quotation mark (U+2039)",
0x8C	:"Unused",
0x8D	:"Unused",
0x8E	:"Unused",
0x8F	:"Unused",
0x90	:"Unused",
0x91	:"left single quotation mark (U+2018)",
0x92	:"right single quotation mark (U+2019)",
0x93	:"left double quotation mark (U+201C)",
0x94	:"right double quotation mark (U+201D)",
0x95	:"bullet (U+2022)",
0x96	:"en dash (U+2013)",
0x97	:"em dash (U+2014)",
0x98	:"small tilde (U+02DC)",
0x99	:"trade mark sign (U+2122)",
0x9A	:"Unused",
0x9B	:"single right-pointing angle quotation mark (U+203A)",
0x9C	:"Unused",
0x9D	:"Unused",
0x9E	:"Unused",
0x9F	:"Unused",
0xA0	:"no-break space (U+00A0)",
0xA1	:"inverted exclamation mark (U+00A1)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"new sheqel sign (U+20AA)",
0xA5	:"yen sign (U+00A5)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"multiplication sign (U+00D7)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"macron (U+00AF)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"acute accent (U+00B4)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"cedilla (U+00B8)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"division sign (U+00F7)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"vulgar fraction one quarter (U+00BC)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"vulgar fraction three quarters (U+00BE)",
0xBF	:"inverted question mark (U+00BF)",
0xC0	:"Hebrew point sheva (U+05B0)",
0xC1	:"Hebrew point hataf segol (U+05B1)",
0xC2	:"Hebrew point hataf patah (U+05B2)",
0xC3	:"Hebrew point hataf qamats (U+05B3)",
0xC4	:"Hebrew point hiriq (U+05B4)",
0xC5	:"Hebrew point tsere (U+05B5)",
0xC6	:"Hebrew point segol (U+05B6)",
0xC7	:"Hebrew point patah (U+05B7)",
0xC8	:"Hebrew point qamats (U+05B8)",
0xC9	:"Hebrew point holam (U+05B9)",
0xCA	:"Unused",
0xCB	:"Hebrew point qubuts (U+05BB)",
0xCC	:"Hebrew point dagesh or mapiq (U+05BC)",
0xCD	:"Hebrew point meteg (U+05BD)",
0xCE	:"Hebrew punctuation maqaf (U+05BE)",
0xCF	:"Hebrew point rafe (U+05BF)",
0xD0	:"Hebrew punctuation paseq (U+05C0)",
0xD1	:"Hebrew point shin dot (U+05C1)",
0xD2	:"Hebrew point sin dot (U+05C2)",
0xD3	:"Hebrew punctuation sof pasuq (U+05C3)",
0xD4	:"Hebrew ligature yiddish double vav (U+05F0)",
0xD5	:"Hebrew ligature yiddish vav yod (U+05F1)",
0xD6	:"Hebrew ligature yiddish double yod (U+05F2)",
0xD7	:"Hebrew punctuation geresh (U+05F3)",
0xD8	:"Hebrew punctuation gershayim (U+05F4)",
0xD9	:"Unused",
0xDA	:"Unused",
0xDB	:"Unused",
0xDC	:"Unused",
0xDD	:"Unused",
0xDE	:"Unused",
0xDF	:"Unused",
0xE0	:"Hebrew letter alef (U+05D0)",
0xE1	:"Hebrew letter bet (U+05D1)",
0xE2	:"Hebrew letter gimel (U+05D2)",
0xE3	:"Hebrew letter dalet (U+05D3)",
0xE4	:"Hebrew letter he (U+05D4)",
0xE5	:"Hebrew letter vav (U+05D5)",
0xE6	:"Hebrew letter zayin (U+05D6)",
0xE7	:"Hebrew letter het (U+05D7)",
0xE8	:"Hebrew letter tet (U+05D8)",
0xE9	:"Hebrew letter yod (U+05D9)",
0xEA	:"Hebrew letter final kaf (U+05DA)",
0xEB	:"Hebrew letter kaf (U+05DB)",
0xEC	:"Hebrew letter lamed (U+05DC)",
0xED	:"Hebrew letter final mem (U+05DD)",
0xEE	:"Hebrew letter mem (U+05DE)",
0xEF	:"Hebrew letter final nun (U+05DF)",
0xF0	:"Hebrew letter nun (U+05E0)",
0xF1	:"Hebrew letter samekh (U+05E1)",
0xF2	:"Hebrew letter ayin (U+05E2)",
0xF3	:"Hebrew letter final pe (U+05E3)",
0xF4	:"Hebrew letter pe (U+05E4)",
0xF5	:"Hebrew letter final tsadi (U+05E5)",
0xF6	:"Hebrew letter tsadi (U+05E6)",
0xF7	:"Hebrew letter qof (U+05E7)",
0xF8	:"Hebrew letter resh (U+05E8)",
0xF9	:"Hebrew letter shin (U+05E9)",
0xFA	:"Hebrew letter tav (U+05EA)",
0xFB	:"Unused",
0xFC	:"Unused",
0xFD	:"left-to-right mark (U+200E)",
0xFE	:"right-to-left mark (U+200F)",
0xFF	:"Unused"
}

#Microsoft Windows Codepage 1256 Arabic
msw1256xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"euro sign (U+20AC)",
0x81	:"Arabic letter peh (U+067E)",
0x82	:"single low-9 quotation mark (U+201A)",
0x83	:"Latin small letter f with hook (U+0192)",
0x84	:"double low-9 quotation mark (U+201E)",
0x85	:"horizontal ellipsis (U+2026)",
0x86	:"dagger (U+2020)",
0x87	:"double dagger (U+2021)",
0x88	:"modifier letter circumflex accent (U+02C6)",
0x89	:"per mille sign (U+2030)",
0x8A	:"Arabic letter tteh (U+0679)",
0x8B	:"single left-pointing angle quotation mark (U+2039)",
0x8C	:"Latin capital ligature oe (U+0152)",
0x8D	:"Arabic letter tcheh (U+0686)",
0x8E	:"Arabic letter jeh (U+0698)",
0x8F	:"Arabic letter ddal (U+0688)",
0x90	:"Arabic letter gaf (U+06AF)",
0x91	:"left single quotation mark (U+2018)",
0x92	:"right single quotation mark (U+2019)",
0x93	:"left double quotation mark (U+201C)",
0x94	:"right double quotation mark (U+201D)",
0x95	:"bullet (U+2022)",
0x96	:"en dash (U+2013)",
0x97	:"em dash (U+2014)",
0x98	:"Arabic letter keheh (U+06A9)",
0x99	:"trade mark sign (U+2122)",
0x9A	:"Arabic letter rreh (U+0691)",
0x9B	:"single right-pointing angle quotation mark (U+203A)",
0x9C	:"Latin small ligature oe (U+0153)",
0x9D	:"zero width non-joiner (U+200C)",
0x9E	:"zero width joiner (U+200D)",
0x9F	:"Arabic letter noon ghunna (U+06BA)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"Arabic comma (U+060C)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"yen sign (U+00A5)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"Arabic letter heh doachashmee (U+06BE)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"macron (U+00AF)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"acute accent (U+00B4)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"cedilla (U+00B8)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"Arabic semicolon (U+061B)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"vulgar fraction one quarter (U+00BC)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"vulgar fraction three quarters (U+00BE)",
0xBF	:"Arabic question mark (U+061F)",
0xC0	:"Arabic letter heh goal (U+06C1)",
0xC1	:"Arabic letter hamza (U+0621)",
0xC2	:"Arabic letter alef with madda above (U+0622)",
0xC3	:"Arabic letter alef with hamza above (U+0623)",
0xC4	:"Arabic letter waw with hamza above (U+0624)",
0xC5	:"Arabic letter alef with hamza below (U+0625)",
0xC6	:"Arabic letter yeh with hamza above (U+0626)",
0xC7	:"Arabic letter alef (U+0627)",
0xC8	:"Arabic letter beh (U+0628)",
0xC9	:"Arabic letter teh marbuta (U+0629)",
0xCA	:"Arabic letter teh (U+062A)",
0xCB	:"Arabic letter theh (U+062B)",
0xCC	:"Arabic letter jeem (U+062C)",
0xCD	:"Arabic letter hah (U+062D)",
0xCE	:"Arabic letter khah (U+062E)",
0xCF	:"Arabic letter dal (U+062F)",
0xD0	:"Arabic letter thal (U+0630)",
0xD1	:"Arabic letter reh (U+0631)",
0xD2	:"Arabic letter zain (U+0632)",
0xD3	:"Arabic letter seen (U+0633)",
0xD4	:"Arabic letter sheen (U+0634)",
0xD5	:"Arabic letter sad (U+0635)",
0xD6	:"Arabic letter dad (U+0636)",
0xD7	:"multiplication sign (U+00D7)",
0xD8	:"Arabic letter tah (U+0637)",
0xD9	:"Arabic letter zah (U+0638)",
0xDA	:"Arabic letter ain (U+0639)",
0xDB	:"Arabic letter ghain (U+063A)",
0xDC	:"Arabic tatweel (U+0640)",
0xDD	:"Arabic letter feh (U+0641)",
0xDE	:"Arabic letter qaf (U+0642)",
0xDF	:"Arabic letter kaf (U+0643)",
0xE0	:"Latin small letter a with grave (U+00E0)",
0xE1	:"Arabic letter lam (U+0644)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Arabic letter meem (U+0645)",
0xE4	:"Arabic letter noon (U+0646)",
0xE5	:"Arabic letter heh (U+0647)",
0xE6	:"Arabic letter waw (U+0648)",
0xE7	:"Latin small letter c with cedilla (U+00E7)",
0xE8	:"Latin small letter e with grave (U+00E8)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with circumflex (U+00EA)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"Arabic letter alef maksura (U+0649)",
0xED	:"Arabic letter yeh (U+064A)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter i with diaeresis (U+00EF)",
0xF0	:"Arabic fathatan (U+064B)",
0xF1	:"Arabic dammatan (U+064C)",
0xF2	:"Arabic kasratan (U+064D)",
0xF3	:"Arabic fatha (U+064E)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Arabic damma (U+064F)",
0xF6	:"Arabic kasra (U+0650)",
0xF7	:"division sign (U+00F7)",
0xF8	:"Arabic shadda (U+0651)",
0xF9	:"Latin small letter u with grave (U+00F9)",
0xFA	:"Arabic sukun (U+0652)",
0xFB	:"Latin small letter u with circumflex (U+00FB)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"left-to-right mark (U+200E)",
0xFE	:"right-to-left mark (U+200F)",
0xFF	:"Arabic letter yeh barree (U+06D2)"
}

#Microsoft Windows Codepage 1257 Estonian, Latvian, Lithuanian
msw1257xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"euro sign (U+20AC)",
0x81	:"undefined (U+      )",
0x82	:"single low-9 quotation mark (U+201A)",
0x83	:"undefined (U+      )",
0x84	:"double low-9 quotation mark (U+201E)",
0x85	:"horizontal ellipsis (U+2026)",
0x86	:"dagger (U+2020)",
0x87	:"double dagger (U+2021)",
0x88	:"undefined (U+      )",
0x89	:"per mille sign (U+2030)",
0x8A	:"undefined (U+      )",
0x8B	:"single left-pointing angle quotation mark (U+2039)",
0x8C	:"undefined (U+      )",
0x8D	:"diaeresis (U+00A8)",
0x8E	:"caron (U+02C7)",
0x8F	:"cedilla (U+00B8)",
0x90	:"undefined (U+      )",
0x91	:"left single quotation mark (U+2018)",
0x92	:"right single quotation mark (U+2019)",
0x93	:"left double quotation mark (U+201C)",
0x94	:"right double quotation mark (U+201D)",
0x95	:"bullet (U+2022)",
0x96	:"en dash (U+2013)",
0x97	:"em dash (U+2014)",
0x98	:"undefined (U+      )",
0x99	:"trade mark sign (U+2122)",
0x9A	:"undefined (U+      )",
0x9B	:"single right-pointing angle quotation mark (U+203A)",
0x9C	:"undefined (U+      )",
0x9D	:"macron (U+00AF)",
0x9E	:"ogonek (U+02DB)",
0x9F	:"undefined (U+      )",
0xA0	:"no-break space (U+00A0)",
0xA1	:"undefined (U+      )",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"undefined (U+      )",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"Latin capital letter o with stroke (U+00D8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"Latin capital letter r with cedilla (U+0156)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"Latin capital letter ae (U+00C6)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"acute accent (U+00B4)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"Latin small letter o with stroke (U+00F8)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"Latin small letter r with cedilla (U+0157)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"vulgar fraction one quarter (U+00BC)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"vulgar fraction three quarters (U+00BE)",
0xBF	:"Latin small letter ae (U+00E6)",
0xC0	:"Latin capital letter a with ogonek (U+0104)",
0xC1	:"Latin capital letter i with ogonek (U+012E)",
0xC2	:"Latin capital letter a with macron (U+0100)",
0xC3	:"Latin capital letter c with acute (U+0106)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter a with ring above (U+00C5)",
0xC6	:"Latin capital letter e with ogonek (U+0118)",
0xC7	:"Latin capital letter e with macron (U+0112)",
0xC8	:"Latin capital letter c with caron (U+010C)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter z with acute (U+0179)",
0xCB	:"Latin capital letter e with dot above (U+0116)",
0xCC	:"Latin capital letter g with cedilla (U+0122)",
0xCD	:"Latin capital letter k with cedilla (U+0136)",
0xCE	:"Latin capital letter i with macron (U+012A)",
0xCF	:"Latin capital letter l with cedilla (U+013B)",
0xD0	:"Latin capital letter s with caron (U+0160)",
0xD1	:"Latin capital letter n with acute (U+0143)",
0xD2	:"Latin capital letter n with cedilla (U+0145)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with macron (U+014C)",
0xD5	:"Latin capital letter o with tilde (U+00D5)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"multiplication sign (U+00D7)",
0xD8	:"Latin capital letter u with ogonek (U+0172)",
0xD9	:"Latin capital letter l with stroke (U+0141)",
0xDA	:"Latin capital letter s with acute (U+015A)",
0xDB	:"Latin capital letter u with macron (U+016A)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter z with dot above (U+017B)",
0xDE	:"Latin capital letter z with caron (U+017D)",
0xDF	:"Latin small letter sharp s (U+00DF)",
0xE0	:"Latin small letter a with ogonek (U+0105)",
0xE1	:"Latin small letter i with ogonek (U+012F)",
0xE2	:"Latin small letter a with macron (U+0101)",
0xE3	:"Latin small letter c with acute (U+0107)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter a with ring above (U+00E5)",
0xE6	:"Latin small letter e with ogonek (U+0119)",
0xE7	:"Latin small letter e with macron (U+0113)",
0xE8	:"Latin small letter c with caron (U+010D)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter z with acute (U+017A)",
0xEB	:"Latin small letter e with dot above (U+0117)",
0xEC	:"Latin small letter g with cedilla (U+0123)",
0xED	:"Latin small letter k with cedilla (U+0137)",
0xEE	:"Latin small letter i with macron (U+012B)",
0xEF	:"Latin small letter l with cedilla (U+013C)",
0xF0	:"Latin small letter s with caron (U+0161)",
0xF1	:"Latin small letter n with acute (U+0144)",
0xF2	:"Latin small letter n with cedilla (U+0146)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with macron (U+014D)",
0xF5	:"Latin small letter o with tilde (U+00F5)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"division sign (U+00F7)",
0xF8	:"Latin small letter u with ogonek (U+0173)",
0xF9	:"Latin small letter l with stroke (U+0142)",
0xFA	:"Latin small letter s with acute (U+015B)",
0xFB	:"Latin small letter u with macron (U+016B)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter z with dot above (U+017C)",
0xFE	:"Latin small letter z with caron (U+017E)",
0xFF	:"dot above (U+02D9)"
}

#Microsoft Windows Codepage 1258 Vietnamese
msw1258xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"euro sign (U+20AC)",
0x81	:"undefined (U+      )",
0x82	:"single low-9 quotation mark (U+201A)",
0x83	:"Latin small letter f with hook (U+0192)",
0x84	:"double low-9 quotation mark (U+201E)",
0x85	:"horizontal ellipsis (U+2026)",
0x86	:"dagger (U+2020)",
0x87	:"double dagger (U+2021)",
0x88	:"modifier letter circumflex accent (U+02C6)",
0x89	:"per mille sign (U+2030)",
0x8A	:"undefined (U+      )",
0x8B	:"single left-pointing angle quotation mark (U+2039)",
0x8C	:"Latin capital ligature oe (U+0152)",
0x8D	:"undefined (U+      )",
0x8E	:"undefined (U+      )",
0x8F	:"undefined (U+      )",
0x90	:"undefined (U+      )",
0x91	:"left single quotation mark (U+2018)",
0x92	:"right single quotation mark (U+2019)",
0x93	:"left double quotation mark (U+201C)",
0x94	:"right double quotation mark (U+201D)",
0x95	:"bullet (U+2022)",
0x96	:"en dash (U+2013)",
0x97	:"em dash (U+2014)",
0x98	:"small tilde (U+02DC)",
0x99	:"trade mark sign (U+2122)",
0x9A	:"undefined (U+      )",
0x9B	:"single right-pointing angle quotation mark (U+203A)",
0x9C	:"Latin small ligature oe (U+0153)",
0x9D	:"undefined (U+      )",
0x9E	:"undefined (U+      )",
0x9F	:"Latin capital letter y with diaeresis (U+0178)",
0xA0	:"no-break space (U+00A0)",
0xA1	:"inverted exclamation mark (U+00A1)",
0xA2	:"cent sign (U+00A2)",
0xA3	:"pound sign (U+00A3)",
0xA4	:"currency sign (U+00A4)",
0xA5	:"yen sign (U+00A5)",
0xA6	:"broken bar (U+00A6)",
0xA7	:"section sign (U+00A7)",
0xA8	:"diaeresis (U+00A8)",
0xA9	:"copyright sign (U+00A9)",
0xAA	:"feminine ordinal indicator (U+00AA)",
0xAB	:"left-pointing double angle quotation mark (U+00AB)",
0xAC	:"not sign (U+00AC)",
0xAD	:"soft hyphen (U+00AD)",
0xAE	:"registered sign (U+00AE)",
0xAF	:"macron (U+00AF)",
0xB0	:"degree sign (U+00B0)",
0xB1	:"plus-minus sign (U+00B1)",
0xB2	:"superscript two (U+00B2)",
0xB3	:"superscript three (U+00B3)",
0xB4	:"acute accent (U+00B4)",
0xB5	:"micro sign (U+00B5)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"middle dot (U+00B7)",
0xB8	:"cedilla (U+00B8)",
0xB9	:"superscript one (U+00B9)",
0xBA	:"masculine ordinal indicator (U+00BA)",
0xBB	:"right-pointing double angle quotation mark (U+00BB)",
0xBC	:"vulgar fraction one quarter (U+00BC)",
0xBD	:"vulgar fraction one half (U+00BD)",
0xBE	:"vulgar fraction three quarters (U+00BE)",
0xBF	:"inverted question mark (U+00BF)",
0xC0	:"Latin capital letter a with grave (U+00C0)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with breve (U+0102)",
0xC4	:"Latin capital letter a with diaeresis (U+00C4)",
0xC5	:"Latin capital letter a with ring above (U+00C5)",
0xC6	:"Latin capital letter ae (U+00C6)",
0xC7	:"Latin capital letter c with cedilla (U+00C7)",
0xC8	:"Latin capital letter e with grave (U+00C8)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with circumflex (U+00CA)",
0xCB	:"Latin capital letter e with diaeresis (U+00CB)",
0xCC	:"combining grave accent (U+0300)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with circumflex (U+00CE)",
0xCF	:"Latin capital letter i with diaeresis (U+00CF)",
0xD0	:"Latin capital letter d with stroke (U+0110)",
0xD1	:"Latin capital letter n with tilde (U+00D1)",
0xD2	:"combining hook above (U+0309)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin capital letter o with horn (U+01A0)",
0xD6	:"Latin capital letter o with diaeresis (U+00D6)",
0xD7	:"multiplication sign (U+00D7)",
0xD8	:"Latin capital letter o with stroke (U+00D8)",
0xD9	:"Latin capital letter u with grave (U+00D9)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin capital letter u with circumflex (U+00DB)",
0xDC	:"Latin capital letter u with diaeresis (U+00DC)",
0xDD	:"Latin capital letter u with horn (U+01AF)",
0xDE	:"combining tilde (U+0303)",
0xDF	:"Latin small letter sharp s (U+00DF)",
0xE0	:"Latin small letter a with grave (U+00E0)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with breve (U+0103)",
0xE4	:"Latin small letter a with diaeresis (U+00E4)",
0xE5	:"Latin small letter a with ring above (U+00E5)",
0xE6	:"Latin small letter ae (U+00E6)",
0xE7	:"Latin small letter c with cedilla (U+00E7)",
0xE8	:"Latin small letter e with grave (U+00E8)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with circumflex (U+00EA)",
0xEB	:"Latin small letter e with diaeresis (U+00EB)",
0xEC	:"combining acute accent (U+0301)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with circumflex (U+00EE)",
0xEF	:"Latin small letter i with diaeresis (U+00EF)",
0xF0	:"Latin small letter d with stroke (U+0111)",
0xF1	:"Latin small letter n with tilde (U+00F1)",
0xF2	:"combining dot below (U+0323)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with horn (U+01A1)",
0xF6	:"Latin small letter o with diaeresis (U+00F6)",
0xF7	:"division sign (U+00F7)",
0xF8	:"Latin small letter o with stroke (U+00F8)",
0xF9	:"Latin small letter u with grave (U+00F9)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with circumflex (U+00FB)",
0xFC	:"Latin small letter u with diaeresis (U+00FC)",
0xFD	:"Latin small letter u with horn (U+01B0)",
0xFE	:"dong sign (U+20AB)",
0xFF	:"Latin small letter y with diaeresis (U+00FF)"
}

#EBCDIC CP500 - an alternative to CP037
ebcdic500xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"control (U+009C)",
0x05	:"horizontal tabulation (U+0009)",
0x06	:"control (U+0086)",
0x07	:"delete (U+007F)",
0x08	:"control (U+0097)",
0x09	:"control (U+008D)",
0x0A	:"control (U+008E)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"control (U+009D)",
0x15	:"control (U+0085)",
0x16	:"backspace (U+0008)",
0x17	:"control (U+0087)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"control (U+0092)",
0x1B	:"control (U+008F)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"control (U+0080)",
0x21	:"control (U+0081)",
0x22	:"control (U+0082)",
0x23	:"control (U+0083)",
0x24	:"control (U+0084)",
0x25	:"line feed (U+000A)",
0x26	:"end of transmission block (U+0017)",
0x27	:"escape (U+001B)",
0x28	:"control (U+0088)",
0x29	:"control (U+0089)",
0x2A	:"control (U+008A)",
0x2B	:"control (U+008B)",
0x2C	:"control (U+008C)",
0x2D	:"enquiry (U+0005)",
0x2E	:"acknowledge (U+0006)",
0x2F	:"bell (U+0007)",
0x30	:"control (U+0090)",
0x31	:"control (U+0091)",
0x32	:"synchronous idle (U+0016)",
0x33	:"control (U+0093)",
0x34	:"control (U+0094)",
0x35	:"control (U+0095)",
0x36	:"control (U+0096)",
0x37	:"end of transmission (U+0004)",
0x38	:"control (U+0098)",
0x39	:"control (U+0099)",
0x3A	:"control (U+009A)",
0x3B	:"control (U+009B)",
0x3C	:"device control four (U+0014)",
0x3D	:"negative acknowledge (U+0015)",
0x3E	:"control (U+009E)",
0x3F	:"substitute (U+001A)",
0x40	:"space (U+0020)",
0x41	:"no-break space (U+00A0)",
0x42	:"latin small letter a with circumflex (U+00E2)",
0x43	:"latin small letter a with diaeresis (U+00E4)",
0x44	:"latin small letter a with grave (U+00E0)",
0x45	:"latin small letter a with acute (U+00E1)",
0x46	:"latin small letter a with tilde (U+00E3)",
0x47	:"latin small letter a with ring above (U+00E5)",
0x48	:"latin small letter c with cedilla (U+00E7)",
0x49	:"latin small letter n with tilde (U+00F1)",
0x4A	:"left square bracket (U+005B)",
0x4B	:"full stop (U+002E)",
0x4C	:"less-than sign (U+003C)",
0x4D	:"left parenthesis (U+0028)",
0x4E	:"plus sign (U+002B)",
0x4F	:"exclamation mark (U+0021)",
0x50	:"ampersand (U+0026)",
0x51	:"latin small letter e with acute (U+00E9)",
0x52	:"latin small letter e with circumflex (U+00EA)",
0x53	:"latin small letter e with diaeresis (U+00EB)",
0x54	:"latin small letter e with grave (U+00E8)",
0x55	:"latin small letter i with acute (U+00ED)",
0x56	:"latin small letter i with circumflex (U+00EE)",
0x57	:"latin small letter i with diaeresis (U+00EF)",
0x58	:"latin small letter i with grave (U+00EC)",
0x59	:"latin small letter sharp s (german) (U+00DF)",
0x5A	:"right square bracket (U+005D)",
0x5B	:"dollar sign (U+0024)",
0x5C	:"asterisk (U+002A)",
0x5D	:"right parenthesis (U+0029)",
0x5E	:"semicolon (U+003B)",
0x5F	:"circumflex accent (U+005E)",
0x60	:"hyphen-minus (U+002D)",
0x61	:"solidus (U+002F)",
0x62	:"latin capital letter a with circumflex (U+00C2)",
0x63	:"latin capital letter a with diaeresis (U+00C4)",
0x64	:"latin capital letter a with grave (U+00C0)",
0x65	:"latin capital letter a with acute (U+00C1)",
0x66	:"latin capital letter a with tilde (U+00C3)",
0x67	:"latin capital letter a with ring above (U+00C5)",
0x68	:"latin capital letter c with cedilla (U+00C7)",
0x69	:"latin capital letter n with tilde (U+00D1)",
0x6A	:"broken bar (U+00A6)",
0x6B	:"comma (U+002C)",
0x6C	:"percent sign (U+0025)",
0x6D	:"low line (U+005F)",
0x6E	:"greater-than sign (U+003E)",
0x6F	:"question mark (U+003F)",
0x70	:"latin small letter o with stroke (U+00F8)",
0x71	:"latin capital letter e with acute (U+00C9)",
0x72	:"latin capital letter e with circumflex (U+00CA)",
0x73	:"latin capital letter e with diaeresis (U+00CB)",
0x74	:"latin capital letter e with grave (U+00C8)",
0x75	:"latin capital letter i with acute (U+00CD)",
0x76	:"latin capital letter i with circumflex (U+00CE)",
0x77	:"latin capital letter i with diaeresis (U+00CF)",
0x78	:"latin capital letter i with grave (U+00CC)",
0x79	:"grave accent (U+0060)",
0x7A	:"colon (U+003A)",
0x7B	:"number sign (U+0023)",
0x7C	:"commercial at (U+0040)",
0x7D	:"apostrophe (U+0027)",
0x7E	:"equals sign (U+003D)",
0x7F	:"quotation mark (U+0022)",
0x80	:"latin capital letter o with stroke (U+00D8)",
0x81	:"latin small letter a (U+0061)",
0x82	:"latin small letter b (U+0062)",
0x83	:"latin small letter c (U+0063)",
0x84	:"latin small letter d (U+0064)",
0x85	:"latin small letter e (U+0065)",
0x86	:"latin small letter f (U+0066)",
0x87	:"latin small letter g (U+0067)",
0x88	:"latin small letter h (U+0068)",
0x89	:"latin small letter i (U+0069)",
0x8A	:"left-pointing double angle quotation mark (U+00AB)",
0x8B	:"right-pointing double angle quotation mark (U+00BB)",
0x8C	:"latin small letter eth (icelandic) (U+00F0)",
0x8D	:"latin small letter y with acute (U+00FD)",
0x8E	:"latin small letter thorn (icelandic) (U+00FE)",
0x8F	:"plus-minus sign (U+00B1)",
0x90	:"degree sign (U+00B0)",
0x91	:"latin small letter j (U+006A)",
0x92	:"latin small letter k (U+006B)",
0x93	:"latin small letter l (U+006C)",
0x94	:"latin small letter m (U+006D)",
0x95	:"latin small letter n (U+006E)",
0x96	:"latin small letter o (U+006F)",
0x97	:"latin small letter p (U+0070)",
0x98	:"latin small letter q (U+0071)",
0x99	:"latin small letter r (U+0072)",
0x9A	:"feminine ordinal indicator (U+00AA)",
0x9B	:"masculine ordinal indicator (U+00BA)",
0x9C	:"latin small ligature ae (U+00E6)",
0x9D	:"cedilla (U+00B8)",
0x9E	:"latin capital ligature ae (U+00C6)",
0x9F	:"currency sign (U+00A4)",
0xA0	:"micro sign (U+00B5)",
0xA1	:"tilde (U+007E)",
0xA2	:"latin small letter s (U+0073)",
0xA3	:"latin small letter t (U+0074)",
0xA4	:"latin small letter u (U+0075)",
0xA5	:"latin small letter v (U+0076)",
0xA6	:"latin small letter w (U+0077)",
0xA7	:"latin small letter x (U+0078)",
0xA8	:"latin small letter y (U+0079)",
0xA9	:"latin small letter z (U+007A)",
0xAA	:"inverted exclamation mark (U+00A1)",
0xAB	:"inverted question mark (U+00BF)",
0xAC	:"latin capital letter eth (icelandic) (U+00D0)",
0xAD	:"latin capital letter y with acute (U+00DD)",
0xAE	:"latin capital letter thorn (icelandic) (U+00DE)",
0xAF	:"registered sign (U+00AE)",
0xB0	:"cent sign (U+00A2)",
0xB1	:"pound sign (U+00A3)",
0xB2	:"yen sign (U+00A5)",
0xB3	:"middle dot (U+00B7)",
0xB4	:"copyright sign (U+00A9)",
0xB5	:"section sign (U+00A7)",
0xB6	:"pilcrow sign (U+00B6)",
0xB7	:"vulgar fraction one quarter (U+00BC)",
0xB8	:"vulgar fraction one half (U+00BD)",
0xB9	:"vulgar fraction three quarters (U+00BE)",
0xBA	:"not sign (U+00AC)",
0xBB	:"vertical line (U+007C)",
0xBC	:"macron (U+00AF)",
0xBD	:"diaeresis (U+00A8)",
0xBE	:"acute accent (U+00B4)",
0xBF	:"multiplication sign (U+00D7)",
0xC0	:"left curly bracket (U+007B)",
0xC1	:"latin capital letter a (U+0041)",
0xC2	:"latin capital letter b (U+0042)",
0xC3	:"latin capital letter c (U+0043)",
0xC4	:"latin capital letter d (U+0044)",
0xC5	:"latin capital letter e (U+0045)",
0xC6	:"latin capital letter f (U+0046)",
0xC7	:"latin capital letter g (U+0047)",
0xC8	:"latin capital letter h (U+0048)",
0xC9	:"latin capital letter i (U+0049)",
0xCA	:"soft hyphen (U+00AD)",
0xCB	:"latin small letter o with circumflex (U+00F4)",
0xCC	:"latin small letter o with diaeresis (U+00F6)",
0xCD	:"latin small letter o with grave (U+00F2)",
0xCE	:"latin small letter o with acute (U+00F3)",
0xCF	:"latin small letter o with tilde (U+00F5)",
0xD0	:"right curly bracket (U+007D)",
0xD1	:"latin capital letter j (U+004A)",
0xD2	:"latin capital letter k (U+004B)",
0xD3	:"latin capital letter l (U+004C)",
0xD4	:"latin capital letter m (U+004D)",
0xD5	:"latin capital letter n (U+004E)",
0xD6	:"latin capital letter o (U+004F)",
0xD7	:"latin capital letter p (U+0050)",
0xD8	:"latin capital letter q (U+0051)",
0xD9	:"latin capital letter r (U+0052)",
0xDA	:"superscript one (U+00B9)",
0xDB	:"latin small letter u with circumflex (U+00FB)",
0xDC	:"latin small letter u with diaeresis (U+00FC)",
0xDD	:"latin small letter u with grave (U+00F9)",
0xDE	:"latin small letter u with acute (U+00FA)",
0xDF	:"latin small letter y with diaeresis (U+00FF)",
0xE0	:"reverse solidus (U+005C)",
0xE1	:"division sign (U+00F7)",
0xE2	:"latin capital letter s (U+0053)",
0xE3	:"latin capital letter t (U+0054)",
0xE4	:"latin capital letter u (U+0055)",
0xE5	:"latin capital letter v (U+0056)",
0xE6	:"latin capital letter w (U+0057)",
0xE7	:"latin capital letter x (U+0058)",
0xE8	:"latin capital letter y (U+0059)",
0xE9	:"latin capital letter z (U+005A)",
0xEA	:"superscript two (U+00B2)",
0xEB	:"latin capital letter o with circumflex (U+00D4)",
0xEC	:"latin capital letter o with diaeresis (U+00D6)",
0xED	:"latin capital letter o with grave (U+00D2)",
0xEE	:"latin capital letter o with acute (U+00D3)",
0xEF	:"latin capital letter o with tilde (U+00D5)",
0xF0	:"digit zero (U+0030)",
0xF1	:"digit one (U+0031)",
0xF2	:"digit two (U+0032)",
0xF3	:"digit three (U+0033)",
0xF4	:"digit four (U+0034)",
0xF5	:"digit five (U+0035)",
0xF6	:"digit six (U+0036)",
0xF7	:"digit seven (U+0037)",
0xF8	:"digit eight (U+0038)",
0xF9	:"digit nine (U+0039)",
0xFA	:"superscript three (U+00B3)",
0xFB	:"latin capital letter u with circumflex (U+00DB)",
0xFC	:"latin capital letter u with diaeresis (U+00DC)",
0xFD	:"latin capital letter u with grave (U+00D9)",
0xFE	:"latin capital letter u with acute (U+00DA)",
0xFF	:"control (U+009F)"
}


#EBCDIC CP037 - Latin-1 charset used in USA, Canada, Australia, New Zealand, South Africa,
#Brazil and Portugal
ebcdic037xtbl = { \
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"control (U+009c)",
0x05	:"horizontal tabulation (U+0009)",
0x06	:"control (U+0086)",
0x07	:"delete (U+007f)",
0x08	:"control (U+0097)",
0x09	:"control (U+008d)",
0x0a	:"control (U+008e)",
0x0b	:"vertical tabulation (U+000b)",
0x0c	:"form feed (U+000c)",
0x0d	:"carriage return (U+000d)",
0x0e	:"shift out (U+000e)",
0x0f	:"shift in (U+000f)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"control (U+009d)",
0x15	:"control (U+0085)",
0x16	:"backspace (U+0008)",
0x17	:"control (U+0087)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1a	:"control (U+0092)",
0x1b	:"control (U+008f)",
0x1c	:"file separator (U+001c)",
0x1d	:"group separator (U+001d)",
0x1e	:"record separator (U+001e)",
0x1f	:"unit separator (U+001f)",
0x20	:"control (U+0080)",
0x21	:"control (U+0081)",
0x22	:"control (U+0082)",
0x23	:"control (U+0083)",
0x24	:"control (U+0084)",
0x25	:"line feed (U+000a)",
0x26	:"end of transmission block (U+0017)",
0x27	:"escape (U+001b)",
0x28	:"control (U+0088)",
0x29	:"control (U+0089)",
0x2a	:"control (U+008a)",
0x2b	:"control (U+008b)",
0x2c	:"control (U+008c)",
0x2d	:"enquiry (U+0005)",
0x2e	:"acknowledge (U+0006)",
0x2f	:"bell (U+0007)",
0x30	:"control (U+0090)",
0x31	:"control (U+0091)",
0x32	:"synchronous idle (U+0016)",
0x33	:"control (U+0093)",
0x34	:"control (U+0094)",
0x35	:"control (U+0095)",
0x36	:"control (U+0096)",
0x37	:"end of transmission (U+0004)",
0x38	:"control (U+0098)",
0x39	:"control (U+0099)",
0x3a	:"control (U+009a)",
0x3b	:"control (U+009b)",
0x3c	:"device control four (U+0014)",
0x3d	:"negative acknowledge (U+0015)",
0x3e	:"control (U+009e)",
0x3f	:"substitute (U+001a)",
0x40	:"space (U+0020)",
0x41	:"no-break space (U+00a0)",
0x42	:"Latin small letter a with circumflex (U+00e2)",
0x43	:"Latin small letter a with diaeresis (U+00e4)",
0x44	:"Latin small letter a with grave (U+00e0)",
0x45	:"Latin small letter a with acute (U+00e1)",
0x46	:"Latin small letter a with tilde (U+00e3)",
0x47	:"Latin small letter a with ring above (U+00e5)",
0x48	:"Latin small letter c with cedilla (U+00e7)",
0x49	:"Latin small letter n with tilde (U+00f1)",
0x4a	:"cent sign (U+00a2)",
0x4b	:"full stop (U+002e)",
0x4c	:"less-than sign (U+003c)",
0x4d	:"left parenthesis (U+0028)",
0x4e	:"plus sign (U+002b)",
0x4f	:"vertical line (U+007c)",
0x50	:"ampersand (U+0026)",
0x51	:"Latin small letter e with acute (U+00e9)",
0x52	:"Latin small letter e with circumflex (U+00ea)",
0x53	:"Latin small letter e with diaeresis (U+00eb)",
0x54	:"Latin small letter e with grave (U+00e8)",
0x55	:"Latin small letter i with acute (U+00ed)",
0x56	:"Latin small letter i with circumflex (U+00ee)",
0x57	:"Latin small letter i with diaeresis (U+00ef)",
0x58	:"Latin small letter i with grave (U+00ec)",
0x59	:"Latin small letter sharp s (german) (U+00df)",
0x5a	:"exclamation mark (U+0021)",
0x5b	:"dollar sign (U+0024)",
0x5c	:"asterisk (U+002a)",
0x5d	:"right parenthesis (U+0029)",
0x5e	:"semicolon (U+003b)",
0x5f	:"not sign (U+00ac)",
0x60	:"hyphen-minus (U+002d)",
0x61	:"solidus (U+002f)",
0x62	:"Latin capital letter a with circumflex (U+00c2)",
0x63	:"Latin capital letter a with diaeresis (U+00c4)",
0x64	:"Latin capital letter a with grave (U+00c0)",
0x65	:"Latin capital letter a with acute (U+00c1)",
0x66	:"Latin capital letter a with tilde (U+00c3)",
0x67	:"Latin capital letter a with ring above (U+00c5)",
0x68	:"Latin capital letter c with cedilla (U+00c7)",
0x69	:"Latin capital letter n with tilde (U+00d1)",
0x6a	:"broken bar (U+00a6)",
0x6b	:"comma (U+002c)",
0x6c	:"percent sign (U+0025)",
0x6d	:"low line (U+005f)",
0x6e	:"greater-than sign (U+003e)",
0x6f	:"question mark (U+003f)",
0x70	:"Latin small letter o with stroke (U+00f8)",
0x71	:"Latin capital letter e with acute (U+00c9)",
0x72	:"Latin capital letter e with circumflex (U+00ca)",
0x73	:"Latin capital letter e with diaeresis (U+00cb)",
0x74	:"Latin capital letter e with grave (U+00c8)",
0x75	:"Latin capital letter i with acute (U+00cd)",
0x76	:"Latin capital letter i with circumflex (U+00ce)",
0x77	:"Latin capital letter i with diaeresis (U+00cf)",
0x78	:"Latin capital letter i with grave (U+00cc)",
0x79	:"grave accent (U+0060)",
0x7a	:"colon (U+003a)",
0x7b	:"number sign (U+0023)",
0x7c	:"commercial at (U+0040)",
0x7d	:"apostrophe (U+0027)",
0x7e	:"equals sign (U+003d)",
0x7f	:"quotation mark (U+0022)",
0x80	:"Latin capital letter o with stroke (U+00d8)",
0x81	:"Latin small letter a (U+0061)",
0x82	:"Latin small letter b (U+0062)",
0x83	:"Latin small letter c (U+0063)",
0x84	:"Latin small letter d (U+0064)",
0x85	:"Latin small letter e (U+0065)",
0x86	:"Latin small letter f (U+0066)",
0x87	:"Latin small letter g (U+0067)",
0x88	:"Latin small letter h (U+0068)",
0x89	:"Latin small letter i (U+0069)",
0x8a	:"left-pointing double angle quotation mark (U+00ab)",
0x8b	:"right-pointing double angle quotation mark (U+00bb)",
0x8c	:"Latin small letter eth (icelandic) (U+00f0)",
0x8d	:"Latin small letter y with acute (U+00fd)",
0x8e	:"Latin small letter thorn (icelandic) (U+00fe)",
0x8f	:"plus-minus sign (U+00b1)",
0x90	:"degree sign (U+00b0)",
0x91	:"Latin small letter j (U+006a)",
0x92	:"Latin small letter k (U+006b)",
0x93	:"Latin small letter l (U+006c)",
0x94	:"Latin small letter m (U+006d)",
0x95	:"Latin small letter n (U+006e)",
0x96	:"Latin small letter o (U+006f)",
0x97	:"Latin small letter p (U+0070)",
0x98	:"Latin small letter q (U+0071)",
0x99	:"Latin small letter r (U+0072)",
0x9a	:"feminine ordinal indicator (U+00aa)",
0x9b	:"masculine ordinal indicator (U+00ba)",
0x9c	:"Latin small ligature ae (U+00e6)",
0x9d	:"cedilla (U+00b8)",
0x9e	:"Latin capital ligature ae (U+00c6)",
0x9f	:"currency sign (U+00a4)",
0xa0	:"micro sign (U+00b5)",
0xa1	:"tilde (U+007e)",
0xa2	:"Latin small letter s (U+0073)",
0xa3	:"Latin small letter t (U+0074)",
0xa4	:"Latin small letter u (U+0075)",
0xa5	:"Latin small letter v (U+0076)",
0xa6	:"Latin small letter w (U+0077)",
0xa7	:"Latin small letter x (U+0078)",
0xa8	:"Latin small letter y (U+0079)",
0xa9	:"Latin small letter z (U+007a)",
0xaa	:"inverted exclamation mark (U+00a1)",
0xab	:"inverted question mark (U+00bf)",
0xac	:"Latin capital letter eth (icelandic) (U+00d0)",
0xad	:"Latin capital letter y with acute (U+00dd)",
0xae	:"Latin capital letter thorn (icelandic) (U+00de)",
0xaf	:"registered sign (U+00ae)",
0xb0	:"circumflex accent (U+005e)",
0xb1	:"pound sign (U+00a3)",
0xb2	:"yen sign (U+00a5)",
0xb3	:"middle dot (U+00b7)",
0xb4	:"copyright sign (U+00a9)",
0xb5	:"section sign (U+00a7)",
0xb6	:"pilcrow sign (U+00b6)",
0xb7	:"vulgar fraction one quarter (U+00bc)",
0xb8	:"vulgar fraction one half (U+00bd)",
0xb9	:"vulgar fraction three quarters (U+00be)",
0xba	:"left square bracket (U+005b)",
0xbb	:"right square bracket (U+005d)",
0xbc	:"macron (U+00af)",
0xbd	:"diaeresis (U+00a8)",
0xbe	:"acute accent (U+00b4)",
0xbf	:"multiplication sign (U+00d7)",
0xc0	:"left curly bracket (U+007b)",
0xc1	:"Latin capital letter a (U+0041)",
0xc2	:"Latin capital letter b (U+0042)",
0xc3	:"Latin capital letter c (U+0043)",
0xc4	:"Latin capital letter d (U+0044)",
0xc5	:"Latin capital letter e (U+0045)",
0xc6	:"Latin capital letter f (U+0046)",
0xc7	:"Latin capital letter g (U+0047)",
0xc8	:"Latin capital letter h (U+0048)",
0xc9	:"Latin capital letter i (U+0049)",
0xca	:"soft hyphen (U+00ad)",
0xcb	:"Latin small letter o with circumflex (U+00f4)",
0xcc	:"Latin small letter o with diaeresis (U+00f6)",
0xcd	:"Latin small letter o with grave (U+00f2)",
0xce	:"Latin small letter o with acute (U+00f3)",
0xcf	:"Latin small letter o with tilde (U+00f5)",
0xd0	:"right curly bracket (U+007d)",
0xd1	:"Latin capital letter j (U+004a)",
0xd2	:"Latin capital letter k (U+004b)",
0xd3	:"Latin capital letter l (U+004c)",
0xd4	:"Latin capital letter m (U+004d)",
0xd5	:"Latin capital letter n (U+004e)",
0xd6	:"Latin capital letter o (U+004f)",
0xd7	:"Latin capital letter p (U+0050)",
0xd8	:"Latin capital letter q (U+0051)",
0xd9	:"Latin capital letter r (U+0052)",
0xda	:"superscript one (U+00b9)",
0xdb	:"Latin small letter u with circumflex (U+00fb)",
0xdc	:"Latin small letter u with diaeresis (U+00fc)",
0xdd	:"Latin small letter u with grave (U+00f9)",
0xde	:"Latin small letter u with acute (U+00fa)",
0xdf	:"Latin small letter y with diaeresis (U+00ff)",
0xe0	:"reverse solidus (U+005c)",
0xe1	:"division sign (U+00f7)",
0xe2	:"Latin capital letter s (U+0053)",
0xe3	:"Latin capital letter t (U+0054)",
0xe4	:"Latin capital letter u (U+0055)",
0xe5	:"Latin capital letter v (U+0056)",
0xe6	:"Latin capital letter w (U+0057)",
0xe7	:"Latin capital letter x (U+0058)",
0xe8	:"Latin capital letter y (U+0059)",
0xe9	:"Latin capital letter z (U+005a)",
0xea	:"superscript two (U+00b2)",
0xeb	:"Latin capital letter o with circumflex (U+00d4)",
0xec	:"Latin capital letter o with diaeresis (U+00d6)",
0xed	:"Latin capital letter o with grave (U+00d2)",
0xee	:"Latin capital letter o with acute (U+00d3)",
0xef	:"Latin capital letter o with tilde (U+00d5)",
0xf0	:"digit zero (U+0030)",
0xf1	:"digit one (U+0031)",
0xf2	:"digit two (U+0032)",
0xf3	:"digit three (U+0033)",
0xf4	:"digit four (U+0034)",
0xf5	:"digit five (U+0035)",
0xf6	:"digit six (U+0036)",
0xf7	:"digit seven (U+0037)",
0xf8	:"digit eight (U+0038)",
0xf9	:"digit nine (U+0039)",
0xfa	:"superscript three (U+00b3)",
0xfb	:"Latin capital letter u with circumflex (U+00db)",
0xfc	:"Latin capital letter u with diaeresis (U+00dc)",
0xfd	:"Latin capital letter u with grave (U+00d9)",
0xfe	:"Latin capital letter u with acute (U+00da)",
0xff	:"control (U+009f)"
}

#NEXTSTEP
nextstepxtbl={\
0x00	:"NUL (ASCII control character)",
0x01	:"SOH (ASCII control character)",
0x02	:"STX (ASCII control character)",
0x03	:"ETX (ASCII control character)",
0x04	:"EOT (ASCII control character)",
0x05	:"ENQ (ASCII control character)",
0x06	:"ACK (ASCII control character)",
0x07	:"BEL (ASCII control character)",
0x08	:"Backspace (ASCII control character)",
0x09	:"Tab (ASCII control character)",
0x0a	:"Newline",
0x0b	:"VT (ASCII control character)",
0x0c	:"FF (ASCII control character)",
0x0d	:"Carriage return",
0x0e	:"SO (ASCII control character)",
0x0f	:"SI (ASCII control character)",
0x10	:"DLE (ASCII control character)",
0x11	:"DC1 (ASCII control character)",
0x12	:"DC2 (ASCII control character)",
0x13	:"DC3 (ASCII control character)",
0x14	:"DC4 (ASCII control character)",
0x15	:"NAK (ASCII control character)",
0x16	:"SYN (ASCII control character)",
0x17	:"ETB (ASCII control character)",
0x18	:"CAN (ASCII control character)",
0x19	:"EM (ASCII control character)",
0x1a	:"SUB (ASCII control character)",
0x1b	:"ESC (ASCII control character)",
0x1c	:"FS (ASCII control character)",
0x1d	:"GS (ASCII control character)",
0x1e	:"RS (ASCII control character)",
0x1f	:"US (ASCII control character)",
0x20	:"Space",
0x21	:"Exclamation point",
0x22	:"Double quote",
0x23	:"Pound sign",
0x24	:"Dollar sign",
0x25	:"Percent sign",
0x26	:"Ampersand",
0x27	:"Right single quote / apostrophe",
0x28	:"Left parenthesis",
0x29	:"Right parenthesis",
0x2a	:"Asterisk",
0x2b	:"Plus",
0x2c	:"Comma",
0x2d	:"Hyphen",
0x2e	:"Period",
0x2f	:"Slash",
0x30	:"Latin digit 0",
0x31	:"Latin digit 1",
0x32	:"Latin digit 2",
0x33	:"Latin digit 3",
0x34	:"Latin digit 4",
0x35	:"Latin digit 5",
0x36	:"Latin digit 6",
0x37	:"Latin digit 7",
0x38	:"Latin digit 8",
0x39	:"Latin digit 9",
0x3a	:"Colon",
0x3b	:"Semi-colon",
0x3c	:"Less-than",
0x3d	:"Equal-sign",
0x3e	:"Greater-than",
0x3f	:"Question mark",
0x40	:"At-sign",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5b	:"Left square bracket",
0x5c	:"Backslash",
0x5d	:"Right square bracket",
0x5e	:"Caret",
0x5f	:"Underscore",
0x60	:"Left single quote",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7b	:"Left curly bracket",
0x7c	:"Pipe",
0x7d	:"Right curly bracket",
0x7e	:"Tilde",
0x7f	:"DEL",
0x80	:"no-break space (U+00a0)",
0x81	:"Latin capital letter a with grave (U+00c0)",
0x82	:"Latin capital letter a with acute (U+00c1)",
0x83	:"Latin capital letter a with circumflex (U+00c2)",
0x84	:"Latin capital letter a with tilde (U+00c3)",
0x85	:"Latin capital letter a with diaeresis (U+00c4)",
0x86	:"Latin capital letter a with ring (U+00c5)",
0x87	:"Latin capital letter c with cedilla (U+00c7)",
0x88	:"Latin capital letter e with grave (U+00c8)",
0x89	:"Latin capital letter e with acute (U+00c9)",
0x8A	:"Latin capital letter e with circumflex (U+00ca)",
0x8B	:"Latin capital letter e with diaeresis (U+00cb)",
0x8C	:"Latin capital letter i with grave (U+00cc)",
0x8D	:"Latin capital letter i with acute (U+00cd)",
0x8E	:"Latin capital letter i with circumflex (U+00ce)",
0x8F	:"Latin capital letter i with diaeresis (U+00cf)",
0x90	:"Latin capital letter eth (U+00d0)",
0x91	:"Latin capital letter n with tilde (U+00d1)",
0x92	:"Latin capital letter o with grave (U+00d2)",
0x93	:"Latin capital letter o with acute (U+00d3)",
0x94	:"Latin capital letter o with circumflex (U+00d4)",
0x95	:"Latin capital letter o with tilde (U+00d5)",
0x96	:"Latin capital letter o with diaeresis (U+00d6)",
0x97	:"Latin capital letter u with grave (U+00d9)",
0x98	:"Latin capital letter u with acute (U+00da)",
0x99	:"Latin capital letter u with circumflex (U+00db)",
0x9A	:"Latin capital letter u with diaeresis (U+00dc)",
0x9B	:"Latin capital letter y with acute (U+00dd)",
0x9C	:"Latin capital letter thorn (U+00de)",
0x9D	:"micro sign  (U+00b5)",
0x9E	:"multiplication sign (U+00d7)",
0x9F	:"division sign (U+00f7)",
0xA0	:"copyright sign (U+00a9)",
0xA1	:"inverted exclamation mark (U+00a1)",
0xA2	:"cent sign (U+00a2)",
0xA3	:"pound sign (U+00a3)",
0xA4	:"fraction slash (U+2044)",
0xA5	:"yen sign (U+00a5)",
0xA6	:"Latin small letter f with hook (U+0192)",
0xA7	:"section sign (U+00a7)",
0xA8	:"currency sign (U+00a4)",
0xA9	:"right single quotation mark (U+2019)",
0xAA	:"left double quotation mark (U+201c)",
0xAB	:"left-pointing double angle quotation mark (U+00ab)",
0xAC	:"single left-pointing angle quotation mark (U+2039)",
0xAD	:"single right-pointing angle quotation mark (U+203a)",
0xAE	:"Latin small ligature fi (U+fb01)",
0xAF	:"Latin small ligature fl (U+fb02)",
0xB0	:"registered sign (U+00ae)",
0xB1	:"en dash (U+2013)",
0xB2	:"dagger (U+2020)",
0xB3	:"double dagger (U+2021)",
0xB4	:"middle dot (U+00b7)",
0xB5	:"broken bar (U+00a6)",
0xB6	:"pilcrow sign (U+00b6)",
0xB7	:"bullet (U+2022)",
0xB8	:"single low-9 quotation mark (U+201a)",
0xB9	:"double low-9 quotation mark (U+201e)",
0xBA	:"right double quotation mark (U+201d)",
0xBB	:"right-pointing double angle quotation mark (U+00bb)",
0xBC	:"horizontal ellipsis (U+2026)",
0xBD	:"per mille sign (U+2030)",
0xBE	:"not sign (U+00ac)",
0xBF	:"inverted question mark (U+00bf)",
0xC0	:"superscript one (U+00b9)",
0xC1	:"modifier letter grave accent (U+02cb)",
0xC2	:"acute accent (U+00b4)",
0xC3	:"modifier letter circumflex accent (U+02c6)",
0xC4	:"small tilde (U+02dc)",
0xC5	:"macron (U+00af)",
0xC6	:"breve (U+02d8)",
0xC7	:"dot above (U+02d9)",
0xC8	:"diaeresis (U+00a8)",
0xC9	:"superscript two (U+00b2)",
0xCA	:"ring above (U+02da)",
0xCB	:"cedilla (U+00b8)",
0xCC	:"superscript three (U+00b3)",
0xCD	:"double acute accent (U+02dd)",
0xCE	:"ogonek (U+02db)",
0xCF	:"caron (U+02c7)",
0xD0	:"em dash (U+2014)",
0xD1	:"plus-minus sign (U+00b1)",
0xD2	:"vulgar fraction one quarter (U+00bc)",
0xD3	:"vulgar fraction one half (U+00bd)",
0xD4	:"vulgar fraction three quarters (U+00be)",
0xD5	:"Latin small letter a with grave (U+00e0)",
0xD6	:"Latin small letter a with acute (U+00e1)",
0xD7	:"Latin small letter a with circumflex (U+00e2)",
0xD8	:"Latin small letter a with tilde (U+00e3)",
0xD9	:"Latin small letter a with diaeresis (U+00e4)",
0xDA	:"Latin small letter a with ring above (U+00e5)",
0xDB	:"Latin small letter c with cedilla (U+00e7)",
0xDC	:"Latin small letter e with grave (U+00e8)",
0xDD	:"Latin small letter e with acute (U+00e9)",
0xDE	:"Latin small letter e with circumflex (U+00ea)",
0xDF	:"Latin small letter e with diaeresis (U+00eb)",
0xE0	:"Latin small letter i with grave (U+00ec)",
0xE1	:"Latin capital letter ae (U+00c6)",
0xE2	:"Latin small letter i with acute (U+00ed)",
0xE3	:"feminine ordinal indicator (U+00aa)",
0xE4	:"Latin small letter i with circumflex (U+00ee)",
0xE5	:"Latin small letter i with diaeresis (U+00ef)",
0xE6	:"Latin small letter eth (U+00f0)",
0xE7	:"Latin small letter n with tilde (U+00f1)",
0xE8	:"Latin capital letter l with stroke (U+0141)",
0xE9	:"Latin capital letter o with stroke (U+00d8)",
0xEA	:"Latin capital ligature oe (U+0152)",
0xEB	:"masculine ordinal indicator (U+00ba)",
0xEC	:"Latin small letter o with grave (U+00f2)",
0xED	:"Latin small letter o with acute (U+00f3)",
0xEE	:"Latin small letter o with circumflex (U+00f4)",
0xEF	:"Latin small letter o with tilde (U+00f5)",
0xF0	:"Latin small letter o with diaeresis (U+00f6)",
0xF1	:"Latin small letter ae (U+00e6)",
0xF2	:"Latin small letter u with grave (U+00f9)",
0xF3	:"Latin small letter u with acute (U+00fa)",
0xF4	:"Latin small letter u with circumflex (U+00fb)",
0xF5	:"Latin small letter dotless i (U+0131)",
0xF6	:"Latin small letter u with diaeresis (U+00fc)",
0xF7	:"Latin small letter y with acute (U+00fd)",
0xF8	:"Latin small letter l with stroke (U+0142)",
0xF9	:"Latin small letter o with stroke (U+00f8)",
0xFA	:"Latin small ligature oe (U+0153)",
0xFB	:"Latin small letter sharp s (U+00df)",
0xFC	:"Latin small letter thorn (U+00fe)",
0xFD	:"Latin small letter y with diaeresis (U+00ff)",
0xFE	:".notdef, replacement character (U+fffd)",
0xFF	:".notdef, replacement character (U+fffd)",
}

#PASCII Indian national standard for Perso-Arabic.
pasciixtbl={\
0x00	:"NUL (U+0000)",
0x01	:"SOH (U+0001)",
0x02	:"STX (U+0002)",
0x03	:"ETX (U+0003)",
0x04	:"EOT (U+0004)",
0x05	:"ENQ (U+0005)",
0x06	:"ACK (U+0006)",
0x07	:"BEL (U+0007)",
0x08	:"Backspace (U+0008)",
0x09	:"Tab (U+0009)",
0x0a	:"Newline (U+000A)",
0x0b	:"Vertical tab (U+000B)",
0x0c	:"Form feed (U+000C)",
0x0d	:"Carriage return (U+000D)",
0x0e	:"SO (U+000E)",
0x0f	:"SI (U+000F)",
0x10	:"DLE (U+0010)",
0x11	:"DC1 (U+0011)",
0x12	:"DC2 (U+0012)",
0x13	:"DC3 (U+0013)",
0x14	:"DC4 (U+0014)",
0x15	:"NAK (U+0015)",
0x16	:"SYN (U+0016)",
0x17	:"ETB (U+0017)",
0x18	:"CAN (U+0018)",
0x19	:"EM (U+0019)",
0x1a	:"SUB (U+001A)",
0x1b	:"Escape (U+001B)",
0x1c	:"FS (U+001C)",
0x1d	:"GS (U+001D)",
0x1e	:"RS (U+001E)",
0x1f	:"US (U+001F)",
0x20	:"Space (U+0020)",
0x21	:"Exclamation point (U+0021)",
0x22	:"Double quote (U+0022)",
0x23	:"Pound sign (U+0023)",
0x24	:"Dollar sign (U+0024)",
0x25	:"Percent sign (U+0025)",
0x26	:"Ampersand (U+0026)",
0x27	:"Apostrophe (U+0027)",
0x28	:"Left parenthesis (U+0028)",
0x29	:"Right parenthesis (U+0029)",
0x2a	:"Asterisk (U+002A)",
0x2b	:"Plus (U+002B)",
0x2c	:"Comma (U+002C)",
0x2d	:"Hyphen (U+002D)",
0x2e	:"Period (U+002E)",
0x2f	:"Slash (U+002F)",
0x30	:"Latin digit 0 (U+0030)",
0x31	:"Latin digit 1 (U+0031)",
0x32	:"Latin digit 2 (U+0032)",
0x33	:"Latin digit 3 (U+0033)",
0x34	:"Latin digit 4 (U+0034)",
0x35	:"Latin digit 5 (U+0035)",
0x36	:"Latin digit 6 (U+0036)",
0x37	:"Latin digit 7 (U+0037)",
0x38	:"Latin digit 8 (U+0038)",
0x39	:"Latin digit 9 (U+0039)",
0x3a	:"Colon (U+003A)",
0x3b	:"Semi-colon (U+003B)",
0x3c	:"Less-than (U+003C)",
0x3d	:"Equal-sign (U+003D)",
0x3e	:"Greater-than (U+003E)",
0x3f	:"Question mark (U+003F)",
0x40	:"At-sign (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5b	:"Left square bracket (U+005B)",
0x5c	:"Backslash (U+005C)",
0x5d	:"Right square bracket (U+005D)",
0x5e	:"Caret (U+005E)",
0x5f	:"Underscore (U+005F)",
0x60	:"Left single quote (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7b	:"Left curly bracket (U+007B)",
0x7c	:"Vertical line (U+007C)",
0x7d	:"Right curly bracket (U+007D)",
0x7e	:"Tilde (U+007E)",
0x7f	:"DEL (U+007F)",
0x80	:"unused (U+FFFD)",
0x81	:"tatweel (kashida) (U+0640)",
0x82	:"alif (U+0627)",
0x83	:"alif with madda (U+0622)",
0x84	:"be (U+0628)",
0x85	:"beeh (U+067B)",
0x86	:"beheh (U+0680)",
0x87	:"pe (U+067E)",
0x88	:"peheh (U+06A6)",
0x89	:"te (U+062A)",
0x8A	:"te marbuta (U+0629)",
0x8B	:"teheh (U+067F)",
0x8C	:"teh with three dots above downwards (U+067D)",
0x8D	:"tte (U+0679)",
0x8E	:"se (U+062B)",
0x8F	:"jeem (U+062C)",
0x90	:"dyeh (U+0684)",
0x91	:"nyeh (U+0683)",
0x92	:"che (U+0686)",
0x93	:"tcheheh (U+0687)",
0x94	:"hay (U+062D)",
0x95	:"khay (U+062E)",
0x96	:"daal (U+062F)",
0x97	:"dahal (U+068C)",
0x98	:"daal (U+0688)",
0x99	:"dal with three dots above downwards (U+068F)",
0x9A	:"ddahal (U+068D)",
0x9B	:"zaal (U+0630)",
0x9C	:"reh (U+0631)",
0x9D	:"rreh (U+0691)",
0x9E	:"rhey (U+0691 U+06BE)",
0x9F	:"ze (U+0632)",
0xA0	:"zhay (U+0698)",
0xA1	:"seen (U+0633)",
0xA2	:"sheen (U+0634)",
0xA3	:"suad (U+0635)",
0xA4	:"zuad (U+0636)",
0xA5	:"toe (U+0637)",
0xA6	:"zoe (U+0638)",
0xA7	:"ain (U+0639)",
0xA8	:"ghain (U+063A)",
0xA9	:"fe (U+0641)",
0xAA	:"qaaf (U+0642)",
0xAB	:"kaaf (U+06A9)",
0xAC	:"swash kaf (U+06AA)",
0xAD	:"gaaf (U+06AF)",
0xAE	:"gueh (U+06B3)",
0xAF	:"nge (U+06B1)",
0xB0	:"laam (U+0644)",
0xB1	:"meem (U+0645)",
0xB2	:"noon (U+0646)",
0xB3	:"noon ghunna (U+06BA)",
0xB4	:"nnoonn (U+06BB)",
0xB5	:"vao (U+0648)",
0xB6	:"vao with ring (U+06C4)",
0xB7	:"he (U+06C1)",
0xB8	:"heh doachashmee (U+06BE)",
0xB9	:"hamza (U+0621)",
0xBA	:"ye (U+06CC)",
0xBB	:"(ye with circle below) (U+FFFD)",
0xBC	:"(bari ye with half circle above) (U+FFFD)",
0xBD	:"yeh barree (bari ye) (U+06D2)",
0xBE	:"fatha (zabar) (U+064E)",
0xBF	:"kasra (zer) (U+0650)",
0xC0	:"damma (pesh) (U+064F)",
0xC1	:"inverted damma (ulta pesh) (U+0657)",
0xC2	:"hamza above (U+0654)",
0xC3	:"hamza below (U+0655)",
0xC4	:"hamza above (Kashmiri) (???????)",
0xC5	:"hamza below (Kashmiri) (???????)",
0xC6	:"shadda (tashdid) (U+0651)",
0xC7	:"madda above (madd) (U+0653)",
0xC8	:"sukun (jazm) (U+0652)",
0xC9	:"superscript alef (U+0670)",
0xCA	:"subscript alef (U+0656)",
0xCB	:"alef wasla (U+0671)",
0xCC	:"tafsiliya (???????)",
0xCD	:"sign takhallus (U+0614)",
0xCE	:"arabic comma (U+060C)",
0xCF	:"sign sallallahou alayhe wassallam (U+0610)",
0xD0	:"sign radi allahou anhu (U+0613)",
0xD1	:"sign rahmatullah alayhe (U+0612)",
0xD2	:"sign alayhe assallam (U+0611)",
0xD3	:"sign 'superscript qaf' (U+FFFD)",
0xD4	:"sign 'superscript kaf' (U+FFFD)",
0xD5	:"sign 'superscript laam-alif' (U+FFFD)",
0xD6	:"sign 'superscript jeem' (U+FFFD)",
0xD7	:"sign 'superscript meem' (U+FFFD)",
0xD8	:"arabic year symbol (U+0601)",
0xD9	:"arabic percent sign (U+066A)",
0xDA	:"arabic date separator (U+060D)",
0xDB	:"arabic decimal separator (U+066B)",
0xDC	:"extended arabic-indic digit 0 (U+06F0)",
0xDD	:"extended arabic-indic digit 1 (U+06F1)",
0xDE	:"extended arabic-indic digit 2 (U+06F2)",
0xDF	:"extended arabic-indic digit 3 (U+06F3)",
0xE0	:"extended arabic-indic digit 4 (U+06F4)",
0xE1	:"extended arabic-indic digit 5 (U+06F5)",
0xE2	:"extended arabic-indic digit 6 (U+06F6)",
0xE3	:"extended arabic-indic digit 7 (U+06F7)",
0xE4	:"extended arabic-indic digit 8 (U+06F8)",
0xE5	:"extended arabic-indic digit 9 (U+06F9)",
0xE6	:"exclamation point (U+0021)",
0xE7	:"left double quote (U+201C)",
0xE8	:"right double quote (U+201D)",
0xE9	:"left single quote (U+2018)",
0xEA	:"right single quote (U+2019)",
0xEB	:"left parenthesis (U+0028)",
0xEC	:"right parenthesis (U+0029)",
0xED	:"asterisk (U+002A)",
0xEE	:"plus sign (U+002B)",
0xEF    :"ATR (change writing system/display mode per next byte)",
0xF0	:"minus sign (U+002D)",
0xF1	:"forward slash (U+002F)",
0xF2	:"arabic semi-colon (U+061B)",
0xF3	:"colon (U+003A)",
0xF4	:"arabic question mark (U+061F)",
0xF5	:"equal sign (U+003C)",
0xF6	:"full stop (U+06D4)",
0xF7	:"white circle (ayat end) (U+25CB)",
0xF8	:"filled circle (U+25CF)",
0xF9	:"arabic thousand separator (U+066C)",
0xFA	:"reserved (U+FFFD)",
0xFB	:"reserved (U+FFFD)",
0xFC	:"empty circle (U+25CC)",
0xFD	:"dot symbol (U+00B7)",
0xFE	:"reserved (U+FFFD)",
0xFF	:"reserved (U+FFFD)"
}


#TIS-620 Thai national standard. Almost identical to ISO-8859-11
tis620xtbl={\
0x00	:"null (U+0000)",
0x01	:"start of heading (U+0001)",
0x02	:"start of text (U+0002)",
0x03	:"end of text (U+0003)",
0x04	:"end of transmission (U+0004)",
0x05	:"enquiry (U+0005)",
0x06	:"acknowledge (U+0006)",
0x07	:"bell (U+0007)",
0x08	:"backspace (U+0008)",
0x09	:"horizontal tabulation (U+0009)",
0x0A	:"line feed (U+000A)",
0x0B	:"vertical tabulation (U+000B)",
0x0C	:"form feed (U+000C)",
0x0D	:"carriage return (U+000D)",
0x0E	:"shift out (U+000E)",
0x0F	:"shift in (U+000F)",
0x10	:"data link escape (U+0010)",
0x11	:"device control one (U+0011)",
0x12	:"device control two (U+0012)",
0x13	:"device control three (U+0013)",
0x14	:"device control four (U+0014)",
0x15	:"negative acknowledge (U+0015)",
0x16	:"synchronous idle (U+0016)",
0x17	:"end of transmission block (U+0017)",
0x18	:"cancel (U+0018)",
0x19	:"end of medium (U+0019)",
0x1A	:"substitute (U+001A)",
0x1B	:"escape (U+001B)",
0x1C	:"file separator (U+001C)",
0x1D	:"group separator (U+001D)",
0x1E	:"record separator (U+001E)",
0x1F	:"unit separator (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"delete (U+007F)",
0x80	:"<control> (U+0080)",
0x81	:"<control> (U+0081)",
0x82	:"<control> (U+0082)",
0x83	:"<control> (U+0083)",
0x84	:"<control> (U+0084)",
0x85	:"<control> (U+0085)",
0x86	:"<control> (U+0086)",
0x87	:"<control> (U+0087)",
0x88	:"<control> (U+0088)",
0x89	:"<control> (U+0089)",
0x8A	:"<control> (U+008A)",
0x8B	:"<control> (U+008B)",
0x8C	:"<control> (U+008C)",
0x8D	:"<control> (U+008D)",
0x8E	:"<control> (U+008E)",
0x8F	:"<control> (U+008F)",
0x90	:"<control> (U+0090)",
0x91	:"<control> (U+0091)",
0x92	:"<control> (U+0092)",
0x93	:"<control> (U+0093)",
0x94	:"<control> (U+0094)",
0x95	:"<control> (U+0095)",
0x96	:"<control> (U+0096)",
0x97	:"<control> (U+0097)",
0x98	:"<control> (U+0098)",
0x99	:"<control> (U+0099)",
0x9A	:"<control> (U+009A)",
0x9B	:"<control> (U+009B)",
0x9C	:"<control> (U+009C)",
0x9D	:"<control> (U+009D)",
0x9E	:"<control> (U+009E)",
0x9F	:"<control> (U+009F)",
0xA0	:"reserved",
0xA1	:"thai character ko kai (U+0E01)",
0xA2	:"thai character kho khai (U+0E02)",
0xA3	:"thai character kho khuat (U+0E03)",
0xA4	:"thai character kho khwai (U+0E04)",
0xA5	:"thai character kho khon (U+0E05)",
0xA6	:"thai character kho rakhang (U+0E06)",
0xA7	:"thai character ngo ngu (U+0E07)",
0xA8	:"thai character cho chan (U+0E08)",
0xA9	:"thai character cho ching (U+0E09)",
0xAA	:"thai character cho chang (U+0E0A)",
0xAB	:"thai character so so (U+0E0B)",
0xAC	:"thai character cho choe (U+0E0C)",
0xAD	:"thai character yo ying (U+0E0D)",
0xAE	:"thai character do chada (U+0E0E)",
0xAF	:"thai character to patak (U+0E0F)",
0xB0	:"thai character tho than (U+0E10)",
0xB1	:"thai character tho nangmontho (U+0E11)",
0xB2	:"thai character tho phuthao (U+0E12)",
0xB3	:"thai character no nen (U+0E13)",
0xB4	:"thai character do dek (U+0E14)",
0xB5	:"thai character to tao (U+0E15)",
0xB6	:"thai character tho thung (U+0E16)",
0xB7	:"thai character tho thahan (U+0E17)",
0xB8	:"thai character tho thong (U+0E18)",
0xB9	:"thai character no nu (U+0E19)",
0xBA	:"thai character bo baimai (U+0E1A)",
0xBB	:"thai character po pla (U+0E1B)",
0xBC	:"thai character pho phung (U+0E1C)",
0xBD	:"thai character fo fa (U+0E1D)",
0xBE	:"thai character pho phan (U+0E1E)",
0xBF	:"thai character fo fan (U+0E1F)",
0xC0	:"thai character pho samphao (U+0E20)",
0xC1	:"thai character mo ma (U+0E21)",
0xC2	:"thai character yo yak (U+0E22)",
0xC3	:"thai character ro rua (U+0E23)",
0xC4	:"thai character ru (U+0E24)",
0xC5	:"thai character lo ling (U+0E25)",
0xC6	:"thai character lu (U+0E26)",
0xC7	:"thai character wo waen (U+0E27)",
0xC8	:"thai character so sala (U+0E28)",
0xC9	:"thai character so rusi (U+0E29)",
0xCA	:"thai character so sua (U+0E2A)",
0xCB	:"thai character ho hip (U+0E2B)",
0xCC	:"thai character lo chula (U+0E2C)",
0xCD	:"thai character o ang (U+0E2D)",
0xCE	:"thai character ho nokhuk (U+0E2E)",
0xCF	:"thai character paiyannoi (U+0E2F)",
0xD0	:"thai character sara a (U+0E30)",
0xD1	:"thai character mai han-akat (U+0E31)",
0xD2	:"thai character sara aa (U+0E32)",
0xD3	:"thai character sara am (U+0E33)",
0xD4	:"thai character sara i (U+0E34)",
0xD5	:"thai character sara ii (U+0E35)",
0xD6	:"thai character sara ue (U+0E36)",
0xD7	:"thai character sara uee (U+0E37)",
0xD8	:"thai character sara u (U+0E38)",
0xD9	:"thai character sara uu (U+0E39)",
0xDA	:"thai character phinthu (U+0E3A)",
0xDB	:"Unused",
0xDC	:"Unused",
0xDD	:"Unused",
0xDE	:"Unused",
0xDF	:"thai currency symbol baht (U+0E3F)",
0xE0	:"thai character sara e (U+0E40)",
0xE1	:"thai character sara ae (U+0E41)",
0xE2	:"thai character sara o (U+0E42)",
0xE3	:"thai character sara ai maimuan (U+0E43)",
0xE4	:"thai character sara ai maimalai (U+0E44)",
0xE5	:"thai character lakkhangyao (U+0E45)",
0xE6	:"thai character maiyamok (U+0E46)",
0xE7	:"thai character maitaikhu (U+0E47)",
0xE8	:"thai character mai ek (U+0E48)",
0xE9	:"thai character mai tho (U+0E49)",
0xEA	:"thai character mai tri (U+0E4A)",
0xEB	:"thai character mai chattawa (U+0E4B)",
0xEC	:"thai character thanthakhat (U+0E4C)",
0xED	:"thai character nikhahit (U+0E4D)",
0xEE	:"thai character yamakkan (U+0E4E)",
0xEF	:"thai character fongman (U+0E4F)",
0xF0	:"thai digit zero (U+0E50)",
0xF1	:"thai digit one (U+0E51)",
0xF2	:"thai digit two (U+0E52)",
0xF3	:"thai digit three (U+0E53)",
0xF4	:"thai digit four (U+0E54)",
0xF5	:"thai digit five (U+0E55)",
0xF6	:"thai digit six (U+0E56)",
0xF7	:"thai digit seven (U+0E57)",
0xF8	:"thai digit eight (U+0E58)",
0xF9	:"thai digit nine (U+0E59)",
0xFA	:"thai character angkhankhu (U+0E5A)",
0xFB	:"thai character khomut (U+0E5B)",
0xFC	:"Unused",
0xFD	:"Unused",
0xFE	:"Unused",
0xFF	:"Unused",
}

isciixtbl = { \
0x00   :"NUL (ASCII control character)",
0x01   :"SOH (ASCII control character)",
0x02   :"STX (ASCII control character)",
0x03   :"ETX (ASCII control character)",
0x04   :"EOT (ASCII control character)",
0x05   :"ENQ (ASCII control character)",
0x06   :"ACK (ASCII control character)",
0x07   :"BEL (ASCII control character)",
0x08   :"Backspace (ASCII control character)",
0x09   :"Tab (ASCII control character)",
0x0a   :"Newline (writing system/display mode reset to default)",
0x0b   :"VT (ASCII control character)",
0x0c   :"FF (ASCII control character)",
0x0d   :"Carriage return",
0x0e   :"SO (ASCII control character)",
0x0f   :"SI (ASCII control character)",
0x10   :"DLE (ASCII control character)",
0x11   :"DC1 (ASCII control character)",
0x12   :"DC2 (ASCII control character)",
0x13   :"DC3 (ASCII control character)",
0x14   :"DC4 (ASCII control character)",
0x15   :"NAK (ASCII control character)",
0x16   :"SYN (ASCII control character)",
0x17   :"ETB (ASCII control character)",
0x18   :"CAN (ASCII control character)",
0x19   :"EM (ASCII control character)",
0x1a   :"SUB (ASCII control character)",
0x1b   :"ESC (ASCII control character)",
0x1c   :"FS (ASCII control character)",
0x1d   :"GS (ASCII control character)",
0x1e   :"RS (ASCII control character)",
0x1f   :"US (ASCII control character)",
0x20   :"Space",
0x21   :"Exclamation point",
0x22   :"Double quote",
0x23   :"Pound sign",
0x24   :"Dollar sign",
0x25   :"Percent sign",
0x26   :"Ampersand",
0x27   :"Right single quote / apostrophe",
0x28   :"Left parenthesis",
0x29   :"Right parenthesis",
0x2a   :"Asterisk",
0x2b   :"Plus",
0x2c   :"Comma",
0x2d   :"Hyphen",
0x2e   :"Period",
0x2f   :"Slash",
0x30   :"Latin digit 0",
0x31   :"Latin digit 1",
0x32   :"Latin digit 2",
0x33   :"Latin digit 3",
0x34   :"Latin digit 4",
0x35   :"Latin digit 5",
0x36   :"Latin digit 6",
0x37   :"Latin digit 7",
0x38   :"Latin digit 8",
0x39   :"Latin digit 9",
0x3a   :"Colon",
0x3b   :"Semi-colon",
0x3c   :"Less-than",
0x3d   :"Equal-sign",
0x3e   :"Greater-than",
0x3f   :"Question mark",
0x40   :"At-sign",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5b   :"Left square bracket",
0x5c   :"Backslash",
0x5d   :"Right square bracket",
0x5e   :"Caret",
0x5f   :"Underscore",
0x60   :"Left single quote",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7b   :"Left curly bracket",
0x7c   :"Pipe",
0x7d   :"Right curly bracket",
0x7e   :"Tilde",
0x7f   :"DEL",
0x80   :"Unused",
0x81   :"Unused",
0x82   :"Unused",
0x83   :"Unused",
0x84   :"Unused",
0x85   :"Unused",
0x86   :"Unused",
0x87   :"Unused",
0x88   :"Unused",
0x89   :"Unused",
0x8a   :"Unused",
0x8b   :"Unused",
0x8c   :"Unused",
0x8d   :"Unused",
0x8e   :"Unused",
0x8f   :"Unused",
0x90   :"Unused",
0x91   :"Unused",
0x92   :"Unused",
0x93   :"Unused",
0x94   :"Unused",
0x95   :"Unused",
0x96   :"Unused",
0x97   :"Unused",
0x98   :"Unused",
0x99   :"Unused",
0x9a   :"Unused",
0x9b   :"Unused",
0x9c   :"Unused",
0x9d   :"Unused",
0x9e   :"Unused",
0x9f   :"Unused",
0xa0   :"Undefined",
0xa1   :"Candrabindu",
0xa2   :"Anusvara",
0xa3   :"Visarga",
0xa4   :"Vowel letter A",
0xa5   :"Vowel letter long A",
0xa6   :"Vowel letter I",
0xa7   :"Vowel letter long I",
0xa8   :"Vowel letter U",
0xa9   :"Vowel letter long U",
0xaa   :"Vowel letter short syllabic R",
0xab   :"Vowel letter E",
0xac   :"Vowel letter EY",
0xad   :"Vowel letter AI",
0xae   :"Vowel letter AYE",
0xaf   :"Vowel letter O",
0xb0   :"Vowel letter OW",
0xb1   :"Vowel letter AU",
0xb2   :"Vowel letter AWE",
0xb3   :"KA   (voiceless unaspirated velar stop)",
0xb4   :"KHA  (voiceless aspirated velar stop)",
0xb5   :"GA   (voiced velar stop)",
0xb6   :"GHA  (breathy voiced velar stop)",
0xb7   :"NGA  (velar nasal)",
0xb8   :"CHA  (voiceless unaspirated palatal affricate)", 
0xb9   :"CCHA (voicelss aspirated palatal affricate)",
0xba   :"JA   (voiced palatal affricate)",
0xbb   :"JHA  (breathy voiced palatal affricate)",
0xbc   :"JNA  (palatal nasal)",
0xbd   :"TA   (voiceless unaspirated retroflex stop)",
0xbe   :"THA  (voiceless aspirated retroflex stop)",
0xbf   :"DA   (voiced retroflex stop)",
0xc0   :"DHA  (breathy voiced retroflex stop)",
0xc1   :"NA   (retroflex nasal)",
0xc2   :"TA   (voiceless unaspirated alveolar stop)",
0xc3   :"THA  (voiceless aspirated alveolar stop)",
0xc4   :"DA   (voiced alveolar stop)",
0xc5   :"DHA  (breathy voiced alveolar stop)",
0xc6   :"NA   (alveolar nasal)",
0xc7   :"NA   (dental nasal)",
0xc8   :"PA   (voiceless unaspirated biblabial stop)",
0xc9   :"PHA  (voiceless aspirated bilabial stop)",
0xca   :"BA   (voiced bilabial stop)",
0xcb   :"BHA  (breathy voiced bilabial stop)",
0xcc   :"MA   (bilabial nasal)",
0xcd   :"YA   (palatal glide)",
0xce   :"JYA  (voiced palatal affricate derived from palatal glide)",
0xcf   :"RA   (alveolar rhotic)",
0xd0   :"RA   (retroflex rhotic)",
0xd1   :"LA   (alveolar lateral)",
0xd2   :"LA   (retroflex lateral)",
0xd3   :"ZHA  (voiced retroflex fricative)",
0xd4   :"VA   (voiced labial fricative)",
0xd5   :"SHA  (voiceless palatal fricative)",
0xd6   :"SHA  (voiceless retroflex fricative)",
0xd7   :"SA   (voiceless alveolar fricative)",
0xd8   :"HA   (voiceless glottal fricative)",
0xd9   :"INV  (invisible character - used to display isolated diacritics",
0xda   :"Vowel sign long A",
0xdb   :"Vowel sign I",
0xdc   :"Vowel sign long I",
0xdd   :"Vowel sign U",
0xde   :"Vowel sign long U",
0xdf   :"Vowel sign short syllabic R",
0xe0   :"Vowel sign E",
0xe1   :"Vowel sign EY",
0xe2   :"Vowel sign AI",
0xe3   :"Vowel sign AYE",
0xe4   :"Vowel sign O",
0xe5   :"Vowel sign OW",
0xe6   :"Vowel sign AU",
0xe7   :"Vowel sign AWE",
0xe8   :"Virama (suppresses default short A)",
0xe9   :"Nukta  (derives additional letters)",
0xea   :"DaNDa (Indic full stop)",
0xeb   :"Unused",
0xec   :"Unused",
0xed   :"Unused",
0xee   :"Unused",
0xef   :"ATR (change writing system/display mode per next byte)",
0xf0   :"EXT (extension)",
0xf1   :"Indic digit 0",
0xf2   :"Indic digit 1",
0xf3   :"Indic digit 2",
0xf4   :"Indic digit 3",
0xf5   :"Indic digit 4",
0xf6   :"Indic digit 5",
0xf7   :"Indic digit 6",
0xf8   :"Indic digit 7",
0xf9   :"Indic digit 8",
0xfa   :"Indic digit 9",
0xfb   :"Unused",
0xfc   :"Unused",
0xfd   :"Unused",
0xfe   :"Unused",
0xff   :"Unused"
}

tsciixtbl = { \
0x00   :"NUL (ASCII control character)",
0x01   :"SOH (ASCII control character)",
0x02   :"STX (ASCII control character)",
0x03   :"ETX (ASCII control character)",
0x04   :"EOT (ASCII control character)",
0x05   :"ENQ (ASCII control character)",
0x06   :"ACK (ASCII control character)",
0x07   :"BEL (ASCII control character)",
0x08   :"Backspace (ASCII control character)",
0x09   :"Tab (ASCII control character)",
0x0a   :"Newline",
0x0b   :"VT (ASCII control character)",
0x0c   :"FF (ASCII control character)",
0x0d   :"Carriage return",
0x0e   :"SO (ASCII control character)",
0x0f   :"SI (ASCII control character)",
0x10   :"DLE (ASCII control character)",
0x11   :"DC1 (ASCII control character)",
0x12   :"DC2 (ASCII control character)",
0x13   :"DC3 (ASCII control character)",
0x14   :"DC4 (ASCII control character)",
0x15   :"NAK (ASCII control character)",
0x16   :"SYN (ASCII control character)",
0x17   :"ETB (ASCII control character)",
0x18   :"CAN (ASCII control character)",
0x19   :"EM (ASCII control character)",
0x1a   :"SUB (ASCII control character)",
0x1b   :"ESC (ASCII control character)",
0x1c   :"FS (ASCII control character)",
0x1d   :"GS (ASCII control character)",
0x1e   :"RS (ASCII control character)",
0x1f   :"US (ASCII control character)",
0x20   :"Space",
0x21   :"Exclamation point",
0x22   :"Double quote",
0x23   :"Pound sign",
0x24   :"Dollar sign",
0x25   :"Percent sign",
0x26   :"Ampersand",
0x27   :"Apostrophe",
0x28   :"Left parenthesis",
0x29   :"Right parenthesis",
0x2a   :"Asterisk",
0x2b   :"Plus",
0x2c   :"Comma",
0x2d   :"Hyphen",
0x2e   :"Period",
0x2f   :"Slash",
0x30   :"Latin digit 0",
0x31   :"Latin digit 1",
0x32   :"Latin digit 2",
0x33   :"Latin digit 3",
0x34   :"Latin digit 4",
0x35   :"Latin digit 5",
0x36   :"Latin digit 6",
0x37   :"Latin digit 7",
0x38   :"Latin digit 8",
0x39   :"Latin digit 9",
0x3a   :"Colon",
0x3b   :"Semi-colon",
0x3c   :"Less-than",
0x3d   :"Equal-sign",
0x3e   :"Greater-than",
0x3f   :"Question mark",
0x40   :"At-sign",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5b   :"Left square bracket",
0x5c   :"Backslash",
0x5d   :"Right square bracket",
0x5e   :"Caret",
0x5f   :"Underscore",
0x60   :"Left single quote",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7b   :"Left curly bracket",
0x7c   :"Pipe",
0x7d   :"Right curly bracket",
0x7e   :"Tilde",
0x7f   :"DEL",
0x80   :"Tamil digit 0 (U+0BE6)",
0x81   :"Tamil digit 1",
0x82   :"Grantha character SRI",
0x83   :"Grantha character ja",
0x84   :"Grantha character sha",
0x85   :"Grantha character sa",
0x86   :"Grantha character ha",
0x87   :"Grantha character ksha",
0x88   :"Grantha character ja with pulli",
0x89   :"Grantha character sha with pulli",
0x8a   :"Grantha character sa with pulli",
0x8b   :"Grantha character ha with pulli",
0x8c   :"Grantha character ksha with pulli",
0x8d   :"Tamil digit 2",
0x8e   :"Tamil digit 3",
0x8f   :"Tamil digit 4",
0x90   :"Tamil digit 5",
0x91   :"Left single quote",
0x92   :"Right single quote",
0x93   :"Left double quote",
0x94   :"Right double quote",
0x95   :"Tamil digit 6",
0x96   :"Tamil digit 7",
0x97   :"Tamil digit 8",
0x98   :"Tamil digit 9",
0x99   :"Tamil combination ngu",
0x9a   :"Tamil combination nyu",
0x9b   :"Tamil combination nguu",
0x9c   :"Tamil combination nyuu",
0x9d   :"Tamil digit 10",
0x9e   :"Tamil digit 100",
0x9f   :"Tamil digit 1000",
0xa0   :"No break space (U+00A0)",
0xa1   :"Tamil vowel sign aa",
0xa2   :"Tamil vowel sign i",
0xa3   :"Tamil vowel sign ii",
0xa4   :"Tamil vowel sign u",
0xa5   :"Tamil vowel sign uu",
0xa6   :"Tamil vowel sign e",
0xa7   :"Tamil vowel sign ee",
0xa8   :"Tamil vowel sign ai",
0xa9   :"Copyright symbol",
0xaa   :"Tamil au length mark" ,
0xab   :"Tamil vowel letter a",
0xac   :"Tamil vowel letter aa",
0xad   :"Tamil vowel letter i (TSCII 1.6 - Unused in TSCII 1.7)",
0xae   :"Tamil vowel letter ii",
0xaf   :"Tamil vowel letter u",
0xb0   :"Tamil vowel letter uu",
0xb1   :"Tamil vowel letter e",
0xb2   :"Tamil vowel letter ee",
0xb3   :"Tamil vowel letter ai",
0xb4   :"Tamil vowel letter o",
0xb5   :"Tamil vowel letter oo",
0xb6   :"Tamil vowel letter au",
0xb7   :"Tamil sign aytham",
0xb8   :"Tamil letter ka",
0xb9   :"Tamil letter nga",
0xba   :"Tamil letter ca",
0xbb   :"Tamil letter nya",
0xbc   :"Tamil letter Ta",
0xbd   :"Tamil letter Na",
0xbe   :"Tamil letter ta",
0xbf   :"Tamil letter na",
0xc0   :"Tamil letter pa",
0xc1   :"Tamil letter ma",
0xc2   :"Tamil letter ja",
0xc3   :"Tamil letter ra",
0xc4   :"Tamil letter la",
0xc5   :"Tamil letter va",
0xc6   :"Tamil letter za",
0xc7   :"Tamil letter La",
0xc8   :"Tamil letter Ra",
0xc9   :"Tamil letter n_a",
0xca   :"Tamil combination Ti",
0xcb   :"Tamil combination Tii",
0xcc   :"Tamil combination ku",
0xcd   :"Tamil combination cu",
0xce   :"Tamil combination Tu",
0xcf   :"Tamil combination Nu",
0xd0   :"Tamil combination tu",
0xd1   :"Tamil combination nu",
0xd2   :"Tamil combination pu",
0xd3   :"Tamil combination mu",
0xd4   :"Tamil combination ju",
0xd5   :"Tamil combination ru",
0xd6   :"Tamil combination lu",
0xd7   :"Tamil combination vu",
0xd8   :"Tamil combination zhu",
0xd9   :"Tamil combination Lu",
0xda   :"Tamil combination Ru",
0xdb   :"Tamil combinatin n_u",
0xdc   :"Tamil combination kuu",
0xdd   :"Tamil combination cuu",
0xde   :"Tamil combination Tuu",
0xdf   :"Tamil combination Nuu",
0xe0   :"Tamil combination tuu",
0xe1   :"Tamil combination nuu",
0xe2   :"Tamil combination puu",
0xe3   :"Tamil combination muu",
0xe4   :"Tamil combination juu",
0xe5   :"Tamil combination ruu",
0xe6   :"Tamil combination luu",
0xe7   :"Tamil combination vuu",
0xe8   :"Tamil combinatin zhuu",
0xe9   :"Tamil combination Luu",
0xea   :"Tamil combination Ruu",
0xeb   :"Tamil combination n_uu",
0xec   :"Tamil letter ka with pulli",
0xed   :"Tamil letter nga with pulli",
0xee   :"Tamil letter ca with pulli",
0xef   :"Tamil letter nja with pulli",
0xf0   :"Tamil letter Ta with pulli",
0xf1   :"Tamil letter Na with pulli",
0xf2   :"Tamil letter ta with pulli",
0xf3   :"Tamil letter na with pulli",
0xf4   :"Tamil letter pa with pulli",
0xf5   :"Tamil letter ma with pulli",
0xf6   :"Tamil letter ya with pulli",
0xf7   :"Tamil letter ra with pulli",
0xf8   :"Tamil letter la with pulli",
0xf9   :"Tamil letter va with pulli",
0xfa   :"Tamil letter zha with pulli",
0xfb   :"Tamil letter La with pulli",
0xfc   :"Tamil letter Ra with pulli",
0xfd   :"Tamil letter n_a with pulli",
0xfe   :"Tamil vowel letter i (TSCII 1.7+ codepoint)",
0xff   :"Unused"
}

#VISCII (Vietnamese)
visciixtbl={\
0x00	:"<control> (U+0000)",
0x01	:"<control> (U+0001)",
0x02	:"Latin capital letter a with breve and hook above (U+1EB2)",
0x03	:"<control> (U+0003)",
0x04	:"<control> (U+0004)",
0x05	:"Latin capital letter a with breve and tilde (U+1EB4)",
0x06	:"Latin capital letter a with circumflex and tilde (U+1EAA)",
0x07	:"<control> (U+0007)",
0x08	:"<control> (U+0008)",
0x09	:"<control> (U+0009)",
0x0A	:"<control> (U+000A)",
0x0B	:"<control> (U+000B)",
0x0C	:"<control> (U+000C)",
0x0D	:"<control> (U+000D)",
0x0E	:"<control> (U+000E)",
0x0F	:"<control> (U+000F)",
0x10	:"<control> (U+0010)",
0x11	:"<control> (U+0011)",
0x12	:"<control> (U+0012)",
0x13	:"<control> (U+0013)",
0x14	:"Latin capital letter y with hook above (U+1EF6)",
0x15	:"<control> (U+0015)",
0x16	:"<control> (U+0016)",
0x17	:"<control> (U+0017)",
0x18	:"<control> (U+0018)",
0x19	:"Latin capital letter y with tilde (U+1EF8)",
0x1A	:"<control> (U+001A)",
0x1B	:"<control> (U+001B)",
0x1C	:"<control> (U+001C)",
0x1D	:"<control> (U+001D)",
0x1E	:"Latin capital letter y with dot below (U+1EF4)",
0x1F	:"<control> (U+001F)",
0x20	:"space (U+0020)",
0x21	:"exclamation mark (U+0021)",
0x22	:"quotation mark (U+0022)",
0x23	:"number sign (U+0023)",
0x24	:"dollar sign (U+0024)",
0x25	:"percent sign (U+0025)",
0x26	:"ampersand (U+0026)",
0x27	:"apostrophe (U+0027)",
0x28	:"left parenthesis (U+0028)",
0x29	:"right parenthesis (U+0029)",
0x2A	:"asterisk (U+002A)",
0x2B	:"plus sign (U+002B)",
0x2C	:"comma (U+002C)",
0x2D	:"hyphen-minus (U+002D)",
0x2E	:"full stop (U+002E)",
0x2F	:"solidus (U+002F)",
0x30	:"digit zero (U+0030)",
0x31	:"digit one (U+0031)",
0x32	:"digit two (U+0032)",
0x33	:"digit three (U+0033)",
0x34	:"digit four (U+0034)",
0x35	:"digit five (U+0035)",
0x36	:"digit six (U+0036)",
0x37	:"digit seven (U+0037)",
0x38	:"digit eight (U+0038)",
0x39	:"digit nine (U+0039)",
0x3A	:"colon (U+003A)",
0x3B	:"semicolon (U+003B)",
0x3C	:"less-than sign (U+003C)",
0x3D	:"equals sign (U+003D)",
0x3E	:"greater-than sign (U+003E)",
0x3F	:"question mark (U+003F)",
0x40	:"commercial at (U+0040)",
0x41	:"Latin capital letter a (U+0041)",
0x42	:"Latin capital letter b (U+0042)",
0x43	:"Latin capital letter c (U+0043)",
0x44	:"Latin capital letter d (U+0044)",
0x45	:"Latin capital letter e (U+0045)",
0x46	:"Latin capital letter f (U+0046)",
0x47	:"Latin capital letter g (U+0047)",
0x48	:"Latin capital letter h (U+0048)",
0x49	:"Latin capital letter i (U+0049)",
0x4A	:"Latin capital letter j (U+004A)",
0x4B	:"Latin capital letter k (U+004B)",
0x4C	:"Latin capital letter l (U+004C)",
0x4D	:"Latin capital letter m (U+004D)",
0x4E	:"Latin capital letter n (U+004E)",
0x4F	:"Latin capital letter o (U+004F)",
0x50	:"Latin capital letter p (U+0050)",
0x51	:"Latin capital letter q (U+0051)",
0x52	:"Latin capital letter r (U+0052)",
0x53	:"Latin capital letter s (U+0053)",
0x54	:"Latin capital letter t (U+0054)",
0x55	:"Latin capital letter u (U+0055)",
0x56	:"Latin capital letter v (U+0056)",
0x57	:"Latin capital letter w (U+0057)",
0x58	:"Latin capital letter x (U+0058)",
0x59	:"Latin capital letter y (U+0059)",
0x5A	:"Latin capital letter z (U+005A)",
0x5B	:"left square bracket (U+005B)",
0x5C	:"reverse solidus (U+005C)",
0x5D	:"right square bracket (U+005D)",
0x5E	:"circumflex accent (U+005E)",
0x5F	:"low line (U+005F)",
0x60	:"grave accent (U+0060)",
0x61	:"Latin small letter a (U+0061)",
0x62	:"Latin small letter b (U+0062)",
0x63	:"Latin small letter c (U+0063)",
0x64	:"Latin small letter d (U+0064)",
0x65	:"Latin small letter e (U+0065)",
0x66	:"Latin small letter f (U+0066)",
0x67	:"Latin small letter g (U+0067)",
0x68	:"Latin small letter h (U+0068)",
0x69	:"Latin small letter i (U+0069)",
0x6A	:"Latin small letter j (U+006A)",
0x6B	:"Latin small letter k (U+006B)",
0x6C	:"Latin small letter l (U+006C)",
0x6D	:"Latin small letter m (U+006D)",
0x6E	:"Latin small letter n (U+006E)",
0x6F	:"Latin small letter o (U+006F)",
0x70	:"Latin small letter p (U+0070)",
0x71	:"Latin small letter q (U+0071)",
0x72	:"Latin small letter r (U+0072)",
0x73	:"Latin small letter s (U+0073)",
0x74	:"Latin small letter t (U+0074)",
0x75	:"Latin small letter u (U+0075)",
0x76	:"Latin small letter v (U+0076)",
0x77	:"Latin small letter w (U+0077)",
0x78	:"Latin small letter x (U+0078)",
0x79	:"Latin small letter y (U+0079)",
0x7A	:"Latin small letter z (U+007A)",
0x7B	:"left curly bracket (U+007B)",
0x7C	:"vertical line (U+007C)",
0x7D	:"right curly bracket (U+007D)",
0x7E	:"tilde (U+007E)",
0x7F	:"<control> (U+007F)",
0x80	:"Latin capital letter a with dot below (U+1EA0)",
0x81	:"Latin capital letter a with breve and acute (U+1EAE)",
0x82	:"Latin capital letter a with breve and grave (U+1EB0)",
0x83	:"Latin capital letter a with breve and dot below (U+1EB6)",
0x84	:"Latin capital letter a with circumflex and acute (U+1EA4)",
0x85	:"Latin capital letter a with circumflex and grave (U+1EA6)",
0x86	:"Latin capital letter a with circumflex and hook above (U+1EA8)",
0x87	:"Latin capital letter a with circumflex and dot below (U+1EAC)",
0x88	:"Latin capital letter e with tilde (U+1EBC)",
0x89	:"Latin capital letter e with dot below (U+1EB8)",
0x8A	:"Latin capital letter e with circumflex and acute (U+1EBE)",
0x8B	:"Latin capital letter e with circumflex and grave (U+1EC0)",
0x8C	:"Latin capital letter e with circumflex and hook above (U+1EC2)",
0x8D	:"Latin capital letter e with circumflex and tilde (U+1EC4)",
0x8E	:"Latin capital letter e with circumflex and dot below (U+1EC6)",
0x8F	:"Latin capital letter o with circumflex and acute (U+1ED0)",
0x90	:"Latin capital letter o with circumflex and grave (U+1ED2)",
0x91	:"Latin capital letter o with circumflex and hook above (U+1ED4)",
0x92	:"Latin capital letter o with circumflex and tilde (U+1ED6)",
0x93	:"Latin capital letter o with circumflex and dot below (U+1ED8)",
0x94	:"Latin capital letter o with horn and dot below (U+1EE2)",
0x95	:"Latin capital letter o with horn and acute (U+1EDA)",
0x96	:"Latin capital letter o with horn and grave (U+1EDC)",
0x97	:"Latin capital letter o with horn and hook above (U+1EDE)",
0x98	:"Latin capital letter i with dot below (U+1ECA)",
0x99	:"Latin capital letter o with hook above (U+1ECE)",
0x9A	:"Latin capital letter o with dot below (U+1ECC)",
0x9B	:"Latin capital letter i with hook above (U+1EC8)",
0x9C	:"Latin capital letter u with hook above (U+1EE6)",
0x9D	:"Latin capital letter u with tilde (U+0168)",
0x9E	:"Latin capital letter u with dot below (U+1EE4)",
0x9F	:"Latin capital letter y with grave (U+1EF2)",
0xA0	:"Latin capital letter o with tilde (U+00D5)",
0xA1	:"Latin small letter a with breve and acute (U+1EAF)",
0xA2	:"Latin small letter a with breve and grave (U+1EB1)",
0xA3	:"Latin small letter a with breve and dot below (U+1EB7)",
0xA4	:"Latin small letter a with circumflex and acute (U+1EA5)",
0xA5	:"Latin small letter a with circumflex and grave (U+1EA7)",
0xA6	:"Latin small letter a with circumflex and hook above (U+1EA9)",
0xA7	:"Latin small letter a with circumflex and dot below (U+1EAD)",
0xA8	:"Latin small letter e with tilde (U+1EBD)",
0xA9	:"Latin small letter e with dot below (U+1EB9)",
0xAA	:"Latin small letter e with circumflex and acute (U+1EBF)",
0xAB	:"Latin small letter e with circumflex and grave (U+1EC1)",
0xAC	:"Latin small letter e with circumflex and hook above (U+1EC3)",
0xAD	:"Latin small letter e with circumflex and tilde (U+1EC5)",
0xAE	:"Latin small letter e with circumflex and dot below (U+1EC7)",
0xAF	:"Latin small letter o with circumflex and acute (U+1ED1)",
0xB0	:"Latin small letter o with circumflex and grave (U+1ED3)",
0xB1	:"Latin small letter o with circumflex and hook above (U+1ED5)",
0xB2	:"Latin small letter o with circumflex and tilde (U+1ED7)",
0xB3	:"Latin capital letter o with horn and tilde (U+1EE0)",
0xB4	:"Latin capital letter o with horn (U+01A0)",
0xB5	:"Latin small letter o with circumflex and dot below (U+1ED9)",
0xB6	:"Latin small letter o with horn and grave (U+1EDD)",
0xB7	:"Latin small letter o with horn and hook above (U+1EDF)",
0xB8	:"Latin small letter i with dot below (U+1ECB)",
0xB9	:"Latin capital letter u with horn and dot below (U+1EF0)",
0xBA	:"Latin capital letter u with horn and acute (U+1EE8)",
0xBB	:"Latin capital letter u with horn and grave (U+1EEA)",
0xBC	:"Latin capital letter u with horn and hook above (U+1EEC)",
0xBD	:"Latin small letter o with horn (U+01A1)",
0xBE	:"Latin small letter o with horn and acute (U+1EDB)",
0xBF	:"Latin capital letter u with horn (U+01AF)",
0xC0	:"Latin capital letter a with grave (U+00C0)",
0xC1	:"Latin capital letter a with acute (U+00C1)",
0xC2	:"Latin capital letter a with circumflex (U+00C2)",
0xC3	:"Latin capital letter a with tilde (U+00C3)",
0xC4	:"Latin capital letter a with hook above (U+1EA2)",
0xC5	:"Latin capital letter a with breve (U+0102)",
0xC6	:"Latin small letter a with breve and hook above (U+1EB3)",
0xC7	:"Latin small letter a with breve and tilde (U+1EB5)",
0xC8	:"Latin capital letter e with grave (U+00C8)",
0xC9	:"Latin capital letter e with acute (U+00C9)",
0xCA	:"Latin capital letter e with circumflex (U+00CA)",
0xCB	:"Latin capital letter e with hook above (U+1EBA)",
0xCC	:"Latin capital letter i with grave (U+00CC)",
0xCD	:"Latin capital letter i with acute (U+00CD)",
0xCE	:"Latin capital letter i with tilde (U+0128)",
0xCF	:"Latin small letter y with grave (U+1EF3)",
0xD0	:"Latin capital letter d with stroke (U+0110)",
0xD1	:"Latin small letter u with horn and acute (U+1EE9)",
0xD2	:"Latin capital letter o with grave (U+00D2)",
0xD3	:"Latin capital letter o with acute (U+00D3)",
0xD4	:"Latin capital letter o with circumflex (U+00D4)",
0xD5	:"Latin small letter a with dot below (U+1EA1)",
0xD6	:"Latin small letter y with hook above (U+1EF7)",
0xD7	:"Latin small letter u with horn and grave (U+1EEB)",
0xD8	:"Latin small letter u with horn and hook above (U+1EED)",
0xD9	:"Latin capital letter u with grave (U+00D9)",
0xDA	:"Latin capital letter u with acute (U+00DA)",
0xDB	:"Latin small letter y with tilde (U+1EF9)",
0xDC	:"Latin small letter y with dot below (U+1EF5)",
0xDD	:"Latin capital letter y with acute (U+00DD)",
0xDE	:"Latin small letter o with horn and tilde (U+1EE1)",
0xDF	:"Latin small letter u with horn (U+01B0)",
0xE0	:"Latin small letter a with grave (U+00E0)",
0xE1	:"Latin small letter a with acute (U+00E1)",
0xE2	:"Latin small letter a with circumflex (U+00E2)",
0xE3	:"Latin small letter a with tilde (U+00E3)",
0xE4	:"Latin small letter a with hook above (U+1EA3)",
0xE5	:"Latin small letter a with breve (U+0103)",
0xE6	:"Latin small letter u with horn and tilde (U+1EEF)",
0xE7	:"Latin small letter a with circumflex and tilde (U+1EAB)",
0xE8	:"Latin small letter e with grave (U+00E8)",
0xE9	:"Latin small letter e with acute (U+00E9)",
0xEA	:"Latin small letter e with circumflex (U+00EA)",
0xEB	:"Latin small letter e with hook above (U+1EBB)",
0xEC	:"Latin small letter i with grave (U+00EC)",
0xED	:"Latin small letter i with acute (U+00ED)",
0xEE	:"Latin small letter i with tilde (U+0129)",
0xEF	:"Latin small letter i with hook above (U+1EC9)",
0xF0	:"Latin small letter d with stroke (U+0111)",
0xF1	:"Latin small letter u with horn and dot below (U+1EF1)",
0xF2	:"Latin small letter o with grave (U+00F2)",
0xF3	:"Latin small letter o with acute (U+00F3)",
0xF4	:"Latin small letter o with circumflex (U+00F4)",
0xF5	:"Latin small letter o with tilde (U+00F5)",
0xF6	:"Latin small letter o with hook above (U+1ECF)",
0xF7	:"Latin small letter o with dot below (U+1ECD)",
0xF8	:"Latin small letter u with dot below (U+1EE5)",
0xF9	:"Latin small letter u with grave (U+00F9)",
0xFA	:"Latin small letter u with acute (U+00FA)",
0xFB	:"Latin small letter u with tilde (U+0169)",
0xFC	:"Latin small letter u with hook above (U+1EE7)",
0xFD	:"Latin small letter y with acute (U+00FD)",
0xFE	:"Latin small letter o with horn and dot below (U+1EE3)",
0xFF	:"Latin capital letter u with horn and tilde (U+1EEE)"
}

IsciiDisplayModes = { \
0x30: "Shift display mode to Bold",
0x31: "Shift display mode to Italic",
0x32: "Shift display mode to Underline",
0x33: "Shift display mode to Expanded",
0x34: "Shift display mode to Highlight",
0x35: "Shift display mode to Outline",
0x36: "Shift display mode to Shadow",
0x37: "Shift display mode to Top",
0x38: "Shift display mode to Low",
0x39: "Shift display mode to Double"
}

IsciiWritingSystems = { \
0x40: "Shift to default writing system",
0x41: "Shift to romanization",
0x42: "Shift to Devanagari",
0x43: "Shift to Bengali",
0x44: "Shift to Tamil",
0x45: "Shift to Telugu",
0x46: "Shift to Assamese",
0x47: "Shift to Oriya",
0x48: "Shift to Kannada",
0x49: "Shift to Malayalam",
0x4A: "Shift to Gujarati",
0x4B: "Shift to Gurmukhi",
0x71: "Shift to Arabic",
0x72: "Shift to Persian",
0x73: "Shift to Urdu",
0x74: "Shift to Sindhi",
0x75: "Shift to Kashmiri",
0x76: "Shift to Pastho"
}

def DescribeTamilTranscription():
	sys.stdout.write("The transcription used for Tamil is as follows:\n")
	sys.stdout.write("\tc  voiceless palatal affricate\n")
	sys.stdout.write("\th  voiceless laryngeal fricative\n")
	sys.stdout.write("\tj  palatal glide\n")
	sys.stdout.write("\tk  voiceless velar stop\n")
	sys.stdout.write("\tl  alveolar lateral\n")
	sys.stdout.write("\tL  retroflex lateral\n")
	sys.stdout.write("\tm  bilabial nasal\n")
	sys.stdout.write("\tn  alveolar nasal\n")
	sys.stdout.write("\tn_ dental nasal\n")
	sys.stdout.write("\tng velar nasal\n")
	sys.stdout.write("\tN  retroflex nasal\n")
	sys.stdout.write("\tny palatal nasal\n")
	sys.stdout.write("\tp  voiceless bilabial stop\n")
	sys.stdout.write("\tr  alveolar approximant\n")
	sys.stdout.write("\tR  retroflex flap\n")
	sys.stdout.write("\tsh voiceless postalveolar fricative\n")
	sys.stdout.write("\ts  voiceless alveolar fricativea\n")
	sys.stdout.write("\tt  voiceless alveolar stop\n")
	sys.stdout.write("\tT  voiceless retroflex stop\n")
	sys.stdout.write("\tv  voiced labial fricative\n")
	sys.stdout.write("\tzh voiced retroflex fricative\n")

def binfmt(k,count=8):
        return "".join(map(lambda y:str((k>>y)&1), range(count-1, -1, -1)))


CharCnt = 0
LineCnt = 0
PutHeaderP=1
ShowAsciiP=1

def DumpChart(xtbl):
	for c in range(256):
		OStringList = []
		if DoHexP:
			OStringList.append(("0x%02X  ") % (c))
		if DoOctalP:	
			OStringList.append(("%03o    ") % (c))
		if DoBinaryP:
			OStringList.append(("%8s  ") % (binfmt(c)))
		if DoDecimalP:
			OStringList.append(("%3d      ") % (c))
		OStringList.append("%s" % xtbl[c])
		OStringList.append("\n")
		sys.stdout.write("".join(OStringList))

def Version():
	sys.stdout.write("Version 1.12\n")
	sys.stdout.write("Copyright 2004-2007 William J. Poser\n")
	sys.stdout.write("Released under the terms of the GNU General Public License\n")
	sys.stdout.write("Report bugs to: billposer@alum.mit.edu\n")
	sys.exit(2)

def ListEncodings():
	sys.stdout.write("\tadobeps\n")
	sys.stdout.write("\tarmscii7 Armenian\n")
	sys.stdout.write("\tarmscii8 Armenian\n")
	sys.stdout.write("\tarmscii8a Armenian\n")
	sys.stdout.write("\tatarist\n")
	sys.stdout.write("\tbrmp (Buddhist Relief Mission Pali)\n")
	sys.stdout.write("\tbuckwalter (Buckwalter Transliteration of Arabic)\n")
	sys.stdout.write("\tcsx (Classical Sanskrit Extended)\n")
	sys.stdout.write("\tebcdic037 (IBM Codepage 037)\n")
	sys.stdout.write("\tebcdic500 (IBM Codepage 500)\n")
	sys.stdout.write("\tegaf (EGA Farsi)\n")
	sys.stdout.write("\tgsm0388\n")
	sys.stdout.write("\tguarani\n")
	sys.stdout.write("\tiscii non-Arabic India \n")
	sys.stdout.write("\tisiri2900 Iran\n");
	sys.stdout.write("\tisiri3342 Iran\n");
	sys.stdout.write("\tiso8859-1 Western Europe\n");
	sys.stdout.write("\tiso8859-2 Eastern Europe\n");
	sys.stdout.write("\tiso8859-3 Esperanto, Maltese, (Turkish)\n");
	sys.stdout.write("\tiso8859-4 North European\n");
	sys.stdout.write("\tiso8859-5 Cyrillic\n");
	sys.stdout.write("\tiso8859-6 Arabic\n")
	sys.stdout.write("\tiso8859-7 Greek\n")
	sys.stdout.write("\tiso8859-8 Hebrew\n")
	sys.stdout.write("\tiso8859-9 Turkish\n")
	sys.stdout.write("\tiso8859-10 Nordic\n")
	sys.stdout.write("\tiso8859-11 Thai\n")
	sys.stdout.write("\tiso8859-13 Baltic Rim\n")
	sys.stdout.write("\tiso8859-14 Celtic\n")
	sys.stdout.write("\tiso8859-15 Western Europe\n")
	sys.stdout.write("\tiso8859-16 South-Eastern Europe\n")
	sys.stdout.write("\tkoi8a Cyrillic - original GOST 19768-74 standard\n")
	sys.stdout.write("\tkoi8b Cyrillic - letter only subset of KOI8-R\n")
	sys.stdout.write("\tkoi8r Russian\n")
	sys.stdout.write("\tkoi8u Ukrainian\n")
	sys.stdout.write("\tmaccyrillic (CP10007)\n")
	sys.stdout.write("\tmacgreek (CP10006)\n")
	sys.stdout.write("\tmacicelandic (CP10079)\n")
	sys.stdout.write("\tmacinuit\n")
	sys.stdout.write("\tmacLatin2 (CP10029)\n")
	sys.stdout.write("\tmacroman (CP10000)\n")
	sys.stdout.write("\tmacthai\n")
	sys.stdout.write("\tmacturkish\n")
	sys.stdout.write("\tmik (Bulgarian)\n")
	sys.stdout.write("\tmsd437  (MS DOS Codepage 437 - original IBM-PC)\n")
	sys.stdout.write("\tmsw850  (MS DOS Codepage 850 Multilingual Latin 1)\n")
	sys.stdout.write("\tmsd860  (MS DOS Codepage 860 Portuguese)\n")
	sys.stdout.write("\tmsd861  (MS DOS Codepage 861 Icelandic/Nordic)\n")
	sys.stdout.write("\tmsd862  (MS DOS Codepage 862 Hebrew)\n")
	sys.stdout.write("\tmsd863  (MS DOS Codepage 863 Canadian French)\n")
	sys.stdout.write("\tmsd864  (MS DOS Codepage 864) Arabic\n")
	sys.stdout.write("\tmsd865  (MS DOS Codepage 865) Nordic\n")
	sys.stdout.write("\tmsd866  (MS DOS Codepage 866 Cyrillic)\n")
	sys.stdout.write("\tmsd869  (MS DOS Codepage 869 Modern Greek)\n")
	sys.stdout.write("\tmsw874  (MS Windows Codepage 874 Thai)\n")
	sys.stdout.write("\tmsw875  (MS Windows Codepage 875 IBM Greek)\n")
	sys.stdout.write("\tmsw1250 (MS Windows Codepage 1250 WinLatin2)\n");
	sys.stdout.write("\tmsw1251 (MS Windows Codepage 1251 Cyrillic)\n");
	sys.stdout.write("\tmsw1252 (MS Windows Codepage 1252 WinLatin1)\n")
	sys.stdout.write("\tmsw1253 (MS Windows Codepage 1253 Greek)\n");
	sys.stdout.write("\tmsw1254 (MS Windows Codepage 1254 Turkish)\n");
	sys.stdout.write("\tmsw1255 (MS Windows Codepage 1255 Hebrew)\n");
	sys.stdout.write("\tmsw1256 (MS Windows Codepage 1256 Arabic)\n")
	sys.stdout.write("\tmsw1257 (MS Windows Codepage 1257 Estonian, Latvian, Lithuanian)\n")
	sys.stdout.write("\tmsw1258 (MS Windows Codepage 1258 Vietnamese)\n")
	sys.stdout.write("\tnextstep\n");
	sys.stdout.write("\tPASCII Kashmiri, Persian, Sindhi, Urdu\n");
	sys.stdout.write("\ttis620 Thai\n")
	sys.stdout.write("\ttscii Tamil\n")
	sys.stdout.write("\tviscii Vietnamese\n")


def Usage(): 
	sys.stdout.write("Describe each byte of input.\n");
	sys.stdout.write("Provides byte offset, hex, octal, binary, decimal and\
	name in chosen encoding.\n"); 
	sys.stdout.write("Reads from stdin or file. Writes on stdout.\n");
	sys.stdout.write("Usage: ByteName (options)\n");
	sys.stdout.write("-c\t\twrite out a chart for the chosen encoding.\n")
	sys.stdout.write("-e <encoding>\n");
	sys.stdout.write("-w <codepoint>\tprint description of codepoint in all known encodings\n")
	sys.stdout.write("-i <input file>\n");
	sys.stdout.write("-s <StartOffset> (byte starting at zero)\n\n");
	sys.stdout.write("-a\t\tsuppress output for bytes in the ASCII range.\n")
	sys.stdout.write("-n\t\tsuppress output of a header at the top of each screenful.\n")
	sys.stdout.write("-D\t\tsuppress description of character.\n")
	sys.stdout.write("-O\t\tsuppress byte offset.\n")
	sys.stdout.write("-b\t\tsuppress binary value of code.\n")
	sys.stdout.write("-o\t\tsuppress octal value of code.\n")
	sys.stdout.write("-d\t\tsuppress decimal value of code.\n")
	sys.stdout.write("-x\t\tsuppress hexadecimal value of code.\n\n")
	sys.stdout.write("-h\t\tprints this help message.\n") ;
	sys.stdout.write("-l\t\tlists the available encodings\n") ;
	sys.stdout.write("-t\t\tdescribes the Tamil transcription\n") 
	sys.stdout.write("-v\t\tprints the program version.\n")
	sys.stdout.write("If no encoding is specified, the default is Latin-1.\n")
	sys.exit(2)
	
TableMap={\
	"adobeps": adobepsxtbl,
	"armscii7" : armscii7xtbl,
	"armscii8" : armscii8xtbl,
	"armscii8a": armscii8axtbl,
	"atarist": ataristxtbl,
	"brmp": brmpxtbl,
	"buckwalter": buckwalterxtbl,
	"csx": csxxtbl,
	"ebcdic037" : ebcdic037xtbl,
	"ebcdic500" : ebcdic500xtbl,
	"egaf": egafxtbl,
	"gsm0388": gsm0388xtbl,
	"guarani": guaranixtbl,
	"iscii": isciixtbl,
	"isiri2900":isiri2900xtbl,
	"isiri3342":isiri3342xtbl,
	"iso8859-1":iso8859_1xtbl,
	"iso8859-2":iso8859_2xtbl,
	"iso8859-3":iso8859_3xtbl,
	"iso8859-4":iso8859_4xtbl,
	"iso8859-5":iso8859_5xtbl,
	"iso8859-6":iso8859_6xtbl,
	"iso8859-7":iso8859_7xtbl,
	"iso8859-8":iso8859_8xtbl,
	"iso8859-9":iso8859_9xtbl,
	"iso8859-10":iso8859_10xtbl,
	"iso8859-11":iso8859_11xtbl,
	"iso8859-13":iso8859_13xtbl,
	"iso8859-14":iso8859_14xtbl,
	"iso8859-15":iso8859_15xtbl,
	"iso8859-16":iso8859_16xtbl,
	"koi8a":koi8axtbl,
	"koi8b":koi8bxtbl,
	"koi8r":koi8rxtbl,
	"koi8u":koi8uxtbl,
	"maccyrillic":maccyrillicxtbl,
	"macgreek":macgreekxtbl,
	"macicelandic":macicelandicxtbl,
	"macinuit":macinuitxtbl,
	"macLatin2":macLatin2xtbl,
	"macroman":macromanxtbl,
	"macthai":macthaixtbl,
	"macturkish":macturkishxtbl,
	"mik":mikxtbl,
	"msd437":msd437xtbl,
	"msd850":msd850xtbl,
	"msd860":msd860xtbl,
	"msd861":msd861xtbl,
	"msd862":msd862xtbl,
	"msd863":msd863xtbl,
	"msd864":msd864xtbl,
	"msd865":msd865xtbl,
	"msd866":msd866xtbl,
	"msd869":msd869xtbl,
	"msw874":msw874xtbl,
	"msw875":msw875xtbl,
	"msw1250":msw1250xtbl,
	"msw1251":msw1251xtbl,
	"msw1252":msw1252xtbl,
	"msw1253":msw1253xtbl,
	"msw1254":msw1254xtbl,
	"msw1255":msw1255xtbl,
	"msw1256":msw1256xtbl,
	"msw1257":msw1257xtbl,
	"msw1258":msw1258xtbl,
	"nextstep":nextstepxtbl,
	"pascii":pasciixtbl,
	"tis620":tis620xtbl,
	"tscii":tsciixtbl,
	"viscii":visciixtbl
}

KeyList = TableMap.keys()
KeyList.sort()

def ShowInAllEncodings(x):
	for e in KeyList:
		sys.stdout.write( ("%-15s\t%-20s\n") % (e, (TableMap[e])[x]))


xtbl = iso8859_1xtbl
ISCIIP = 0

DoOffsetP      = 1
DoHexP         = 1
DoOctalP       = 1
DoBinaryP      = 1
DoDecimalP     = 1
DoDescriptionP = 1
DumpChartP     = 0

StartByte      = 0
ChunkSize      = 1024
input = sys.stdin
Encoding = "Latin1"

#Handle command line arguments
try:
    opts, args = getopt.getopt(sys.argv[1:], "abcDde:hi:lnOos:tvw:x")
except getopt.GetoptError:
	sys.stderr.write("Invalid command line option.\n")
        Usage()
        sys.exit(2)

if len(opts):
	for o, a in opts:
		if o == "-h":
			Usage()
			sys.exit(2)
		elif o == '-i':
			input = open(a,'rb')
		elif o == "-a":
			ShowAsciiP=0
		elif o == "-l":
			ListEncodings()
			sys.exit(2)
		elif o == "-t":
			DescribeTamilTranscription()
			sys.exit(2)
		elif o == "-x":
			DoHexP = 0
		elif o == "-o":
			DoOctalP = 0
		elif o == "-b":
			DoBinaryP = 0
		elif o ==  "-c":
			DumpChartP = 1
			DoOffsetP  = 0
		elif o == "-d":
			DoDecimalP = 0
		elif o == "-D":
			DoDescriptionP = 0
		elif o == "-O":
			DoOffsetP = 0
		elif o == '-w':
			ShowInAllEncodings(int(a,0));
			sys.exit(0);
		elif o == "-s":
			try: StartByte = int(a)
			except:
				sys.stderr.write("%s is not an integer\n" % a)
				sys.exit(3)
			if StartByte < 0:
				sys.stderr.write("%d is not a reasonable byte offset\n" % StartByte)
				sys.exit(3)
		elif o == "-e":
			if a == "iso8859-1":
				xtbl = iso8859_1xtbl
				Encoding = "iso8859-1"
			elif a == "iso8859-2":
				xtbl = iso8859_2xtbl
				Encoding = "iso8859-2"
			elif a =="iso8859-3":
				xtbl = iso8859_3xtbl
				Encoding = "iso8859-3"
			elif a =="iso8859-4":
				xtbl = iso8859_4xtbl
				Encoding = "iso8859-4"
			elif a =="iso8859-5":
				xtbl = iso8859_5xtbl
				Encoding = "iso8859-5"
			elif a =="iso8859-6":
				xtbl = iso8859_6xtbl
				Encoding = "iso8859-6"
			elif a =="iso8859-7":
				xtbl = iso8859_7xtbl
				Encoding = "iso8859-7"
			elif a =="iso8859-8":
				xtbl = iso8859_8xtbl
				Encoding = "iso8859-8"
			elif a =="iso8859-9":
				xtbl = iso8859_9xtbl
				Encoding = "iso8859-9"
			elif a =="iso8859-10":
				xtbl = iso8859_10xtbl
				Encoding = "iso8859-10"
			elif a =="iso8859-11":
				xtbl = iso8859_11xtbl
				Encoding = "iso8859-11"
			elif a =="iso8859-12":
				sys.stderr.write("the iso8859-12 encoding was abandoned.\n\
				It does not exist.\n")
				sys.exit(2)
			elif a =="iso8859-13":
				xtbl = iso8859_13xtbl
				Encoding = "iso8859-13"
			elif a =="iso8859-14":
				xtbl = iso8859_14xtbl
				Encoding = "iso8859-14"
			elif a =="iso8859-15":
				xtbl = iso8859_15xtbl
				Encoding = "iso8859-15"
			elif a =="iso8859-16":
				xtbl = iso8859_16xtbl
				Encoding = "iso8859-16"
			elif a =="msd437":
				xtbl = msd437xtbl
				Encoding = "Microsoft DOS CP437 (DOS-US)"
			elif a =="msd850":
				xtbl = msd850xtbl
				Encoding = "Microsoft DOS CP850 (Multilingual Latin 1)"
			elif a =="msd860":
				xtbl = msd860xtbl
				Encoding = "Microsoft DOS CP860 (Portuguese)"
			elif a =="msd861":
				xtbl = msd861xtbl
				Encoding = "Microsoft DOS CP861 (Icelandic/Nordic)"
			elif a =="msd862":
				xtbl = msd862xtbl
				Encoding = "Microsoft DOS CP862 (Hebrew)"
			elif a =="msd863":
				xtbl = msd863xtbl
				Encoding = "Microsoft DOS CP863 (Canadian French)"
			elif a =="msd864":
				xtbl = msd864xtbl
				Encoding = "Microsoft DOS CP864 (Arabic)"
			elif a =="msd865":
				xtbl = msd865xtbl
				Encoding = "Microsoft DOS CP865 (Nordic)"
			elif a =="msd866":
				xtbl = msd866xtbl
				Encoding = "Microsoft DOS CP866 (Cyrillic)"
			elif a =="msd869":
				xtbl = msd869xtbl
				Encoding = "Microsoft DOS CP869 (Modern Greek)"
			elif a =="msw874":    
				xtbl = msw874xtbl
				Encoding = "Microsoft Windows CP874 (Thai)"
			elif a =="msw875":
				xtbl = msw875xtbl
				Encoding = "Microsoft Windows CP875 (IBM Greek)"
			elif a =="msw1250":
				xtbl = msw1250xtbl
				Encoding = "Microsoft Windows CP1250 (WinLatin2)"
			elif a =="msw1251":	    
				xtbl = msw1251xtbl
				Encoding = "Microsoft Windows CP1251"
			elif a =="msw1252":	    
				xtbl = msw1252xtbl
				Encoding = "Microsoft Windows CP1252 (WinLatin1)"
			elif a =="msw1253":	    
				xtbl = msw1253xtbl
				Encoding = "Microsoft Windows CP1253 (Greek)"
			elif a =="msw1254":	    
				xtbl = msw1254xtbl
				Encoding = "Microsoft Windows CP1254 (Turkish)"
			elif a =="msw1256":	    
				xtbl = msw1256xtbl
				Encoding = "Microsoft Windows CP1256 (Arabic)"
			elif a =="msw1257":	    
				xtbl = msw1257xtbl
				Encoding = "Microsoft Windows CP1257 (Estonian, Latvian, Lithuanian)"
			elif a =="msw1258":    
				xtbl = msw1258xtbl
				Encoding = "Microsoft Windows CP1258 (Vietnamese)"
			elif a =="armscii7":
				xtbl = armscii7xtbl
				Encoding = "ARMSCII7"
			elif a =="armscii8":
				xtbl = armscii8xtbl
				Encoding = "ARMSCII8"
			elif a =="armscii8a":
				xtbl = armscii8axtbl
				Encoding = "ARMSCII8A"
			elif a =="koi8-a":
				xtbl = koi8axtbl
				Encoding = "koi8a"
			elif a =="koi8-b":
				xtbl = koi8bxtbl
				Encoding = "koi8b"
			elif a =="koi8-r":
				xtbl = koi8rxtbl
				Encoding = "koi8r"
			elif a =="koi8-u":
				xtbl = koi8uxtbl
				Encoding = "koi8u"
			elif a =="maccyrillic":
				xtbl = maccyrillicxtbl
				Encoding = "Mac Cyrillic (CP10007)"
			elif a =="macgreek":
				xtbl = macgreekxtbl
				Encoding = "Mac Greek (CP10006)"
			elif a =="macicelandic":
				xtbl = macicelandicxtbl
				Encoding = "Mac Icelandic (CP10079)"
			elif a =="macinuit":
				xtbl = macinuitxtbl
				Encoding = "Mac Inuit"
			elif a =="macLatin2":
				xtbl = maclatin2xtbl
				Encoding = "Mac Central Europe (CP10029)"
			elif a =="macroman":
				xtbl = macromanxtbl
				Encoding = "Mac Roman (CP10000)"
			elif a =="macthai":
				xtbl = macthaixtbl
				Encoding = "Mac Thai"
			elif a =="macturkish":
				xtbl = macturkishxtbl
				Encoding = "Mac Turkish"
			elif a =="nextstep":
				xtbl = nextstepxtbl
				Encoding = "nextstep"
			elif a =="ebcdic037":    
				xtbl = ebcdic037xtbl
				Encoding = "EBCDIC037"
			elif a =="adobeps":
				xtbl = adobepsxtbl
				Encoding = "Adobe"
			elif a =="atarist":
				xtbl = ataristxtbl
				Encoding = "AtariST"
			elif a =="tis620":    
				xtbl = tis620xtbl
				Encoding = "TIS-620"
			elif a =="tscii":    
				xtbl = tsciixtbl
				Encoding = "TSCII"
			elif a =="iscii":    
				xtbl = isciixtbl
				Encoding = "ISCII"
				ISCIIP = 1
			elif a =="viscii":    
				xtbl = visciixtbl
				Encoding = "VISCII"
			elif a =="isiri2900":
				xtbl = isiri2900xtbl
				Encoding = "isiri2900"
			elif a =="isiri3342":
				xtbl = isiri3342xtbl
				Encoding = "isiri3342"
			elif a =="gsm0388":
				xtbl = gsm0388xtbl
				Encoding = "gsm0388"
			elif a =="guarani":
				xtbl = guaranixtbl
				Encoding = "guarani"
			elif a == "mik":
				xtbl = mikxtbl
				Encoding = "mik"
			elif a == "brmp":
				xtbl = brmpxtbl
				Encoding = "brmp"
			elif a == "csx":
				xtbl = csxxtbl
				Encoding = "csx"
			elif a == "buckwalter":
				xtbl = buckwalterxtbl
				Encoding = "buckwalter"
			elif a == "pascii":
				xtbl = pasciixtbl
				Encoding = "PASCII"
				ISCIIP = 1
			else:
				sys.stderr.write("Unrecognized encoding %s\n" % a)
				sys.exit(2)
		elif o == "-n":
			PutHeaderP=0    
		elif o == "-v":
			Version()
			sys.exit(2)
			
	    
if PutHeaderP:
	hstr = os.environ.get('LINES')
	if hstr != None:
		ScreenHeight = int(hstr)
	else:
		ScreenHeight = 0
	HeaderList = []
	if DoOffsetP:
		HeaderList.append("%-8s" % "Offset")
	if DoHexP:
		HeaderList.append("%-6s" % "Hex")
	if DoOctalP:
		HeaderList.append("%-7s" % "Octal")
	if DoBinaryP:
		HeaderList.append("%-10s" % "Binary")
	if DoDecimalP:
		HeaderList.append("%-9s" % "Decimal")
	if DoDescriptionP:
		HeaderList.append("Description (%s)" % Encoding)
	HeaderList.append("\n")
	Header = "".join(HeaderList)

if DumpChartP:
	sys.stdout.write(Header)
	DumpChart(xtbl)
	sys.exit(0)
	
CharCnt = 0
#Move to requested starting point
#Attempt to seek. This will fail if input is a pipe, in which case we
#read input and throw it away
try: input.seek(StartByte)
except IOError:
	(Chunks,Residue) = divmod(StartByte,ChunkSize)
	for i in range(Chunks):
		input.read(ChunkSize)
	input.read(Residue)	

#Read one byte at a time and describe it
PreviousCharATR = 0
while 1:
	try:
		ch = input.read(1)
		if not ch:
			sys.exit(0)
		c = ord(ch)
		CharCnt = CharCnt + 1
		if ShowAsciiP == 1 or c >= 0x7F:
			if PutHeaderP:
				LineCnt = LineCnt + 1
				if ScreenHeight > 1:
					if divmod(LineCnt,(ScreenHeight - 2))[1] == 1:
						sys.stdout.write(Header)
			OStringList = []
			if DoOffsetP:
				OStringList.append("%6d  " % CharCnt)
			if DoHexP:
				OStringList.append(("0x%02X  ") % (c))
			if DoOctalP:	
				OStringList.append(("%03o    ") % (c))
			if DoBinaryP:
				OStringList.append(("%8s  ") % (binfmt(c)))
			if DoDecimalP:
				OStringList.append(("%3d      ") % (c))
			if ISCIIP:
				if PreviousCharATR:
					PreviousCharATR = 0
					if DoDescriptionP:
						if c in IsciiWritingSystems:
							OStringList.append(("%s") %\
									   (IsciiWritingSystems[c]))
						elif c in IsciiDisplayModes:
							OStringList.append(("%s") %\
									   (IsciiDisplayModes[c]))
						else:
							OStringList.append("Unrecognized ATR argument")

				else:
					if c == 0xEF:
						PreviousCharATR = 1
					else:
						PreviousCharATR = 0

					if DoDescriptionP:
						OStringList.append(("%s") % (xtbl[c]))
			else:
				if DoDescriptionP:
					OStringList.append("%s" % xtbl[c])
			OStringList.append("\n")	
			sys.stdout.write("".join(OStringList))
	except IOError:
		sys.exit(0)
	except SystemExit:
		sys.exit(0)
